/* @copyright Itential, LLC 2019 (pre-modifications) */

// Set globals
/* global describe it log pronghornProps */
/* eslint no-unused-vars: warn */

// include required items for testing & logging
const assert = require('assert');
const fs = require('fs');
const mocha = require('mocha');
const path = require('path');
const winston = require('winston');
const { expect } = require('chai');
const { use } = require('chai');
const td = require('testdouble');

const anything = td.matchers.anything();

// stub and attemptTimeout are used throughout the code so set them here
let logLevel = 'none';
const stub = true;
const isRapidFail = false;
const isSaveMockData = false;
const attemptTimeout = 5000;

// these variables can be changed to run in integrated mode so easier to set them here
// always check these in with bogus data!!!
const host = 'replace.hostorip.here';
const username = 'username';
const password = 'password';
const protocol = 'http';
const port = 80;
const sslenable = false;
const sslinvalid = false;

// these are the adapter properties. You generally should not need to alter
// any of these after they are initially set up
global.pronghornProps = {
  pathProps: {
    encrypted: false
  },
  adapterProps: {
    adapters: [{
      id: 'Test-awsec2',
      type: 'Awsec2',
      properties: {
        host,
        port,
        base_path: '/',
        version: '',
        cache_location: 'none',
        protocol,
        stub,
        authentication: {
          auth_method: 'no_authentication',
          username,
          password,
          token: '',
          token_timeout: -1,
          token_cache: 'local',
          invalid_token_error: 401,
          auth_field: 'header.headers.Authorization',
          auth_field_format: 'Basic {b64}{username}:{password}{/b64}'
        },
        healthcheck: {
          type: 'none',
          frequency: 60000
        },
        throttle: {
          throttle_enabled: false,
          number_pronghorns: 1,
          sync_async: 'sync',
          max_in_queue: 1000,
          concurrent_max: 1,
          expire_timeout: 0,
          avg_runtime: 200
        },
        request: {
          number_retries: 3,
          limit_retry_error: 0,
          failover_codes: [],
          attempt_timeout: attemptTimeout,
          healthcheck_on_timeout: true,
          archiving: false
        },
        proxy: {
          enabled: false,
          host: '',
          port: 1,
          protocol: 'http'
        },
        ssl: {
          ecdhCurve: '',
          enabled: sslenable,
          accept_invalid_cert: sslinvalid,
          ca_file: '',
          secure_protocol: '',
          ciphers: ''
        }
      }
    }]
  }
};

global.$HOME = `${__dirname}/../..`;

// set the log levels that Pronghorn uses, spam and trace are not defaulted in so without
// this you may error on log.trace calls.
const myCustomLevels = {
  levels: {
    spam: 6,
    trace: 5,
    debug: 4,
    info: 3,
    warn: 2,
    error: 1,
    none: 0
  }
};

// need to see if there is a log level passed in
process.argv.forEach((val) => {
  // is there a log level defined to be passed in?
  if (val.indexOf('--LOG') === 0) {
    // get the desired log level
    const inputVal = val.split('=')[1];

    // validate the log level is supported, if so set it
    if (Object.hasOwnProperty.call(myCustomLevels.levels, inputVal)) {
      logLevel = inputVal;
    }
  }
});

// need to set global logging
global.log = new (winston.Logger)({
  level: logLevel,
  levels: myCustomLevels.levels,
  transports: [
    new winston.transports.Console()
  ]
});

/**
 * Runs the common asserts for test
 */
function runCommonAsserts(data, error) {
  assert.equal(undefined, error);
  assert.notEqual(undefined, data);
  assert.notEqual(null, data);
  assert.notEqual(undefined, data.response);
  assert.notEqual(null, data.response);
}

/**
 * Runs the error asserts for the test
 */
function runErrorAsserts(data, error, code, origin, displayStr) {
  assert.equal(null, data);
  assert.notEqual(undefined, error);
  assert.notEqual(null, error);
  assert.notEqual(undefined, error.IAPerror);
  assert.notEqual(null, error.IAPerror);
  assert.notEqual(undefined, error.IAPerror.displayString);
  assert.notEqual(null, error.IAPerror.displayString);
  assert.equal(code, error.icode);
  assert.equal(origin, error.IAPerror.origin);
  assert.equal(displayStr, error.IAPerror.displayString);
}

/**
 * @function saveMockData
 * Attempts to take data from responses and place them in MockDataFiles to help create Mockdata.
 * Note, this was built based on entity file structure for Adapter-Engine 1.6.x
 * @param {string} entityName - Name of the entity saving mock data for
 * @param {string} actionName -  Name of the action saving mock data for
 * @param {string} descriptor -  Something to describe this test (used as a type)
 * @param {string or object} responseData - The data to put in the mock file.
 */
function saveMockData(entityName, actionName, descriptor, responseData) {
  // do not need to save mockdata if we are running in stub mode (already has mock data) or if told not to save
  if (stub || !isSaveMockData) {
    return false;
  }

  // must have a response in order to store the response
  if (responseData && responseData.response) {
    const data = responseData.response;

    try {
      const base = `./entities/${entityName}/`;
      const filename = `mockdatafiles/${actionName}-${descriptor}.json`;

      // write the data we retrieved
      fs.writeFile(base + filename, JSON.stringify(data, null, 2), 'utf8', (errWritingMock) => {
        if (errWritingMock) throw errWritingMock;

        // update the action file to reflect the changes. Note: We're replacing the default object for now!
        fs.readFile(`${base}action.json`, (errRead, content) => {
          if (errRead) throw errRead;

          // parse the action file into JSON
          const parsedJson = JSON.parse(content);

          // The object update we'll write in.
          const responseObj = {
            type: descriptor,
            key: '',
            mockFile: filename
          };

          // get the object for method we're trying to change.
          const currentMethodAction = parsedJson.actions.find(obj => obj.name === actionName);

          // if the method was not found - should never happen but...
          if (!currentMethodAction) {
            throw Error('Can\'t find an action for this method in the provided entity.');
          }

          // if there is a response object, we want to replace the Response object. Otherwise we'll create one.
          const actionResponseObj = currentMethodAction.responseObjects.find(obj => obj.type === descriptor);

          // Add the action responseObj back into the array of response objects.
          if (!actionResponseObj) {
            // if there is a default response object, we want to get the key.
            const defaultResponseObj = currentMethodAction.responseObjects.find(obj => obj.type === 'default');

            // save the default key into the new response object
            if (!defaultResponseObj) {
              responseObj.key = defaultResponseObj.key;
            }

            // save the new response object
            currentMethodAction.responseObjects = [responseObj];
          } else {
            // update the location of the mock data file
            actionResponseObj.mockFile = responseObj.mockFile;
          }

          // Save results
          fs.writeFile(`${base}action.json`, JSON.stringify(parsedJson, null, 2), (err) => {
            if (err) throw err;
          });
        });
      });
    } catch (e) {
      log.debug(`Failed to save mock data for ${actionName}. ${e.message}`);
      return false;
    }
  }

  // no response to save
  log.debug(`No data passed to save into mockdata for ${actionName}`);
  return false;
}


// require the adapter that we are going to be using
const Awsec2 = require('../../adapter.js');

// begin the testing - these should be pretty well defined between the describe and the it!
describe('[integration] Awsec2 Adapter Test', () => {
  describe('Awsec2 Class Tests', () => {
    const a = new Awsec2(
      pronghornProps.adapterProps.adapters[0].id,
      pronghornProps.adapterProps.adapters[0].properties
    );

    if (isRapidFail) {
      const state = {};
      state.passed = true;

      mocha.afterEach(function x() {
        state.passed = state.passed
        && (this.currentTest.state === 'passed');
      });
      mocha.beforeEach(function x() {
        if (!state.passed) {
          return this.currentTest.skip();
        }
        return true;
      });
    }

    describe('#class instance created', () => {
      it('should be a class with properties', (done) => {
        try {
          assert.notEqual(null, a);
          assert.notEqual(undefined, a);
          assert.notEqual(null, a.allProps);
          const check = global.pronghornProps.adapterProps.adapters[0].properties.healthcheck.type;
          assert.equal(check, a.healthcheckType);
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#connect', () => {
      it('should get connected - no healthcheck', (done) => {
        try {
          a.healthcheckType = 'none';
          a.connect();

          try {
            assert.equal(true, a.alive);
            done();
          } catch (error) {
            log.error(`Test Failure: ${error}`);
            done(error);
          }
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      });
      it('should get connected - startup healthcheck', (done) => {
        try {
          a.healthcheckType = 'startup';
          a.connect();

          try {
            assert.equal(true, a.alive);
            done();
          } catch (error) {
            log.error(`Test Failure: ${error}`);
            done(error);
          }
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      });
    });

    describe('#healthCheck', () => {
      it('should be healthy', (done) => {
        try {
          a.healthCheck(null, (data) => {
            try {
              assert.equal(true, a.healthy);
              saveMockData('system', 'healthcheck', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    /*
    -----------------------------------------------------------------------
    -----------------------------------------------------------------------
    *** All code above this comment will be replaced during a migration ***
    ******************* DO NOT REMOVE THIS COMMENT BLOCK ******************
    -----------------------------------------------------------------------
    -----------------------------------------------------------------------
    */

    const actionAcceptReservedInstancesExchangeQuoteAction = 'fakedata';
    const actionAcceptReservedInstancesExchangeQuoteVersion = 'fakedata';
    const actionAcceptReservedInstancesExchangeQuoteBodyFormData = 'fakedata';
    describe('#postAcceptReservedInstancesExchangeQuote - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postAcceptReservedInstancesExchangeQuote(actionAcceptReservedInstancesExchangeQuoteAction, actionAcceptReservedInstancesExchangeQuoteVersion, actionAcceptReservedInstancesExchangeQuoteBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.ExchangeId);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionAcceptReservedInstancesExchangeQuote', 'postAcceptReservedInstancesExchangeQuote', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionAcceptReservedInstancesExchangeQuoteReservedInstanceId = [];
    describe('#getAcceptReservedInstancesExchangeQuote - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getAcceptReservedInstancesExchangeQuote(null, actionAcceptReservedInstancesExchangeQuoteReservedInstanceId, null, actionAcceptReservedInstancesExchangeQuoteAction, actionAcceptReservedInstancesExchangeQuoteVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.ExchangeId);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionAcceptReservedInstancesExchangeQuote', 'getAcceptReservedInstancesExchangeQuote', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionAcceptTransitGatewayVpcAttachmentAction = 'fakedata';
    const actionAcceptTransitGatewayVpcAttachmentVersion = 'fakedata';
    const actionAcceptTransitGatewayVpcAttachmentBodyFormData = 'fakedata';
    describe('#postAcceptTransitGatewayVpcAttachment - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postAcceptTransitGatewayVpcAttachment(actionAcceptTransitGatewayVpcAttachmentAction, actionAcceptTransitGatewayVpcAttachmentVersion, actionAcceptTransitGatewayVpcAttachmentBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.TransitGatewayVpcAttachment);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionAcceptTransitGatewayVpcAttachment', 'postAcceptTransitGatewayVpcAttachment', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionAcceptTransitGatewayVpcAttachmentTransitGatewayAttachmentId = 'fakedata';
    describe('#getAcceptTransitGatewayVpcAttachment - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getAcceptTransitGatewayVpcAttachment(actionAcceptTransitGatewayVpcAttachmentTransitGatewayAttachmentId, null, actionAcceptTransitGatewayVpcAttachmentAction, actionAcceptTransitGatewayVpcAttachmentVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.TransitGatewayVpcAttachment);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionAcceptTransitGatewayVpcAttachment', 'getAcceptTransitGatewayVpcAttachment', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionAcceptVpcEndpointConnectionsAction = 'fakedata';
    const actionAcceptVpcEndpointConnectionsVersion = 'fakedata';
    const actionAcceptVpcEndpointConnectionsBodyFormData = 'fakedata';
    describe('#postAcceptVpcEndpointConnections - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postAcceptVpcEndpointConnections(actionAcceptVpcEndpointConnectionsAction, actionAcceptVpcEndpointConnectionsVersion, actionAcceptVpcEndpointConnectionsBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.Unsuccessful));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionAcceptVpcEndpointConnections', 'postAcceptVpcEndpointConnections', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionAcceptVpcEndpointConnectionsServiceId = 'fakedata';
    const actionAcceptVpcEndpointConnectionsVpcEndpointId = [];
    describe('#getAcceptVpcEndpointConnections - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getAcceptVpcEndpointConnections(null, actionAcceptVpcEndpointConnectionsServiceId, actionAcceptVpcEndpointConnectionsVpcEndpointId, actionAcceptVpcEndpointConnectionsAction, actionAcceptVpcEndpointConnectionsVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.Unsuccessful));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionAcceptVpcEndpointConnections', 'getAcceptVpcEndpointConnections', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionAcceptVpcPeeringConnectionAction = 'fakedata';
    const actionAcceptVpcPeeringConnectionVersion = 'fakedata';
    describe('#postAcceptVpcPeeringConnection - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postAcceptVpcPeeringConnection(actionAcceptVpcPeeringConnectionAction, actionAcceptVpcPeeringConnectionVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.VpcPeeringConnection);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionAcceptVpcPeeringConnection', 'postAcceptVpcPeeringConnection', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getAcceptVpcPeeringConnection - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getAcceptVpcPeeringConnection(null, null, actionAcceptVpcPeeringConnectionAction, actionAcceptVpcPeeringConnectionVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.VpcPeeringConnection);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionAcceptVpcPeeringConnection', 'getAcceptVpcPeeringConnection', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionAdvertiseByoipCidrAction = 'fakedata';
    const actionAdvertiseByoipCidrVersion = 'fakedata';
    const actionAdvertiseByoipCidrBodyFormData = 'fakedata';
    describe('#postAdvertiseByoipCidr - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postAdvertiseByoipCidr(actionAdvertiseByoipCidrAction, actionAdvertiseByoipCidrVersion, actionAdvertiseByoipCidrBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.ByoipCidr);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionAdvertiseByoipCidr', 'postAdvertiseByoipCidr', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionAdvertiseByoipCidrCidr = 'fakedata';
    describe('#getAdvertiseByoipCidr - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getAdvertiseByoipCidr(actionAdvertiseByoipCidrCidr, null, actionAdvertiseByoipCidrAction, actionAdvertiseByoipCidrVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.ByoipCidr);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionAdvertiseByoipCidr', 'getAdvertiseByoipCidr', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionAllocateAddressAction = 'fakedata';
    const actionAllocateAddressVersion = 'fakedata';
    describe('#postAllocateAddress - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postAllocateAddress(actionAllocateAddressAction, actionAllocateAddressVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.PublicIp);
              assert.equal('string', data.response.AllocationId);
              assert.equal('string', data.response.publicIpv4Pool);
              assert.equal('vpc', data.response.domain);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionAllocateAddress', 'postAllocateAddress', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getAllocateAddress - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getAllocateAddress(null, null, null, null, actionAllocateAddressAction, actionAllocateAddressVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.PublicIp);
              assert.equal('string', data.response.AllocationId);
              assert.equal('string', data.response.publicIpv4Pool);
              assert.equal('vpc', data.response.domain);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionAllocateAddress', 'getAllocateAddress', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionAllocateHostsAction = 'fakedata';
    const actionAllocateHostsVersion = 'fakedata';
    const actionAllocateHostsBodyFormData = 'fakedata';
    describe('#postAllocateHosts - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postAllocateHosts(actionAllocateHostsAction, actionAllocateHostsVersion, actionAllocateHostsBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.HostIds));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionAllocateHosts', 'postAllocateHosts', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionAllocateHostsAvailabilityZone = 'fakedata';
    const actionAllocateHostsInstanceType = 'fakedata';
    const actionAllocateHostsQuantity = 555;
    describe('#getAllocateHosts - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getAllocateHosts(null, actionAllocateHostsAvailabilityZone, null, actionAllocateHostsInstanceType, actionAllocateHostsQuantity, null, actionAllocateHostsAction, actionAllocateHostsVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.HostIds));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionAllocateHosts', 'getAllocateHosts', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionApplySecurityGroupsToClientVpnTargetNetworkAction = 'fakedata';
    const actionApplySecurityGroupsToClientVpnTargetNetworkVersion = 'fakedata';
    const actionApplySecurityGroupsToClientVpnTargetNetworkBodyFormData = 'fakedata';
    describe('#postApplySecurityGroupsToClientVpnTargetNetwork - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postApplySecurityGroupsToClientVpnTargetNetwork(actionApplySecurityGroupsToClientVpnTargetNetworkAction, actionApplySecurityGroupsToClientVpnTargetNetworkVersion, actionApplySecurityGroupsToClientVpnTargetNetworkBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.SecurityGroupIds));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionApplySecurityGroupsToClientVpnTargetNetwork', 'postApplySecurityGroupsToClientVpnTargetNetwork', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionApplySecurityGroupsToClientVpnTargetNetworkClientVpnEndpointId = 'fakedata';
    const actionApplySecurityGroupsToClientVpnTargetNetworkVpcId = 'fakedata';
    const actionApplySecurityGroupsToClientVpnTargetNetworkSecurityGroupId = [];
    describe('#getApplySecurityGroupsToClientVpnTargetNetwork - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getApplySecurityGroupsToClientVpnTargetNetwork(actionApplySecurityGroupsToClientVpnTargetNetworkClientVpnEndpointId, actionApplySecurityGroupsToClientVpnTargetNetworkVpcId, actionApplySecurityGroupsToClientVpnTargetNetworkSecurityGroupId, null, actionApplySecurityGroupsToClientVpnTargetNetworkAction, actionApplySecurityGroupsToClientVpnTargetNetworkVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.SecurityGroupIds));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionApplySecurityGroupsToClientVpnTargetNetwork', 'getApplySecurityGroupsToClientVpnTargetNetwork', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    let actionAssignIpv6AddressesNetworkInterfaceId = 'fakedata';
    const actionAssignIpv6AddressesAction = 'fakedata';
    const actionAssignIpv6AddressesVersion = 'fakedata';
    const actionAssignIpv6AddressesBodyFormData = 'fakedata';
    describe('#postAssignIpv6Addresses - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postAssignIpv6Addresses(actionAssignIpv6AddressesAction, actionAssignIpv6AddressesVersion, actionAssignIpv6AddressesBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.AssignedIpv6Addresses));
              assert.equal('string', data.response.networkInterfaceId);
            } else {
              runCommonAsserts(data, error);
            }
            actionAssignIpv6AddressesNetworkInterfaceId = data.response.networkInterfaceId;
            saveMockData('ActionAssignIpv6Addresses', 'postAssignIpv6Addresses', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getAssignIpv6Addresses - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getAssignIpv6Addresses(null, null, actionAssignIpv6AddressesNetworkInterfaceId, actionAssignIpv6AddressesAction, actionAssignIpv6AddressesVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.AssignedIpv6Addresses));
              assert.equal('string', data.response.networkInterfaceId);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionAssignIpv6Addresses', 'getAssignIpv6Addresses', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionAssignPrivateIpAddressesAction = 'fakedata';
    const actionAssignPrivateIpAddressesVersion = 'fakedata';
    const actionAssignPrivateIpAddressesBodyFormData = 'fakedata';
    describe('#postAssignPrivateIpAddresses - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postAssignPrivateIpAddresses(actionAssignPrivateIpAddressesAction, actionAssignPrivateIpAddressesVersion, actionAssignPrivateIpAddressesBodyFormData, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionAssignPrivateIpAddresses', 'postAssignPrivateIpAddresses', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionAssignPrivateIpAddressesNetworkInterfaceId = 'fakedata';
    describe('#getAssignPrivateIpAddresses - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getAssignPrivateIpAddresses(null, actionAssignPrivateIpAddressesNetworkInterfaceId, null, null, actionAssignPrivateIpAddressesAction, actionAssignPrivateIpAddressesVersion, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionAssignPrivateIpAddresses', 'getAssignPrivateIpAddresses', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionAssociateAddressAction = 'fakedata';
    const actionAssociateAddressVersion = 'fakedata';
    describe('#postAssociateAddress - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postAssociateAddress(actionAssociateAddressAction, actionAssociateAddressVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.AssociationId);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionAssociateAddress', 'postAssociateAddress', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getAssociateAddress - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getAssociateAddress(null, null, null, null, null, null, null, actionAssociateAddressAction, actionAssociateAddressVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.AssociationId);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionAssociateAddress', 'getAssociateAddress', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionAssociateClientVpnTargetNetworkAction = 'fakedata';
    const actionAssociateClientVpnTargetNetworkVersion = 'fakedata';
    const actionAssociateClientVpnTargetNetworkBodyFormData = 'fakedata';
    describe('#postAssociateClientVpnTargetNetwork - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postAssociateClientVpnTargetNetwork(actionAssociateClientVpnTargetNetworkAction, actionAssociateClientVpnTargetNetworkVersion, actionAssociateClientVpnTargetNetworkBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.AssociationId);
              assert.equal('object', typeof data.response.Status);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionAssociateClientVpnTargetNetwork', 'postAssociateClientVpnTargetNetwork', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionAssociateClientVpnTargetNetworkClientVpnEndpointId = 'fakedata';
    const actionAssociateClientVpnTargetNetworkSubnetId = 'fakedata';
    describe('#getAssociateClientVpnTargetNetwork - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getAssociateClientVpnTargetNetwork(actionAssociateClientVpnTargetNetworkClientVpnEndpointId, actionAssociateClientVpnTargetNetworkSubnetId, null, actionAssociateClientVpnTargetNetworkAction, actionAssociateClientVpnTargetNetworkVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.AssociationId);
              assert.equal('object', typeof data.response.Status);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionAssociateClientVpnTargetNetwork', 'getAssociateClientVpnTargetNetwork', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionAssociateDhcpOptionsAction = 'fakedata';
    const actionAssociateDhcpOptionsVersion = 'fakedata';
    const actionAssociateDhcpOptionsBodyFormData = 'fakedata';
    describe('#postAssociateDhcpOptions - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postAssociateDhcpOptions(actionAssociateDhcpOptionsAction, actionAssociateDhcpOptionsVersion, actionAssociateDhcpOptionsBodyFormData, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionAssociateDhcpOptions', 'postAssociateDhcpOptions', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionAssociateDhcpOptionsDhcpOptionsId = 'fakedata';
    const actionAssociateDhcpOptionsVpcId = 'fakedata';
    describe('#getAssociateDhcpOptions - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getAssociateDhcpOptions(actionAssociateDhcpOptionsDhcpOptionsId, actionAssociateDhcpOptionsVpcId, null, actionAssociateDhcpOptionsAction, actionAssociateDhcpOptionsVersion, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionAssociateDhcpOptions', 'getAssociateDhcpOptions', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionAssociateIamInstanceProfileAction = 'fakedata';
    const actionAssociateIamInstanceProfileVersion = 'fakedata';
    const actionAssociateIamInstanceProfileBodyFormData = 'fakedata';
    describe('#postAssociateIamInstanceProfile - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postAssociateIamInstanceProfile(actionAssociateIamInstanceProfileAction, actionAssociateIamInstanceProfileVersion, actionAssociateIamInstanceProfileBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.IamInstanceProfileAssociation);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionAssociateIamInstanceProfile', 'postAssociateIamInstanceProfile', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionAssociateIamInstanceProfileInstanceId = 'fakedata';
    describe('#getAssociateIamInstanceProfile - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getAssociateIamInstanceProfile(null, null, actionAssociateIamInstanceProfileInstanceId, actionAssociateIamInstanceProfileAction, actionAssociateIamInstanceProfileVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.IamInstanceProfileAssociation);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionAssociateIamInstanceProfile', 'getAssociateIamInstanceProfile', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionAssociateRouteTableAction = 'fakedata';
    const actionAssociateRouteTableVersion = 'fakedata';
    const actionAssociateRouteTableBodyFormData = 'fakedata';
    describe('#postAssociateRouteTable - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postAssociateRouteTable(actionAssociateRouteTableAction, actionAssociateRouteTableVersion, actionAssociateRouteTableBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.AssociationId);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionAssociateRouteTable', 'postAssociateRouteTable', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionAssociateRouteTableRouteTableId = 'fakedata';
    const actionAssociateRouteTableSubnetId = 'fakedata';
    describe('#getAssociateRouteTable - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getAssociateRouteTable(null, actionAssociateRouteTableRouteTableId, actionAssociateRouteTableSubnetId, actionAssociateRouteTableAction, actionAssociateRouteTableVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.AssociationId);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionAssociateRouteTable', 'getAssociateRouteTable', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    let actionAssociateSubnetCidrBlockSubnetId = 'fakedata';
    const actionAssociateSubnetCidrBlockAction = 'fakedata';
    const actionAssociateSubnetCidrBlockVersion = 'fakedata';
    const actionAssociateSubnetCidrBlockBodyFormData = 'fakedata';
    describe('#postAssociateSubnetCidrBlock - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postAssociateSubnetCidrBlock(actionAssociateSubnetCidrBlockAction, actionAssociateSubnetCidrBlockVersion, actionAssociateSubnetCidrBlockBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.Ipv6CidrBlockAssociation);
              assert.equal('string', data.response.subnetId);
            } else {
              runCommonAsserts(data, error);
            }
            actionAssociateSubnetCidrBlockSubnetId = data.response.subnetId;
            saveMockData('ActionAssociateSubnetCidrBlock', 'postAssociateSubnetCidrBlock', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionAssociateSubnetCidrBlockIpv6CidrBlock = 'fakedata';
    describe('#getAssociateSubnetCidrBlock - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getAssociateSubnetCidrBlock(actionAssociateSubnetCidrBlockIpv6CidrBlock, actionAssociateSubnetCidrBlockSubnetId, actionAssociateSubnetCidrBlockAction, actionAssociateSubnetCidrBlockVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.Ipv6CidrBlockAssociation);
              assert.equal('string', data.response.subnetId);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionAssociateSubnetCidrBlock', 'getAssociateSubnetCidrBlock', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionAssociateTransitGatewayRouteTableAction = 'fakedata';
    const actionAssociateTransitGatewayRouteTableVersion = 'fakedata';
    const actionAssociateTransitGatewayRouteTableBodyFormData = 'fakedata';
    describe('#postAssociateTransitGatewayRouteTable - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postAssociateTransitGatewayRouteTable(actionAssociateTransitGatewayRouteTableAction, actionAssociateTransitGatewayRouteTableVersion, actionAssociateTransitGatewayRouteTableBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.Association);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionAssociateTransitGatewayRouteTable', 'postAssociateTransitGatewayRouteTable', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionAssociateTransitGatewayRouteTableTransitGatewayRouteTableId = 'fakedata';
    const actionAssociateTransitGatewayRouteTableTransitGatewayAttachmentId = 'fakedata';
    describe('#getAssociateTransitGatewayRouteTable - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getAssociateTransitGatewayRouteTable(actionAssociateTransitGatewayRouteTableTransitGatewayRouteTableId, actionAssociateTransitGatewayRouteTableTransitGatewayAttachmentId, null, actionAssociateTransitGatewayRouteTableAction, actionAssociateTransitGatewayRouteTableVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.Association);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionAssociateTransitGatewayRouteTable', 'getAssociateTransitGatewayRouteTable', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    let actionAssociateVpcCidrBlockVpcId = 'fakedata';
    const actionAssociateVpcCidrBlockAction = 'fakedata';
    const actionAssociateVpcCidrBlockVersion = 'fakedata';
    const actionAssociateVpcCidrBlockBodyFormData = 'fakedata';
    describe('#postAssociateVpcCidrBlock - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postAssociateVpcCidrBlock(actionAssociateVpcCidrBlockAction, actionAssociateVpcCidrBlockVersion, actionAssociateVpcCidrBlockBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.Ipv6CidrBlockAssociation);
              assert.equal('object', typeof data.response.CidrBlockAssociation);
              assert.equal('string', data.response.vpcId);
            } else {
              runCommonAsserts(data, error);
            }
            actionAssociateVpcCidrBlockVpcId = data.response.vpcId;
            saveMockData('ActionAssociateVpcCidrBlock', 'postAssociateVpcCidrBlock', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getAssociateVpcCidrBlock - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getAssociateVpcCidrBlock(null, null, actionAssociateVpcCidrBlockVpcId, actionAssociateVpcCidrBlockAction, actionAssociateVpcCidrBlockVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.Ipv6CidrBlockAssociation);
              assert.equal('object', typeof data.response.CidrBlockAssociation);
              assert.equal('string', data.response.vpcId);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionAssociateVpcCidrBlock', 'getAssociateVpcCidrBlock', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionAttachClassicLinkVpcAction = 'fakedata';
    const actionAttachClassicLinkVpcVersion = 'fakedata';
    const actionAttachClassicLinkVpcBodyFormData = 'fakedata';
    describe('#postAttachClassicLinkVpc - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postAttachClassicLinkVpc(actionAttachClassicLinkVpcAction, actionAttachClassicLinkVpcVersion, actionAttachClassicLinkVpcBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, data.response.Return);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionAttachClassicLinkVpc', 'postAttachClassicLinkVpc', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionAttachClassicLinkVpcSecurityGroupId = [];
    const actionAttachClassicLinkVpcInstanceId = 'fakedata';
    const actionAttachClassicLinkVpcVpcId = 'fakedata';
    describe('#getAttachClassicLinkVpc - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getAttachClassicLinkVpc(null, actionAttachClassicLinkVpcSecurityGroupId, actionAttachClassicLinkVpcInstanceId, actionAttachClassicLinkVpcVpcId, actionAttachClassicLinkVpcAction, actionAttachClassicLinkVpcVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(false, data.response.Return);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionAttachClassicLinkVpc', 'getAttachClassicLinkVpc', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionAttachInternetGatewayAction = 'fakedata';
    const actionAttachInternetGatewayVersion = 'fakedata';
    const actionAttachInternetGatewayBodyFormData = 'fakedata';
    describe('#postAttachInternetGateway - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postAttachInternetGateway(actionAttachInternetGatewayAction, actionAttachInternetGatewayVersion, actionAttachInternetGatewayBodyFormData, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionAttachInternetGateway', 'postAttachInternetGateway', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionAttachInternetGatewayInternetGatewayId = 'fakedata';
    const actionAttachInternetGatewayVpcId = 'fakedata';
    describe('#getAttachInternetGateway - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getAttachInternetGateway(null, actionAttachInternetGatewayInternetGatewayId, actionAttachInternetGatewayVpcId, actionAttachInternetGatewayAction, actionAttachInternetGatewayVersion, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionAttachInternetGateway', 'getAttachInternetGateway', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionAttachNetworkInterfaceAction = 'fakedata';
    const actionAttachNetworkInterfaceVersion = 'fakedata';
    const actionAttachNetworkInterfaceBodyFormData = 'fakedata';
    describe('#postAttachNetworkInterface - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postAttachNetworkInterface(actionAttachNetworkInterfaceAction, actionAttachNetworkInterfaceVersion, actionAttachNetworkInterfaceBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.AttachmentId);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionAttachNetworkInterface', 'postAttachNetworkInterface', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionAttachNetworkInterfaceDeviceIndex = 555;
    const actionAttachNetworkInterfaceInstanceId = 'fakedata';
    const actionAttachNetworkInterfaceNetworkInterfaceId = 'fakedata';
    describe('#getAttachNetworkInterface - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getAttachNetworkInterface(actionAttachNetworkInterfaceDeviceIndex, null, actionAttachNetworkInterfaceInstanceId, actionAttachNetworkInterfaceNetworkInterfaceId, actionAttachNetworkInterfaceAction, actionAttachNetworkInterfaceVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.AttachmentId);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionAttachNetworkInterface', 'getAttachNetworkInterface', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    let actionAttachVolumeDevice = 'fakedata';
    let actionAttachVolumeInstanceId = 'fakedata';
    let actionAttachVolumeVolumeId = 'fakedata';
    const actionAttachVolumeAction = 'fakedata';
    const actionAttachVolumeVersion = 'fakedata';
    const actionAttachVolumeBodyFormData = 'fakedata';
    describe('#postAttachVolume - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postAttachVolume(actionAttachVolumeAction, actionAttachVolumeVersion, actionAttachVolumeBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.AttachTime);
              assert.equal('string', data.response.device);
              assert.equal('string', data.response.instanceId);
              assert.equal('attaching', data.response.State);
              assert.equal('string', data.response.volumeId);
              assert.equal(false, data.response.DeleteOnTermination);
            } else {
              runCommonAsserts(data, error);
            }
            actionAttachVolumeDevice = data.response.device;
            actionAttachVolumeInstanceId = data.response.instanceId;
            actionAttachVolumeVolumeId = data.response.volumeId;
            saveMockData('ActionAttachVolume', 'postAttachVolume', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getAttachVolume - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getAttachVolume(actionAttachVolumeDevice, actionAttachVolumeInstanceId, actionAttachVolumeVolumeId, null, actionAttachVolumeAction, actionAttachVolumeVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.AttachTime);
              assert.equal('string', data.response.device);
              assert.equal('string', data.response.instanceId);
              assert.equal('detaching', data.response.State);
              assert.equal('string', data.response.volumeId);
              assert.equal(true, data.response.DeleteOnTermination);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionAttachVolume', 'getAttachVolume', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionAttachVpnGatewayAction = 'fakedata';
    const actionAttachVpnGatewayVersion = 'fakedata';
    const actionAttachVpnGatewayBodyFormData = 'fakedata';
    describe('#postAttachVpnGateway - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postAttachVpnGateway(actionAttachVpnGatewayAction, actionAttachVpnGatewayVersion, actionAttachVpnGatewayBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.VpcAttachment);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionAttachVpnGateway', 'postAttachVpnGateway', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionAttachVpnGatewayVpcId = 'fakedata';
    const actionAttachVpnGatewayVpnGatewayId = 'fakedata';
    describe('#getAttachVpnGateway - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getAttachVpnGateway(actionAttachVpnGatewayVpcId, actionAttachVpnGatewayVpnGatewayId, null, actionAttachVpnGatewayAction, actionAttachVpnGatewayVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.VpcAttachment);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionAttachVpnGateway', 'getAttachVpnGateway', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionAuthorizeClientVpnIngressAction = 'fakedata';
    const actionAuthorizeClientVpnIngressVersion = 'fakedata';
    const actionAuthorizeClientVpnIngressBodyFormData = 'fakedata';
    describe('#postAuthorizeClientVpnIngress - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postAuthorizeClientVpnIngress(actionAuthorizeClientVpnIngressAction, actionAuthorizeClientVpnIngressVersion, actionAuthorizeClientVpnIngressBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.Status);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionAuthorizeClientVpnIngress', 'postAuthorizeClientVpnIngress', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionAuthorizeClientVpnIngressClientVpnEndpointId = 'fakedata';
    const actionAuthorizeClientVpnIngressTargetNetworkCidr = 'fakedata';
    describe('#getAuthorizeClientVpnIngress - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getAuthorizeClientVpnIngress(actionAuthorizeClientVpnIngressClientVpnEndpointId, actionAuthorizeClientVpnIngressTargetNetworkCidr, null, null, null, null, actionAuthorizeClientVpnIngressAction, actionAuthorizeClientVpnIngressVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.Status);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionAuthorizeClientVpnIngress', 'getAuthorizeClientVpnIngress', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionAuthorizeSecurityGroupEgressAction = 'fakedata';
    const actionAuthorizeSecurityGroupEgressVersion = 'fakedata';
    const actionAuthorizeSecurityGroupEgressBodyFormData = 'fakedata';
    describe('#postAuthorizeSecurityGroupEgress - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postAuthorizeSecurityGroupEgress(actionAuthorizeSecurityGroupEgressAction, actionAuthorizeSecurityGroupEgressVersion, actionAuthorizeSecurityGroupEgressBodyFormData, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionAuthorizeSecurityGroupEgress', 'postAuthorizeSecurityGroupEgress', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionAuthorizeSecurityGroupEgressGroupId = 'fakedata';
    describe('#getAuthorizeSecurityGroupEgress - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getAuthorizeSecurityGroupEgress(null, actionAuthorizeSecurityGroupEgressGroupId, null, null, null, null, null, null, null, actionAuthorizeSecurityGroupEgressAction, actionAuthorizeSecurityGroupEgressVersion, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionAuthorizeSecurityGroupEgress', 'getAuthorizeSecurityGroupEgress', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionAuthorizeSecurityGroupIngressAction = 'fakedata';
    const actionAuthorizeSecurityGroupIngressVersion = 'fakedata';
    describe('#postAuthorizeSecurityGroupIngress - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postAuthorizeSecurityGroupIngress(actionAuthorizeSecurityGroupIngressAction, actionAuthorizeSecurityGroupIngressVersion, null, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionAuthorizeSecurityGroupIngress', 'postAuthorizeSecurityGroupIngress', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getAuthorizeSecurityGroupIngress - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getAuthorizeSecurityGroupIngress(null, null, null, null, null, null, null, null, null, null, actionAuthorizeSecurityGroupIngressAction, actionAuthorizeSecurityGroupIngressVersion, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionAuthorizeSecurityGroupIngress', 'getAuthorizeSecurityGroupIngress', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionBundleInstanceAction = 'fakedata';
    const actionBundleInstanceVersion = 'fakedata';
    const actionBundleInstanceBodyFormData = 'fakedata';
    describe('#postBundleInstance - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postBundleInstance(actionBundleInstanceAction, actionBundleInstanceVersion, actionBundleInstanceBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.BundleTask);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionBundleInstance', 'postBundleInstance', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionBundleInstanceInstanceId = 'fakedata';
    describe('#getBundleInstance - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getBundleInstance(actionBundleInstanceInstanceId, null, null, actionBundleInstanceAction, actionBundleInstanceVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.BundleTask);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionBundleInstance', 'getBundleInstance', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCancelBundleTaskAction = 'fakedata';
    const actionCancelBundleTaskVersion = 'fakedata';
    const actionCancelBundleTaskBodyFormData = 'fakedata';
    describe('#postCancelBundleTask - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postCancelBundleTask(actionCancelBundleTaskAction, actionCancelBundleTaskVersion, actionCancelBundleTaskBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.BundleTask);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCancelBundleTask', 'postCancelBundleTask', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCancelBundleTaskBundleId = 'fakedata';
    describe('#getCancelBundleTask - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getCancelBundleTask(actionCancelBundleTaskBundleId, null, actionCancelBundleTaskAction, actionCancelBundleTaskVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.BundleTask);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCancelBundleTask', 'getCancelBundleTask', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCancelCapacityReservationAction = 'fakedata';
    const actionCancelCapacityReservationVersion = 'fakedata';
    const actionCancelCapacityReservationBodyFormData = 'fakedata';
    describe('#postCancelCapacityReservation - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postCancelCapacityReservation(actionCancelCapacityReservationAction, actionCancelCapacityReservationVersion, actionCancelCapacityReservationBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(false, data.response.Return);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCancelCapacityReservation', 'postCancelCapacityReservation', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCancelCapacityReservationCapacityReservationId = 'fakedata';
    describe('#getCancelCapacityReservation - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getCancelCapacityReservation(actionCancelCapacityReservationCapacityReservationId, null, actionCancelCapacityReservationAction, actionCancelCapacityReservationVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, data.response.Return);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCancelCapacityReservation', 'getCancelCapacityReservation', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCancelConversionTaskAction = 'fakedata';
    const actionCancelConversionTaskVersion = 'fakedata';
    const actionCancelConversionTaskBodyFormData = 'fakedata';
    describe('#postCancelConversionTask - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postCancelConversionTask(actionCancelConversionTaskAction, actionCancelConversionTaskVersion, actionCancelConversionTaskBodyFormData, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCancelConversionTask', 'postCancelConversionTask', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCancelConversionTaskConversionTaskId = 'fakedata';
    describe('#getCancelConversionTask - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getCancelConversionTask(actionCancelConversionTaskConversionTaskId, null, null, actionCancelConversionTaskAction, actionCancelConversionTaskVersion, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCancelConversionTask', 'getCancelConversionTask', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCancelExportTaskAction = 'fakedata';
    const actionCancelExportTaskVersion = 'fakedata';
    const actionCancelExportTaskBodyFormData = 'fakedata';
    describe('#postCancelExportTask - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postCancelExportTask(actionCancelExportTaskAction, actionCancelExportTaskVersion, actionCancelExportTaskBodyFormData, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCancelExportTask', 'postCancelExportTask', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCancelExportTaskExportTaskId = 'fakedata';
    describe('#getCancelExportTask - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getCancelExportTask(actionCancelExportTaskExportTaskId, actionCancelExportTaskAction, actionCancelExportTaskVersion, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCancelExportTask', 'getCancelExportTask', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCancelImportTaskAction = 'fakedata';
    const actionCancelImportTaskVersion = 'fakedata';
    describe('#postCancelImportTask - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postCancelImportTask(actionCancelImportTaskAction, actionCancelImportTaskVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.importTaskId);
              assert.equal('string', data.response.PreviousState);
              assert.equal('string', data.response.State);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCancelImportTask', 'postCancelImportTask', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getCancelImportTask - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getCancelImportTask(null, null, null, actionCancelImportTaskAction, actionCancelImportTaskVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.importTaskId);
              assert.equal('string', data.response.PreviousState);
              assert.equal('string', data.response.State);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCancelImportTask', 'getCancelImportTask', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCancelReservedInstancesListingAction = 'fakedata';
    const actionCancelReservedInstancesListingVersion = 'fakedata';
    const actionCancelReservedInstancesListingBodyFormData = 'fakedata';
    describe('#postCancelReservedInstancesListing - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postCancelReservedInstancesListing(actionCancelReservedInstancesListingAction, actionCancelReservedInstancesListingVersion, actionCancelReservedInstancesListingBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.ReservedInstancesListings));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCancelReservedInstancesListing', 'postCancelReservedInstancesListing', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCancelReservedInstancesListingReservedInstancesListingId = 'fakedata';
    describe('#getCancelReservedInstancesListing - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getCancelReservedInstancesListing(actionCancelReservedInstancesListingReservedInstancesListingId, actionCancelReservedInstancesListingAction, actionCancelReservedInstancesListingVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.ReservedInstancesListings));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCancelReservedInstancesListing', 'getCancelReservedInstancesListing', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCancelSpotFleetRequestsAction = 'fakedata';
    const actionCancelSpotFleetRequestsVersion = 'fakedata';
    const actionCancelSpotFleetRequestsBodyFormData = 'fakedata';
    describe('#postCancelSpotFleetRequests - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postCancelSpotFleetRequests(actionCancelSpotFleetRequestsAction, actionCancelSpotFleetRequestsVersion, actionCancelSpotFleetRequestsBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.SuccessfulFleetRequests));
              assert.equal(true, Array.isArray(data.response.UnsuccessfulFleetRequests));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCancelSpotFleetRequests', 'postCancelSpotFleetRequests', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCancelSpotFleetRequestsSpotFleetRequestId = [];
    const actionCancelSpotFleetRequestsTerminateInstances = true;
    describe('#getCancelSpotFleetRequests - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getCancelSpotFleetRequests(null, actionCancelSpotFleetRequestsSpotFleetRequestId, actionCancelSpotFleetRequestsTerminateInstances, actionCancelSpotFleetRequestsAction, actionCancelSpotFleetRequestsVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.SuccessfulFleetRequests));
              assert.equal(true, Array.isArray(data.response.UnsuccessfulFleetRequests));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCancelSpotFleetRequests', 'getCancelSpotFleetRequests', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCancelSpotInstanceRequestsAction = 'fakedata';
    const actionCancelSpotInstanceRequestsVersion = 'fakedata';
    const actionCancelSpotInstanceRequestsBodyFormData = 'fakedata';
    describe('#postCancelSpotInstanceRequests - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postCancelSpotInstanceRequests(actionCancelSpotInstanceRequestsAction, actionCancelSpotInstanceRequestsVersion, actionCancelSpotInstanceRequestsBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.CancelledSpotInstanceRequests));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCancelSpotInstanceRequests', 'postCancelSpotInstanceRequests', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCancelSpotInstanceRequestsSpotInstanceRequestId = [];
    describe('#getCancelSpotInstanceRequests - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getCancelSpotInstanceRequests(null, actionCancelSpotInstanceRequestsSpotInstanceRequestId, actionCancelSpotInstanceRequestsAction, actionCancelSpotInstanceRequestsVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.CancelledSpotInstanceRequests));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCancelSpotInstanceRequests', 'getCancelSpotInstanceRequests', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionConfirmProductInstanceAction = 'fakedata';
    const actionConfirmProductInstanceVersion = 'fakedata';
    const actionConfirmProductInstanceBodyFormData = 'fakedata';
    describe('#postConfirmProductInstance - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postConfirmProductInstance(actionConfirmProductInstanceAction, actionConfirmProductInstanceVersion, actionConfirmProductInstanceBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.OwnerId);
              assert.equal(false, data.response.Return);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionConfirmProductInstance', 'postConfirmProductInstance', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionConfirmProductInstanceInstanceId = 'fakedata';
    const actionConfirmProductInstanceProductCode = 'fakedata';
    describe('#getConfirmProductInstance - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getConfirmProductInstance(actionConfirmProductInstanceInstanceId, actionConfirmProductInstanceProductCode, null, actionConfirmProductInstanceAction, actionConfirmProductInstanceVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.OwnerId);
              assert.equal(false, data.response.Return);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionConfirmProductInstance', 'getConfirmProductInstance', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCopyFpgaImageAction = 'fakedata';
    const actionCopyFpgaImageVersion = 'fakedata';
    const actionCopyFpgaImageBodyFormData = 'fakedata';
    describe('#postCopyFpgaImage - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postCopyFpgaImage(actionCopyFpgaImageAction, actionCopyFpgaImageVersion, actionCopyFpgaImageBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.FpgaImageId);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCopyFpgaImage', 'postCopyFpgaImage', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCopyFpgaImageSourceFpgaImageId = 'fakedata';
    const actionCopyFpgaImageSourceRegion = 'fakedata';
    describe('#getCopyFpgaImage - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getCopyFpgaImage(null, actionCopyFpgaImageSourceFpgaImageId, null, null, actionCopyFpgaImageSourceRegion, null, actionCopyFpgaImageAction, actionCopyFpgaImageVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.FpgaImageId);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCopyFpgaImage', 'getCopyFpgaImage', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCopyImageAction = 'fakedata';
    const actionCopyImageVersion = 'fakedata';
    const actionCopyImageBodyFormData = 'fakedata';
    describe('#postCopyImage - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postCopyImage(actionCopyImageAction, actionCopyImageVersion, actionCopyImageBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.ImageId);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCopyImage', 'postCopyImage', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCopyImageName = 'fakedata';
    const actionCopyImageSourceImageId = 'fakedata';
    const actionCopyImageSourceRegion = 'fakedata';
    describe('#getCopyImage - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getCopyImage(null, null, null, null, actionCopyImageName, actionCopyImageSourceImageId, actionCopyImageSourceRegion, null, actionCopyImageAction, actionCopyImageVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.ImageId);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCopyImage', 'getCopyImage', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCopySnapshotAction = 'fakedata';
    const actionCopySnapshotVersion = 'fakedata';
    const actionCopySnapshotBodyFormData = 'fakedata';
    describe('#postCopySnapshot - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postCopySnapshot(actionCopySnapshotAction, actionCopySnapshotVersion, actionCopySnapshotBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.SnapshotId);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCopySnapshot', 'postCopySnapshot', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCopySnapshotSourceRegion = 'fakedata';
    const actionCopySnapshotSourceSnapshotId = 'fakedata';
    describe('#getCopySnapshot - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getCopySnapshot(null, null, null, null, null, actionCopySnapshotSourceRegion, actionCopySnapshotSourceSnapshotId, null, actionCopySnapshotAction, actionCopySnapshotVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.SnapshotId);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCopySnapshot', 'getCopySnapshot', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateCapacityReservationAction = 'fakedata';
    const actionCreateCapacityReservationVersion = 'fakedata';
    const actionCreateCapacityReservationBodyFormData = 'fakedata';
    describe('#postCreateCapacityReservation - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateCapacityReservation(actionCreateCapacityReservationAction, actionCreateCapacityReservationVersion, actionCreateCapacityReservationBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.CapacityReservation);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateCapacityReservation', 'postCreateCapacityReservation', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateCapacityReservationInstanceType = 'fakedata';
    const actionCreateCapacityReservationInstancePlatform = 'fakedata';
    const actionCreateCapacityReservationAvailabilityZone = 'fakedata';
    const actionCreateCapacityReservationInstanceCount = 555;
    describe('#getCreateCapacityReservation - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateCapacityReservation(null, actionCreateCapacityReservationInstanceType, actionCreateCapacityReservationInstancePlatform, actionCreateCapacityReservationAvailabilityZone, null, actionCreateCapacityReservationInstanceCount, null, null, null, null, null, null, null, actionCreateCapacityReservationAction, actionCreateCapacityReservationVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.CapacityReservation);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateCapacityReservation', 'getCreateCapacityReservation', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateClientVpnEndpointAction = 'fakedata';
    const actionCreateClientVpnEndpointVersion = 'fakedata';
    const actionCreateClientVpnEndpointBodyFormData = 'fakedata';
    describe('#postCreateClientVpnEndpoint - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateClientVpnEndpoint(actionCreateClientVpnEndpointAction, actionCreateClientVpnEndpointVersion, actionCreateClientVpnEndpointBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.ClientVpnEndpointId);
              assert.equal('object', typeof data.response.Status);
              assert.equal('string', data.response.DnsName);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateClientVpnEndpoint', 'postCreateClientVpnEndpoint', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateClientVpnEndpointClientCidrBlock = 'fakedata';
    const actionCreateClientVpnEndpointServerCertificateArn = 'fakedata';
    const actionCreateClientVpnEndpointAuthentication = [];
    describe('#getCreateClientVpnEndpoint - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateClientVpnEndpoint(actionCreateClientVpnEndpointClientCidrBlock, actionCreateClientVpnEndpointServerCertificateArn, actionCreateClientVpnEndpointAuthentication, null, null, null, null, null, null, null, null, null, actionCreateClientVpnEndpointAction, actionCreateClientVpnEndpointVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.ClientVpnEndpointId);
              assert.equal('object', typeof data.response.Status);
              assert.equal('string', data.response.DnsName);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateClientVpnEndpoint', 'getCreateClientVpnEndpoint', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateClientVpnRouteAction = 'fakedata';
    const actionCreateClientVpnRouteVersion = 'fakedata';
    const actionCreateClientVpnRouteBodyFormData = 'fakedata';
    describe('#postCreateClientVpnRoute - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateClientVpnRoute(actionCreateClientVpnRouteAction, actionCreateClientVpnRouteVersion, actionCreateClientVpnRouteBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.Status);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateClientVpnRoute', 'postCreateClientVpnRoute', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateClientVpnRouteClientVpnEndpointId = 'fakedata';
    const actionCreateClientVpnRouteDestinationCidrBlock = 'fakedata';
    const actionCreateClientVpnRouteTargetVpcSubnetId = 'fakedata';
    describe('#getCreateClientVpnRoute - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateClientVpnRoute(actionCreateClientVpnRouteClientVpnEndpointId, actionCreateClientVpnRouteDestinationCidrBlock, actionCreateClientVpnRouteTargetVpcSubnetId, null, null, actionCreateClientVpnRouteAction, actionCreateClientVpnRouteVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.Status);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateClientVpnRoute', 'getCreateClientVpnRoute', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateCustomerGatewayAction = 'fakedata';
    const actionCreateCustomerGatewayVersion = 'fakedata';
    const actionCreateCustomerGatewayBodyFormData = 'fakedata';
    describe('#postCreateCustomerGateway - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateCustomerGateway(actionCreateCustomerGatewayAction, actionCreateCustomerGatewayVersion, actionCreateCustomerGatewayBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.CustomerGateway);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateCustomerGateway', 'postCreateCustomerGateway', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateCustomerGatewayBgpAsn = 555;
    const actionCreateCustomerGatewayIpAddress = 'fakedata';
    const actionCreateCustomerGatewayType = 'fakedata';
    describe('#getCreateCustomerGateway - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateCustomerGateway(actionCreateCustomerGatewayBgpAsn, actionCreateCustomerGatewayIpAddress, actionCreateCustomerGatewayType, null, actionCreateCustomerGatewayAction, actionCreateCustomerGatewayVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.CustomerGateway);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateCustomerGateway', 'getCreateCustomerGateway', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateDefaultSubnetAction = 'fakedata';
    const actionCreateDefaultSubnetVersion = 'fakedata';
    const actionCreateDefaultSubnetBodyFormData = 'fakedata';
    describe('#postCreateDefaultSubnet - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateDefaultSubnet(actionCreateDefaultSubnetAction, actionCreateDefaultSubnetVersion, actionCreateDefaultSubnetBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.Subnet);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateDefaultSubnet', 'postCreateDefaultSubnet', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateDefaultSubnetAvailabilityZone = 'fakedata';
    describe('#getCreateDefaultSubnet - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateDefaultSubnet(actionCreateDefaultSubnetAvailabilityZone, null, actionCreateDefaultSubnetAction, actionCreateDefaultSubnetVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.Subnet);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateDefaultSubnet', 'getCreateDefaultSubnet', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateDefaultVpcAction = 'fakedata';
    const actionCreateDefaultVpcVersion = 'fakedata';
    describe('#postCreateDefaultVpc - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateDefaultVpc(actionCreateDefaultVpcAction, actionCreateDefaultVpcVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.Vpc);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateDefaultVpc', 'postCreateDefaultVpc', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getCreateDefaultVpc - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateDefaultVpc(null, actionCreateDefaultVpcAction, actionCreateDefaultVpcVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.Vpc);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateDefaultVpc', 'getCreateDefaultVpc', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateDhcpOptionsAction = 'fakedata';
    const actionCreateDhcpOptionsVersion = 'fakedata';
    const actionCreateDhcpOptionsBodyFormData = 'fakedata';
    describe('#postCreateDhcpOptions - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateDhcpOptions(actionCreateDhcpOptionsAction, actionCreateDhcpOptionsVersion, actionCreateDhcpOptionsBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.DhcpOptions);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateDhcpOptions', 'postCreateDhcpOptions', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateDhcpOptionsDhcpConfiguration = [];
    describe('#getCreateDhcpOptions - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateDhcpOptions(actionCreateDhcpOptionsDhcpConfiguration, null, actionCreateDhcpOptionsAction, actionCreateDhcpOptionsVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.DhcpOptions);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateDhcpOptions', 'getCreateDhcpOptions', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateEgressOnlyInternetGatewayAction = 'fakedata';
    const actionCreateEgressOnlyInternetGatewayVersion = 'fakedata';
    const actionCreateEgressOnlyInternetGatewayBodyFormData = 'fakedata';
    describe('#postCreateEgressOnlyInternetGateway - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateEgressOnlyInternetGateway(actionCreateEgressOnlyInternetGatewayAction, actionCreateEgressOnlyInternetGatewayVersion, actionCreateEgressOnlyInternetGatewayBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.clientToken);
              assert.equal('object', typeof data.response.EgressOnlyInternetGateway);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateEgressOnlyInternetGateway', 'postCreateEgressOnlyInternetGateway', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateEgressOnlyInternetGatewayVpcId = 'fakedata';
    describe('#getCreateEgressOnlyInternetGateway - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateEgressOnlyInternetGateway(null, null, actionCreateEgressOnlyInternetGatewayVpcId, actionCreateEgressOnlyInternetGatewayAction, actionCreateEgressOnlyInternetGatewayVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.clientToken);
              assert.equal('object', typeof data.response.EgressOnlyInternetGateway);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateEgressOnlyInternetGateway', 'getCreateEgressOnlyInternetGateway', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateFleetAction = 'fakedata';
    const actionCreateFleetVersion = 'fakedata';
    const actionCreateFleetBodyFormData = 'fakedata';
    describe('#postCreateFleet - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateFleet(actionCreateFleetAction, actionCreateFleetVersion, actionCreateFleetBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.FleetId);
              assert.equal(true, Array.isArray(data.response.Errors));
              assert.equal(true, Array.isArray(data.response.Instances));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateFleet', 'postCreateFleet', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateFleetLaunchTemplateConfigs = [];
    describe('#getCreateFleet - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateFleet(null, null, null, null, null, null, null, null, null, null, null, null, null, actionCreateFleetLaunchTemplateConfigs, null, null, null, null, null, null, null, null, null, null, actionCreateFleetAction, actionCreateFleetVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.FleetId);
              assert.equal(true, Array.isArray(data.response.Errors));
              assert.equal(true, Array.isArray(data.response.Instances));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateFleet', 'getCreateFleet', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateFlowLogsAction = 'fakedata';
    const actionCreateFlowLogsVersion = 'fakedata';
    const actionCreateFlowLogsBodyFormData = 'fakedata';
    describe('#postCreateFlowLogs - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateFlowLogs(actionCreateFlowLogsAction, actionCreateFlowLogsVersion, actionCreateFlowLogsBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.clientToken);
              assert.equal(true, Array.isArray(data.response.FlowLogIds));
              assert.equal(true, Array.isArray(data.response.Unsuccessful));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateFlowLogs', 'postCreateFlowLogs', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateFlowLogsResourceId = [];
    const actionCreateFlowLogsResourceType = 'fakedata';
    const actionCreateFlowLogsTrafficType = 'fakedata';
    describe('#getCreateFlowLogs - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateFlowLogs(null, null, null, null, actionCreateFlowLogsResourceId, actionCreateFlowLogsResourceType, actionCreateFlowLogsTrafficType, null, null, actionCreateFlowLogsAction, actionCreateFlowLogsVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.clientToken);
              assert.equal(true, Array.isArray(data.response.FlowLogIds));
              assert.equal(true, Array.isArray(data.response.Unsuccessful));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateFlowLogs', 'getCreateFlowLogs', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateFpgaImageAction = 'fakedata';
    const actionCreateFpgaImageVersion = 'fakedata';
    describe('#postCreateFpgaImage - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateFpgaImage(actionCreateFpgaImageAction, actionCreateFpgaImageVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.FpgaImageId);
              assert.equal('string', data.response.FpgaImageGlobalId);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateFpgaImage', 'postCreateFpgaImage', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getCreateFpgaImage - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateFpgaImage(null, null, null, null, null, null, null, null, actionCreateFpgaImageAction, actionCreateFpgaImageVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.FpgaImageId);
              assert.equal('string', data.response.FpgaImageGlobalId);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateFpgaImage', 'getCreateFpgaImage', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateImageAction = 'fakedata';
    const actionCreateImageVersion = 'fakedata';
    const actionCreateImageBodyFormData = 'fakedata';
    describe('#postCreateImage - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateImage(actionCreateImageAction, actionCreateImageVersion, actionCreateImageBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.ImageId);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateImage', 'postCreateImage', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateImageInstanceId = 'fakedata';
    const actionCreateImageName = 'fakedata';
    describe('#getCreateImage - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateImage(null, null, null, actionCreateImageInstanceId, actionCreateImageName, null, actionCreateImageAction, actionCreateImageVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.ImageId);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateImage', 'getCreateImage', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateInstanceExportTaskAction = 'fakedata';
    const actionCreateInstanceExportTaskVersion = 'fakedata';
    const actionCreateInstanceExportTaskBodyFormData = 'fakedata';
    describe('#postCreateInstanceExportTask - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateInstanceExportTask(actionCreateInstanceExportTaskAction, actionCreateInstanceExportTaskVersion, actionCreateInstanceExportTaskBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.ExportTask);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateInstanceExportTask', 'postCreateInstanceExportTask', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateInstanceExportTaskInstanceId = 'fakedata';
    describe('#getCreateInstanceExportTask - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateInstanceExportTask(null, null, null, null, null, actionCreateInstanceExportTaskInstanceId, null, actionCreateInstanceExportTaskAction, actionCreateInstanceExportTaskVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.ExportTask);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateInstanceExportTask', 'getCreateInstanceExportTask', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateInternetGatewayAction = 'fakedata';
    const actionCreateInternetGatewayVersion = 'fakedata';
    describe('#postCreateInternetGateway - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateInternetGateway(actionCreateInternetGatewayAction, actionCreateInternetGatewayVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.InternetGateway);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateInternetGateway', 'postCreateInternetGateway', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getCreateInternetGateway - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateInternetGateway(null, actionCreateInternetGatewayAction, actionCreateInternetGatewayVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.InternetGateway);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateInternetGateway', 'getCreateInternetGateway', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    let actionCreateKeyPairKeyName = 'fakedata';
    const actionCreateKeyPairAction = 'fakedata';
    const actionCreateKeyPairVersion = 'fakedata';
    const actionCreateKeyPairBodyFormData = 'fakedata';
    describe('#postCreateKeyPair - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateKeyPair(actionCreateKeyPairAction, actionCreateKeyPairVersion, actionCreateKeyPairBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.KeyFingerprint);
              assert.equal('string', data.response.KeyMaterial);
              assert.equal('string', data.response.keyName);
            } else {
              runCommonAsserts(data, error);
            }
            actionCreateKeyPairKeyName = data.response.keyName;
            saveMockData('ActionCreateKeyPair', 'postCreateKeyPair', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getCreateKeyPair - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateKeyPair(actionCreateKeyPairKeyName, null, actionCreateKeyPairAction, actionCreateKeyPairVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.KeyFingerprint);
              assert.equal('string', data.response.KeyMaterial);
              assert.equal('string', data.response.keyName);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateKeyPair', 'getCreateKeyPair', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateLaunchTemplateAction = 'fakedata';
    const actionCreateLaunchTemplateVersion = 'fakedata';
    const actionCreateLaunchTemplateBodyFormData = 'fakedata';
    describe('#postCreateLaunchTemplate - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateLaunchTemplate(actionCreateLaunchTemplateAction, actionCreateLaunchTemplateVersion, actionCreateLaunchTemplateBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.LaunchTemplate);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateLaunchTemplate', 'postCreateLaunchTemplate', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateLaunchTemplateLaunchTemplateName = 'fakedata';
    describe('#getCreateLaunchTemplate - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateLaunchTemplate(null, null, actionCreateLaunchTemplateLaunchTemplateName, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, actionCreateLaunchTemplateAction, actionCreateLaunchTemplateVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.LaunchTemplate);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateLaunchTemplate', 'getCreateLaunchTemplate', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateLaunchTemplateVersionAction = 'fakedata';
    const actionCreateLaunchTemplateVersionVersion = 'fakedata';
    describe('#postCreateLaunchTemplateVersion - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateLaunchTemplateVersion(actionCreateLaunchTemplateVersionAction, actionCreateLaunchTemplateVersionVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.LaunchTemplateVersion);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateLaunchTemplateVersion', 'postCreateLaunchTemplateVersion', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getCreateLaunchTemplateVersion - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateLaunchTemplateVersion(null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, actionCreateLaunchTemplateVersionAction, actionCreateLaunchTemplateVersionVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.LaunchTemplateVersion);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateLaunchTemplateVersion', 'getCreateLaunchTemplateVersion', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateNatGatewayAction = 'fakedata';
    const actionCreateNatGatewayVersion = 'fakedata';
    const actionCreateNatGatewayBodyFormData = 'fakedata';
    describe('#postCreateNatGateway - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateNatGateway(actionCreateNatGatewayAction, actionCreateNatGatewayVersion, actionCreateNatGatewayBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.clientToken);
              assert.equal('object', typeof data.response.NatGateway);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateNatGateway', 'postCreateNatGateway', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateNatGatewayAllocationId = 'fakedata';
    const actionCreateNatGatewaySubnetId = 'fakedata';
    describe('#getCreateNatGateway - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateNatGateway(actionCreateNatGatewayAllocationId, null, actionCreateNatGatewaySubnetId, actionCreateNatGatewayAction, actionCreateNatGatewayVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.clientToken);
              assert.equal('object', typeof data.response.NatGateway);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateNatGateway', 'getCreateNatGateway', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateNetworkAclAction = 'fakedata';
    const actionCreateNetworkAclVersion = 'fakedata';
    const actionCreateNetworkAclBodyFormData = 'fakedata';
    describe('#postCreateNetworkAcl - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateNetworkAcl(actionCreateNetworkAclAction, actionCreateNetworkAclVersion, actionCreateNetworkAclBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.NetworkAcl);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateNetworkAcl', 'postCreateNetworkAcl', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateNetworkAclVpcId = 'fakedata';
    describe('#getCreateNetworkAcl - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateNetworkAcl(null, actionCreateNetworkAclVpcId, actionCreateNetworkAclAction, actionCreateNetworkAclVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.NetworkAcl);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateNetworkAcl', 'getCreateNetworkAcl', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateNetworkAclEntryAction = 'fakedata';
    const actionCreateNetworkAclEntryVersion = 'fakedata';
    const actionCreateNetworkAclEntryBodyFormData = 'fakedata';
    describe('#postCreateNetworkAclEntry - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateNetworkAclEntry(actionCreateNetworkAclEntryAction, actionCreateNetworkAclEntryVersion, actionCreateNetworkAclEntryBodyFormData, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateNetworkAclEntry', 'postCreateNetworkAclEntry', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateNetworkAclEntryEgress = true;
    const actionCreateNetworkAclEntryNetworkAclId = 'fakedata';
    const actionCreateNetworkAclEntryProtocol = 'fakedata';
    const actionCreateNetworkAclEntryRuleAction = 'fakedata';
    const actionCreateNetworkAclEntryRuleNumber = 555;
    describe('#getCreateNetworkAclEntry - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateNetworkAclEntry(null, null, actionCreateNetworkAclEntryEgress, null, null, null, actionCreateNetworkAclEntryNetworkAclId, null, null, actionCreateNetworkAclEntryProtocol, actionCreateNetworkAclEntryRuleAction, actionCreateNetworkAclEntryRuleNumber, actionCreateNetworkAclEntryAction, actionCreateNetworkAclEntryVersion, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateNetworkAclEntry', 'getCreateNetworkAclEntry', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateNetworkInterfaceAction = 'fakedata';
    const actionCreateNetworkInterfaceVersion = 'fakedata';
    const actionCreateNetworkInterfaceBodyFormData = 'fakedata';
    describe('#postCreateNetworkInterface - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateNetworkInterface(actionCreateNetworkInterfaceAction, actionCreateNetworkInterfaceVersion, actionCreateNetworkInterfaceBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.NetworkInterface);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateNetworkInterface', 'postCreateNetworkInterface', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateNetworkInterfaceSubnetId = 'fakedata';
    describe('#getCreateNetworkInterface - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateNetworkInterface(null, null, null, null, null, null, null, null, null, actionCreateNetworkInterfaceSubnetId, actionCreateNetworkInterfaceAction, actionCreateNetworkInterfaceVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.NetworkInterface);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateNetworkInterface', 'getCreateNetworkInterface', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateNetworkInterfacePermissionAction = 'fakedata';
    const actionCreateNetworkInterfacePermissionVersion = 'fakedata';
    const actionCreateNetworkInterfacePermissionBodyFormData = 'fakedata';
    describe('#postCreateNetworkInterfacePermission - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateNetworkInterfacePermission(actionCreateNetworkInterfacePermissionAction, actionCreateNetworkInterfacePermissionVersion, actionCreateNetworkInterfacePermissionBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.InterfacePermission);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateNetworkInterfacePermission', 'postCreateNetworkInterfacePermission', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateNetworkInterfacePermissionNetworkInterfaceId = 'fakedata';
    const actionCreateNetworkInterfacePermissionPermission = 'fakedata';
    describe('#getCreateNetworkInterfacePermission - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateNetworkInterfacePermission(actionCreateNetworkInterfacePermissionNetworkInterfaceId, null, null, actionCreateNetworkInterfacePermissionPermission, null, actionCreateNetworkInterfacePermissionAction, actionCreateNetworkInterfacePermissionVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.InterfacePermission);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateNetworkInterfacePermission', 'getCreateNetworkInterfacePermission', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreatePlacementGroupAction = 'fakedata';
    const actionCreatePlacementGroupVersion = 'fakedata';
    describe('#postCreatePlacementGroup - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postCreatePlacementGroup(actionCreatePlacementGroupAction, actionCreatePlacementGroupVersion, null, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreatePlacementGroup', 'postCreatePlacementGroup', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getCreatePlacementGroup - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getCreatePlacementGroup(null, null, null, null, actionCreatePlacementGroupAction, actionCreatePlacementGroupVersion, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreatePlacementGroup', 'getCreatePlacementGroup', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateReservedInstancesListingAction = 'fakedata';
    const actionCreateReservedInstancesListingVersion = 'fakedata';
    const actionCreateReservedInstancesListingBodyFormData = 'fakedata';
    describe('#postCreateReservedInstancesListing - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateReservedInstancesListing(actionCreateReservedInstancesListingAction, actionCreateReservedInstancesListingVersion, actionCreateReservedInstancesListingBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.ReservedInstancesListings));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateReservedInstancesListing', 'postCreateReservedInstancesListing', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateReservedInstancesListingClientToken = 'fakedata';
    const actionCreateReservedInstancesListingInstanceCount = 555;
    const actionCreateReservedInstancesListingPriceSchedules = [];
    const actionCreateReservedInstancesListingReservedInstancesId = 'fakedata';
    describe('#getCreateReservedInstancesListing - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateReservedInstancesListing(actionCreateReservedInstancesListingClientToken, actionCreateReservedInstancesListingInstanceCount, actionCreateReservedInstancesListingPriceSchedules, actionCreateReservedInstancesListingReservedInstancesId, actionCreateReservedInstancesListingAction, actionCreateReservedInstancesListingVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.ReservedInstancesListings));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateReservedInstancesListing', 'getCreateReservedInstancesListing', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateRouteAction = 'fakedata';
    const actionCreateRouteVersion = 'fakedata';
    const actionCreateRouteBodyFormData = 'fakedata';
    describe('#postCreateRoute - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateRoute(actionCreateRouteAction, actionCreateRouteVersion, actionCreateRouteBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, data.response.Return);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateRoute', 'postCreateRoute', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateRouteRouteTableId = 'fakedata';
    describe('#getCreateRoute - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateRoute(null, null, null, null, null, null, null, null, null, actionCreateRouteRouteTableId, null, actionCreateRouteAction, actionCreateRouteVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, data.response.Return);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateRoute', 'getCreateRoute', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateRouteTableAction = 'fakedata';
    const actionCreateRouteTableVersion = 'fakedata';
    const actionCreateRouteTableBodyFormData = 'fakedata';
    describe('#postCreateRouteTable - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateRouteTable(actionCreateRouteTableAction, actionCreateRouteTableVersion, actionCreateRouteTableBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.RouteTable);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateRouteTable', 'postCreateRouteTable', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateRouteTableVpcId = 'fakedata';
    describe('#getCreateRouteTable - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateRouteTable(null, actionCreateRouteTableVpcId, actionCreateRouteTableAction, actionCreateRouteTableVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.RouteTable);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateRouteTable', 'getCreateRouteTable', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateSecurityGroupAction = 'fakedata';
    const actionCreateSecurityGroupVersion = 'fakedata';
    const actionCreateSecurityGroupBodyFormData = 'fakedata';
    describe('#postCreateSecurityGroup - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateSecurityGroup(actionCreateSecurityGroupAction, actionCreateSecurityGroupVersion, actionCreateSecurityGroupBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.GroupId);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateSecurityGroup', 'postCreateSecurityGroup', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateSecurityGroupGroupDescription = 'fakedata';
    const actionCreateSecurityGroupGroupName = 'fakedata';
    describe('#getCreateSecurityGroup - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateSecurityGroup(actionCreateSecurityGroupGroupDescription, actionCreateSecurityGroupGroupName, null, null, actionCreateSecurityGroupAction, actionCreateSecurityGroupVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.GroupId);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateSecurityGroup', 'getCreateSecurityGroup', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    let actionCreateSnapshotVolumeId = 'fakedata';
    const actionCreateSnapshotAction = 'fakedata';
    const actionCreateSnapshotVersion = 'fakedata';
    const actionCreateSnapshotBodyFormData = 'fakedata';
    describe('#postCreateSnapshot - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateSnapshot(actionCreateSnapshotAction, actionCreateSnapshotVersion, actionCreateSnapshotBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.DataEncryptionKeyId);
              assert.equal('string', data.response.description);
              assert.equal(false, data.response.Encrypted);
              assert.equal('string', data.response.KmsKeyId);
              assert.equal('string', data.response.OwnerId);
              assert.equal('string', data.response.Progress);
              assert.equal('string', data.response.SnapshotId);
              assert.equal('string', data.response.StartTime);
              assert.equal('completed', data.response.State);
              assert.equal('string', data.response.StateMessage);
              assert.equal('string', data.response.volumeId);
              assert.equal(8, data.response.VolumeSize);
              assert.equal('string', data.response.OwnerAlias);
              assert.equal(true, Array.isArray(data.response.Tags));
            } else {
              runCommonAsserts(data, error);
            }
            actionCreateSnapshotVolumeId = data.response.volumeId;
            saveMockData('ActionCreateSnapshot', 'postCreateSnapshot', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getCreateSnapshot - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateSnapshot(null, actionCreateSnapshotVolumeId, null, null, actionCreateSnapshotAction, actionCreateSnapshotVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.DataEncryptionKeyId);
              assert.equal('string', data.response.description);
              assert.equal(true, data.response.Encrypted);
              assert.equal('string', data.response.KmsKeyId);
              assert.equal('string', data.response.OwnerId);
              assert.equal('string', data.response.Progress);
              assert.equal('string', data.response.SnapshotId);
              assert.equal('string', data.response.StartTime);
              assert.equal('completed', data.response.State);
              assert.equal('string', data.response.StateMessage);
              assert.equal('string', data.response.volumeId);
              assert.equal(3, data.response.VolumeSize);
              assert.equal('string', data.response.OwnerAlias);
              assert.equal(true, Array.isArray(data.response.Tags));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateSnapshot', 'getCreateSnapshot', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateSpotDatafeedSubscriptionAction = 'fakedata';
    const actionCreateSpotDatafeedSubscriptionVersion = 'fakedata';
    const actionCreateSpotDatafeedSubscriptionBodyFormData = 'fakedata';
    describe('#postCreateSpotDatafeedSubscription - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateSpotDatafeedSubscription(actionCreateSpotDatafeedSubscriptionAction, actionCreateSpotDatafeedSubscriptionVersion, actionCreateSpotDatafeedSubscriptionBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.SpotDatafeedSubscription);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateSpotDatafeedSubscription', 'postCreateSpotDatafeedSubscription', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateSpotDatafeedSubscriptionBucket = 'fakedata';
    describe('#getCreateSpotDatafeedSubscription - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateSpotDatafeedSubscription(actionCreateSpotDatafeedSubscriptionBucket, null, null, actionCreateSpotDatafeedSubscriptionAction, actionCreateSpotDatafeedSubscriptionVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.SpotDatafeedSubscription);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateSpotDatafeedSubscription', 'getCreateSpotDatafeedSubscription', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateSubnetAction = 'fakedata';
    const actionCreateSubnetVersion = 'fakedata';
    const actionCreateSubnetBodyFormData = 'fakedata';
    describe('#postCreateSubnet - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateSubnet(actionCreateSubnetAction, actionCreateSubnetVersion, actionCreateSubnetBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.Subnet);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateSubnet', 'postCreateSubnet', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateSubnetCidrBlock = 'fakedata';
    const actionCreateSubnetVpcId = 'fakedata';
    describe('#getCreateSubnet - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateSubnet(null, null, actionCreateSubnetCidrBlock, null, actionCreateSubnetVpcId, null, actionCreateSubnetAction, actionCreateSubnetVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.Subnet);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateSubnet', 'getCreateSubnet', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateTagsAction = 'fakedata';
    const actionCreateTagsVersion = 'fakedata';
    const actionCreateTagsBodyFormData = 'fakedata';
    describe('#postCreateTags - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateTags(actionCreateTagsAction, actionCreateTagsVersion, actionCreateTagsBodyFormData, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateTags', 'postCreateTags', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateTagsResourceId = [];
    const actionCreateTagsTag = [];
    describe('#getCreateTags - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateTags(null, actionCreateTagsResourceId, actionCreateTagsTag, actionCreateTagsAction, actionCreateTagsVersion, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateTags', 'getCreateTags', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateTransitGatewayAction = 'fakedata';
    const actionCreateTransitGatewayVersion = 'fakedata';
    describe('#postCreateTransitGateway - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateTransitGateway(actionCreateTransitGatewayAction, actionCreateTransitGatewayVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.TransitGateway);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateTransitGateway', 'postCreateTransitGateway', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getCreateTransitGateway - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateTransitGateway(null, null, null, null, null, null, null, null, null, actionCreateTransitGatewayAction, actionCreateTransitGatewayVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.TransitGateway);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateTransitGateway', 'getCreateTransitGateway', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateTransitGatewayRouteAction = 'fakedata';
    const actionCreateTransitGatewayRouteVersion = 'fakedata';
    const actionCreateTransitGatewayRouteBodyFormData = 'fakedata';
    describe('#postCreateTransitGatewayRoute - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateTransitGatewayRoute(actionCreateTransitGatewayRouteAction, actionCreateTransitGatewayRouteVersion, actionCreateTransitGatewayRouteBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.Route);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateTransitGatewayRoute', 'postCreateTransitGatewayRoute', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateTransitGatewayRouteDestinationCidrBlock = 'fakedata';
    const actionCreateTransitGatewayRouteTransitGatewayRouteTableId = 'fakedata';
    describe('#getCreateTransitGatewayRoute - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateTransitGatewayRoute(actionCreateTransitGatewayRouteDestinationCidrBlock, actionCreateTransitGatewayRouteTransitGatewayRouteTableId, null, null, null, actionCreateTransitGatewayRouteAction, actionCreateTransitGatewayRouteVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.Route);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateTransitGatewayRoute', 'getCreateTransitGatewayRoute', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateTransitGatewayRouteTableAction = 'fakedata';
    const actionCreateTransitGatewayRouteTableVersion = 'fakedata';
    const actionCreateTransitGatewayRouteTableBodyFormData = 'fakedata';
    describe('#postCreateTransitGatewayRouteTable - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateTransitGatewayRouteTable(actionCreateTransitGatewayRouteTableAction, actionCreateTransitGatewayRouteTableVersion, actionCreateTransitGatewayRouteTableBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.TransitGatewayRouteTable);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateTransitGatewayRouteTable', 'postCreateTransitGatewayRouteTable', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateTransitGatewayRouteTableTransitGatewayId = 'fakedata';
    describe('#getCreateTransitGatewayRouteTable - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateTransitGatewayRouteTable(actionCreateTransitGatewayRouteTableTransitGatewayId, null, null, actionCreateTransitGatewayRouteTableAction, actionCreateTransitGatewayRouteTableVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.TransitGatewayRouteTable);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateTransitGatewayRouteTable', 'getCreateTransitGatewayRouteTable', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateTransitGatewayVpcAttachmentAction = 'fakedata';
    const actionCreateTransitGatewayVpcAttachmentVersion = 'fakedata';
    const actionCreateTransitGatewayVpcAttachmentBodyFormData = 'fakedata';
    describe('#postCreateTransitGatewayVpcAttachment - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateTransitGatewayVpcAttachment(actionCreateTransitGatewayVpcAttachmentAction, actionCreateTransitGatewayVpcAttachmentVersion, actionCreateTransitGatewayVpcAttachmentBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.TransitGatewayVpcAttachment);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateTransitGatewayVpcAttachment', 'postCreateTransitGatewayVpcAttachment', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateTransitGatewayVpcAttachmentTransitGatewayId = 'fakedata';
    const actionCreateTransitGatewayVpcAttachmentVpcId = 'fakedata';
    const actionCreateTransitGatewayVpcAttachmentSubnetIds = [];
    describe('#getCreateTransitGatewayVpcAttachment - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateTransitGatewayVpcAttachment(actionCreateTransitGatewayVpcAttachmentTransitGatewayId, actionCreateTransitGatewayVpcAttachmentVpcId, actionCreateTransitGatewayVpcAttachmentSubnetIds, null, null, null, null, actionCreateTransitGatewayVpcAttachmentAction, actionCreateTransitGatewayVpcAttachmentVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.TransitGatewayVpcAttachment);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateTransitGatewayVpcAttachment', 'getCreateTransitGatewayVpcAttachment', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    let actionCreateVolumeAvailabilityZone = 'fakedata';
    const actionCreateVolumeAction = 'fakedata';
    const actionCreateVolumeVersion = 'fakedata';
    const actionCreateVolumeBodyFormData = 'fakedata';
    describe('#postCreateVolume - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateVolume(actionCreateVolumeAction, actionCreateVolumeVersion, actionCreateVolumeBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.Attachments));
              assert.equal('string', data.response.availabilityZone);
              assert.equal('string', data.response.CreateTime);
              assert.equal(true, data.response.encrypted);
              assert.equal('string', data.response.kmsKeyId);
              assert.equal(10, data.response.size);
              assert.equal('string', data.response.snapshotId);
              assert.equal('deleting', data.response.State);
              assert.equal('string', data.response.VolumeId);
              assert.equal(9, data.response.iops);
              assert.equal(true, Array.isArray(data.response.Tags));
              assert.equal('st1', data.response.volumeType);
            } else {
              runCommonAsserts(data, error);
            }
            actionCreateVolumeAvailabilityZone = data.response.availabilityZone;
            saveMockData('ActionCreateVolume', 'postCreateVolume', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getCreateVolume - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateVolume(actionCreateVolumeAvailabilityZone, null, null, null, null, null, null, null, null, actionCreateVolumeAction, actionCreateVolumeVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.Attachments));
              assert.equal('string', data.response.availabilityZone);
              assert.equal('string', data.response.CreateTime);
              assert.equal(false, data.response.encrypted);
              assert.equal('string', data.response.kmsKeyId);
              assert.equal(10, data.response.size);
              assert.equal('string', data.response.snapshotId);
              assert.equal('error', data.response.State);
              assert.equal('string', data.response.VolumeId);
              assert.equal(8, data.response.iops);
              assert.equal(true, Array.isArray(data.response.Tags));
              assert.equal('sc1', data.response.volumeType);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateVolume', 'getCreateVolume', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateVpcAction = 'fakedata';
    const actionCreateVpcVersion = 'fakedata';
    const actionCreateVpcBodyFormData = 'fakedata';
    describe('#postCreateVpc - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateVpc(actionCreateVpcAction, actionCreateVpcVersion, actionCreateVpcBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.Vpc);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateVpc', 'postCreateVpc', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateVpcCidrBlock = 'fakedata';
    describe('#getCreateVpc - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateVpc(actionCreateVpcCidrBlock, null, null, null, actionCreateVpcAction, actionCreateVpcVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.Vpc);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateVpc', 'getCreateVpc', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateVpcEndpointAction = 'fakedata';
    const actionCreateVpcEndpointVersion = 'fakedata';
    const actionCreateVpcEndpointBodyFormData = 'fakedata';
    describe('#postCreateVpcEndpoint - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateVpcEndpoint(actionCreateVpcEndpointAction, actionCreateVpcEndpointVersion, actionCreateVpcEndpointBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.VpcEndpoint);
              assert.equal('string', data.response.clientToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateVpcEndpoint', 'postCreateVpcEndpoint', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateVpcEndpointVpcId = 'fakedata';
    const actionCreateVpcEndpointServiceName = 'fakedata';
    describe('#getCreateVpcEndpoint - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateVpcEndpoint(null, null, actionCreateVpcEndpointVpcId, actionCreateVpcEndpointServiceName, null, null, null, null, null, null, actionCreateVpcEndpointAction, actionCreateVpcEndpointVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.VpcEndpoint);
              assert.equal('string', data.response.clientToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateVpcEndpoint', 'getCreateVpcEndpoint', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateVpcEndpointConnectionNotificationAction = 'fakedata';
    const actionCreateVpcEndpointConnectionNotificationVersion = 'fakedata';
    const actionCreateVpcEndpointConnectionNotificationBodyFormData = 'fakedata';
    describe('#postCreateVpcEndpointConnectionNotification - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateVpcEndpointConnectionNotification(actionCreateVpcEndpointConnectionNotificationAction, actionCreateVpcEndpointConnectionNotificationVersion, actionCreateVpcEndpointConnectionNotificationBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.ConnectionNotification);
              assert.equal('string', data.response.clientToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateVpcEndpointConnectionNotification', 'postCreateVpcEndpointConnectionNotification', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateVpcEndpointConnectionNotificationConnectionNotificationArn = 'fakedata';
    const actionCreateVpcEndpointConnectionNotificationConnectionEvents = [];
    describe('#getCreateVpcEndpointConnectionNotification - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateVpcEndpointConnectionNotification(null, null, null, actionCreateVpcEndpointConnectionNotificationConnectionNotificationArn, actionCreateVpcEndpointConnectionNotificationConnectionEvents, null, actionCreateVpcEndpointConnectionNotificationAction, actionCreateVpcEndpointConnectionNotificationVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.ConnectionNotification);
              assert.equal('string', data.response.clientToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateVpcEndpointConnectionNotification', 'getCreateVpcEndpointConnectionNotification', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateVpcEndpointServiceConfigurationAction = 'fakedata';
    const actionCreateVpcEndpointServiceConfigurationVersion = 'fakedata';
    const actionCreateVpcEndpointServiceConfigurationBodyFormData = 'fakedata';
    describe('#postCreateVpcEndpointServiceConfiguration - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateVpcEndpointServiceConfiguration(actionCreateVpcEndpointServiceConfigurationAction, actionCreateVpcEndpointServiceConfigurationVersion, actionCreateVpcEndpointServiceConfigurationBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.ServiceConfiguration);
              assert.equal('string', data.response.clientToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateVpcEndpointServiceConfiguration', 'postCreateVpcEndpointServiceConfiguration', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateVpcEndpointServiceConfigurationNetworkLoadBalancerArn = [];
    describe('#getCreateVpcEndpointServiceConfiguration - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateVpcEndpointServiceConfiguration(null, null, actionCreateVpcEndpointServiceConfigurationNetworkLoadBalancerArn, null, actionCreateVpcEndpointServiceConfigurationAction, actionCreateVpcEndpointServiceConfigurationVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.ServiceConfiguration);
              assert.equal('string', data.response.clientToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateVpcEndpointServiceConfiguration', 'getCreateVpcEndpointServiceConfiguration', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateVpcPeeringConnectionAction = 'fakedata';
    const actionCreateVpcPeeringConnectionVersion = 'fakedata';
    describe('#postCreateVpcPeeringConnection - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateVpcPeeringConnection(actionCreateVpcPeeringConnectionAction, actionCreateVpcPeeringConnectionVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.VpcPeeringConnection);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateVpcPeeringConnection', 'postCreateVpcPeeringConnection', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getCreateVpcPeeringConnection - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateVpcPeeringConnection(null, null, null, null, null, actionCreateVpcPeeringConnectionAction, actionCreateVpcPeeringConnectionVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.VpcPeeringConnection);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateVpcPeeringConnection', 'getCreateVpcPeeringConnection', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateVpnConnectionAction = 'fakedata';
    const actionCreateVpnConnectionVersion = 'fakedata';
    const actionCreateVpnConnectionBodyFormData = 'fakedata';
    describe('#postCreateVpnConnection - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateVpnConnection(actionCreateVpnConnectionAction, actionCreateVpnConnectionVersion, actionCreateVpnConnectionBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.VpnConnection);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateVpnConnection', 'postCreateVpnConnection', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateVpnConnectionCustomerGatewayId = 'fakedata';
    const actionCreateVpnConnectionType = 'fakedata';
    describe('#getCreateVpnConnection - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateVpnConnection(actionCreateVpnConnectionCustomerGatewayId, actionCreateVpnConnectionType, null, null, null, null, null, actionCreateVpnConnectionAction, actionCreateVpnConnectionVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.VpnConnection);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateVpnConnection', 'getCreateVpnConnection', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateVpnConnectionRouteAction = 'fakedata';
    const actionCreateVpnConnectionRouteVersion = 'fakedata';
    const actionCreateVpnConnectionRouteBodyFormData = 'fakedata';
    describe('#postCreateVpnConnectionRoute - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateVpnConnectionRoute(actionCreateVpnConnectionRouteAction, actionCreateVpnConnectionRouteVersion, actionCreateVpnConnectionRouteBodyFormData, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateVpnConnectionRoute', 'postCreateVpnConnectionRoute', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateVpnConnectionRouteDestinationCidrBlock = 'fakedata';
    const actionCreateVpnConnectionRouteVpnConnectionId = 'fakedata';
    describe('#getCreateVpnConnectionRoute - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateVpnConnectionRoute(actionCreateVpnConnectionRouteDestinationCidrBlock, actionCreateVpnConnectionRouteVpnConnectionId, actionCreateVpnConnectionRouteAction, actionCreateVpnConnectionRouteVersion, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateVpnConnectionRoute', 'getCreateVpnConnectionRoute', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateVpnGatewayAction = 'fakedata';
    const actionCreateVpnGatewayVersion = 'fakedata';
    const actionCreateVpnGatewayBodyFormData = 'fakedata';
    describe('#postCreateVpnGateway - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateVpnGateway(actionCreateVpnGatewayAction, actionCreateVpnGatewayVersion, actionCreateVpnGatewayBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.VpnGateway);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateVpnGateway', 'postCreateVpnGateway', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionCreateVpnGatewayType = 'fakedata';
    describe('#getCreateVpnGateway - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateVpnGateway(null, actionCreateVpnGatewayType, null, null, actionCreateVpnGatewayAction, actionCreateVpnGatewayVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.VpnGateway);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionCreateVpnGateway', 'getCreateVpnGateway', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeleteClientVpnEndpointAction = 'fakedata';
    const actionDeleteClientVpnEndpointVersion = 'fakedata';
    const actionDeleteClientVpnEndpointBodyFormData = 'fakedata';
    describe('#postDeleteClientVpnEndpoint - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteClientVpnEndpoint(actionDeleteClientVpnEndpointAction, actionDeleteClientVpnEndpointVersion, actionDeleteClientVpnEndpointBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.Status);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeleteClientVpnEndpoint', 'postDeleteClientVpnEndpoint', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeleteClientVpnEndpointClientVpnEndpointId = 'fakedata';
    describe('#getDeleteClientVpnEndpoint - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteClientVpnEndpoint(actionDeleteClientVpnEndpointClientVpnEndpointId, null, actionDeleteClientVpnEndpointAction, actionDeleteClientVpnEndpointVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.Status);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeleteClientVpnEndpoint', 'getDeleteClientVpnEndpoint', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeleteClientVpnRouteAction = 'fakedata';
    const actionDeleteClientVpnRouteVersion = 'fakedata';
    const actionDeleteClientVpnRouteBodyFormData = 'fakedata';
    describe('#postDeleteClientVpnRoute - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteClientVpnRoute(actionDeleteClientVpnRouteAction, actionDeleteClientVpnRouteVersion, actionDeleteClientVpnRouteBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.Status);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeleteClientVpnRoute', 'postDeleteClientVpnRoute', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeleteClientVpnRouteClientVpnEndpointId = 'fakedata';
    const actionDeleteClientVpnRouteDestinationCidrBlock = 'fakedata';
    describe('#getDeleteClientVpnRoute - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteClientVpnRoute(actionDeleteClientVpnRouteClientVpnEndpointId, null, actionDeleteClientVpnRouteDestinationCidrBlock, null, actionDeleteClientVpnRouteAction, actionDeleteClientVpnRouteVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.Status);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeleteClientVpnRoute', 'getDeleteClientVpnRoute', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeleteCustomerGatewayAction = 'fakedata';
    const actionDeleteCustomerGatewayVersion = 'fakedata';
    const actionDeleteCustomerGatewayBodyFormData = 'fakedata';
    describe('#postDeleteCustomerGateway - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteCustomerGateway(actionDeleteCustomerGatewayAction, actionDeleteCustomerGatewayVersion, actionDeleteCustomerGatewayBodyFormData, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeleteCustomerGateway', 'postDeleteCustomerGateway', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeleteCustomerGatewayCustomerGatewayId = 'fakedata';
    describe('#getDeleteCustomerGateway - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteCustomerGateway(actionDeleteCustomerGatewayCustomerGatewayId, null, actionDeleteCustomerGatewayAction, actionDeleteCustomerGatewayVersion, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeleteCustomerGateway', 'getDeleteCustomerGateway', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeleteDhcpOptionsAction = 'fakedata';
    const actionDeleteDhcpOptionsVersion = 'fakedata';
    const actionDeleteDhcpOptionsBodyFormData = 'fakedata';
    describe('#postDeleteDhcpOptions - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteDhcpOptions(actionDeleteDhcpOptionsAction, actionDeleteDhcpOptionsVersion, actionDeleteDhcpOptionsBodyFormData, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeleteDhcpOptions', 'postDeleteDhcpOptions', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeleteDhcpOptionsDhcpOptionsId = 'fakedata';
    describe('#getDeleteDhcpOptions - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteDhcpOptions(actionDeleteDhcpOptionsDhcpOptionsId, null, actionDeleteDhcpOptionsAction, actionDeleteDhcpOptionsVersion, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeleteDhcpOptions', 'getDeleteDhcpOptions', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeleteEgressOnlyInternetGatewayAction = 'fakedata';
    const actionDeleteEgressOnlyInternetGatewayVersion = 'fakedata';
    const actionDeleteEgressOnlyInternetGatewayBodyFormData = 'fakedata';
    describe('#postDeleteEgressOnlyInternetGateway - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteEgressOnlyInternetGateway(actionDeleteEgressOnlyInternetGatewayAction, actionDeleteEgressOnlyInternetGatewayVersion, actionDeleteEgressOnlyInternetGatewayBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(false, data.response.ReturnCode);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeleteEgressOnlyInternetGateway', 'postDeleteEgressOnlyInternetGateway', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeleteEgressOnlyInternetGatewayEgressOnlyInternetGatewayId = 'fakedata';
    describe('#getDeleteEgressOnlyInternetGateway - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteEgressOnlyInternetGateway(null, actionDeleteEgressOnlyInternetGatewayEgressOnlyInternetGatewayId, actionDeleteEgressOnlyInternetGatewayAction, actionDeleteEgressOnlyInternetGatewayVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, data.response.ReturnCode);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeleteEgressOnlyInternetGateway', 'getDeleteEgressOnlyInternetGateway', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeleteFleetsAction = 'fakedata';
    const actionDeleteFleetsVersion = 'fakedata';
    const actionDeleteFleetsBodyFormData = 'fakedata';
    describe('#postDeleteFleets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteFleets(actionDeleteFleetsAction, actionDeleteFleetsVersion, actionDeleteFleetsBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.SuccessfulFleetDeletions));
              assert.equal(true, Array.isArray(data.response.UnsuccessfulFleetDeletions));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeleteFleets', 'postDeleteFleets', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeleteFleetsFleetId = [];
    const actionDeleteFleetsTerminateInstances = true;
    describe('#getDeleteFleets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteFleets(null, actionDeleteFleetsFleetId, actionDeleteFleetsTerminateInstances, actionDeleteFleetsAction, actionDeleteFleetsVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.SuccessfulFleetDeletions));
              assert.equal(true, Array.isArray(data.response.UnsuccessfulFleetDeletions));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeleteFleets', 'getDeleteFleets', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeleteFlowLogsAction = 'fakedata';
    const actionDeleteFlowLogsVersion = 'fakedata';
    const actionDeleteFlowLogsBodyFormData = 'fakedata';
    describe('#postDeleteFlowLogs - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteFlowLogs(actionDeleteFlowLogsAction, actionDeleteFlowLogsVersion, actionDeleteFlowLogsBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.Unsuccessful));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeleteFlowLogs', 'postDeleteFlowLogs', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeleteFlowLogsFlowLogId = [];
    describe('#getDeleteFlowLogs - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteFlowLogs(null, actionDeleteFlowLogsFlowLogId, actionDeleteFlowLogsAction, actionDeleteFlowLogsVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.Unsuccessful));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeleteFlowLogs', 'getDeleteFlowLogs', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeleteFpgaImageAction = 'fakedata';
    const actionDeleteFpgaImageVersion = 'fakedata';
    const actionDeleteFpgaImageBodyFormData = 'fakedata';
    describe('#postDeleteFpgaImage - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteFpgaImage(actionDeleteFpgaImageAction, actionDeleteFpgaImageVersion, actionDeleteFpgaImageBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(false, data.response.Return);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeleteFpgaImage', 'postDeleteFpgaImage', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeleteFpgaImageFpgaImageId = 'fakedata';
    describe('#getDeleteFpgaImage - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteFpgaImage(null, actionDeleteFpgaImageFpgaImageId, actionDeleteFpgaImageAction, actionDeleteFpgaImageVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, data.response.Return);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeleteFpgaImage', 'getDeleteFpgaImage', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeleteInternetGatewayAction = 'fakedata';
    const actionDeleteInternetGatewayVersion = 'fakedata';
    const actionDeleteInternetGatewayBodyFormData = 'fakedata';
    describe('#postDeleteInternetGateway - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteInternetGateway(actionDeleteInternetGatewayAction, actionDeleteInternetGatewayVersion, actionDeleteInternetGatewayBodyFormData, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeleteInternetGateway', 'postDeleteInternetGateway', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeleteInternetGatewayInternetGatewayId = 'fakedata';
    describe('#getDeleteInternetGateway - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteInternetGateway(null, actionDeleteInternetGatewayInternetGatewayId, actionDeleteInternetGatewayAction, actionDeleteInternetGatewayVersion, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeleteInternetGateway', 'getDeleteInternetGateway', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeleteKeyPairAction = 'fakedata';
    const actionDeleteKeyPairVersion = 'fakedata';
    const actionDeleteKeyPairBodyFormData = 'fakedata';
    describe('#postDeleteKeyPair - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteKeyPair(actionDeleteKeyPairAction, actionDeleteKeyPairVersion, actionDeleteKeyPairBodyFormData, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeleteKeyPair', 'postDeleteKeyPair', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeleteKeyPairKeyName = 'fakedata';
    describe('#getDeleteKeyPair - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteKeyPair(actionDeleteKeyPairKeyName, null, actionDeleteKeyPairAction, actionDeleteKeyPairVersion, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeleteKeyPair', 'getDeleteKeyPair', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeleteLaunchTemplateAction = 'fakedata';
    const actionDeleteLaunchTemplateVersion = 'fakedata';
    describe('#postDeleteLaunchTemplate - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteLaunchTemplate(actionDeleteLaunchTemplateAction, actionDeleteLaunchTemplateVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.LaunchTemplate);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeleteLaunchTemplate', 'postDeleteLaunchTemplate', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDeleteLaunchTemplate - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteLaunchTemplate(null, null, null, actionDeleteLaunchTemplateAction, actionDeleteLaunchTemplateVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.LaunchTemplate);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeleteLaunchTemplate', 'getDeleteLaunchTemplate', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeleteLaunchTemplateVersionsAction = 'fakedata';
    const actionDeleteLaunchTemplateVersionsVersion = 'fakedata';
    const actionDeleteLaunchTemplateVersionsBodyFormData = 'fakedata';
    describe('#postDeleteLaunchTemplateVersions - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteLaunchTemplateVersions(actionDeleteLaunchTemplateVersionsAction, actionDeleteLaunchTemplateVersionsVersion, actionDeleteLaunchTemplateVersionsBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.SuccessfullyDeletedLaunchTemplateVersions));
              assert.equal(true, Array.isArray(data.response.UnsuccessfullyDeletedLaunchTemplateVersions));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeleteLaunchTemplateVersions', 'postDeleteLaunchTemplateVersions', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeleteLaunchTemplateVersionsLaunchTemplateVersion = [];
    describe('#getDeleteLaunchTemplateVersions - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteLaunchTemplateVersions(null, null, null, actionDeleteLaunchTemplateVersionsLaunchTemplateVersion, actionDeleteLaunchTemplateVersionsAction, actionDeleteLaunchTemplateVersionsVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.SuccessfullyDeletedLaunchTemplateVersions));
              assert.equal(true, Array.isArray(data.response.UnsuccessfullyDeletedLaunchTemplateVersions));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeleteLaunchTemplateVersions', 'getDeleteLaunchTemplateVersions', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    let actionDeleteNatGatewayNatGatewayId = 'fakedata';
    const actionDeleteNatGatewayAction = 'fakedata';
    const actionDeleteNatGatewayVersion = 'fakedata';
    const actionDeleteNatGatewayBodyFormData = 'fakedata';
    describe('#postDeleteNatGateway - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteNatGateway(actionDeleteNatGatewayAction, actionDeleteNatGatewayVersion, actionDeleteNatGatewayBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.natGatewayId);
            } else {
              runCommonAsserts(data, error);
            }
            actionDeleteNatGatewayNatGatewayId = data.response.natGatewayId;
            saveMockData('ActionDeleteNatGateway', 'postDeleteNatGateway', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDeleteNatGateway - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteNatGateway(actionDeleteNatGatewayNatGatewayId, actionDeleteNatGatewayAction, actionDeleteNatGatewayVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.natGatewayId);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeleteNatGateway', 'getDeleteNatGateway', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeleteNetworkAclAction = 'fakedata';
    const actionDeleteNetworkAclVersion = 'fakedata';
    const actionDeleteNetworkAclBodyFormData = 'fakedata';
    describe('#postDeleteNetworkAcl - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteNetworkAcl(actionDeleteNetworkAclAction, actionDeleteNetworkAclVersion, actionDeleteNetworkAclBodyFormData, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeleteNetworkAcl', 'postDeleteNetworkAcl', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeleteNetworkAclNetworkAclId = 'fakedata';
    describe('#getDeleteNetworkAcl - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteNetworkAcl(null, actionDeleteNetworkAclNetworkAclId, actionDeleteNetworkAclAction, actionDeleteNetworkAclVersion, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeleteNetworkAcl', 'getDeleteNetworkAcl', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeleteNetworkAclEntryAction = 'fakedata';
    const actionDeleteNetworkAclEntryVersion = 'fakedata';
    const actionDeleteNetworkAclEntryBodyFormData = 'fakedata';
    describe('#postDeleteNetworkAclEntry - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteNetworkAclEntry(actionDeleteNetworkAclEntryAction, actionDeleteNetworkAclEntryVersion, actionDeleteNetworkAclEntryBodyFormData, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeleteNetworkAclEntry', 'postDeleteNetworkAclEntry', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeleteNetworkAclEntryEgress = true;
    const actionDeleteNetworkAclEntryNetworkAclId = 'fakedata';
    const actionDeleteNetworkAclEntryRuleNumber = 555;
    describe('#getDeleteNetworkAclEntry - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteNetworkAclEntry(null, actionDeleteNetworkAclEntryEgress, actionDeleteNetworkAclEntryNetworkAclId, actionDeleteNetworkAclEntryRuleNumber, actionDeleteNetworkAclEntryAction, actionDeleteNetworkAclEntryVersion, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeleteNetworkAclEntry', 'getDeleteNetworkAclEntry', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeleteNetworkInterfaceAction = 'fakedata';
    const actionDeleteNetworkInterfaceVersion = 'fakedata';
    const actionDeleteNetworkInterfaceBodyFormData = 'fakedata';
    describe('#postDeleteNetworkInterface - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteNetworkInterface(actionDeleteNetworkInterfaceAction, actionDeleteNetworkInterfaceVersion, actionDeleteNetworkInterfaceBodyFormData, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeleteNetworkInterface', 'postDeleteNetworkInterface', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeleteNetworkInterfaceNetworkInterfaceId = 'fakedata';
    describe('#getDeleteNetworkInterface - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteNetworkInterface(null, actionDeleteNetworkInterfaceNetworkInterfaceId, actionDeleteNetworkInterfaceAction, actionDeleteNetworkInterfaceVersion, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeleteNetworkInterface', 'getDeleteNetworkInterface', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeleteNetworkInterfacePermissionAction = 'fakedata';
    const actionDeleteNetworkInterfacePermissionVersion = 'fakedata';
    const actionDeleteNetworkInterfacePermissionBodyFormData = 'fakedata';
    describe('#postDeleteNetworkInterfacePermission - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteNetworkInterfacePermission(actionDeleteNetworkInterfacePermissionAction, actionDeleteNetworkInterfacePermissionVersion, actionDeleteNetworkInterfacePermissionBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, data.response.Return);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeleteNetworkInterfacePermission', 'postDeleteNetworkInterfacePermission', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeleteNetworkInterfacePermissionNetworkInterfacePermissionId = 'fakedata';
    describe('#getDeleteNetworkInterfacePermission - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteNetworkInterfacePermission(actionDeleteNetworkInterfacePermissionNetworkInterfacePermissionId, null, null, actionDeleteNetworkInterfacePermissionAction, actionDeleteNetworkInterfacePermissionVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, data.response.Return);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeleteNetworkInterfacePermission', 'getDeleteNetworkInterfacePermission', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeletePlacementGroupAction = 'fakedata';
    const actionDeletePlacementGroupVersion = 'fakedata';
    const actionDeletePlacementGroupBodyFormData = 'fakedata';
    describe('#postDeletePlacementGroup - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postDeletePlacementGroup(actionDeletePlacementGroupAction, actionDeletePlacementGroupVersion, actionDeletePlacementGroupBodyFormData, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeletePlacementGroup', 'postDeletePlacementGroup', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeletePlacementGroupGroupName = 'fakedata';
    describe('#getDeletePlacementGroup - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getDeletePlacementGroup(null, actionDeletePlacementGroupGroupName, actionDeletePlacementGroupAction, actionDeletePlacementGroupVersion, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeletePlacementGroup', 'getDeletePlacementGroup', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeleteRouteAction = 'fakedata';
    const actionDeleteRouteVersion = 'fakedata';
    const actionDeleteRouteBodyFormData = 'fakedata';
    describe('#postDeleteRoute - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteRoute(actionDeleteRouteAction, actionDeleteRouteVersion, actionDeleteRouteBodyFormData, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeleteRoute', 'postDeleteRoute', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeleteRouteRouteTableId = 'fakedata';
    describe('#getDeleteRoute - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteRoute(null, null, null, actionDeleteRouteRouteTableId, actionDeleteRouteAction, actionDeleteRouteVersion, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeleteRoute', 'getDeleteRoute', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeleteRouteTableAction = 'fakedata';
    const actionDeleteRouteTableVersion = 'fakedata';
    const actionDeleteRouteTableBodyFormData = 'fakedata';
    describe('#postDeleteRouteTable - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteRouteTable(actionDeleteRouteTableAction, actionDeleteRouteTableVersion, actionDeleteRouteTableBodyFormData, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeleteRouteTable', 'postDeleteRouteTable', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeleteRouteTableRouteTableId = 'fakedata';
    describe('#getDeleteRouteTable - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteRouteTable(null, actionDeleteRouteTableRouteTableId, actionDeleteRouteTableAction, actionDeleteRouteTableVersion, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeleteRouteTable', 'getDeleteRouteTable', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeleteSecurityGroupAction = 'fakedata';
    const actionDeleteSecurityGroupVersion = 'fakedata';
    describe('#postDeleteSecurityGroup - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteSecurityGroup(actionDeleteSecurityGroupAction, actionDeleteSecurityGroupVersion, null, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeleteSecurityGroup', 'postDeleteSecurityGroup', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDeleteSecurityGroup - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteSecurityGroup(null, null, null, actionDeleteSecurityGroupAction, actionDeleteSecurityGroupVersion, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeleteSecurityGroup', 'getDeleteSecurityGroup', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeleteSnapshotAction = 'fakedata';
    const actionDeleteSnapshotVersion = 'fakedata';
    const actionDeleteSnapshotBodyFormData = 'fakedata';
    describe('#postDeleteSnapshot - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteSnapshot(actionDeleteSnapshotAction, actionDeleteSnapshotVersion, actionDeleteSnapshotBodyFormData, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeleteSnapshot', 'postDeleteSnapshot', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeleteSnapshotSnapshotId = 'fakedata';
    describe('#getDeleteSnapshot - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteSnapshot(actionDeleteSnapshotSnapshotId, null, actionDeleteSnapshotAction, actionDeleteSnapshotVersion, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeleteSnapshot', 'getDeleteSnapshot', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeleteSpotDatafeedSubscriptionAction = 'fakedata';
    const actionDeleteSpotDatafeedSubscriptionVersion = 'fakedata';
    describe('#postDeleteSpotDatafeedSubscription - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteSpotDatafeedSubscription(actionDeleteSpotDatafeedSubscriptionAction, actionDeleteSpotDatafeedSubscriptionVersion, null, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeleteSpotDatafeedSubscription', 'postDeleteSpotDatafeedSubscription', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDeleteSpotDatafeedSubscription - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteSpotDatafeedSubscription(null, actionDeleteSpotDatafeedSubscriptionAction, actionDeleteSpotDatafeedSubscriptionVersion, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeleteSpotDatafeedSubscription', 'getDeleteSpotDatafeedSubscription', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeleteSubnetAction = 'fakedata';
    const actionDeleteSubnetVersion = 'fakedata';
    const actionDeleteSubnetBodyFormData = 'fakedata';
    describe('#postDeleteSubnet - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteSubnet(actionDeleteSubnetAction, actionDeleteSubnetVersion, actionDeleteSubnetBodyFormData, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeleteSubnet', 'postDeleteSubnet', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeleteSubnetSubnetId = 'fakedata';
    describe('#getDeleteSubnet - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteSubnet(actionDeleteSubnetSubnetId, null, actionDeleteSubnetAction, actionDeleteSubnetVersion, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeleteSubnet', 'getDeleteSubnet', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeleteTagsAction = 'fakedata';
    const actionDeleteTagsVersion = 'fakedata';
    const actionDeleteTagsBodyFormData = 'fakedata';
    describe('#postDeleteTags - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteTags(actionDeleteTagsAction, actionDeleteTagsVersion, actionDeleteTagsBodyFormData, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeleteTags', 'postDeleteTags', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeleteTagsResourceId = [];
    describe('#getDeleteTags - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteTags(null, actionDeleteTagsResourceId, null, actionDeleteTagsAction, actionDeleteTagsVersion, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeleteTags', 'getDeleteTags', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeleteTransitGatewayAction = 'fakedata';
    const actionDeleteTransitGatewayVersion = 'fakedata';
    const actionDeleteTransitGatewayBodyFormData = 'fakedata';
    describe('#postDeleteTransitGateway - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteTransitGateway(actionDeleteTransitGatewayAction, actionDeleteTransitGatewayVersion, actionDeleteTransitGatewayBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.TransitGateway);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeleteTransitGateway', 'postDeleteTransitGateway', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeleteTransitGatewayTransitGatewayId = 'fakedata';
    describe('#getDeleteTransitGateway - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteTransitGateway(actionDeleteTransitGatewayTransitGatewayId, null, actionDeleteTransitGatewayAction, actionDeleteTransitGatewayVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.TransitGateway);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeleteTransitGateway', 'getDeleteTransitGateway', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeleteTransitGatewayRouteAction = 'fakedata';
    const actionDeleteTransitGatewayRouteVersion = 'fakedata';
    const actionDeleteTransitGatewayRouteBodyFormData = 'fakedata';
    describe('#postDeleteTransitGatewayRoute - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteTransitGatewayRoute(actionDeleteTransitGatewayRouteAction, actionDeleteTransitGatewayRouteVersion, actionDeleteTransitGatewayRouteBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.Route);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeleteTransitGatewayRoute', 'postDeleteTransitGatewayRoute', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeleteTransitGatewayRouteTransitGatewayRouteTableId = 'fakedata';
    const actionDeleteTransitGatewayRouteDestinationCidrBlock = 'fakedata';
    describe('#getDeleteTransitGatewayRoute - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteTransitGatewayRoute(actionDeleteTransitGatewayRouteTransitGatewayRouteTableId, actionDeleteTransitGatewayRouteDestinationCidrBlock, null, actionDeleteTransitGatewayRouteAction, actionDeleteTransitGatewayRouteVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.Route);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeleteTransitGatewayRoute', 'getDeleteTransitGatewayRoute', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeleteTransitGatewayRouteTableAction = 'fakedata';
    const actionDeleteTransitGatewayRouteTableVersion = 'fakedata';
    const actionDeleteTransitGatewayRouteTableBodyFormData = 'fakedata';
    describe('#postDeleteTransitGatewayRouteTable - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteTransitGatewayRouteTable(actionDeleteTransitGatewayRouteTableAction, actionDeleteTransitGatewayRouteTableVersion, actionDeleteTransitGatewayRouteTableBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.TransitGatewayRouteTable);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeleteTransitGatewayRouteTable', 'postDeleteTransitGatewayRouteTable', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeleteTransitGatewayRouteTableTransitGatewayRouteTableId = 'fakedata';
    describe('#getDeleteTransitGatewayRouteTable - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteTransitGatewayRouteTable(actionDeleteTransitGatewayRouteTableTransitGatewayRouteTableId, null, actionDeleteTransitGatewayRouteTableAction, actionDeleteTransitGatewayRouteTableVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.TransitGatewayRouteTable);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeleteTransitGatewayRouteTable', 'getDeleteTransitGatewayRouteTable', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeleteTransitGatewayVpcAttachmentAction = 'fakedata';
    const actionDeleteTransitGatewayVpcAttachmentVersion = 'fakedata';
    const actionDeleteTransitGatewayVpcAttachmentBodyFormData = 'fakedata';
    describe('#postDeleteTransitGatewayVpcAttachment - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteTransitGatewayVpcAttachment(actionDeleteTransitGatewayVpcAttachmentAction, actionDeleteTransitGatewayVpcAttachmentVersion, actionDeleteTransitGatewayVpcAttachmentBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.TransitGatewayVpcAttachment);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeleteTransitGatewayVpcAttachment', 'postDeleteTransitGatewayVpcAttachment', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeleteTransitGatewayVpcAttachmentTransitGatewayAttachmentId = 'fakedata';
    describe('#getDeleteTransitGatewayVpcAttachment - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteTransitGatewayVpcAttachment(actionDeleteTransitGatewayVpcAttachmentTransitGatewayAttachmentId, null, actionDeleteTransitGatewayVpcAttachmentAction, actionDeleteTransitGatewayVpcAttachmentVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.TransitGatewayVpcAttachment);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeleteTransitGatewayVpcAttachment', 'getDeleteTransitGatewayVpcAttachment', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeleteVolumeAction = 'fakedata';
    const actionDeleteVolumeVersion = 'fakedata';
    const actionDeleteVolumeBodyFormData = 'fakedata';
    describe('#postDeleteVolume - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteVolume(actionDeleteVolumeAction, actionDeleteVolumeVersion, actionDeleteVolumeBodyFormData, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeleteVolume', 'postDeleteVolume', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeleteVolumeVolumeId = 'fakedata';
    describe('#getDeleteVolume - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteVolume(actionDeleteVolumeVolumeId, null, actionDeleteVolumeAction, actionDeleteVolumeVersion, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeleteVolume', 'getDeleteVolume', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeleteVpcAction = 'fakedata';
    const actionDeleteVpcVersion = 'fakedata';
    const actionDeleteVpcBodyFormData = 'fakedata';
    describe('#postDeleteVpc - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteVpc(actionDeleteVpcAction, actionDeleteVpcVersion, actionDeleteVpcBodyFormData, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeleteVpc', 'postDeleteVpc', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeleteVpcVpcId = 'fakedata';
    describe('#getDeleteVpc - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteVpc(actionDeleteVpcVpcId, null, actionDeleteVpcAction, actionDeleteVpcVersion, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeleteVpc', 'getDeleteVpc', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeleteVpcEndpointConnectionNotificationsAction = 'fakedata';
    const actionDeleteVpcEndpointConnectionNotificationsVersion = 'fakedata';
    const actionDeleteVpcEndpointConnectionNotificationsBodyFormData = 'fakedata';
    describe('#postDeleteVpcEndpointConnectionNotifications - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteVpcEndpointConnectionNotifications(actionDeleteVpcEndpointConnectionNotificationsAction, actionDeleteVpcEndpointConnectionNotificationsVersion, actionDeleteVpcEndpointConnectionNotificationsBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.Unsuccessful));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeleteVpcEndpointConnectionNotifications', 'postDeleteVpcEndpointConnectionNotifications', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeleteVpcEndpointConnectionNotificationsConnectionNotificationId = [];
    describe('#getDeleteVpcEndpointConnectionNotifications - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteVpcEndpointConnectionNotifications(null, actionDeleteVpcEndpointConnectionNotificationsConnectionNotificationId, actionDeleteVpcEndpointConnectionNotificationsAction, actionDeleteVpcEndpointConnectionNotificationsVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.Unsuccessful));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeleteVpcEndpointConnectionNotifications', 'getDeleteVpcEndpointConnectionNotifications', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeleteVpcEndpointServiceConfigurationsAction = 'fakedata';
    const actionDeleteVpcEndpointServiceConfigurationsVersion = 'fakedata';
    const actionDeleteVpcEndpointServiceConfigurationsBodyFormData = 'fakedata';
    describe('#postDeleteVpcEndpointServiceConfigurations - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteVpcEndpointServiceConfigurations(actionDeleteVpcEndpointServiceConfigurationsAction, actionDeleteVpcEndpointServiceConfigurationsVersion, actionDeleteVpcEndpointServiceConfigurationsBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.Unsuccessful));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeleteVpcEndpointServiceConfigurations', 'postDeleteVpcEndpointServiceConfigurations', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeleteVpcEndpointServiceConfigurationsServiceId = [];
    describe('#getDeleteVpcEndpointServiceConfigurations - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteVpcEndpointServiceConfigurations(null, actionDeleteVpcEndpointServiceConfigurationsServiceId, actionDeleteVpcEndpointServiceConfigurationsAction, actionDeleteVpcEndpointServiceConfigurationsVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.Unsuccessful));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeleteVpcEndpointServiceConfigurations', 'getDeleteVpcEndpointServiceConfigurations', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeleteVpcEndpointsAction = 'fakedata';
    const actionDeleteVpcEndpointsVersion = 'fakedata';
    const actionDeleteVpcEndpointsBodyFormData = 'fakedata';
    describe('#postDeleteVpcEndpoints - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteVpcEndpoints(actionDeleteVpcEndpointsAction, actionDeleteVpcEndpointsVersion, actionDeleteVpcEndpointsBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.Unsuccessful));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeleteVpcEndpoints', 'postDeleteVpcEndpoints', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeleteVpcEndpointsVpcEndpointId = [];
    describe('#getDeleteVpcEndpoints - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteVpcEndpoints(null, actionDeleteVpcEndpointsVpcEndpointId, actionDeleteVpcEndpointsAction, actionDeleteVpcEndpointsVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.Unsuccessful));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeleteVpcEndpoints', 'getDeleteVpcEndpoints', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeleteVpcPeeringConnectionAction = 'fakedata';
    const actionDeleteVpcPeeringConnectionVersion = 'fakedata';
    const actionDeleteVpcPeeringConnectionBodyFormData = 'fakedata';
    describe('#postDeleteVpcPeeringConnection - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteVpcPeeringConnection(actionDeleteVpcPeeringConnectionAction, actionDeleteVpcPeeringConnectionVersion, actionDeleteVpcPeeringConnectionBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, data.response.Return);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeleteVpcPeeringConnection', 'postDeleteVpcPeeringConnection', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeleteVpcPeeringConnectionVpcPeeringConnectionId = 'fakedata';
    describe('#getDeleteVpcPeeringConnection - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteVpcPeeringConnection(null, actionDeleteVpcPeeringConnectionVpcPeeringConnectionId, actionDeleteVpcPeeringConnectionAction, actionDeleteVpcPeeringConnectionVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(false, data.response.Return);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeleteVpcPeeringConnection', 'getDeleteVpcPeeringConnection', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeleteVpnConnectionAction = 'fakedata';
    const actionDeleteVpnConnectionVersion = 'fakedata';
    const actionDeleteVpnConnectionBodyFormData = 'fakedata';
    describe('#postDeleteVpnConnection - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteVpnConnection(actionDeleteVpnConnectionAction, actionDeleteVpnConnectionVersion, actionDeleteVpnConnectionBodyFormData, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeleteVpnConnection', 'postDeleteVpnConnection', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeleteVpnConnectionVpnConnectionId = 'fakedata';
    describe('#getDeleteVpnConnection - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteVpnConnection(actionDeleteVpnConnectionVpnConnectionId, null, actionDeleteVpnConnectionAction, actionDeleteVpnConnectionVersion, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeleteVpnConnection', 'getDeleteVpnConnection', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeleteVpnConnectionRouteAction = 'fakedata';
    const actionDeleteVpnConnectionRouteVersion = 'fakedata';
    const actionDeleteVpnConnectionRouteBodyFormData = 'fakedata';
    describe('#postDeleteVpnConnectionRoute - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteVpnConnectionRoute(actionDeleteVpnConnectionRouteAction, actionDeleteVpnConnectionRouteVersion, actionDeleteVpnConnectionRouteBodyFormData, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeleteVpnConnectionRoute', 'postDeleteVpnConnectionRoute', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeleteVpnConnectionRouteDestinationCidrBlock = 'fakedata';
    const actionDeleteVpnConnectionRouteVpnConnectionId = 'fakedata';
    describe('#getDeleteVpnConnectionRoute - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteVpnConnectionRoute(actionDeleteVpnConnectionRouteDestinationCidrBlock, actionDeleteVpnConnectionRouteVpnConnectionId, actionDeleteVpnConnectionRouteAction, actionDeleteVpnConnectionRouteVersion, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeleteVpnConnectionRoute', 'getDeleteVpnConnectionRoute', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeleteVpnGatewayAction = 'fakedata';
    const actionDeleteVpnGatewayVersion = 'fakedata';
    const actionDeleteVpnGatewayBodyFormData = 'fakedata';
    describe('#postDeleteVpnGateway - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteVpnGateway(actionDeleteVpnGatewayAction, actionDeleteVpnGatewayVersion, actionDeleteVpnGatewayBodyFormData, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeleteVpnGateway', 'postDeleteVpnGateway', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeleteVpnGatewayVpnGatewayId = 'fakedata';
    describe('#getDeleteVpnGateway - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteVpnGateway(actionDeleteVpnGatewayVpnGatewayId, null, actionDeleteVpnGatewayAction, actionDeleteVpnGatewayVersion, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeleteVpnGateway', 'getDeleteVpnGateway', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeprovisionByoipCidrAction = 'fakedata';
    const actionDeprovisionByoipCidrVersion = 'fakedata';
    const actionDeprovisionByoipCidrBodyFormData = 'fakedata';
    describe('#postDeprovisionByoipCidr - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDeprovisionByoipCidr(actionDeprovisionByoipCidrAction, actionDeprovisionByoipCidrVersion, actionDeprovisionByoipCidrBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.ByoipCidr);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeprovisionByoipCidr', 'postDeprovisionByoipCidr', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeprovisionByoipCidrCidr = 'fakedata';
    describe('#getDeprovisionByoipCidr - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDeprovisionByoipCidr(actionDeprovisionByoipCidrCidr, null, actionDeprovisionByoipCidrAction, actionDeprovisionByoipCidrVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.ByoipCidr);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeprovisionByoipCidr', 'getDeprovisionByoipCidr', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeregisterImageAction = 'fakedata';
    const actionDeregisterImageVersion = 'fakedata';
    const actionDeregisterImageBodyFormData = 'fakedata';
    describe('#postDeregisterImage - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postDeregisterImage(actionDeregisterImageAction, actionDeregisterImageVersion, actionDeregisterImageBodyFormData, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeregisterImage', 'postDeregisterImage', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDeregisterImageImageId = 'fakedata';
    describe('#getDeregisterImage - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getDeregisterImage(actionDeregisterImageImageId, null, actionDeregisterImageAction, actionDeregisterImageVersion, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDeregisterImage', 'getDeregisterImage', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeAccountAttributesAction = 'fakedata';
    const actionDescribeAccountAttributesVersion = 'fakedata';
    describe('#postDescribeAccountAttributes - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeAccountAttributes(actionDescribeAccountAttributesAction, actionDescribeAccountAttributesVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.AccountAttributes));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeAccountAttributes', 'postDescribeAccountAttributes', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeAccountAttributes - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeAccountAttributes(null, null, actionDescribeAccountAttributesAction, actionDescribeAccountAttributesVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.AccountAttributes));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeAccountAttributes', 'getDescribeAccountAttributes', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeAddressesAction = 'fakedata';
    const actionDescribeAddressesVersion = 'fakedata';
    describe('#postDescribeAddresses - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeAddresses(actionDescribeAddressesAction, actionDescribeAddressesVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.Addresses));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeAddresses', 'postDescribeAddresses', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeAddresses - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeAddresses(null, null, null, null, actionDescribeAddressesAction, actionDescribeAddressesVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.Addresses));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeAddresses', 'getDescribeAddresses', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeAggregateIdFormatAction = 'fakedata';
    const actionDescribeAggregateIdFormatVersion = 'fakedata';
    describe('#postDescribeAggregateIdFormat - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeAggregateIdFormat(actionDescribeAggregateIdFormatAction, actionDescribeAggregateIdFormatVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(false, data.response.UseLongIdsAggregated);
              assert.equal(true, Array.isArray(data.response.Statuses));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeAggregateIdFormat', 'postDescribeAggregateIdFormat', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeAggregateIdFormat - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeAggregateIdFormat(null, actionDescribeAggregateIdFormatAction, actionDescribeAggregateIdFormatVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, data.response.UseLongIdsAggregated);
              assert.equal(true, Array.isArray(data.response.Statuses));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeAggregateIdFormat', 'getDescribeAggregateIdFormat', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeAvailabilityZonesAction = 'fakedata';
    const actionDescribeAvailabilityZonesVersion = 'fakedata';
    describe('#postDescribeAvailabilityZones - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeAvailabilityZones(actionDescribeAvailabilityZonesAction, actionDescribeAvailabilityZonesVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.AvailabilityZones));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeAvailabilityZones', 'postDescribeAvailabilityZones', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeAvailabilityZones - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeAvailabilityZones(null, null, null, null, actionDescribeAvailabilityZonesAction, actionDescribeAvailabilityZonesVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.AvailabilityZones));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeAvailabilityZones', 'getDescribeAvailabilityZones', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeBundleTasksAction = 'fakedata';
    const actionDescribeBundleTasksVersion = 'fakedata';
    describe('#postDescribeBundleTasks - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeBundleTasks(actionDescribeBundleTasksAction, actionDescribeBundleTasksVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.BundleTasks));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeBundleTasks', 'postDescribeBundleTasks', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeBundleTasks - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeBundleTasks(null, null, null, actionDescribeBundleTasksAction, actionDescribeBundleTasksVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.BundleTasks));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeBundleTasks', 'getDescribeBundleTasks', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeByoipCidrsAction = 'fakedata';
    const actionDescribeByoipCidrsVersion = 'fakedata';
    const actionDescribeByoipCidrsBodyFormData = 'fakedata';
    describe('#postDescribeByoipCidrs - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeByoipCidrs(actionDescribeByoipCidrsAction, actionDescribeByoipCidrsVersion, actionDescribeByoipCidrsBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.ByoipCidrs));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeByoipCidrs', 'postDescribeByoipCidrs', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeByoipCidrsMaxResults = 555;
    describe('#getDescribeByoipCidrs - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeByoipCidrs(null, actionDescribeByoipCidrsMaxResults, null, actionDescribeByoipCidrsAction, actionDescribeByoipCidrsVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.ByoipCidrs));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeByoipCidrs', 'getDescribeByoipCidrs', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeCapacityReservationsAction = 'fakedata';
    const actionDescribeCapacityReservationsVersion = 'fakedata';
    describe('#postDescribeCapacityReservations - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeCapacityReservations(actionDescribeCapacityReservationsAction, actionDescribeCapacityReservationsVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.nextToken);
              assert.equal(true, Array.isArray(data.response.CapacityReservations));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeCapacityReservations', 'postDescribeCapacityReservations', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeCapacityReservations - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeCapacityReservations(null, null, null, null, null, actionDescribeCapacityReservationsAction, actionDescribeCapacityReservationsVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.nextToken);
              assert.equal(true, Array.isArray(data.response.CapacityReservations));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeCapacityReservations', 'getDescribeCapacityReservations', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeClassicLinkInstancesAction = 'fakedata';
    const actionDescribeClassicLinkInstancesVersion = 'fakedata';
    describe('#postDescribeClassicLinkInstances - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeClassicLinkInstances(actionDescribeClassicLinkInstancesAction, actionDescribeClassicLinkInstancesVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.Instances));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeClassicLinkInstances', 'postDescribeClassicLinkInstances', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeClassicLinkInstances - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeClassicLinkInstances(null, null, null, null, null, actionDescribeClassicLinkInstancesAction, actionDescribeClassicLinkInstancesVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.Instances));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeClassicLinkInstances', 'getDescribeClassicLinkInstances', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeClientVpnAuthorizationRulesAction = 'fakedata';
    const actionDescribeClientVpnAuthorizationRulesVersion = 'fakedata';
    const actionDescribeClientVpnAuthorizationRulesBodyFormData = 'fakedata';
    describe('#postDescribeClientVpnAuthorizationRules - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeClientVpnAuthorizationRules(actionDescribeClientVpnAuthorizationRulesAction, actionDescribeClientVpnAuthorizationRulesVersion, actionDescribeClientVpnAuthorizationRulesBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.AuthorizationRules));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeClientVpnAuthorizationRules', 'postDescribeClientVpnAuthorizationRules', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeClientVpnAuthorizationRulesClientVpnEndpointId = 'fakedata';
    describe('#getDescribeClientVpnAuthorizationRules - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeClientVpnAuthorizationRules(actionDescribeClientVpnAuthorizationRulesClientVpnEndpointId, null, null, null, null, actionDescribeClientVpnAuthorizationRulesAction, actionDescribeClientVpnAuthorizationRulesVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.AuthorizationRules));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeClientVpnAuthorizationRules', 'getDescribeClientVpnAuthorizationRules', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeClientVpnConnectionsAction = 'fakedata';
    const actionDescribeClientVpnConnectionsVersion = 'fakedata';
    const actionDescribeClientVpnConnectionsBodyFormData = 'fakedata';
    describe('#postDescribeClientVpnConnections - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeClientVpnConnections(actionDescribeClientVpnConnectionsAction, actionDescribeClientVpnConnectionsVersion, actionDescribeClientVpnConnectionsBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.Connections));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeClientVpnConnections', 'postDescribeClientVpnConnections', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeClientVpnConnectionsClientVpnEndpointId = 'fakedata';
    describe('#getDescribeClientVpnConnections - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeClientVpnConnections(actionDescribeClientVpnConnectionsClientVpnEndpointId, null, null, null, null, actionDescribeClientVpnConnectionsAction, actionDescribeClientVpnConnectionsVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.Connections));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeClientVpnConnections', 'getDescribeClientVpnConnections', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeClientVpnEndpointsAction = 'fakedata';
    const actionDescribeClientVpnEndpointsVersion = 'fakedata';
    describe('#postDescribeClientVpnEndpoints - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeClientVpnEndpoints(actionDescribeClientVpnEndpointsAction, actionDescribeClientVpnEndpointsVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.ClientVpnEndpoints));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeClientVpnEndpoints', 'postDescribeClientVpnEndpoints', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeClientVpnEndpoints - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeClientVpnEndpoints(null, null, null, null, null, actionDescribeClientVpnEndpointsAction, actionDescribeClientVpnEndpointsVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.ClientVpnEndpoints));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeClientVpnEndpoints', 'getDescribeClientVpnEndpoints', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeClientVpnRoutesAction = 'fakedata';
    const actionDescribeClientVpnRoutesVersion = 'fakedata';
    const actionDescribeClientVpnRoutesBodyFormData = 'fakedata';
    describe('#postDescribeClientVpnRoutes - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeClientVpnRoutes(actionDescribeClientVpnRoutesAction, actionDescribeClientVpnRoutesVersion, actionDescribeClientVpnRoutesBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.Routes));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeClientVpnRoutes', 'postDescribeClientVpnRoutes', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeClientVpnRoutesClientVpnEndpointId = 'fakedata';
    describe('#getDescribeClientVpnRoutes - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeClientVpnRoutes(actionDescribeClientVpnRoutesClientVpnEndpointId, null, null, null, null, actionDescribeClientVpnRoutesAction, actionDescribeClientVpnRoutesVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.Routes));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeClientVpnRoutes', 'getDescribeClientVpnRoutes', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeClientVpnTargetNetworksAction = 'fakedata';
    const actionDescribeClientVpnTargetNetworksVersion = 'fakedata';
    const actionDescribeClientVpnTargetNetworksBodyFormData = 'fakedata';
    describe('#postDescribeClientVpnTargetNetworks - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeClientVpnTargetNetworks(actionDescribeClientVpnTargetNetworksAction, actionDescribeClientVpnTargetNetworksVersion, actionDescribeClientVpnTargetNetworksBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.ClientVpnTargetNetworks));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeClientVpnTargetNetworks', 'postDescribeClientVpnTargetNetworks', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeClientVpnTargetNetworksClientVpnEndpointId = 'fakedata';
    describe('#getDescribeClientVpnTargetNetworks - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeClientVpnTargetNetworks(actionDescribeClientVpnTargetNetworksClientVpnEndpointId, null, null, null, null, null, actionDescribeClientVpnTargetNetworksAction, actionDescribeClientVpnTargetNetworksVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.ClientVpnTargetNetworks));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeClientVpnTargetNetworks', 'getDescribeClientVpnTargetNetworks', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeConversionTasksAction = 'fakedata';
    const actionDescribeConversionTasksVersion = 'fakedata';
    describe('#postDescribeConversionTasks - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeConversionTasks(actionDescribeConversionTasksAction, actionDescribeConversionTasksVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.ConversionTasks));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeConversionTasks', 'postDescribeConversionTasks', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeConversionTasks - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeConversionTasks(null, null, actionDescribeConversionTasksAction, actionDescribeConversionTasksVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.ConversionTasks));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeConversionTasks', 'getDescribeConversionTasks', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeCustomerGatewaysAction = 'fakedata';
    const actionDescribeCustomerGatewaysVersion = 'fakedata';
    describe('#postDescribeCustomerGateways - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeCustomerGateways(actionDescribeCustomerGatewaysAction, actionDescribeCustomerGatewaysVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.CustomerGateways));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeCustomerGateways', 'postDescribeCustomerGateways', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeCustomerGateways - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeCustomerGateways(null, null, null, actionDescribeCustomerGatewaysAction, actionDescribeCustomerGatewaysVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.CustomerGateways));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeCustomerGateways', 'getDescribeCustomerGateways', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeDhcpOptionsAction = 'fakedata';
    const actionDescribeDhcpOptionsVersion = 'fakedata';
    describe('#postDescribeDhcpOptions - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeDhcpOptions(actionDescribeDhcpOptionsAction, actionDescribeDhcpOptionsVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.DhcpOptions));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeDhcpOptions', 'postDescribeDhcpOptions', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeDhcpOptions - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeDhcpOptions(null, null, null, null, null, actionDescribeDhcpOptionsAction, actionDescribeDhcpOptionsVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.DhcpOptions));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeDhcpOptions', 'getDescribeDhcpOptions', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeEgressOnlyInternetGatewaysAction = 'fakedata';
    const actionDescribeEgressOnlyInternetGatewaysVersion = 'fakedata';
    describe('#postDescribeEgressOnlyInternetGateways - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeEgressOnlyInternetGateways(actionDescribeEgressOnlyInternetGatewaysAction, actionDescribeEgressOnlyInternetGatewaysVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.EgressOnlyInternetGateways));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeEgressOnlyInternetGateways', 'postDescribeEgressOnlyInternetGateways', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeEgressOnlyInternetGateways - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeEgressOnlyInternetGateways(null, null, null, null, actionDescribeEgressOnlyInternetGatewaysAction, actionDescribeEgressOnlyInternetGatewaysVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.EgressOnlyInternetGateways));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeEgressOnlyInternetGateways', 'getDescribeEgressOnlyInternetGateways', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeElasticGpusAction = 'fakedata';
    const actionDescribeElasticGpusVersion = 'fakedata';
    describe('#postDescribeElasticGpus - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeElasticGpus(actionDescribeElasticGpusAction, actionDescribeElasticGpusVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.ElasticGpuSet));
              assert.equal(5, data.response.maxResults);
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeElasticGpus', 'postDescribeElasticGpus', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeElasticGpus - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeElasticGpus(null, null, null, null, null, actionDescribeElasticGpusAction, actionDescribeElasticGpusVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.ElasticGpuSet));
              assert.equal(2, data.response.maxResults);
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeElasticGpus', 'getDescribeElasticGpus', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeExportTasksAction = 'fakedata';
    const actionDescribeExportTasksVersion = 'fakedata';
    describe('#postDescribeExportTasks - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeExportTasks(actionDescribeExportTasksAction, actionDescribeExportTasksVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.ExportTasks));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeExportTasks', 'postDescribeExportTasks', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeExportTasks - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeExportTasks(null, actionDescribeExportTasksAction, actionDescribeExportTasksVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.ExportTasks));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeExportTasks', 'getDescribeExportTasks', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    let actionDescribeFleetHistoryFleetId = 'fakedata';
    let actionDescribeFleetHistoryStartTime = 'fakedata';
    const actionDescribeFleetHistoryAction = 'fakedata';
    const actionDescribeFleetHistoryVersion = 'fakedata';
    const actionDescribeFleetHistoryBodyFormData = 'fakedata';
    describe('#postDescribeFleetHistory - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeFleetHistory(actionDescribeFleetHistoryAction, actionDescribeFleetHistoryVersion, actionDescribeFleetHistoryBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.HistoryRecords));
              assert.equal('string', data.response.LastEvaluatedTime);
              assert.equal('string', data.response.nextToken);
              assert.equal('string', data.response.fleetId);
              assert.equal('string', data.response.startTime);
            } else {
              runCommonAsserts(data, error);
            }
            actionDescribeFleetHistoryFleetId = data.response.fleetId;
            actionDescribeFleetHistoryStartTime = data.response.startTime;
            saveMockData('ActionDescribeFleetHistory', 'postDescribeFleetHistory', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeFleetHistory - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeFleetHistory(null, null, null, null, actionDescribeFleetHistoryFleetId, actionDescribeFleetHistoryStartTime, actionDescribeFleetHistoryAction, actionDescribeFleetHistoryVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.HistoryRecords));
              assert.equal('string', data.response.LastEvaluatedTime);
              assert.equal('string', data.response.nextToken);
              assert.equal('string', data.response.fleetId);
              assert.equal('string', data.response.startTime);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeFleetHistory', 'getDescribeFleetHistory', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    let actionDescribeFleetInstancesFleetId = 'fakedata';
    const actionDescribeFleetInstancesAction = 'fakedata';
    const actionDescribeFleetInstancesVersion = 'fakedata';
    const actionDescribeFleetInstancesBodyFormData = 'fakedata';
    describe('#postDescribeFleetInstances - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeFleetInstances(actionDescribeFleetInstancesAction, actionDescribeFleetInstancesVersion, actionDescribeFleetInstancesBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.ActiveInstances));
              assert.equal('string', data.response.nextToken);
              assert.equal('string', data.response.fleetId);
            } else {
              runCommonAsserts(data, error);
            }
            actionDescribeFleetInstancesFleetId = data.response.fleetId;
            saveMockData('ActionDescribeFleetInstances', 'postDescribeFleetInstances', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeFleetInstances - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeFleetInstances(null, null, null, actionDescribeFleetInstancesFleetId, null, actionDescribeFleetInstancesAction, actionDescribeFleetInstancesVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.ActiveInstances));
              assert.equal('string', data.response.nextToken);
              assert.equal('string', data.response.fleetId);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeFleetInstances', 'getDescribeFleetInstances', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeFleetsAction = 'fakedata';
    const actionDescribeFleetsVersion = 'fakedata';
    describe('#postDescribeFleets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeFleets(actionDescribeFleetsAction, actionDescribeFleetsVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.nextToken);
              assert.equal(true, Array.isArray(data.response.Fleets));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeFleets', 'postDescribeFleets', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeFleets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeFleets(null, null, null, null, null, actionDescribeFleetsAction, actionDescribeFleetsVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.nextToken);
              assert.equal(true, Array.isArray(data.response.Fleets));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeFleets', 'getDescribeFleets', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeFlowLogsAction = 'fakedata';
    const actionDescribeFlowLogsVersion = 'fakedata';
    describe('#postDescribeFlowLogs - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeFlowLogs(actionDescribeFlowLogsAction, actionDescribeFlowLogsVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.FlowLogs));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeFlowLogs', 'postDescribeFlowLogs', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeFlowLogs - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeFlowLogs(null, null, null, null, null, actionDescribeFlowLogsAction, actionDescribeFlowLogsVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.FlowLogs));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeFlowLogs', 'getDescribeFlowLogs', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeFpgaImageAttributeAction = 'fakedata';
    const actionDescribeFpgaImageAttributeVersion = 'fakedata';
    const actionDescribeFpgaImageAttributeBodyFormData = 'fakedata';
    describe('#postDescribeFpgaImageAttribute - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeFpgaImageAttribute(actionDescribeFpgaImageAttributeAction, actionDescribeFpgaImageAttributeVersion, actionDescribeFpgaImageAttributeBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.FpgaImageAttribute);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeFpgaImageAttribute', 'postDescribeFpgaImageAttribute', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeFpgaImageAttributeFpgaImageId = 'fakedata';
    const actionDescribeFpgaImageAttributeAttribute = 'fakedata';
    describe('#getDescribeFpgaImageAttribute - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeFpgaImageAttribute(null, actionDescribeFpgaImageAttributeFpgaImageId, actionDescribeFpgaImageAttributeAttribute, actionDescribeFpgaImageAttributeAction, actionDescribeFpgaImageAttributeVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.FpgaImageAttribute);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeFpgaImageAttribute', 'getDescribeFpgaImageAttribute', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeFpgaImagesAction = 'fakedata';
    const actionDescribeFpgaImagesVersion = 'fakedata';
    describe('#postDescribeFpgaImages - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeFpgaImages(actionDescribeFpgaImagesAction, actionDescribeFpgaImagesVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.FpgaImages));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeFpgaImages', 'postDescribeFpgaImages', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeFpgaImages - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeFpgaImages(null, null, null, null, null, null, actionDescribeFpgaImagesAction, actionDescribeFpgaImagesVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.FpgaImages));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeFpgaImages', 'getDescribeFpgaImages', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeHostReservationOfferingsAction = 'fakedata';
    const actionDescribeHostReservationOfferingsVersion = 'fakedata';
    describe('#postDescribeHostReservationOfferings - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeHostReservationOfferings(actionDescribeHostReservationOfferingsAction, actionDescribeHostReservationOfferingsVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.nextToken);
              assert.equal(true, Array.isArray(data.response.OfferingSet));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeHostReservationOfferings', 'postDescribeHostReservationOfferings', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeHostReservationOfferings - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeHostReservationOfferings(null, null, null, null, null, null, actionDescribeHostReservationOfferingsAction, actionDescribeHostReservationOfferingsVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.nextToken);
              assert.equal(true, Array.isArray(data.response.OfferingSet));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeHostReservationOfferings', 'getDescribeHostReservationOfferings', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeHostReservationsAction = 'fakedata';
    const actionDescribeHostReservationsVersion = 'fakedata';
    describe('#postDescribeHostReservations - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeHostReservations(actionDescribeHostReservationsAction, actionDescribeHostReservationsVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.HostReservationSet));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeHostReservations', 'postDescribeHostReservations', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeHostReservations - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeHostReservations(null, null, null, null, actionDescribeHostReservationsAction, actionDescribeHostReservationsVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.HostReservationSet));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeHostReservations', 'getDescribeHostReservations', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeHostsAction = 'fakedata';
    const actionDescribeHostsVersion = 'fakedata';
    describe('#postDescribeHosts - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeHosts(actionDescribeHostsAction, actionDescribeHostsVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.Hosts));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeHosts', 'postDescribeHosts', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeHosts - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeHosts(null, null, null, null, actionDescribeHostsAction, actionDescribeHostsVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.Hosts));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeHosts', 'getDescribeHosts', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeIamInstanceProfileAssociationsAction = 'fakedata';
    const actionDescribeIamInstanceProfileAssociationsVersion = 'fakedata';
    describe('#postDescribeIamInstanceProfileAssociations - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeIamInstanceProfileAssociations(actionDescribeIamInstanceProfileAssociationsAction, actionDescribeIamInstanceProfileAssociationsVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.IamInstanceProfileAssociations));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeIamInstanceProfileAssociations', 'postDescribeIamInstanceProfileAssociations', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeIamInstanceProfileAssociations - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeIamInstanceProfileAssociations(null, null, null, null, actionDescribeIamInstanceProfileAssociationsAction, actionDescribeIamInstanceProfileAssociationsVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.IamInstanceProfileAssociations));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeIamInstanceProfileAssociations', 'getDescribeIamInstanceProfileAssociations', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeIdFormatAction = 'fakedata';
    const actionDescribeIdFormatVersion = 'fakedata';
    describe('#postDescribeIdFormat - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeIdFormat(actionDescribeIdFormatAction, actionDescribeIdFormatVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.Statuses));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeIdFormat', 'postDescribeIdFormat', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeIdFormat - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeIdFormat(null, actionDescribeIdFormatAction, actionDescribeIdFormatVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.Statuses));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeIdFormat', 'getDescribeIdFormat', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeIdentityIdFormatAction = 'fakedata';
    const actionDescribeIdentityIdFormatVersion = 'fakedata';
    const actionDescribeIdentityIdFormatBodyFormData = 'fakedata';
    describe('#postDescribeIdentityIdFormat - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeIdentityIdFormat(actionDescribeIdentityIdFormatAction, actionDescribeIdentityIdFormatVersion, actionDescribeIdentityIdFormatBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.Statuses));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeIdentityIdFormat', 'postDescribeIdentityIdFormat', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeIdentityIdFormatPrincipalArn = 'fakedata';
    describe('#getDescribeIdentityIdFormat - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeIdentityIdFormat(actionDescribeIdentityIdFormatPrincipalArn, null, actionDescribeIdentityIdFormatAction, actionDescribeIdentityIdFormatVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.Statuses));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeIdentityIdFormat', 'getDescribeIdentityIdFormat', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    let actionDescribeImageAttributeImageId = 'fakedata';
    const actionDescribeImageAttributeAction = 'fakedata';
    const actionDescribeImageAttributeVersion = 'fakedata';
    const actionDescribeImageAttributeBodyFormData = 'fakedata';
    describe('#postDescribeImageAttribute - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeImageAttribute(actionDescribeImageAttributeAction, actionDescribeImageAttributeVersion, actionDescribeImageAttributeBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.BlockDeviceMappings));
              assert.equal('string', data.response.imageId);
              assert.equal(true, Array.isArray(data.response.LaunchPermissions));
              assert.equal(true, Array.isArray(data.response.ProductCodes));
              assert.equal('object', typeof data.response.Description);
              assert.equal('object', typeof data.response.KernelId);
              assert.equal('object', typeof data.response.RamdiskId);
              assert.equal('object', typeof data.response.SriovNetSupport);
            } else {
              runCommonAsserts(data, error);
            }
            actionDescribeImageAttributeImageId = data.response.imageId;
            saveMockData('ActionDescribeImageAttribute', 'postDescribeImageAttribute', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeImageAttributeAttribute = 'fakedata';
    describe('#getDescribeImageAttribute - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeImageAttribute(actionDescribeImageAttributeAttribute, actionDescribeImageAttributeImageId, null, actionDescribeImageAttributeAction, actionDescribeImageAttributeVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.BlockDeviceMappings));
              assert.equal('string', data.response.imageId);
              assert.equal(true, Array.isArray(data.response.LaunchPermissions));
              assert.equal(true, Array.isArray(data.response.ProductCodes));
              assert.equal('object', typeof data.response.Description);
              assert.equal('object', typeof data.response.KernelId);
              assert.equal('object', typeof data.response.RamdiskId);
              assert.equal('object', typeof data.response.SriovNetSupport);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeImageAttribute', 'getDescribeImageAttribute', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeImagesAction = 'fakedata';
    const actionDescribeImagesVersion = 'fakedata';
    describe('#postDescribeImages - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeImages(actionDescribeImagesAction, actionDescribeImagesVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.Images));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeImages', 'postDescribeImages', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeImages - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeImages(null, null, null, null, null, actionDescribeImagesAction, actionDescribeImagesVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.Images));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeImages', 'getDescribeImages', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeImportImageTasksAction = 'fakedata';
    const actionDescribeImportImageTasksVersion = 'fakedata';
    describe('#postDescribeImportImageTasks - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeImportImageTasks(actionDescribeImportImageTasksAction, actionDescribeImportImageTasksVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.ImportImageTasks));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeImportImageTasks', 'postDescribeImportImageTasks', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeImportImageTasks - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeImportImageTasks(null, null, null, null, null, actionDescribeImportImageTasksAction, actionDescribeImportImageTasksVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.ImportImageTasks));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeImportImageTasks', 'getDescribeImportImageTasks', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeImportSnapshotTasksAction = 'fakedata';
    const actionDescribeImportSnapshotTasksVersion = 'fakedata';
    describe('#postDescribeImportSnapshotTasks - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeImportSnapshotTasks(actionDescribeImportSnapshotTasksAction, actionDescribeImportSnapshotTasksVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.ImportSnapshotTasks));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeImportSnapshotTasks', 'postDescribeImportSnapshotTasks', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeImportSnapshotTasks - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeImportSnapshotTasks(null, null, null, null, null, actionDescribeImportSnapshotTasksAction, actionDescribeImportSnapshotTasksVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.ImportSnapshotTasks));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeImportSnapshotTasks', 'getDescribeImportSnapshotTasks', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    let actionDescribeInstanceAttributeInstanceId = 'fakedata';
    const actionDescribeInstanceAttributeAction = 'fakedata';
    const actionDescribeInstanceAttributeVersion = 'fakedata';
    const actionDescribeInstanceAttributeBodyFormData = 'fakedata';
    describe('#postDescribeInstanceAttribute - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeInstanceAttribute(actionDescribeInstanceAttributeAction, actionDescribeInstanceAttributeVersion, actionDescribeInstanceAttributeBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.Groups));
              assert.equal(true, Array.isArray(data.response.BlockDeviceMappings));
              assert.equal('object', typeof data.response.DisableApiTermination);
              assert.equal('object', typeof data.response.EnaSupport);
              assert.equal('object', typeof data.response.EbsOptimized);
              assert.equal('string', data.response.instanceId);
              assert.equal('object', typeof data.response.InstanceInitiatedShutdownBehavior);
              assert.equal('object', typeof data.response.InstanceType);
              assert.equal('object', typeof data.response.KernelId);
              assert.equal(true, Array.isArray(data.response.ProductCodes));
              assert.equal('object', typeof data.response.RamdiskId);
              assert.equal('object', typeof data.response.RootDeviceName);
              assert.equal('object', typeof data.response.SourceDestCheck);
              assert.equal('object', typeof data.response.SriovNetSupport);
              assert.equal('object', typeof data.response.UserData);
            } else {
              runCommonAsserts(data, error);
            }
            actionDescribeInstanceAttributeInstanceId = data.response.instanceId;
            saveMockData('ActionDescribeInstanceAttribute', 'postDescribeInstanceAttribute', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeInstanceAttributeAttribute = 'fakedata';
    describe('#getDescribeInstanceAttribute - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeInstanceAttribute(actionDescribeInstanceAttributeAttribute, null, actionDescribeInstanceAttributeInstanceId, actionDescribeInstanceAttributeAction, actionDescribeInstanceAttributeVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.Groups));
              assert.equal(true, Array.isArray(data.response.BlockDeviceMappings));
              assert.equal('object', typeof data.response.DisableApiTermination);
              assert.equal('object', typeof data.response.EnaSupport);
              assert.equal('object', typeof data.response.EbsOptimized);
              assert.equal('string', data.response.instanceId);
              assert.equal('object', typeof data.response.InstanceInitiatedShutdownBehavior);
              assert.equal('object', typeof data.response.InstanceType);
              assert.equal('object', typeof data.response.KernelId);
              assert.equal(true, Array.isArray(data.response.ProductCodes));
              assert.equal('object', typeof data.response.RamdiskId);
              assert.equal('object', typeof data.response.RootDeviceName);
              assert.equal('object', typeof data.response.SourceDestCheck);
              assert.equal('object', typeof data.response.SriovNetSupport);
              assert.equal('object', typeof data.response.UserData);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeInstanceAttribute', 'getDescribeInstanceAttribute', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeInstanceCreditSpecificationsAction = 'fakedata';
    const actionDescribeInstanceCreditSpecificationsVersion = 'fakedata';
    describe('#postDescribeInstanceCreditSpecifications - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeInstanceCreditSpecifications(actionDescribeInstanceCreditSpecificationsAction, actionDescribeInstanceCreditSpecificationsVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.InstanceCreditSpecifications));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeInstanceCreditSpecifications', 'postDescribeInstanceCreditSpecifications', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeInstanceCreditSpecifications - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeInstanceCreditSpecifications(null, null, null, null, null, actionDescribeInstanceCreditSpecificationsAction, actionDescribeInstanceCreditSpecificationsVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.InstanceCreditSpecifications));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeInstanceCreditSpecifications', 'getDescribeInstanceCreditSpecifications', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeInstanceStatusAction = 'fakedata';
    const actionDescribeInstanceStatusVersion = 'fakedata';
    describe('#postDescribeInstanceStatus - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeInstanceStatus(actionDescribeInstanceStatusAction, actionDescribeInstanceStatusVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.InstanceStatuses));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeInstanceStatus', 'postDescribeInstanceStatus', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeInstanceStatus - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeInstanceStatus(null, null, null, null, null, null, actionDescribeInstanceStatusAction, actionDescribeInstanceStatusVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.InstanceStatuses));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeInstanceStatus', 'getDescribeInstanceStatus', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeInstancesAction = 'fakedata';
    const actionDescribeInstancesVersion = 'fakedata';
    describe('#postDescribeInstances - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeInstances(actionDescribeInstancesAction, actionDescribeInstancesVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.Reservations));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeInstances', 'postDescribeInstances', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeInstances - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeInstances(null, null, null, null, null, actionDescribeInstancesAction, actionDescribeInstancesVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.Reservations));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeInstances', 'getDescribeInstances', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeInternetGatewaysAction = 'fakedata';
    const actionDescribeInternetGatewaysVersion = 'fakedata';
    describe('#postDescribeInternetGateways - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeInternetGateways(actionDescribeInternetGatewaysAction, actionDescribeInternetGatewaysVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.InternetGateways));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeInternetGateways', 'postDescribeInternetGateways', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeInternetGateways - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeInternetGateways(null, null, null, null, null, actionDescribeInternetGatewaysAction, actionDescribeInternetGatewaysVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.InternetGateways));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeInternetGateways', 'getDescribeInternetGateways', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeKeyPairsAction = 'fakedata';
    const actionDescribeKeyPairsVersion = 'fakedata';
    describe('#postDescribeKeyPairs - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeKeyPairs(actionDescribeKeyPairsAction, actionDescribeKeyPairsVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.KeyPairs));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeKeyPairs', 'postDescribeKeyPairs', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeKeyPairs - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeKeyPairs(null, null, null, actionDescribeKeyPairsAction, actionDescribeKeyPairsVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.KeyPairs));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeKeyPairs', 'getDescribeKeyPairs', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeLaunchTemplateVersionsAction = 'fakedata';
    const actionDescribeLaunchTemplateVersionsVersion = 'fakedata';
    describe('#postDescribeLaunchTemplateVersions - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeLaunchTemplateVersions(actionDescribeLaunchTemplateVersionsAction, actionDescribeLaunchTemplateVersionsVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.LaunchTemplateVersions));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeLaunchTemplateVersions', 'postDescribeLaunchTemplateVersions', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeLaunchTemplateVersions - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeLaunchTemplateVersions(null, null, null, null, null, null, null, null, null, actionDescribeLaunchTemplateVersionsAction, actionDescribeLaunchTemplateVersionsVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.LaunchTemplateVersions));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeLaunchTemplateVersions', 'getDescribeLaunchTemplateVersions', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeLaunchTemplatesAction = 'fakedata';
    const actionDescribeLaunchTemplatesVersion = 'fakedata';
    describe('#postDescribeLaunchTemplates - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeLaunchTemplates(actionDescribeLaunchTemplatesAction, actionDescribeLaunchTemplatesVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.LaunchTemplates));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeLaunchTemplates', 'postDescribeLaunchTemplates', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeLaunchTemplates - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeLaunchTemplates(null, null, null, null, null, null, actionDescribeLaunchTemplatesAction, actionDescribeLaunchTemplatesVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.LaunchTemplates));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeLaunchTemplates', 'getDescribeLaunchTemplates', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeMovingAddressesAction = 'fakedata';
    const actionDescribeMovingAddressesVersion = 'fakedata';
    describe('#postDescribeMovingAddresses - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeMovingAddresses(actionDescribeMovingAddressesAction, actionDescribeMovingAddressesVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.MovingAddressStatuses));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeMovingAddresses', 'postDescribeMovingAddresses', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeMovingAddresses - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeMovingAddresses(null, null, null, null, null, actionDescribeMovingAddressesAction, actionDescribeMovingAddressesVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.MovingAddressStatuses));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeMovingAddresses', 'getDescribeMovingAddresses', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeNatGatewaysAction = 'fakedata';
    const actionDescribeNatGatewaysVersion = 'fakedata';
    describe('#postDescribeNatGateways - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeNatGateways(actionDescribeNatGatewaysAction, actionDescribeNatGatewaysVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.NatGateways));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeNatGateways', 'postDescribeNatGateways', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeNatGateways - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeNatGateways(null, null, null, null, actionDescribeNatGatewaysAction, actionDescribeNatGatewaysVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.NatGateways));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeNatGateways', 'getDescribeNatGateways', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeNetworkAclsAction = 'fakedata';
    const actionDescribeNetworkAclsVersion = 'fakedata';
    describe('#postDescribeNetworkAcls - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeNetworkAcls(actionDescribeNetworkAclsAction, actionDescribeNetworkAclsVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.NetworkAcls));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeNetworkAcls', 'postDescribeNetworkAcls', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeNetworkAcls - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeNetworkAcls(null, null, null, null, null, actionDescribeNetworkAclsAction, actionDescribeNetworkAclsVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.NetworkAcls));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeNetworkAcls', 'getDescribeNetworkAcls', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    let actionDescribeNetworkInterfaceAttributeNetworkInterfaceId = 'fakedata';
    const actionDescribeNetworkInterfaceAttributeAction = 'fakedata';
    const actionDescribeNetworkInterfaceAttributeVersion = 'fakedata';
    const actionDescribeNetworkInterfaceAttributeBodyFormData = 'fakedata';
    describe('#postDescribeNetworkInterfaceAttribute - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeNetworkInterfaceAttribute(actionDescribeNetworkInterfaceAttributeAction, actionDescribeNetworkInterfaceAttributeVersion, actionDescribeNetworkInterfaceAttributeBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.Attachment);
              assert.equal('object', typeof data.response.Description);
              assert.equal(true, Array.isArray(data.response.Groups));
              assert.equal('string', data.response.networkInterfaceId);
              assert.equal('object', typeof data.response.SourceDestCheck);
            } else {
              runCommonAsserts(data, error);
            }
            actionDescribeNetworkInterfaceAttributeNetworkInterfaceId = data.response.networkInterfaceId;
            saveMockData('ActionDescribeNetworkInterfaceAttribute', 'postDescribeNetworkInterfaceAttribute', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeNetworkInterfaceAttribute - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeNetworkInterfaceAttribute(null, null, actionDescribeNetworkInterfaceAttributeNetworkInterfaceId, actionDescribeNetworkInterfaceAttributeAction, actionDescribeNetworkInterfaceAttributeVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.Attachment);
              assert.equal('object', typeof data.response.Description);
              assert.equal(true, Array.isArray(data.response.Groups));
              assert.equal('string', data.response.networkInterfaceId);
              assert.equal('object', typeof data.response.SourceDestCheck);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeNetworkInterfaceAttribute', 'getDescribeNetworkInterfaceAttribute', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeNetworkInterfacePermissionsAction = 'fakedata';
    const actionDescribeNetworkInterfacePermissionsVersion = 'fakedata';
    describe('#postDescribeNetworkInterfacePermissions - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeNetworkInterfacePermissions(actionDescribeNetworkInterfacePermissionsAction, actionDescribeNetworkInterfacePermissionsVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.NetworkInterfacePermissions));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeNetworkInterfacePermissions', 'postDescribeNetworkInterfacePermissions', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeNetworkInterfacePermissions - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeNetworkInterfacePermissions(null, null, null, null, actionDescribeNetworkInterfacePermissionsAction, actionDescribeNetworkInterfacePermissionsVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.NetworkInterfacePermissions));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeNetworkInterfacePermissions', 'getDescribeNetworkInterfacePermissions', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeNetworkInterfacesAction = 'fakedata';
    const actionDescribeNetworkInterfacesVersion = 'fakedata';
    describe('#postDescribeNetworkInterfaces - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeNetworkInterfaces(actionDescribeNetworkInterfacesAction, actionDescribeNetworkInterfacesVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.NetworkInterfaces));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeNetworkInterfaces', 'postDescribeNetworkInterfaces', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeNetworkInterfaces - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeNetworkInterfaces(null, null, null, null, null, actionDescribeNetworkInterfacesAction, actionDescribeNetworkInterfacesVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.NetworkInterfaces));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeNetworkInterfaces', 'getDescribeNetworkInterfaces', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribePlacementGroupsAction = 'fakedata';
    const actionDescribePlacementGroupsVersion = 'fakedata';
    describe('#postDescribePlacementGroups - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribePlacementGroups(actionDescribePlacementGroupsAction, actionDescribePlacementGroupsVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.PlacementGroups));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribePlacementGroups', 'postDescribePlacementGroups', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribePlacementGroups - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribePlacementGroups(null, null, null, actionDescribePlacementGroupsAction, actionDescribePlacementGroupsVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.PlacementGroups));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribePlacementGroups', 'getDescribePlacementGroups', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribePrefixListsAction = 'fakedata';
    const actionDescribePrefixListsVersion = 'fakedata';
    describe('#postDescribePrefixLists - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribePrefixLists(actionDescribePrefixListsAction, actionDescribePrefixListsVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.nextToken);
              assert.equal(true, Array.isArray(data.response.PrefixLists));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribePrefixLists', 'postDescribePrefixLists', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribePrefixLists - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribePrefixLists(null, null, null, null, null, actionDescribePrefixListsAction, actionDescribePrefixListsVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.nextToken);
              assert.equal(true, Array.isArray(data.response.PrefixLists));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribePrefixLists', 'getDescribePrefixLists', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribePrincipalIdFormatAction = 'fakedata';
    const actionDescribePrincipalIdFormatVersion = 'fakedata';
    describe('#postDescribePrincipalIdFormat - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribePrincipalIdFormat(actionDescribePrincipalIdFormatAction, actionDescribePrincipalIdFormatVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.Principals));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribePrincipalIdFormat', 'postDescribePrincipalIdFormat', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribePrincipalIdFormat - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribePrincipalIdFormat(null, null, null, null, actionDescribePrincipalIdFormatAction, actionDescribePrincipalIdFormatVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.Principals));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribePrincipalIdFormat', 'getDescribePrincipalIdFormat', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribePublicIpv4PoolsAction = 'fakedata';
    const actionDescribePublicIpv4PoolsVersion = 'fakedata';
    describe('#postDescribePublicIpv4Pools - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribePublicIpv4Pools(actionDescribePublicIpv4PoolsAction, actionDescribePublicIpv4PoolsVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.PublicIpv4Pools));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribePublicIpv4Pools', 'postDescribePublicIpv4Pools', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribePublicIpv4Pools - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribePublicIpv4Pools(null, null, null, actionDescribePublicIpv4PoolsAction, actionDescribePublicIpv4PoolsVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.PublicIpv4Pools));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribePublicIpv4Pools', 'getDescribePublicIpv4Pools', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeRegionsAction = 'fakedata';
    const actionDescribeRegionsVersion = 'fakedata';
    describe('#postDescribeRegions - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeRegions(actionDescribeRegionsAction, actionDescribeRegionsVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.Regions));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeRegions', 'postDescribeRegions', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeRegions - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeRegions(null, null, null, actionDescribeRegionsAction, actionDescribeRegionsVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.Regions));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeRegions', 'getDescribeRegions', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeReservedInstancesAction = 'fakedata';
    const actionDescribeReservedInstancesVersion = 'fakedata';
    describe('#postDescribeReservedInstances - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeReservedInstances(actionDescribeReservedInstancesAction, actionDescribeReservedInstancesVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.ReservedInstances));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeReservedInstances', 'postDescribeReservedInstances', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeReservedInstances - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeReservedInstances(null, null, null, null, null, actionDescribeReservedInstancesAction, actionDescribeReservedInstancesVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.ReservedInstances));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeReservedInstances', 'getDescribeReservedInstances', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeReservedInstancesListingsAction = 'fakedata';
    const actionDescribeReservedInstancesListingsVersion = 'fakedata';
    describe('#postDescribeReservedInstancesListings - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeReservedInstancesListings(actionDescribeReservedInstancesListingsAction, actionDescribeReservedInstancesListingsVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.ReservedInstancesListings));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeReservedInstancesListings', 'postDescribeReservedInstancesListings', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeReservedInstancesListings - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeReservedInstancesListings(null, null, null, actionDescribeReservedInstancesListingsAction, actionDescribeReservedInstancesListingsVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.ReservedInstancesListings));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeReservedInstancesListings', 'getDescribeReservedInstancesListings', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeReservedInstancesModificationsAction = 'fakedata';
    const actionDescribeReservedInstancesModificationsVersion = 'fakedata';
    describe('#postDescribeReservedInstancesModifications - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeReservedInstancesModifications(actionDescribeReservedInstancesModificationsAction, actionDescribeReservedInstancesModificationsVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.nextToken);
              assert.equal(true, Array.isArray(data.response.ReservedInstancesModifications));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeReservedInstancesModifications', 'postDescribeReservedInstancesModifications', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeReservedInstancesModifications - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeReservedInstancesModifications(null, null, null, actionDescribeReservedInstancesModificationsAction, actionDescribeReservedInstancesModificationsVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.nextToken);
              assert.equal(true, Array.isArray(data.response.ReservedInstancesModifications));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeReservedInstancesModifications', 'getDescribeReservedInstancesModifications', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeReservedInstancesOfferingsAction = 'fakedata';
    const actionDescribeReservedInstancesOfferingsVersion = 'fakedata';
    describe('#postDescribeReservedInstancesOfferings - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeReservedInstancesOfferings(actionDescribeReservedInstancesOfferingsAction, actionDescribeReservedInstancesOfferingsVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.ReservedInstancesOfferings));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeReservedInstancesOfferings', 'postDescribeReservedInstancesOfferings', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeReservedInstancesOfferings - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeReservedInstancesOfferings(null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, actionDescribeReservedInstancesOfferingsAction, actionDescribeReservedInstancesOfferingsVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.ReservedInstancesOfferings));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeReservedInstancesOfferings', 'getDescribeReservedInstancesOfferings', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeRouteTablesAction = 'fakedata';
    const actionDescribeRouteTablesVersion = 'fakedata';
    describe('#postDescribeRouteTables - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeRouteTables(actionDescribeRouteTablesAction, actionDescribeRouteTablesVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.RouteTables));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeRouteTables', 'postDescribeRouteTables', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeRouteTables - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeRouteTables(null, null, null, null, null, actionDescribeRouteTablesAction, actionDescribeRouteTablesVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.RouteTables));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeRouteTables', 'getDescribeRouteTables', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeScheduledInstanceAvailabilityAction = 'fakedata';
    const actionDescribeScheduledInstanceAvailabilityVersion = 'fakedata';
    describe('#postDescribeScheduledInstanceAvailability - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeScheduledInstanceAvailability(actionDescribeScheduledInstanceAvailabilityAction, actionDescribeScheduledInstanceAvailabilityVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.nextToken);
              assert.equal(true, Array.isArray(data.response.ScheduledInstanceAvailabilitySet));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeScheduledInstanceAvailability', 'postDescribeScheduledInstanceAvailability', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeScheduledInstanceAvailability - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeScheduledInstanceAvailability(null, null, null, null, null, null, null, null, null, null, null, null, null, actionDescribeScheduledInstanceAvailabilityAction, actionDescribeScheduledInstanceAvailabilityVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.nextToken);
              assert.equal(true, Array.isArray(data.response.ScheduledInstanceAvailabilitySet));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeScheduledInstanceAvailability', 'getDescribeScheduledInstanceAvailability', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeScheduledInstancesAction = 'fakedata';
    const actionDescribeScheduledInstancesVersion = 'fakedata';
    describe('#postDescribeScheduledInstances - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeScheduledInstances(actionDescribeScheduledInstancesAction, actionDescribeScheduledInstancesVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.nextToken);
              assert.equal(true, Array.isArray(data.response.ScheduledInstanceSet));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeScheduledInstances', 'postDescribeScheduledInstances', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeScheduledInstances - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeScheduledInstances(null, null, null, null, null, null, null, actionDescribeScheduledInstancesAction, actionDescribeScheduledInstancesVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.nextToken);
              assert.equal(true, Array.isArray(data.response.ScheduledInstanceSet));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeScheduledInstances', 'getDescribeScheduledInstances', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeSecurityGroupReferencesAction = 'fakedata';
    const actionDescribeSecurityGroupReferencesVersion = 'fakedata';
    const actionDescribeSecurityGroupReferencesBodyFormData = 'fakedata';
    describe('#postDescribeSecurityGroupReferences - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeSecurityGroupReferences(actionDescribeSecurityGroupReferencesAction, actionDescribeSecurityGroupReferencesVersion, actionDescribeSecurityGroupReferencesBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.SecurityGroupReferenceSet));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeSecurityGroupReferences', 'postDescribeSecurityGroupReferences', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeSecurityGroupReferencesGroupId = [];
    describe('#getDescribeSecurityGroupReferences - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeSecurityGroupReferences(null, actionDescribeSecurityGroupReferencesGroupId, actionDescribeSecurityGroupReferencesAction, actionDescribeSecurityGroupReferencesVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.SecurityGroupReferenceSet));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeSecurityGroupReferences', 'getDescribeSecurityGroupReferences', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeSecurityGroupsAction = 'fakedata';
    const actionDescribeSecurityGroupsVersion = 'fakedata';
    describe('#postDescribeSecurityGroups - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeSecurityGroups(actionDescribeSecurityGroupsAction, actionDescribeSecurityGroupsVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.SecurityGroups));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeSecurityGroups', 'postDescribeSecurityGroups', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeSecurityGroups - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeSecurityGroups(null, null, null, null, null, null, actionDescribeSecurityGroupsAction, actionDescribeSecurityGroupsVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.SecurityGroups));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeSecurityGroups', 'getDescribeSecurityGroups', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    let actionDescribeSnapshotAttributeSnapshotId = 'fakedata';
    const actionDescribeSnapshotAttributeAction = 'fakedata';
    const actionDescribeSnapshotAttributeVersion = 'fakedata';
    const actionDescribeSnapshotAttributeBodyFormData = 'fakedata';
    describe('#postDescribeSnapshotAttribute - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeSnapshotAttribute(actionDescribeSnapshotAttributeAction, actionDescribeSnapshotAttributeVersion, actionDescribeSnapshotAttributeBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.CreateVolumePermissions));
              assert.equal(true, Array.isArray(data.response.ProductCodes));
              assert.equal('string', data.response.snapshotId);
            } else {
              runCommonAsserts(data, error);
            }
            actionDescribeSnapshotAttributeSnapshotId = data.response.snapshotId;
            saveMockData('ActionDescribeSnapshotAttribute', 'postDescribeSnapshotAttribute', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeSnapshotAttributeAttribute = 'fakedata';
    describe('#getDescribeSnapshotAttribute - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeSnapshotAttribute(actionDescribeSnapshotAttributeAttribute, actionDescribeSnapshotAttributeSnapshotId, null, actionDescribeSnapshotAttributeAction, actionDescribeSnapshotAttributeVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.CreateVolumePermissions));
              assert.equal(true, Array.isArray(data.response.ProductCodes));
              assert.equal('string', data.response.snapshotId);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeSnapshotAttribute', 'getDescribeSnapshotAttribute', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeSnapshotsAction = 'fakedata';
    const actionDescribeSnapshotsVersion = 'fakedata';
    describe('#postDescribeSnapshots - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeSnapshots(actionDescribeSnapshotsAction, actionDescribeSnapshotsVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.Snapshots));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeSnapshots', 'postDescribeSnapshots', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeSnapshots - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeSnapshots(null, null, null, null, null, null, null, actionDescribeSnapshotsAction, actionDescribeSnapshotsVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.Snapshots));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeSnapshots', 'getDescribeSnapshots', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeSpotDatafeedSubscriptionAction = 'fakedata';
    const actionDescribeSpotDatafeedSubscriptionVersion = 'fakedata';
    describe('#postDescribeSpotDatafeedSubscription - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeSpotDatafeedSubscription(actionDescribeSpotDatafeedSubscriptionAction, actionDescribeSpotDatafeedSubscriptionVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.SpotDatafeedSubscription);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeSpotDatafeedSubscription', 'postDescribeSpotDatafeedSubscription', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeSpotDatafeedSubscription - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeSpotDatafeedSubscription(null, actionDescribeSpotDatafeedSubscriptionAction, actionDescribeSpotDatafeedSubscriptionVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.SpotDatafeedSubscription);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeSpotDatafeedSubscription', 'getDescribeSpotDatafeedSubscription', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    let actionDescribeSpotFleetInstancesSpotFleetRequestId = 'fakedata';
    const actionDescribeSpotFleetInstancesAction = 'fakedata';
    const actionDescribeSpotFleetInstancesVersion = 'fakedata';
    const actionDescribeSpotFleetInstancesBodyFormData = 'fakedata';
    describe('#postDescribeSpotFleetInstances - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeSpotFleetInstances(actionDescribeSpotFleetInstancesAction, actionDescribeSpotFleetInstancesVersion, actionDescribeSpotFleetInstancesBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.ActiveInstances));
              assert.equal('string', data.response.nextToken);
              assert.equal('string', data.response.spotFleetRequestId);
            } else {
              runCommonAsserts(data, error);
            }
            actionDescribeSpotFleetInstancesSpotFleetRequestId = data.response.spotFleetRequestId;
            saveMockData('ActionDescribeSpotFleetInstances', 'postDescribeSpotFleetInstances', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeSpotFleetInstances - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeSpotFleetInstances(null, null, null, actionDescribeSpotFleetInstancesSpotFleetRequestId, actionDescribeSpotFleetInstancesAction, actionDescribeSpotFleetInstancesVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.ActiveInstances));
              assert.equal('string', data.response.nextToken);
              assert.equal('string', data.response.spotFleetRequestId);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeSpotFleetInstances', 'getDescribeSpotFleetInstances', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    let actionDescribeSpotFleetRequestHistorySpotFleetRequestId = 'fakedata';
    let actionDescribeSpotFleetRequestHistoryStartTime = 'fakedata';
    const actionDescribeSpotFleetRequestHistoryAction = 'fakedata';
    const actionDescribeSpotFleetRequestHistoryVersion = 'fakedata';
    const actionDescribeSpotFleetRequestHistoryBodyFormData = 'fakedata';
    describe('#postDescribeSpotFleetRequestHistory - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeSpotFleetRequestHistory(actionDescribeSpotFleetRequestHistoryAction, actionDescribeSpotFleetRequestHistoryVersion, actionDescribeSpotFleetRequestHistoryBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.HistoryRecords));
              assert.equal('string', data.response.LastEvaluatedTime);
              assert.equal('string', data.response.nextToken);
              assert.equal('string', data.response.spotFleetRequestId);
              assert.equal('string', data.response.startTime);
            } else {
              runCommonAsserts(data, error);
            }
            actionDescribeSpotFleetRequestHistorySpotFleetRequestId = data.response.spotFleetRequestId;
            actionDescribeSpotFleetRequestHistoryStartTime = data.response.startTime;
            saveMockData('ActionDescribeSpotFleetRequestHistory', 'postDescribeSpotFleetRequestHistory', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeSpotFleetRequestHistory - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeSpotFleetRequestHistory(null, null, null, null, actionDescribeSpotFleetRequestHistorySpotFleetRequestId, actionDescribeSpotFleetRequestHistoryStartTime, actionDescribeSpotFleetRequestHistoryAction, actionDescribeSpotFleetRequestHistoryVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.HistoryRecords));
              assert.equal('string', data.response.LastEvaluatedTime);
              assert.equal('string', data.response.nextToken);
              assert.equal('string', data.response.spotFleetRequestId);
              assert.equal('string', data.response.startTime);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeSpotFleetRequestHistory', 'getDescribeSpotFleetRequestHistory', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeSpotFleetRequestsAction = 'fakedata';
    const actionDescribeSpotFleetRequestsVersion = 'fakedata';
    describe('#postDescribeSpotFleetRequests - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeSpotFleetRequests(actionDescribeSpotFleetRequestsAction, actionDescribeSpotFleetRequestsVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.nextToken);
              assert.equal(true, Array.isArray(data.response.SpotFleetRequestConfigs));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeSpotFleetRequests', 'postDescribeSpotFleetRequests', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeSpotFleetRequests - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeSpotFleetRequests(null, null, null, null, actionDescribeSpotFleetRequestsAction, actionDescribeSpotFleetRequestsVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.nextToken);
              assert.equal(true, Array.isArray(data.response.SpotFleetRequestConfigs));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeSpotFleetRequests', 'getDescribeSpotFleetRequests', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeSpotInstanceRequestsAction = 'fakedata';
    const actionDescribeSpotInstanceRequestsVersion = 'fakedata';
    describe('#postDescribeSpotInstanceRequests - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeSpotInstanceRequests(actionDescribeSpotInstanceRequestsAction, actionDescribeSpotInstanceRequestsVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.SpotInstanceRequests));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeSpotInstanceRequests', 'postDescribeSpotInstanceRequests', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeSpotInstanceRequests - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeSpotInstanceRequests(null, null, null, null, null, actionDescribeSpotInstanceRequestsAction, actionDescribeSpotInstanceRequestsVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.SpotInstanceRequests));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeSpotInstanceRequests', 'getDescribeSpotInstanceRequests', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeSpotPriceHistoryAction = 'fakedata';
    const actionDescribeSpotPriceHistoryVersion = 'fakedata';
    describe('#postDescribeSpotPriceHistory - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeSpotPriceHistory(actionDescribeSpotPriceHistoryAction, actionDescribeSpotPriceHistoryVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.nextToken);
              assert.equal(true, Array.isArray(data.response.SpotPriceHistory));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeSpotPriceHistory', 'postDescribeSpotPriceHistory', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeSpotPriceHistory - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeSpotPriceHistory(null, null, null, null, null, null, null, null, null, actionDescribeSpotPriceHistoryAction, actionDescribeSpotPriceHistoryVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.nextToken);
              assert.equal(true, Array.isArray(data.response.SpotPriceHistory));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeSpotPriceHistory', 'getDescribeSpotPriceHistory', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeStaleSecurityGroupsAction = 'fakedata';
    const actionDescribeStaleSecurityGroupsVersion = 'fakedata';
    const actionDescribeStaleSecurityGroupsBodyFormData = 'fakedata';
    describe('#postDescribeStaleSecurityGroups - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeStaleSecurityGroups(actionDescribeStaleSecurityGroupsAction, actionDescribeStaleSecurityGroupsVersion, actionDescribeStaleSecurityGroupsBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.nextToken);
              assert.equal(true, Array.isArray(data.response.StaleSecurityGroupSet));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeStaleSecurityGroups', 'postDescribeStaleSecurityGroups', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeStaleSecurityGroupsVpcId = 'fakedata';
    describe('#getDescribeStaleSecurityGroups - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeStaleSecurityGroups(null, null, null, actionDescribeStaleSecurityGroupsVpcId, actionDescribeStaleSecurityGroupsAction, actionDescribeStaleSecurityGroupsVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.nextToken);
              assert.equal(true, Array.isArray(data.response.StaleSecurityGroupSet));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeStaleSecurityGroups', 'getDescribeStaleSecurityGroups', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeSubnetsAction = 'fakedata';
    const actionDescribeSubnetsVersion = 'fakedata';
    describe('#postDescribeSubnets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeSubnets(actionDescribeSubnetsAction, actionDescribeSubnetsVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.Subnets));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeSubnets', 'postDescribeSubnets', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeSubnets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeSubnets(null, null, null, null, null, actionDescribeSubnetsAction, actionDescribeSubnetsVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.Subnets));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeSubnets', 'getDescribeSubnets', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeTagsAction = 'fakedata';
    const actionDescribeTagsVersion = 'fakedata';
    describe('#postDescribeTags - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeTags(actionDescribeTagsAction, actionDescribeTagsVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.nextToken);
              assert.equal(true, Array.isArray(data.response.Tags));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeTags', 'postDescribeTags', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeTags - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeTags(null, null, null, null, actionDescribeTagsAction, actionDescribeTagsVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.nextToken);
              assert.equal(true, Array.isArray(data.response.Tags));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeTags', 'getDescribeTags', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeTransitGatewayAttachmentsAction = 'fakedata';
    const actionDescribeTransitGatewayAttachmentsVersion = 'fakedata';
    describe('#postDescribeTransitGatewayAttachments - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeTransitGatewayAttachments(actionDescribeTransitGatewayAttachmentsAction, actionDescribeTransitGatewayAttachmentsVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.TransitGatewayAttachments));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeTransitGatewayAttachments', 'postDescribeTransitGatewayAttachments', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeTransitGatewayAttachments - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeTransitGatewayAttachments(null, null, null, null, null, actionDescribeTransitGatewayAttachmentsAction, actionDescribeTransitGatewayAttachmentsVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.TransitGatewayAttachments));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeTransitGatewayAttachments', 'getDescribeTransitGatewayAttachments', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeTransitGatewayRouteTablesAction = 'fakedata';
    const actionDescribeTransitGatewayRouteTablesVersion = 'fakedata';
    describe('#postDescribeTransitGatewayRouteTables - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeTransitGatewayRouteTables(actionDescribeTransitGatewayRouteTablesAction, actionDescribeTransitGatewayRouteTablesVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.TransitGatewayRouteTables));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeTransitGatewayRouteTables', 'postDescribeTransitGatewayRouteTables', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeTransitGatewayRouteTables - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeTransitGatewayRouteTables(null, null, null, null, null, actionDescribeTransitGatewayRouteTablesAction, actionDescribeTransitGatewayRouteTablesVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.TransitGatewayRouteTables));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeTransitGatewayRouteTables', 'getDescribeTransitGatewayRouteTables', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeTransitGatewayVpcAttachmentsAction = 'fakedata';
    const actionDescribeTransitGatewayVpcAttachmentsVersion = 'fakedata';
    describe('#postDescribeTransitGatewayVpcAttachments - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeTransitGatewayVpcAttachments(actionDescribeTransitGatewayVpcAttachmentsAction, actionDescribeTransitGatewayVpcAttachmentsVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.TransitGatewayVpcAttachments));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeTransitGatewayVpcAttachments', 'postDescribeTransitGatewayVpcAttachments', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeTransitGatewayVpcAttachments - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeTransitGatewayVpcAttachments(null, null, null, null, null, actionDescribeTransitGatewayVpcAttachmentsAction, actionDescribeTransitGatewayVpcAttachmentsVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.TransitGatewayVpcAttachments));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeTransitGatewayVpcAttachments', 'getDescribeTransitGatewayVpcAttachments', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeTransitGatewaysAction = 'fakedata';
    const actionDescribeTransitGatewaysVersion = 'fakedata';
    describe('#postDescribeTransitGateways - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeTransitGateways(actionDescribeTransitGatewaysAction, actionDescribeTransitGatewaysVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.TransitGateways));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeTransitGateways', 'postDescribeTransitGateways', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeTransitGateways - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeTransitGateways(null, null, null, null, null, actionDescribeTransitGatewaysAction, actionDescribeTransitGatewaysVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.TransitGateways));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeTransitGateways', 'getDescribeTransitGateways', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    let actionDescribeVolumeAttributeVolumeId = 'fakedata';
    const actionDescribeVolumeAttributeAction = 'fakedata';
    const actionDescribeVolumeAttributeVersion = 'fakedata';
    const actionDescribeVolumeAttributeBodyFormData = 'fakedata';
    describe('#postDescribeVolumeAttribute - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeVolumeAttribute(actionDescribeVolumeAttributeAction, actionDescribeVolumeAttributeVersion, actionDescribeVolumeAttributeBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.AutoEnableIO);
              assert.equal(true, Array.isArray(data.response.ProductCodes));
              assert.equal('string', data.response.volumeId);
            } else {
              runCommonAsserts(data, error);
            }
            actionDescribeVolumeAttributeVolumeId = data.response.volumeId;
            saveMockData('ActionDescribeVolumeAttribute', 'postDescribeVolumeAttribute', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeVolumeAttributeAttribute = 'fakedata';
    describe('#getDescribeVolumeAttribute - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeVolumeAttribute(actionDescribeVolumeAttributeAttribute, actionDescribeVolumeAttributeVolumeId, null, actionDescribeVolumeAttributeAction, actionDescribeVolumeAttributeVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.AutoEnableIO);
              assert.equal(true, Array.isArray(data.response.ProductCodes));
              assert.equal('string', data.response.volumeId);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeVolumeAttribute', 'getDescribeVolumeAttribute', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeVolumeStatusAction = 'fakedata';
    const actionDescribeVolumeStatusVersion = 'fakedata';
    describe('#postDescribeVolumeStatus - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeVolumeStatus(actionDescribeVolumeStatusAction, actionDescribeVolumeStatusVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.nextToken);
              assert.equal(true, Array.isArray(data.response.VolumeStatuses));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeVolumeStatus', 'postDescribeVolumeStatus', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeVolumeStatus - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeVolumeStatus(null, null, null, null, null, actionDescribeVolumeStatusAction, actionDescribeVolumeStatusVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.nextToken);
              assert.equal(true, Array.isArray(data.response.VolumeStatuses));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeVolumeStatus', 'getDescribeVolumeStatus', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeVolumesAction = 'fakedata';
    const actionDescribeVolumesVersion = 'fakedata';
    describe('#postDescribeVolumes - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeVolumes(actionDescribeVolumesAction, actionDescribeVolumesVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.Volumes));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeVolumes', 'postDescribeVolumes', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeVolumes - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeVolumes(null, null, null, null, null, actionDescribeVolumesAction, actionDescribeVolumesVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.Volumes));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeVolumes', 'getDescribeVolumes', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeVolumesModificationsAction = 'fakedata';
    const actionDescribeVolumesModificationsVersion = 'fakedata';
    describe('#postDescribeVolumesModifications - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeVolumesModifications(actionDescribeVolumesModificationsAction, actionDescribeVolumesModificationsVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.VolumesModifications));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeVolumesModifications', 'postDescribeVolumesModifications', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeVolumesModifications - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeVolumesModifications(null, null, null, null, null, actionDescribeVolumesModificationsAction, actionDescribeVolumesModificationsVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.VolumesModifications));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeVolumesModifications', 'getDescribeVolumesModifications', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    let actionDescribeVpcAttributeVpcId = 'fakedata';
    const actionDescribeVpcAttributeAction = 'fakedata';
    const actionDescribeVpcAttributeVersion = 'fakedata';
    const actionDescribeVpcAttributeBodyFormData = 'fakedata';
    describe('#postDescribeVpcAttribute - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeVpcAttribute(actionDescribeVpcAttributeAction, actionDescribeVpcAttributeVersion, actionDescribeVpcAttributeBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.vpcId);
              assert.equal('object', typeof data.response.EnableDnsHostnames);
              assert.equal('object', typeof data.response.EnableDnsSupport);
            } else {
              runCommonAsserts(data, error);
            }
            actionDescribeVpcAttributeVpcId = data.response.vpcId;
            saveMockData('ActionDescribeVpcAttribute', 'postDescribeVpcAttribute', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeVpcAttributeAttribute = 'fakedata';
    describe('#getDescribeVpcAttribute - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeVpcAttribute(actionDescribeVpcAttributeAttribute, actionDescribeVpcAttributeVpcId, null, actionDescribeVpcAttributeAction, actionDescribeVpcAttributeVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.vpcId);
              assert.equal('object', typeof data.response.EnableDnsHostnames);
              assert.equal('object', typeof data.response.EnableDnsSupport);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeVpcAttribute', 'getDescribeVpcAttribute', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeVpcClassicLinkAction = 'fakedata';
    const actionDescribeVpcClassicLinkVersion = 'fakedata';
    describe('#postDescribeVpcClassicLink - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeVpcClassicLink(actionDescribeVpcClassicLinkAction, actionDescribeVpcClassicLinkVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.Vpcs));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeVpcClassicLink', 'postDescribeVpcClassicLink', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeVpcClassicLink - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeVpcClassicLink(null, null, null, actionDescribeVpcClassicLinkAction, actionDescribeVpcClassicLinkVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.Vpcs));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeVpcClassicLink', 'getDescribeVpcClassicLink', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeVpcClassicLinkDnsSupportAction = 'fakedata';
    const actionDescribeVpcClassicLinkDnsSupportVersion = 'fakedata';
    describe('#postDescribeVpcClassicLinkDnsSupport - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeVpcClassicLinkDnsSupport(actionDescribeVpcClassicLinkDnsSupportAction, actionDescribeVpcClassicLinkDnsSupportVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.nextToken);
              assert.equal(true, Array.isArray(data.response.Vpcs));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeVpcClassicLinkDnsSupport', 'postDescribeVpcClassicLinkDnsSupport', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeVpcClassicLinkDnsSupport - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeVpcClassicLinkDnsSupport(null, null, null, actionDescribeVpcClassicLinkDnsSupportAction, actionDescribeVpcClassicLinkDnsSupportVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.nextToken);
              assert.equal(true, Array.isArray(data.response.Vpcs));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeVpcClassicLinkDnsSupport', 'getDescribeVpcClassicLinkDnsSupport', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeVpcEndpointConnectionNotificationsAction = 'fakedata';
    const actionDescribeVpcEndpointConnectionNotificationsVersion = 'fakedata';
    describe('#postDescribeVpcEndpointConnectionNotifications - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeVpcEndpointConnectionNotifications(actionDescribeVpcEndpointConnectionNotificationsAction, actionDescribeVpcEndpointConnectionNotificationsVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.ConnectionNotificationSet));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeVpcEndpointConnectionNotifications', 'postDescribeVpcEndpointConnectionNotifications', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeVpcEndpointConnectionNotifications - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeVpcEndpointConnectionNotifications(null, null, null, null, null, actionDescribeVpcEndpointConnectionNotificationsAction, actionDescribeVpcEndpointConnectionNotificationsVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.ConnectionNotificationSet));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeVpcEndpointConnectionNotifications', 'getDescribeVpcEndpointConnectionNotifications', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeVpcEndpointConnectionsAction = 'fakedata';
    const actionDescribeVpcEndpointConnectionsVersion = 'fakedata';
    describe('#postDescribeVpcEndpointConnections - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeVpcEndpointConnections(actionDescribeVpcEndpointConnectionsAction, actionDescribeVpcEndpointConnectionsVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.VpcEndpointConnections));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeVpcEndpointConnections', 'postDescribeVpcEndpointConnections', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeVpcEndpointConnections - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeVpcEndpointConnections(null, null, null, null, actionDescribeVpcEndpointConnectionsAction, actionDescribeVpcEndpointConnectionsVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.VpcEndpointConnections));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeVpcEndpointConnections', 'getDescribeVpcEndpointConnections', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeVpcEndpointServiceConfigurationsAction = 'fakedata';
    const actionDescribeVpcEndpointServiceConfigurationsVersion = 'fakedata';
    describe('#postDescribeVpcEndpointServiceConfigurations - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeVpcEndpointServiceConfigurations(actionDescribeVpcEndpointServiceConfigurationsAction, actionDescribeVpcEndpointServiceConfigurationsVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.ServiceConfigurations));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeVpcEndpointServiceConfigurations', 'postDescribeVpcEndpointServiceConfigurations', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeVpcEndpointServiceConfigurations - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeVpcEndpointServiceConfigurations(null, null, null, null, null, actionDescribeVpcEndpointServiceConfigurationsAction, actionDescribeVpcEndpointServiceConfigurationsVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.ServiceConfigurations));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeVpcEndpointServiceConfigurations', 'getDescribeVpcEndpointServiceConfigurations', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeVpcEndpointServicePermissionsAction = 'fakedata';
    const actionDescribeVpcEndpointServicePermissionsVersion = 'fakedata';
    const actionDescribeVpcEndpointServicePermissionsBodyFormData = 'fakedata';
    describe('#postDescribeVpcEndpointServicePermissions - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeVpcEndpointServicePermissions(actionDescribeVpcEndpointServicePermissionsAction, actionDescribeVpcEndpointServicePermissionsVersion, actionDescribeVpcEndpointServicePermissionsBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.AllowedPrincipals));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeVpcEndpointServicePermissions', 'postDescribeVpcEndpointServicePermissions', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeVpcEndpointServicePermissionsServiceId = 'fakedata';
    describe('#getDescribeVpcEndpointServicePermissions - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeVpcEndpointServicePermissions(null, actionDescribeVpcEndpointServicePermissionsServiceId, null, null, null, actionDescribeVpcEndpointServicePermissionsAction, actionDescribeVpcEndpointServicePermissionsVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.AllowedPrincipals));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeVpcEndpointServicePermissions', 'getDescribeVpcEndpointServicePermissions', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeVpcEndpointServicesAction = 'fakedata';
    const actionDescribeVpcEndpointServicesVersion = 'fakedata';
    describe('#postDescribeVpcEndpointServices - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeVpcEndpointServices(actionDescribeVpcEndpointServicesAction, actionDescribeVpcEndpointServicesVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.ServiceNames));
              assert.equal(true, Array.isArray(data.response.ServiceDetails));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeVpcEndpointServices', 'postDescribeVpcEndpointServices', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeVpcEndpointServices - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeVpcEndpointServices(null, null, null, null, null, actionDescribeVpcEndpointServicesAction, actionDescribeVpcEndpointServicesVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.ServiceNames));
              assert.equal(true, Array.isArray(data.response.ServiceDetails));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeVpcEndpointServices', 'getDescribeVpcEndpointServices', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeVpcEndpointsAction = 'fakedata';
    const actionDescribeVpcEndpointsVersion = 'fakedata';
    describe('#postDescribeVpcEndpoints - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeVpcEndpoints(actionDescribeVpcEndpointsAction, actionDescribeVpcEndpointsVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.VpcEndpoints));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeVpcEndpoints', 'postDescribeVpcEndpoints', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeVpcEndpoints - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeVpcEndpoints(null, null, null, null, null, actionDescribeVpcEndpointsAction, actionDescribeVpcEndpointsVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.VpcEndpoints));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeVpcEndpoints', 'getDescribeVpcEndpoints', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeVpcPeeringConnectionsAction = 'fakedata';
    const actionDescribeVpcPeeringConnectionsVersion = 'fakedata';
    describe('#postDescribeVpcPeeringConnections - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeVpcPeeringConnections(actionDescribeVpcPeeringConnectionsAction, actionDescribeVpcPeeringConnectionsVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.VpcPeeringConnections));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeVpcPeeringConnections', 'postDescribeVpcPeeringConnections', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeVpcPeeringConnections - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeVpcPeeringConnections(null, null, null, null, null, actionDescribeVpcPeeringConnectionsAction, actionDescribeVpcPeeringConnectionsVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.VpcPeeringConnections));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeVpcPeeringConnections', 'getDescribeVpcPeeringConnections', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeVpcsAction = 'fakedata';
    const actionDescribeVpcsVersion = 'fakedata';
    describe('#postDescribeVpcs - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeVpcs(actionDescribeVpcsAction, actionDescribeVpcsVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.Vpcs));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeVpcs', 'postDescribeVpcs', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeVpcs - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeVpcs(null, null, null, null, null, actionDescribeVpcsAction, actionDescribeVpcsVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.Vpcs));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeVpcs', 'getDescribeVpcs', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeVpnConnectionsAction = 'fakedata';
    const actionDescribeVpnConnectionsVersion = 'fakedata';
    describe('#postDescribeVpnConnections - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeVpnConnections(actionDescribeVpnConnectionsAction, actionDescribeVpnConnectionsVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.VpnConnections));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeVpnConnections', 'postDescribeVpnConnections', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeVpnConnections - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeVpnConnections(null, null, null, actionDescribeVpnConnectionsAction, actionDescribeVpnConnectionsVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.VpnConnections));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeVpnConnections', 'getDescribeVpnConnections', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDescribeVpnGatewaysAction = 'fakedata';
    const actionDescribeVpnGatewaysVersion = 'fakedata';
    describe('#postDescribeVpnGateways - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeVpnGateways(actionDescribeVpnGatewaysAction, actionDescribeVpnGatewaysVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.VpnGateways));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeVpnGateways', 'postDescribeVpnGateways', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeVpnGateways - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeVpnGateways(null, null, null, actionDescribeVpnGatewaysAction, actionDescribeVpnGatewaysVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.VpnGateways));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDescribeVpnGateways', 'getDescribeVpnGateways', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDetachClassicLinkVpcAction = 'fakedata';
    const actionDetachClassicLinkVpcVersion = 'fakedata';
    const actionDetachClassicLinkVpcBodyFormData = 'fakedata';
    describe('#postDetachClassicLinkVpc - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDetachClassicLinkVpc(actionDetachClassicLinkVpcAction, actionDetachClassicLinkVpcVersion, actionDetachClassicLinkVpcBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(false, data.response.Return);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDetachClassicLinkVpc', 'postDetachClassicLinkVpc', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDetachClassicLinkVpcInstanceId = 'fakedata';
    const actionDetachClassicLinkVpcVpcId = 'fakedata';
    describe('#getDetachClassicLinkVpc - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDetachClassicLinkVpc(null, actionDetachClassicLinkVpcInstanceId, actionDetachClassicLinkVpcVpcId, actionDetachClassicLinkVpcAction, actionDetachClassicLinkVpcVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(false, data.response.Return);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDetachClassicLinkVpc', 'getDetachClassicLinkVpc', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDetachInternetGatewayAction = 'fakedata';
    const actionDetachInternetGatewayVersion = 'fakedata';
    const actionDetachInternetGatewayBodyFormData = 'fakedata';
    describe('#postDetachInternetGateway - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postDetachInternetGateway(actionDetachInternetGatewayAction, actionDetachInternetGatewayVersion, actionDetachInternetGatewayBodyFormData, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDetachInternetGateway', 'postDetachInternetGateway', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDetachInternetGatewayInternetGatewayId = 'fakedata';
    const actionDetachInternetGatewayVpcId = 'fakedata';
    describe('#getDetachInternetGateway - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getDetachInternetGateway(null, actionDetachInternetGatewayInternetGatewayId, actionDetachInternetGatewayVpcId, actionDetachInternetGatewayAction, actionDetachInternetGatewayVersion, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDetachInternetGateway', 'getDetachInternetGateway', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDetachNetworkInterfaceAction = 'fakedata';
    const actionDetachNetworkInterfaceVersion = 'fakedata';
    const actionDetachNetworkInterfaceBodyFormData = 'fakedata';
    describe('#postDetachNetworkInterface - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postDetachNetworkInterface(actionDetachNetworkInterfaceAction, actionDetachNetworkInterfaceVersion, actionDetachNetworkInterfaceBodyFormData, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDetachNetworkInterface', 'postDetachNetworkInterface', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDetachNetworkInterfaceAttachmentId = 'fakedata';
    describe('#getDetachNetworkInterface - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getDetachNetworkInterface(actionDetachNetworkInterfaceAttachmentId, null, null, actionDetachNetworkInterfaceAction, actionDetachNetworkInterfaceVersion, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDetachNetworkInterface', 'getDetachNetworkInterface', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    let actionDetachVolumeVolumeId = 'fakedata';
    const actionDetachVolumeAction = 'fakedata';
    const actionDetachVolumeVersion = 'fakedata';
    const actionDetachVolumeBodyFormData = 'fakedata';
    describe('#postDetachVolume - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDetachVolume(actionDetachVolumeAction, actionDetachVolumeVersion, actionDetachVolumeBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.AttachTime);
              assert.equal('string', data.response.device);
              assert.equal('string', data.response.instanceId);
              assert.equal('attached', data.response.State);
              assert.equal('string', data.response.volumeId);
              assert.equal(false, data.response.DeleteOnTermination);
            } else {
              runCommonAsserts(data, error);
            }
            actionDetachVolumeVolumeId = data.response.volumeId;
            saveMockData('ActionDetachVolume', 'postDetachVolume', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDetachVolume - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDetachVolume(null, null, null, actionDetachVolumeVolumeId, null, actionDetachVolumeAction, actionDetachVolumeVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.AttachTime);
              assert.equal('string', data.response.device);
              assert.equal('string', data.response.instanceId);
              assert.equal('detaching', data.response.State);
              assert.equal('string', data.response.volumeId);
              assert.equal(true, data.response.DeleteOnTermination);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDetachVolume', 'getDetachVolume', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDetachVpnGatewayAction = 'fakedata';
    const actionDetachVpnGatewayVersion = 'fakedata';
    const actionDetachVpnGatewayBodyFormData = 'fakedata';
    describe('#postDetachVpnGateway - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postDetachVpnGateway(actionDetachVpnGatewayAction, actionDetachVpnGatewayVersion, actionDetachVpnGatewayBodyFormData, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDetachVpnGateway', 'postDetachVpnGateway', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDetachVpnGatewayVpcId = 'fakedata';
    const actionDetachVpnGatewayVpnGatewayId = 'fakedata';
    describe('#getDetachVpnGateway - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getDetachVpnGateway(actionDetachVpnGatewayVpcId, actionDetachVpnGatewayVpnGatewayId, null, actionDetachVpnGatewayAction, actionDetachVpnGatewayVersion, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDetachVpnGateway', 'getDetachVpnGateway', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDisableTransitGatewayRouteTablePropagationAction = 'fakedata';
    const actionDisableTransitGatewayRouteTablePropagationVersion = 'fakedata';
    const actionDisableTransitGatewayRouteTablePropagationBodyFormData = 'fakedata';
    describe('#postDisableTransitGatewayRouteTablePropagation - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDisableTransitGatewayRouteTablePropagation(actionDisableTransitGatewayRouteTablePropagationAction, actionDisableTransitGatewayRouteTablePropagationVersion, actionDisableTransitGatewayRouteTablePropagationBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.Propagation);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDisableTransitGatewayRouteTablePropagation', 'postDisableTransitGatewayRouteTablePropagation', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDisableTransitGatewayRouteTablePropagationTransitGatewayRouteTableId = 'fakedata';
    const actionDisableTransitGatewayRouteTablePropagationTransitGatewayAttachmentId = 'fakedata';
    describe('#getDisableTransitGatewayRouteTablePropagation - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDisableTransitGatewayRouteTablePropagation(actionDisableTransitGatewayRouteTablePropagationTransitGatewayRouteTableId, actionDisableTransitGatewayRouteTablePropagationTransitGatewayAttachmentId, null, actionDisableTransitGatewayRouteTablePropagationAction, actionDisableTransitGatewayRouteTablePropagationVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.Propagation);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDisableTransitGatewayRouteTablePropagation', 'getDisableTransitGatewayRouteTablePropagation', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDisableVgwRoutePropagationAction = 'fakedata';
    const actionDisableVgwRoutePropagationVersion = 'fakedata';
    const actionDisableVgwRoutePropagationBodyFormData = 'fakedata';
    describe('#postDisableVgwRoutePropagation - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postDisableVgwRoutePropagation(actionDisableVgwRoutePropagationAction, actionDisableVgwRoutePropagationVersion, actionDisableVgwRoutePropagationBodyFormData, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDisableVgwRoutePropagation', 'postDisableVgwRoutePropagation', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDisableVgwRoutePropagationGatewayId = 'fakedata';
    const actionDisableVgwRoutePropagationRouteTableId = 'fakedata';
    describe('#getDisableVgwRoutePropagation - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getDisableVgwRoutePropagation(actionDisableVgwRoutePropagationGatewayId, actionDisableVgwRoutePropagationRouteTableId, actionDisableVgwRoutePropagationAction, actionDisableVgwRoutePropagationVersion, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDisableVgwRoutePropagation', 'getDisableVgwRoutePropagation', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDisableVpcClassicLinkAction = 'fakedata';
    const actionDisableVpcClassicLinkVersion = 'fakedata';
    const actionDisableVpcClassicLinkBodyFormData = 'fakedata';
    describe('#postDisableVpcClassicLink - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDisableVpcClassicLink(actionDisableVpcClassicLinkAction, actionDisableVpcClassicLinkVersion, actionDisableVpcClassicLinkBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, data.response.Return);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDisableVpcClassicLink', 'postDisableVpcClassicLink', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDisableVpcClassicLinkVpcId = 'fakedata';
    describe('#getDisableVpcClassicLink - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDisableVpcClassicLink(null, actionDisableVpcClassicLinkVpcId, actionDisableVpcClassicLinkAction, actionDisableVpcClassicLinkVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(false, data.response.Return);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDisableVpcClassicLink', 'getDisableVpcClassicLink', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDisableVpcClassicLinkDnsSupportAction = 'fakedata';
    const actionDisableVpcClassicLinkDnsSupportVersion = 'fakedata';
    describe('#postDisableVpcClassicLinkDnsSupport - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDisableVpcClassicLinkDnsSupport(actionDisableVpcClassicLinkDnsSupportAction, actionDisableVpcClassicLinkDnsSupportVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, data.response.Return);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDisableVpcClassicLinkDnsSupport', 'postDisableVpcClassicLinkDnsSupport', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDisableVpcClassicLinkDnsSupport - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDisableVpcClassicLinkDnsSupport(null, actionDisableVpcClassicLinkDnsSupportAction, actionDisableVpcClassicLinkDnsSupportVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, data.response.Return);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDisableVpcClassicLinkDnsSupport', 'getDisableVpcClassicLinkDnsSupport', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDisassociateAddressAction = 'fakedata';
    const actionDisassociateAddressVersion = 'fakedata';
    describe('#postDisassociateAddress - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postDisassociateAddress(actionDisassociateAddressAction, actionDisassociateAddressVersion, null, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDisassociateAddress', 'postDisassociateAddress', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDisassociateAddress - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getDisassociateAddress(null, null, null, actionDisassociateAddressAction, actionDisassociateAddressVersion, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDisassociateAddress', 'getDisassociateAddress', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    let actionDisassociateClientVpnTargetNetworkAssociationId = 'fakedata';
    const actionDisassociateClientVpnTargetNetworkAction = 'fakedata';
    const actionDisassociateClientVpnTargetNetworkVersion = 'fakedata';
    const actionDisassociateClientVpnTargetNetworkBodyFormData = 'fakedata';
    describe('#postDisassociateClientVpnTargetNetwork - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDisassociateClientVpnTargetNetwork(actionDisassociateClientVpnTargetNetworkAction, actionDisassociateClientVpnTargetNetworkVersion, actionDisassociateClientVpnTargetNetworkBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.associationId);
              assert.equal('object', typeof data.response.Status);
            } else {
              runCommonAsserts(data, error);
            }
            actionDisassociateClientVpnTargetNetworkAssociationId = data.response.associationId;
            saveMockData('ActionDisassociateClientVpnTargetNetwork', 'postDisassociateClientVpnTargetNetwork', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDisassociateClientVpnTargetNetworkClientVpnEndpointId = 'fakedata';
    describe('#getDisassociateClientVpnTargetNetwork - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDisassociateClientVpnTargetNetwork(actionDisassociateClientVpnTargetNetworkClientVpnEndpointId, actionDisassociateClientVpnTargetNetworkAssociationId, null, actionDisassociateClientVpnTargetNetworkAction, actionDisassociateClientVpnTargetNetworkVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.associationId);
              assert.equal('object', typeof data.response.Status);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDisassociateClientVpnTargetNetwork', 'getDisassociateClientVpnTargetNetwork', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDisassociateIamInstanceProfileAction = 'fakedata';
    const actionDisassociateIamInstanceProfileVersion = 'fakedata';
    const actionDisassociateIamInstanceProfileBodyFormData = 'fakedata';
    describe('#postDisassociateIamInstanceProfile - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDisassociateIamInstanceProfile(actionDisassociateIamInstanceProfileAction, actionDisassociateIamInstanceProfileVersion, actionDisassociateIamInstanceProfileBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.IamInstanceProfileAssociation);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDisassociateIamInstanceProfile', 'postDisassociateIamInstanceProfile', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDisassociateIamInstanceProfileAssociationId = 'fakedata';
    describe('#getDisassociateIamInstanceProfile - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDisassociateIamInstanceProfile(actionDisassociateIamInstanceProfileAssociationId, actionDisassociateIamInstanceProfileAction, actionDisassociateIamInstanceProfileVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.IamInstanceProfileAssociation);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDisassociateIamInstanceProfile', 'getDisassociateIamInstanceProfile', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDisassociateRouteTableAction = 'fakedata';
    const actionDisassociateRouteTableVersion = 'fakedata';
    const actionDisassociateRouteTableBodyFormData = 'fakedata';
    describe('#postDisassociateRouteTable - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postDisassociateRouteTable(actionDisassociateRouteTableAction, actionDisassociateRouteTableVersion, actionDisassociateRouteTableBodyFormData, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDisassociateRouteTable', 'postDisassociateRouteTable', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDisassociateRouteTableAssociationId = 'fakedata';
    describe('#getDisassociateRouteTable - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getDisassociateRouteTable(actionDisassociateRouteTableAssociationId, null, actionDisassociateRouteTableAction, actionDisassociateRouteTableVersion, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDisassociateRouteTable', 'getDisassociateRouteTable', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDisassociateSubnetCidrBlockAction = 'fakedata';
    const actionDisassociateSubnetCidrBlockVersion = 'fakedata';
    const actionDisassociateSubnetCidrBlockBodyFormData = 'fakedata';
    describe('#postDisassociateSubnetCidrBlock - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDisassociateSubnetCidrBlock(actionDisassociateSubnetCidrBlockAction, actionDisassociateSubnetCidrBlockVersion, actionDisassociateSubnetCidrBlockBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.Ipv6CidrBlockAssociation);
              assert.equal('string', data.response.SubnetId);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDisassociateSubnetCidrBlock', 'postDisassociateSubnetCidrBlock', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDisassociateSubnetCidrBlockAssociationId = 'fakedata';
    describe('#getDisassociateSubnetCidrBlock - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDisassociateSubnetCidrBlock(actionDisassociateSubnetCidrBlockAssociationId, actionDisassociateSubnetCidrBlockAction, actionDisassociateSubnetCidrBlockVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.Ipv6CidrBlockAssociation);
              assert.equal('string', data.response.SubnetId);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDisassociateSubnetCidrBlock', 'getDisassociateSubnetCidrBlock', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDisassociateTransitGatewayRouteTableAction = 'fakedata';
    const actionDisassociateTransitGatewayRouteTableVersion = 'fakedata';
    const actionDisassociateTransitGatewayRouteTableBodyFormData = 'fakedata';
    describe('#postDisassociateTransitGatewayRouteTable - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDisassociateTransitGatewayRouteTable(actionDisassociateTransitGatewayRouteTableAction, actionDisassociateTransitGatewayRouteTableVersion, actionDisassociateTransitGatewayRouteTableBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.Association);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDisassociateTransitGatewayRouteTable', 'postDisassociateTransitGatewayRouteTable', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDisassociateTransitGatewayRouteTableTransitGatewayRouteTableId = 'fakedata';
    const actionDisassociateTransitGatewayRouteTableTransitGatewayAttachmentId = 'fakedata';
    describe('#getDisassociateTransitGatewayRouteTable - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDisassociateTransitGatewayRouteTable(actionDisassociateTransitGatewayRouteTableTransitGatewayRouteTableId, actionDisassociateTransitGatewayRouteTableTransitGatewayAttachmentId, null, actionDisassociateTransitGatewayRouteTableAction, actionDisassociateTransitGatewayRouteTableVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.Association);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDisassociateTransitGatewayRouteTable', 'getDisassociateTransitGatewayRouteTable', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDisassociateVpcCidrBlockAction = 'fakedata';
    const actionDisassociateVpcCidrBlockVersion = 'fakedata';
    const actionDisassociateVpcCidrBlockBodyFormData = 'fakedata';
    describe('#postDisassociateVpcCidrBlock - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postDisassociateVpcCidrBlock(actionDisassociateVpcCidrBlockAction, actionDisassociateVpcCidrBlockVersion, actionDisassociateVpcCidrBlockBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.Ipv6CidrBlockAssociation);
              assert.equal('object', typeof data.response.CidrBlockAssociation);
              assert.equal('string', data.response.VpcId);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDisassociateVpcCidrBlock', 'postDisassociateVpcCidrBlock', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionDisassociateVpcCidrBlockAssociationId = 'fakedata';
    describe('#getDisassociateVpcCidrBlock - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getDisassociateVpcCidrBlock(actionDisassociateVpcCidrBlockAssociationId, actionDisassociateVpcCidrBlockAction, actionDisassociateVpcCidrBlockVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.Ipv6CidrBlockAssociation);
              assert.equal('object', typeof data.response.CidrBlockAssociation);
              assert.equal('string', data.response.VpcId);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionDisassociateVpcCidrBlock', 'getDisassociateVpcCidrBlock', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionEnableTransitGatewayRouteTablePropagationAction = 'fakedata';
    const actionEnableTransitGatewayRouteTablePropagationVersion = 'fakedata';
    const actionEnableTransitGatewayRouteTablePropagationBodyFormData = 'fakedata';
    describe('#postEnableTransitGatewayRouteTablePropagation - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postEnableTransitGatewayRouteTablePropagation(actionEnableTransitGatewayRouteTablePropagationAction, actionEnableTransitGatewayRouteTablePropagationVersion, actionEnableTransitGatewayRouteTablePropagationBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.Propagation);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionEnableTransitGatewayRouteTablePropagation', 'postEnableTransitGatewayRouteTablePropagation', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionEnableTransitGatewayRouteTablePropagationTransitGatewayRouteTableId = 'fakedata';
    const actionEnableTransitGatewayRouteTablePropagationTransitGatewayAttachmentId = 'fakedata';
    describe('#getEnableTransitGatewayRouteTablePropagation - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getEnableTransitGatewayRouteTablePropagation(actionEnableTransitGatewayRouteTablePropagationTransitGatewayRouteTableId, actionEnableTransitGatewayRouteTablePropagationTransitGatewayAttachmentId, null, actionEnableTransitGatewayRouteTablePropagationAction, actionEnableTransitGatewayRouteTablePropagationVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.Propagation);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionEnableTransitGatewayRouteTablePropagation', 'getEnableTransitGatewayRouteTablePropagation', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionEnableVgwRoutePropagationAction = 'fakedata';
    const actionEnableVgwRoutePropagationVersion = 'fakedata';
    const actionEnableVgwRoutePropagationBodyFormData = 'fakedata';
    describe('#postEnableVgwRoutePropagation - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postEnableVgwRoutePropagation(actionEnableVgwRoutePropagationAction, actionEnableVgwRoutePropagationVersion, actionEnableVgwRoutePropagationBodyFormData, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionEnableVgwRoutePropagation', 'postEnableVgwRoutePropagation', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionEnableVgwRoutePropagationGatewayId = 'fakedata';
    const actionEnableVgwRoutePropagationRouteTableId = 'fakedata';
    describe('#getEnableVgwRoutePropagation - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getEnableVgwRoutePropagation(actionEnableVgwRoutePropagationGatewayId, actionEnableVgwRoutePropagationRouteTableId, actionEnableVgwRoutePropagationAction, actionEnableVgwRoutePropagationVersion, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionEnableVgwRoutePropagation', 'getEnableVgwRoutePropagation', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionEnableVolumeIOAction = 'fakedata';
    const actionEnableVolumeIOVersion = 'fakedata';
    const actionEnableVolumeIOBodyFormData = 'fakedata';
    describe('#postEnableVolumeIO - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postEnableVolumeIO(actionEnableVolumeIOAction, actionEnableVolumeIOVersion, actionEnableVolumeIOBodyFormData, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionEnableVolumeIO', 'postEnableVolumeIO', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionEnableVolumeIOVolumeId = 'fakedata';
    describe('#getEnableVolumeIO - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getEnableVolumeIO(null, actionEnableVolumeIOVolumeId, actionEnableVolumeIOAction, actionEnableVolumeIOVersion, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionEnableVolumeIO', 'getEnableVolumeIO', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionEnableVpcClassicLinkAction = 'fakedata';
    const actionEnableVpcClassicLinkVersion = 'fakedata';
    const actionEnableVpcClassicLinkBodyFormData = 'fakedata';
    describe('#postEnableVpcClassicLink - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postEnableVpcClassicLink(actionEnableVpcClassicLinkAction, actionEnableVpcClassicLinkVersion, actionEnableVpcClassicLinkBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(false, data.response.Return);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionEnableVpcClassicLink', 'postEnableVpcClassicLink', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionEnableVpcClassicLinkVpcId = 'fakedata';
    describe('#getEnableVpcClassicLink - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getEnableVpcClassicLink(null, actionEnableVpcClassicLinkVpcId, actionEnableVpcClassicLinkAction, actionEnableVpcClassicLinkVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, data.response.Return);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionEnableVpcClassicLink', 'getEnableVpcClassicLink', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionEnableVpcClassicLinkDnsSupportAction = 'fakedata';
    const actionEnableVpcClassicLinkDnsSupportVersion = 'fakedata';
    describe('#postEnableVpcClassicLinkDnsSupport - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postEnableVpcClassicLinkDnsSupport(actionEnableVpcClassicLinkDnsSupportAction, actionEnableVpcClassicLinkDnsSupportVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(false, data.response.Return);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionEnableVpcClassicLinkDnsSupport', 'postEnableVpcClassicLinkDnsSupport', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getEnableVpcClassicLinkDnsSupport - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getEnableVpcClassicLinkDnsSupport(null, actionEnableVpcClassicLinkDnsSupportAction, actionEnableVpcClassicLinkDnsSupportVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, data.response.Return);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionEnableVpcClassicLinkDnsSupport', 'getEnableVpcClassicLinkDnsSupport', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionExportClientVpnClientCertificateRevocationListAction = 'fakedata';
    const actionExportClientVpnClientCertificateRevocationListVersion = 'fakedata';
    const actionExportClientVpnClientCertificateRevocationListBodyFormData = 'fakedata';
    describe('#postExportClientVpnClientCertificateRevocationList - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postExportClientVpnClientCertificateRevocationList(actionExportClientVpnClientCertificateRevocationListAction, actionExportClientVpnClientCertificateRevocationListVersion, actionExportClientVpnClientCertificateRevocationListBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.CertificateRevocationList);
              assert.equal('object', typeof data.response.Status);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionExportClientVpnClientCertificateRevocationList', 'postExportClientVpnClientCertificateRevocationList', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionExportClientVpnClientCertificateRevocationListClientVpnEndpointId = 'fakedata';
    describe('#getExportClientVpnClientCertificateRevocationList - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getExportClientVpnClientCertificateRevocationList(actionExportClientVpnClientCertificateRevocationListClientVpnEndpointId, null, actionExportClientVpnClientCertificateRevocationListAction, actionExportClientVpnClientCertificateRevocationListVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.CertificateRevocationList);
              assert.equal('object', typeof data.response.Status);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionExportClientVpnClientCertificateRevocationList', 'getExportClientVpnClientCertificateRevocationList', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionExportClientVpnClientConfigurationAction = 'fakedata';
    const actionExportClientVpnClientConfigurationVersion = 'fakedata';
    const actionExportClientVpnClientConfigurationBodyFormData = 'fakedata';
    describe('#postExportClientVpnClientConfiguration - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postExportClientVpnClientConfiguration(actionExportClientVpnClientConfigurationAction, actionExportClientVpnClientConfigurationVersion, actionExportClientVpnClientConfigurationBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.ClientConfiguration);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionExportClientVpnClientConfiguration', 'postExportClientVpnClientConfiguration', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionExportClientVpnClientConfigurationClientVpnEndpointId = 'fakedata';
    describe('#getExportClientVpnClientConfiguration - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getExportClientVpnClientConfiguration(actionExportClientVpnClientConfigurationClientVpnEndpointId, null, actionExportClientVpnClientConfigurationAction, actionExportClientVpnClientConfigurationVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.ClientConfiguration);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionExportClientVpnClientConfiguration', 'getExportClientVpnClientConfiguration', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionExportTransitGatewayRoutesAction = 'fakedata';
    const actionExportTransitGatewayRoutesVersion = 'fakedata';
    const actionExportTransitGatewayRoutesBodyFormData = 'fakedata';
    describe('#postExportTransitGatewayRoutes - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postExportTransitGatewayRoutes(actionExportTransitGatewayRoutesAction, actionExportTransitGatewayRoutesVersion, actionExportTransitGatewayRoutesBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.S3Location);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionExportTransitGatewayRoutes', 'postExportTransitGatewayRoutes', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionExportTransitGatewayRoutesTransitGatewayRouteTableId = 'fakedata';
    const actionExportTransitGatewayRoutesS3Bucket = 'fakedata';
    describe('#getExportTransitGatewayRoutes - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getExportTransitGatewayRoutes(actionExportTransitGatewayRoutesTransitGatewayRouteTableId, null, actionExportTransitGatewayRoutesS3Bucket, null, actionExportTransitGatewayRoutesAction, actionExportTransitGatewayRoutesVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.S3Location);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionExportTransitGatewayRoutes', 'getExportTransitGatewayRoutes', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    let actionGetConsoleOutputInstanceId = 'fakedata';
    const actionGetConsoleOutputAction = 'fakedata';
    const actionGetConsoleOutputVersion = 'fakedata';
    const actionGetConsoleOutputBodyFormData = 'fakedata';
    describe('#postGetConsoleOutput - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postGetConsoleOutput(actionGetConsoleOutputAction, actionGetConsoleOutputVersion, actionGetConsoleOutputBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.instanceId);
              assert.equal('string', data.response.Output);
              assert.equal('string', data.response.Timestamp);
            } else {
              runCommonAsserts(data, error);
            }
            actionGetConsoleOutputInstanceId = data.response.instanceId;
            saveMockData('ActionGetConsoleOutput', 'postGetConsoleOutput', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getGetConsoleOutput - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getGetConsoleOutput(actionGetConsoleOutputInstanceId, null, null, actionGetConsoleOutputAction, actionGetConsoleOutputVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.instanceId);
              assert.equal('string', data.response.Output);
              assert.equal('string', data.response.Timestamp);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionGetConsoleOutput', 'getGetConsoleOutput', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    let actionGetConsoleScreenshotInstanceId = 'fakedata';
    const actionGetConsoleScreenshotAction = 'fakedata';
    const actionGetConsoleScreenshotVersion = 'fakedata';
    const actionGetConsoleScreenshotBodyFormData = 'fakedata';
    describe('#postGetConsoleScreenshot - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postGetConsoleScreenshot(actionGetConsoleScreenshotAction, actionGetConsoleScreenshotVersion, actionGetConsoleScreenshotBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.ImageData);
              assert.equal('string', data.response.instanceId);
            } else {
              runCommonAsserts(data, error);
            }
            actionGetConsoleScreenshotInstanceId = data.response.instanceId;
            saveMockData('ActionGetConsoleScreenshot', 'postGetConsoleScreenshot', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getGetConsoleScreenshot - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getGetConsoleScreenshot(null, actionGetConsoleScreenshotInstanceId, null, actionGetConsoleScreenshotAction, actionGetConsoleScreenshotVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.ImageData);
              assert.equal('string', data.response.instanceId);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionGetConsoleScreenshot', 'getGetConsoleScreenshot', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionGetHostReservationPurchasePreviewAction = 'fakedata';
    const actionGetHostReservationPurchasePreviewVersion = 'fakedata';
    const actionGetHostReservationPurchasePreviewBodyFormData = 'fakedata';
    describe('#postGetHostReservationPurchasePreview - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postGetHostReservationPurchasePreview(actionGetHostReservationPurchasePreviewAction, actionGetHostReservationPurchasePreviewVersion, actionGetHostReservationPurchasePreviewBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('USD', data.response.CurrencyCode);
              assert.equal(true, Array.isArray(data.response.Purchase));
              assert.equal('string', data.response.TotalHourlyPrice);
              assert.equal('string', data.response.TotalUpfrontPrice);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionGetHostReservationPurchasePreview', 'postGetHostReservationPurchasePreview', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionGetHostReservationPurchasePreviewHostIdSet = [];
    const actionGetHostReservationPurchasePreviewOfferingId = 'fakedata';
    describe('#getGetHostReservationPurchasePreview - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getGetHostReservationPurchasePreview(actionGetHostReservationPurchasePreviewHostIdSet, actionGetHostReservationPurchasePreviewOfferingId, actionGetHostReservationPurchasePreviewAction, actionGetHostReservationPurchasePreviewVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('USD', data.response.CurrencyCode);
              assert.equal(true, Array.isArray(data.response.Purchase));
              assert.equal('string', data.response.TotalHourlyPrice);
              assert.equal('string', data.response.TotalUpfrontPrice);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionGetHostReservationPurchasePreview', 'getGetHostReservationPurchasePreview', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionGetLaunchTemplateDataAction = 'fakedata';
    const actionGetLaunchTemplateDataVersion = 'fakedata';
    const actionGetLaunchTemplateDataBodyFormData = 'fakedata';
    describe('#postGetLaunchTemplateData - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postGetLaunchTemplateData(actionGetLaunchTemplateDataAction, actionGetLaunchTemplateDataVersion, actionGetLaunchTemplateDataBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.LaunchTemplateData);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionGetLaunchTemplateData', 'postGetLaunchTemplateData', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionGetLaunchTemplateDataInstanceId = 'fakedata';
    describe('#getGetLaunchTemplateData - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getGetLaunchTemplateData(null, actionGetLaunchTemplateDataInstanceId, actionGetLaunchTemplateDataAction, actionGetLaunchTemplateDataVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.LaunchTemplateData);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionGetLaunchTemplateData', 'getGetLaunchTemplateData', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    let actionGetPasswordDataInstanceId = 'fakedata';
    const actionGetPasswordDataAction = 'fakedata';
    const actionGetPasswordDataVersion = 'fakedata';
    const actionGetPasswordDataBodyFormData = 'fakedata';
    describe('#postGetPasswordData - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postGetPasswordData(actionGetPasswordDataAction, actionGetPasswordDataVersion, actionGetPasswordDataBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.instanceId);
              assert.equal('string', data.response.PasswordData);
              assert.equal('string', data.response.Timestamp);
            } else {
              runCommonAsserts(data, error);
            }
            actionGetPasswordDataInstanceId = data.response.instanceId;
            saveMockData('ActionGetPasswordData', 'postGetPasswordData', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getGetPasswordData - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getGetPasswordData(actionGetPasswordDataInstanceId, null, actionGetPasswordDataAction, actionGetPasswordDataVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.instanceId);
              assert.equal('string', data.response.PasswordData);
              assert.equal('string', data.response.Timestamp);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionGetPasswordData', 'getGetPasswordData', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionGetReservedInstancesExchangeQuoteAction = 'fakedata';
    const actionGetReservedInstancesExchangeQuoteVersion = 'fakedata';
    const actionGetReservedInstancesExchangeQuoteBodyFormData = 'fakedata';
    describe('#postGetReservedInstancesExchangeQuote - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postGetReservedInstancesExchangeQuote(actionGetReservedInstancesExchangeQuoteAction, actionGetReservedInstancesExchangeQuoteVersion, actionGetReservedInstancesExchangeQuoteBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.CurrencyCode);
              assert.equal(false, data.response.IsValidExchange);
              assert.equal('string', data.response.OutputReservedInstancesWillExpireAt);
              assert.equal('string', data.response.PaymentDue);
              assert.equal('object', typeof data.response.ReservedInstanceValueRollup);
              assert.equal(true, Array.isArray(data.response.ReservedInstanceValueSet));
              assert.equal('object', typeof data.response.TargetConfigurationValueRollup);
              assert.equal(true, Array.isArray(data.response.TargetConfigurationValueSet));
              assert.equal('string', data.response.ValidationFailureReason);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionGetReservedInstancesExchangeQuote', 'postGetReservedInstancesExchangeQuote', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionGetReservedInstancesExchangeQuoteReservedInstanceId = [];
    describe('#getGetReservedInstancesExchangeQuote - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getGetReservedInstancesExchangeQuote(null, actionGetReservedInstancesExchangeQuoteReservedInstanceId, null, actionGetReservedInstancesExchangeQuoteAction, actionGetReservedInstancesExchangeQuoteVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.CurrencyCode);
              assert.equal(true, data.response.IsValidExchange);
              assert.equal('string', data.response.OutputReservedInstancesWillExpireAt);
              assert.equal('string', data.response.PaymentDue);
              assert.equal('object', typeof data.response.ReservedInstanceValueRollup);
              assert.equal(true, Array.isArray(data.response.ReservedInstanceValueSet));
              assert.equal('object', typeof data.response.TargetConfigurationValueRollup);
              assert.equal(true, Array.isArray(data.response.TargetConfigurationValueSet));
              assert.equal('string', data.response.ValidationFailureReason);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionGetReservedInstancesExchangeQuote', 'getGetReservedInstancesExchangeQuote', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionGetTransitGatewayAttachmentPropagationsAction = 'fakedata';
    const actionGetTransitGatewayAttachmentPropagationsVersion = 'fakedata';
    const actionGetTransitGatewayAttachmentPropagationsBodyFormData = 'fakedata';
    describe('#postGetTransitGatewayAttachmentPropagations - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postGetTransitGatewayAttachmentPropagations(actionGetTransitGatewayAttachmentPropagationsAction, actionGetTransitGatewayAttachmentPropagationsVersion, actionGetTransitGatewayAttachmentPropagationsBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.TransitGatewayAttachmentPropagations));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionGetTransitGatewayAttachmentPropagations', 'postGetTransitGatewayAttachmentPropagations', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionGetTransitGatewayAttachmentPropagationsTransitGatewayAttachmentId = 'fakedata';
    describe('#getGetTransitGatewayAttachmentPropagations - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getGetTransitGatewayAttachmentPropagations(actionGetTransitGatewayAttachmentPropagationsTransitGatewayAttachmentId, null, null, null, null, actionGetTransitGatewayAttachmentPropagationsAction, actionGetTransitGatewayAttachmentPropagationsVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.TransitGatewayAttachmentPropagations));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionGetTransitGatewayAttachmentPropagations', 'getGetTransitGatewayAttachmentPropagations', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionGetTransitGatewayRouteTableAssociationsAction = 'fakedata';
    const actionGetTransitGatewayRouteTableAssociationsVersion = 'fakedata';
    const actionGetTransitGatewayRouteTableAssociationsBodyFormData = 'fakedata';
    describe('#postGetTransitGatewayRouteTableAssociations - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postGetTransitGatewayRouteTableAssociations(actionGetTransitGatewayRouteTableAssociationsAction, actionGetTransitGatewayRouteTableAssociationsVersion, actionGetTransitGatewayRouteTableAssociationsBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.Associations));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionGetTransitGatewayRouteTableAssociations', 'postGetTransitGatewayRouteTableAssociations', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionGetTransitGatewayRouteTableAssociationsTransitGatewayRouteTableId = 'fakedata';
    describe('#getGetTransitGatewayRouteTableAssociations - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getGetTransitGatewayRouteTableAssociations(actionGetTransitGatewayRouteTableAssociationsTransitGatewayRouteTableId, null, null, null, null, actionGetTransitGatewayRouteTableAssociationsAction, actionGetTransitGatewayRouteTableAssociationsVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.Associations));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionGetTransitGatewayRouteTableAssociations', 'getGetTransitGatewayRouteTableAssociations', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionGetTransitGatewayRouteTablePropagationsAction = 'fakedata';
    const actionGetTransitGatewayRouteTablePropagationsVersion = 'fakedata';
    const actionGetTransitGatewayRouteTablePropagationsBodyFormData = 'fakedata';
    describe('#postGetTransitGatewayRouteTablePropagations - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postGetTransitGatewayRouteTablePropagations(actionGetTransitGatewayRouteTablePropagationsAction, actionGetTransitGatewayRouteTablePropagationsVersion, actionGetTransitGatewayRouteTablePropagationsBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.TransitGatewayRouteTablePropagations));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionGetTransitGatewayRouteTablePropagations', 'postGetTransitGatewayRouteTablePropagations', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionGetTransitGatewayRouteTablePropagationsTransitGatewayRouteTableId = 'fakedata';
    describe('#getGetTransitGatewayRouteTablePropagations - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getGetTransitGatewayRouteTablePropagations(actionGetTransitGatewayRouteTablePropagationsTransitGatewayRouteTableId, null, null, null, null, actionGetTransitGatewayRouteTablePropagationsAction, actionGetTransitGatewayRouteTablePropagationsVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.TransitGatewayRouteTablePropagations));
              assert.equal('string', data.response.nextToken);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionGetTransitGatewayRouteTablePropagations', 'getGetTransitGatewayRouteTablePropagations', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionImportClientVpnClientCertificateRevocationListAction = 'fakedata';
    const actionImportClientVpnClientCertificateRevocationListVersion = 'fakedata';
    const actionImportClientVpnClientCertificateRevocationListBodyFormData = 'fakedata';
    describe('#postImportClientVpnClientCertificateRevocationList - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postImportClientVpnClientCertificateRevocationList(actionImportClientVpnClientCertificateRevocationListAction, actionImportClientVpnClientCertificateRevocationListVersion, actionImportClientVpnClientCertificateRevocationListBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, data.response.Return);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionImportClientVpnClientCertificateRevocationList', 'postImportClientVpnClientCertificateRevocationList', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionImportClientVpnClientCertificateRevocationListClientVpnEndpointId = 'fakedata';
    const actionImportClientVpnClientCertificateRevocationListCertificateRevocationList = 'fakedata';
    describe('#getImportClientVpnClientCertificateRevocationList - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getImportClientVpnClientCertificateRevocationList(actionImportClientVpnClientCertificateRevocationListClientVpnEndpointId, actionImportClientVpnClientCertificateRevocationListCertificateRevocationList, null, actionImportClientVpnClientCertificateRevocationListAction, actionImportClientVpnClientCertificateRevocationListVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(false, data.response.Return);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionImportClientVpnClientCertificateRevocationList', 'getImportClientVpnClientCertificateRevocationList', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionImportImageAction = 'fakedata';
    const actionImportImageVersion = 'fakedata';
    describe('#postImportImage - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postImportImage(actionImportImageAction, actionImportImageVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.architecture);
              assert.equal('string', data.response.description);
              assert.equal(false, data.response.encrypted);
              assert.equal('string', data.response.hypervisor);
              assert.equal('string', data.response.ImageId);
              assert.equal('string', data.response.ImportTaskId);
              assert.equal('string', data.response.kmsKeyId);
              assert.equal('string', data.response.licenseType);
              assert.equal('string', data.response.platform);
              assert.equal('string', data.response.Progress);
              assert.equal(true, Array.isArray(data.response.SnapshotDetails));
              assert.equal('string', data.response.Status);
              assert.equal('string', data.response.StatusMessage);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionImportImage', 'postImportImage', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getImportImage - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getImportImage(null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, actionImportImageAction, actionImportImageVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.architecture);
              assert.equal('string', data.response.description);
              assert.equal(false, data.response.encrypted);
              assert.equal('string', data.response.hypervisor);
              assert.equal('string', data.response.ImageId);
              assert.equal('string', data.response.ImportTaskId);
              assert.equal('string', data.response.kmsKeyId);
              assert.equal('string', data.response.licenseType);
              assert.equal('string', data.response.platform);
              assert.equal('string', data.response.Progress);
              assert.equal(true, Array.isArray(data.response.SnapshotDetails));
              assert.equal('string', data.response.Status);
              assert.equal('string', data.response.StatusMessage);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionImportImage', 'getImportImage', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionImportInstanceAction = 'fakedata';
    const actionImportInstanceVersion = 'fakedata';
    const actionImportInstanceBodyFormData = 'fakedata';
    describe('#postImportInstance - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postImportInstance(actionImportInstanceAction, actionImportInstanceVersion, actionImportInstanceBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.ConversionTask);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionImportInstance', 'postImportInstance', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionImportInstancePlatform = 'fakedata';
    describe('#getImportInstance - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getImportInstance(null, null, null, null, null, null, null, null, null, null, null, null, null, null, actionImportInstancePlatform, actionImportInstanceAction, actionImportInstanceVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.ConversionTask);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionImportInstance', 'getImportInstance', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    let actionImportKeyPairKeyName = 'fakedata';
    const actionImportKeyPairAction = 'fakedata';
    const actionImportKeyPairVersion = 'fakedata';
    const actionImportKeyPairBodyFormData = 'fakedata';
    describe('#postImportKeyPair - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postImportKeyPair(actionImportKeyPairAction, actionImportKeyPairVersion, actionImportKeyPairBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.KeyFingerprint);
              assert.equal('string', data.response.keyName);
            } else {
              runCommonAsserts(data, error);
            }
            actionImportKeyPairKeyName = data.response.keyName;
            saveMockData('ActionImportKeyPair', 'postImportKeyPair', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionImportKeyPairPublicKeyMaterial = 'fakedata';
    describe('#getImportKeyPair - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getImportKeyPair(null, actionImportKeyPairKeyName, actionImportKeyPairPublicKeyMaterial, actionImportKeyPairAction, actionImportKeyPairVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.KeyFingerprint);
              assert.equal('string', data.response.keyName);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionImportKeyPair', 'getImportKeyPair', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionImportSnapshotAction = 'fakedata';
    const actionImportSnapshotVersion = 'fakedata';
    describe('#postImportSnapshot - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postImportSnapshot(actionImportSnapshotAction, actionImportSnapshotVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.description);
              assert.equal('string', data.response.ImportTaskId);
              assert.equal('object', typeof data.response.SnapshotTaskDetail);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionImportSnapshot', 'postImportSnapshot', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getImportSnapshot - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getImportSnapshot(null, null, null, null, null, null, null, null, null, null, null, null, null, null, actionImportSnapshotAction, actionImportSnapshotVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.description);
              assert.equal('string', data.response.ImportTaskId);
              assert.equal('object', typeof data.response.SnapshotTaskDetail);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionImportSnapshot', 'getImportSnapshot', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionImportVolumeAction = 'fakedata';
    const actionImportVolumeVersion = 'fakedata';
    const actionImportVolumeBodyFormData = 'fakedata';
    describe('#postImportVolume - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postImportVolume(actionImportVolumeAction, actionImportVolumeVersion, actionImportVolumeBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.ConversionTask);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionImportVolume', 'postImportVolume', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionImportVolumeAvailabilityZone = 'fakedata';
    describe('#getImportVolume - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getImportVolume(actionImportVolumeAvailabilityZone, null, null, null, null, null, null, actionImportVolumeAction, actionImportVolumeVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.ConversionTask);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionImportVolume', 'getImportVolume', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionModifyCapacityReservationAction = 'fakedata';
    const actionModifyCapacityReservationVersion = 'fakedata';
    const actionModifyCapacityReservationBodyFormData = 'fakedata';
    describe('#postModifyCapacityReservation - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyCapacityReservation(actionModifyCapacityReservationAction, actionModifyCapacityReservationVersion, actionModifyCapacityReservationBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(false, data.response.Return);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionModifyCapacityReservation', 'postModifyCapacityReservation', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionModifyCapacityReservationCapacityReservationId = 'fakedata';
    describe('#getModifyCapacityReservation - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyCapacityReservation(actionModifyCapacityReservationCapacityReservationId, null, null, null, null, actionModifyCapacityReservationAction, actionModifyCapacityReservationVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(false, data.response.Return);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionModifyCapacityReservation', 'getModifyCapacityReservation', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionModifyClientVpnEndpointAction = 'fakedata';
    const actionModifyClientVpnEndpointVersion = 'fakedata';
    const actionModifyClientVpnEndpointBodyFormData = 'fakedata';
    describe('#postModifyClientVpnEndpoint - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyClientVpnEndpoint(actionModifyClientVpnEndpointAction, actionModifyClientVpnEndpointVersion, actionModifyClientVpnEndpointBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(false, data.response.Return);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionModifyClientVpnEndpoint', 'postModifyClientVpnEndpoint', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionModifyClientVpnEndpointClientVpnEndpointId = 'fakedata';
    describe('#getModifyClientVpnEndpoint - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyClientVpnEndpoint(actionModifyClientVpnEndpointClientVpnEndpointId, null, null, null, null, null, null, null, null, actionModifyClientVpnEndpointAction, actionModifyClientVpnEndpointVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, data.response.Return);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionModifyClientVpnEndpoint', 'getModifyClientVpnEndpoint', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionModifyFleetAction = 'fakedata';
    const actionModifyFleetVersion = 'fakedata';
    const actionModifyFleetBodyFormData = 'fakedata';
    describe('#postModifyFleet - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyFleet(actionModifyFleetAction, actionModifyFleetVersion, actionModifyFleetBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, data.response.Return);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionModifyFleet', 'postModifyFleet', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionModifyFleetFleetId = 'fakedata';
    describe('#getModifyFleet - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyFleet(null, null, actionModifyFleetFleetId, null, null, null, null, actionModifyFleetAction, actionModifyFleetVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(false, data.response.Return);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionModifyFleet', 'getModifyFleet', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionModifyFpgaImageAttributeAction = 'fakedata';
    const actionModifyFpgaImageAttributeVersion = 'fakedata';
    const actionModifyFpgaImageAttributeBodyFormData = 'fakedata';
    describe('#postModifyFpgaImageAttribute - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyFpgaImageAttribute(actionModifyFpgaImageAttributeAction, actionModifyFpgaImageAttributeVersion, actionModifyFpgaImageAttributeBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.FpgaImageAttribute);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionModifyFpgaImageAttribute', 'postModifyFpgaImageAttribute', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionModifyFpgaImageAttributeFpgaImageId = 'fakedata';
    describe('#getModifyFpgaImageAttribute - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyFpgaImageAttribute(null, actionModifyFpgaImageAttributeFpgaImageId, null, null, null, null, null, null, null, null, null, actionModifyFpgaImageAttributeAction, actionModifyFpgaImageAttributeVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.FpgaImageAttribute);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionModifyFpgaImageAttribute', 'getModifyFpgaImageAttribute', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionModifyHostsAction = 'fakedata';
    const actionModifyHostsVersion = 'fakedata';
    const actionModifyHostsBodyFormData = 'fakedata';
    describe('#postModifyHosts - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyHosts(actionModifyHostsAction, actionModifyHostsVersion, actionModifyHostsBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.Successful));
              assert.equal(true, Array.isArray(data.response.Unsuccessful));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionModifyHosts', 'postModifyHosts', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionModifyHostsAutoPlacement = 'fakedata';
    const actionModifyHostsHostId = [];
    describe('#getModifyHosts - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyHosts(actionModifyHostsAutoPlacement, actionModifyHostsHostId, actionModifyHostsAction, actionModifyHostsVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.Successful));
              assert.equal(true, Array.isArray(data.response.Unsuccessful));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionModifyHosts', 'getModifyHosts', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionModifyIdFormatAction = 'fakedata';
    const actionModifyIdFormatVersion = 'fakedata';
    const actionModifyIdFormatBodyFormData = 'fakedata';
    describe('#postModifyIdFormat - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyIdFormat(actionModifyIdFormatAction, actionModifyIdFormatVersion, actionModifyIdFormatBodyFormData, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionModifyIdFormat', 'postModifyIdFormat', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionModifyIdFormatResource = 'fakedata';
    const actionModifyIdFormatUseLongIds = true;
    describe('#getModifyIdFormat - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyIdFormat(actionModifyIdFormatResource, actionModifyIdFormatUseLongIds, actionModifyIdFormatAction, actionModifyIdFormatVersion, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionModifyIdFormat', 'getModifyIdFormat', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionModifyIdentityIdFormatAction = 'fakedata';
    const actionModifyIdentityIdFormatVersion = 'fakedata';
    const actionModifyIdentityIdFormatBodyFormData = 'fakedata';
    describe('#postModifyIdentityIdFormat - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyIdentityIdFormat(actionModifyIdentityIdFormatAction, actionModifyIdentityIdFormatVersion, actionModifyIdentityIdFormatBodyFormData, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionModifyIdentityIdFormat', 'postModifyIdentityIdFormat', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionModifyIdentityIdFormatPrincipalArn = 'fakedata';
    const actionModifyIdentityIdFormatResource = 'fakedata';
    const actionModifyIdentityIdFormatUseLongIds = true;
    describe('#getModifyIdentityIdFormat - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyIdentityIdFormat(actionModifyIdentityIdFormatPrincipalArn, actionModifyIdentityIdFormatResource, actionModifyIdentityIdFormatUseLongIds, actionModifyIdentityIdFormatAction, actionModifyIdentityIdFormatVersion, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionModifyIdentityIdFormat', 'getModifyIdentityIdFormat', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionModifyImageAttributeAction = 'fakedata';
    const actionModifyImageAttributeVersion = 'fakedata';
    const actionModifyImageAttributeBodyFormData = 'fakedata';
    describe('#postModifyImageAttribute - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyImageAttribute(actionModifyImageAttributeAction, actionModifyImageAttributeVersion, actionModifyImageAttributeBodyFormData, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionModifyImageAttribute', 'postModifyImageAttribute', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionModifyImageAttributeImageId = 'fakedata';
    describe('#getModifyImageAttribute - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyImageAttribute(null, null, actionModifyImageAttributeImageId, null, null, null, null, null, null, null, null, actionModifyImageAttributeAction, actionModifyImageAttributeVersion, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionModifyImageAttribute', 'getModifyImageAttribute', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionModifyInstanceAttributeAction = 'fakedata';
    const actionModifyInstanceAttributeVersion = 'fakedata';
    const actionModifyInstanceAttributeBodyFormData = 'fakedata';
    describe('#postModifyInstanceAttribute - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyInstanceAttribute(actionModifyInstanceAttributeAction, actionModifyInstanceAttributeVersion, actionModifyInstanceAttributeBodyFormData, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionModifyInstanceAttribute', 'postModifyInstanceAttribute', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionModifyInstanceAttributeInstanceId = 'fakedata';
    describe('#getModifyInstanceAttribute - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyInstanceAttribute(null, null, null, null, null, null, null, null, actionModifyInstanceAttributeInstanceId, null, null, null, null, null, null, null, actionModifyInstanceAttributeAction, actionModifyInstanceAttributeVersion, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionModifyInstanceAttribute', 'getModifyInstanceAttribute', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionModifyInstanceCapacityReservationAttributesAction = 'fakedata';
    const actionModifyInstanceCapacityReservationAttributesVersion = 'fakedata';
    const actionModifyInstanceCapacityReservationAttributesBodyFormData = 'fakedata';
    describe('#postModifyInstanceCapacityReservationAttributes - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyInstanceCapacityReservationAttributes(actionModifyInstanceCapacityReservationAttributesAction, actionModifyInstanceCapacityReservationAttributesVersion, actionModifyInstanceCapacityReservationAttributesBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(false, data.response.Return);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionModifyInstanceCapacityReservationAttributes', 'postModifyInstanceCapacityReservationAttributes', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionModifyInstanceCapacityReservationAttributesInstanceId = 'fakedata';
    describe('#getModifyInstanceCapacityReservationAttributes - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyInstanceCapacityReservationAttributes(actionModifyInstanceCapacityReservationAttributesInstanceId, null, null, null, actionModifyInstanceCapacityReservationAttributesAction, actionModifyInstanceCapacityReservationAttributesVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, data.response.Return);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionModifyInstanceCapacityReservationAttributes', 'getModifyInstanceCapacityReservationAttributes', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionModifyInstanceCreditSpecificationAction = 'fakedata';
    const actionModifyInstanceCreditSpecificationVersion = 'fakedata';
    const actionModifyInstanceCreditSpecificationBodyFormData = 'fakedata';
    describe('#postModifyInstanceCreditSpecification - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyInstanceCreditSpecification(actionModifyInstanceCreditSpecificationAction, actionModifyInstanceCreditSpecificationVersion, actionModifyInstanceCreditSpecificationBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.SuccessfulInstanceCreditSpecifications));
              assert.equal(true, Array.isArray(data.response.UnsuccessfulInstanceCreditSpecifications));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionModifyInstanceCreditSpecification', 'postModifyInstanceCreditSpecification', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionModifyInstanceCreditSpecificationInstanceCreditSpecification = [];
    describe('#getModifyInstanceCreditSpecification - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyInstanceCreditSpecification(null, null, actionModifyInstanceCreditSpecificationInstanceCreditSpecification, actionModifyInstanceCreditSpecificationAction, actionModifyInstanceCreditSpecificationVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.SuccessfulInstanceCreditSpecifications));
              assert.equal(true, Array.isArray(data.response.UnsuccessfulInstanceCreditSpecifications));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionModifyInstanceCreditSpecification', 'getModifyInstanceCreditSpecification', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionModifyInstanceEventStartTimeAction = 'fakedata';
    const actionModifyInstanceEventStartTimeVersion = 'fakedata';
    const actionModifyInstanceEventStartTimeBodyFormData = 'fakedata';
    describe('#postModifyInstanceEventStartTime - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyInstanceEventStartTime(actionModifyInstanceEventStartTimeAction, actionModifyInstanceEventStartTimeVersion, actionModifyInstanceEventStartTimeBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.Event);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionModifyInstanceEventStartTime', 'postModifyInstanceEventStartTime', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionModifyInstanceEventStartTimeInstanceId = 'fakedata';
    const actionModifyInstanceEventStartTimeInstanceEventId = 'fakedata';
    const actionModifyInstanceEventStartTimeNotBefore = 'fakedata';
    describe('#getModifyInstanceEventStartTime - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyInstanceEventStartTime(null, actionModifyInstanceEventStartTimeInstanceId, actionModifyInstanceEventStartTimeInstanceEventId, actionModifyInstanceEventStartTimeNotBefore, actionModifyInstanceEventStartTimeAction, actionModifyInstanceEventStartTimeVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.Event);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionModifyInstanceEventStartTime', 'getModifyInstanceEventStartTime', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionModifyInstancePlacementAction = 'fakedata';
    const actionModifyInstancePlacementVersion = 'fakedata';
    const actionModifyInstancePlacementBodyFormData = 'fakedata';
    describe('#postModifyInstancePlacement - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyInstancePlacement(actionModifyInstancePlacementAction, actionModifyInstancePlacementVersion, actionModifyInstancePlacementBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, data.response.Return);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionModifyInstancePlacement', 'postModifyInstancePlacement', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionModifyInstancePlacementInstanceId = 'fakedata';
    describe('#getModifyInstancePlacement - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyInstancePlacement(null, null, null, actionModifyInstancePlacementInstanceId, null, null, actionModifyInstancePlacementAction, actionModifyInstancePlacementVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(false, data.response.Return);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionModifyInstancePlacement', 'getModifyInstancePlacement', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionModifyLaunchTemplateAction = 'fakedata';
    const actionModifyLaunchTemplateVersion = 'fakedata';
    describe('#postModifyLaunchTemplate - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyLaunchTemplate(actionModifyLaunchTemplateAction, actionModifyLaunchTemplateVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.LaunchTemplate);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionModifyLaunchTemplate', 'postModifyLaunchTemplate', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getModifyLaunchTemplate - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyLaunchTemplate(null, null, null, null, null, actionModifyLaunchTemplateAction, actionModifyLaunchTemplateVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.LaunchTemplate);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionModifyLaunchTemplate', 'getModifyLaunchTemplate', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionModifyNetworkInterfaceAttributeAction = 'fakedata';
    const actionModifyNetworkInterfaceAttributeVersion = 'fakedata';
    const actionModifyNetworkInterfaceAttributeBodyFormData = 'fakedata';
    describe('#postModifyNetworkInterfaceAttribute - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyNetworkInterfaceAttribute(actionModifyNetworkInterfaceAttributeAction, actionModifyNetworkInterfaceAttributeVersion, actionModifyNetworkInterfaceAttributeBodyFormData, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionModifyNetworkInterfaceAttribute', 'postModifyNetworkInterfaceAttribute', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionModifyNetworkInterfaceAttributeNetworkInterfaceId = 'fakedata';
    describe('#getModifyNetworkInterfaceAttribute - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyNetworkInterfaceAttribute(null, null, null, null, null, actionModifyNetworkInterfaceAttributeNetworkInterfaceId, null, actionModifyNetworkInterfaceAttributeAction, actionModifyNetworkInterfaceAttributeVersion, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionModifyNetworkInterfaceAttribute', 'getModifyNetworkInterfaceAttribute', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionModifyReservedInstancesAction = 'fakedata';
    const actionModifyReservedInstancesVersion = 'fakedata';
    const actionModifyReservedInstancesBodyFormData = 'fakedata';
    describe('#postModifyReservedInstances - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyReservedInstances(actionModifyReservedInstancesAction, actionModifyReservedInstancesVersion, actionModifyReservedInstancesBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.ReservedInstancesModificationId);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionModifyReservedInstances', 'postModifyReservedInstances', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionModifyReservedInstancesReservedInstancesId = [];
    const actionModifyReservedInstancesReservedInstancesConfigurationSetItemType = [];
    describe('#getModifyReservedInstances - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyReservedInstances(actionModifyReservedInstancesReservedInstancesId, null, actionModifyReservedInstancesReservedInstancesConfigurationSetItemType, actionModifyReservedInstancesAction, actionModifyReservedInstancesVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.ReservedInstancesModificationId);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionModifyReservedInstances', 'getModifyReservedInstances', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionModifySnapshotAttributeAction = 'fakedata';
    const actionModifySnapshotAttributeVersion = 'fakedata';
    const actionModifySnapshotAttributeBodyFormData = 'fakedata';
    describe('#postModifySnapshotAttribute - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postModifySnapshotAttribute(actionModifySnapshotAttributeAction, actionModifySnapshotAttributeVersion, actionModifySnapshotAttributeBodyFormData, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionModifySnapshotAttribute', 'postModifySnapshotAttribute', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionModifySnapshotAttributeSnapshotId = 'fakedata';
    describe('#getModifySnapshotAttribute - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getModifySnapshotAttribute(null, null, null, null, null, actionModifySnapshotAttributeSnapshotId, null, null, actionModifySnapshotAttributeAction, actionModifySnapshotAttributeVersion, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionModifySnapshotAttribute', 'getModifySnapshotAttribute', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionModifySpotFleetRequestAction = 'fakedata';
    const actionModifySpotFleetRequestVersion = 'fakedata';
    const actionModifySpotFleetRequestBodyFormData = 'fakedata';
    describe('#postModifySpotFleetRequest - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postModifySpotFleetRequest(actionModifySpotFleetRequestAction, actionModifySpotFleetRequestVersion, actionModifySpotFleetRequestBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, data.response.Return);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionModifySpotFleetRequest', 'postModifySpotFleetRequest', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionModifySpotFleetRequestSpotFleetRequestId = 'fakedata';
    describe('#getModifySpotFleetRequest - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getModifySpotFleetRequest(null, actionModifySpotFleetRequestSpotFleetRequestId, null, actionModifySpotFleetRequestAction, actionModifySpotFleetRequestVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, data.response.Return);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionModifySpotFleetRequest', 'getModifySpotFleetRequest', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionModifySubnetAttributeAction = 'fakedata';
    const actionModifySubnetAttributeVersion = 'fakedata';
    const actionModifySubnetAttributeBodyFormData = 'fakedata';
    describe('#postModifySubnetAttribute - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postModifySubnetAttribute(actionModifySubnetAttributeAction, actionModifySubnetAttributeVersion, actionModifySubnetAttributeBodyFormData, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionModifySubnetAttribute', 'postModifySubnetAttribute', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionModifySubnetAttributeSubnetId = 'fakedata';
    describe('#getModifySubnetAttribute - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getModifySubnetAttribute(null, null, actionModifySubnetAttributeSubnetId, actionModifySubnetAttributeAction, actionModifySubnetAttributeVersion, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionModifySubnetAttribute', 'getModifySubnetAttribute', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionModifyTransitGatewayVpcAttachmentAction = 'fakedata';
    const actionModifyTransitGatewayVpcAttachmentVersion = 'fakedata';
    const actionModifyTransitGatewayVpcAttachmentBodyFormData = 'fakedata';
    describe('#postModifyTransitGatewayVpcAttachment - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyTransitGatewayVpcAttachment(actionModifyTransitGatewayVpcAttachmentAction, actionModifyTransitGatewayVpcAttachmentVersion, actionModifyTransitGatewayVpcAttachmentBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.TransitGatewayVpcAttachment);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionModifyTransitGatewayVpcAttachment', 'postModifyTransitGatewayVpcAttachment', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionModifyTransitGatewayVpcAttachmentTransitGatewayAttachmentId = 'fakedata';
    describe('#getModifyTransitGatewayVpcAttachment - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyTransitGatewayVpcAttachment(actionModifyTransitGatewayVpcAttachmentTransitGatewayAttachmentId, null, null, null, null, null, actionModifyTransitGatewayVpcAttachmentAction, actionModifyTransitGatewayVpcAttachmentVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.TransitGatewayVpcAttachment);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionModifyTransitGatewayVpcAttachment', 'getModifyTransitGatewayVpcAttachment', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionModifyVolumeAction = 'fakedata';
    const actionModifyVolumeVersion = 'fakedata';
    const actionModifyVolumeBodyFormData = 'fakedata';
    describe('#postModifyVolume - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyVolume(actionModifyVolumeAction, actionModifyVolumeVersion, actionModifyVolumeBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.VolumeModification);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionModifyVolume', 'postModifyVolume', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionModifyVolumeVolumeId = 'fakedata';
    describe('#getModifyVolume - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyVolume(null, actionModifyVolumeVolumeId, null, null, null, actionModifyVolumeAction, actionModifyVolumeVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.VolumeModification);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionModifyVolume', 'getModifyVolume', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionModifyVolumeAttributeAction = 'fakedata';
    const actionModifyVolumeAttributeVersion = 'fakedata';
    const actionModifyVolumeAttributeBodyFormData = 'fakedata';
    describe('#postModifyVolumeAttribute - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyVolumeAttribute(actionModifyVolumeAttributeAction, actionModifyVolumeAttributeVersion, actionModifyVolumeAttributeBodyFormData, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionModifyVolumeAttribute', 'postModifyVolumeAttribute', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionModifyVolumeAttributeVolumeId = 'fakedata';
    describe('#getModifyVolumeAttribute - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyVolumeAttribute(null, actionModifyVolumeAttributeVolumeId, null, actionModifyVolumeAttributeAction, actionModifyVolumeAttributeVersion, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionModifyVolumeAttribute', 'getModifyVolumeAttribute', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionModifyVpcAttributeAction = 'fakedata';
    const actionModifyVpcAttributeVersion = 'fakedata';
    const actionModifyVpcAttributeBodyFormData = 'fakedata';
    describe('#postModifyVpcAttribute - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyVpcAttribute(actionModifyVpcAttributeAction, actionModifyVpcAttributeVersion, actionModifyVpcAttributeBodyFormData, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionModifyVpcAttribute', 'postModifyVpcAttribute', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionModifyVpcAttributeVpcId = 'fakedata';
    describe('#getModifyVpcAttribute - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyVpcAttribute(null, null, actionModifyVpcAttributeVpcId, actionModifyVpcAttributeAction, actionModifyVpcAttributeVersion, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionModifyVpcAttribute', 'getModifyVpcAttribute', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionModifyVpcEndpointAction = 'fakedata';
    const actionModifyVpcEndpointVersion = 'fakedata';
    const actionModifyVpcEndpointBodyFormData = 'fakedata';
    describe('#postModifyVpcEndpoint - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyVpcEndpoint(actionModifyVpcEndpointAction, actionModifyVpcEndpointVersion, actionModifyVpcEndpointBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, data.response.Return);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionModifyVpcEndpoint', 'postModifyVpcEndpoint', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionModifyVpcEndpointVpcEndpointId = 'fakedata';
    describe('#getModifyVpcEndpoint - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyVpcEndpoint(null, actionModifyVpcEndpointVpcEndpointId, null, null, null, null, null, null, null, null, null, actionModifyVpcEndpointAction, actionModifyVpcEndpointVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, data.response.Return);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionModifyVpcEndpoint', 'getModifyVpcEndpoint', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionModifyVpcEndpointConnectionNotificationAction = 'fakedata';
    const actionModifyVpcEndpointConnectionNotificationVersion = 'fakedata';
    const actionModifyVpcEndpointConnectionNotificationBodyFormData = 'fakedata';
    describe('#postModifyVpcEndpointConnectionNotification - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyVpcEndpointConnectionNotification(actionModifyVpcEndpointConnectionNotificationAction, actionModifyVpcEndpointConnectionNotificationVersion, actionModifyVpcEndpointConnectionNotificationBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(false, data.response.ReturnValue);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionModifyVpcEndpointConnectionNotification', 'postModifyVpcEndpointConnectionNotification', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionModifyVpcEndpointConnectionNotificationConnectionNotificationId = 'fakedata';
    describe('#getModifyVpcEndpointConnectionNotification - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyVpcEndpointConnectionNotification(null, actionModifyVpcEndpointConnectionNotificationConnectionNotificationId, null, null, actionModifyVpcEndpointConnectionNotificationAction, actionModifyVpcEndpointConnectionNotificationVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(false, data.response.ReturnValue);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionModifyVpcEndpointConnectionNotification', 'getModifyVpcEndpointConnectionNotification', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionModifyVpcEndpointServiceConfigurationAction = 'fakedata';
    const actionModifyVpcEndpointServiceConfigurationVersion = 'fakedata';
    const actionModifyVpcEndpointServiceConfigurationBodyFormData = 'fakedata';
    describe('#postModifyVpcEndpointServiceConfiguration - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyVpcEndpointServiceConfiguration(actionModifyVpcEndpointServiceConfigurationAction, actionModifyVpcEndpointServiceConfigurationVersion, actionModifyVpcEndpointServiceConfigurationBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, data.response.Return);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionModifyVpcEndpointServiceConfiguration', 'postModifyVpcEndpointServiceConfiguration', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionModifyVpcEndpointServiceConfigurationServiceId = 'fakedata';
    describe('#getModifyVpcEndpointServiceConfiguration - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyVpcEndpointServiceConfiguration(null, actionModifyVpcEndpointServiceConfigurationServiceId, null, null, null, actionModifyVpcEndpointServiceConfigurationAction, actionModifyVpcEndpointServiceConfigurationVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, data.response.Return);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionModifyVpcEndpointServiceConfiguration', 'getModifyVpcEndpointServiceConfiguration', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionModifyVpcEndpointServicePermissionsAction = 'fakedata';
    const actionModifyVpcEndpointServicePermissionsVersion = 'fakedata';
    const actionModifyVpcEndpointServicePermissionsBodyFormData = 'fakedata';
    describe('#postModifyVpcEndpointServicePermissions - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyVpcEndpointServicePermissions(actionModifyVpcEndpointServicePermissionsAction, actionModifyVpcEndpointServicePermissionsVersion, actionModifyVpcEndpointServicePermissionsBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, data.response.ReturnValue);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionModifyVpcEndpointServicePermissions', 'postModifyVpcEndpointServicePermissions', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionModifyVpcEndpointServicePermissionsServiceId = 'fakedata';
    describe('#getModifyVpcEndpointServicePermissions - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyVpcEndpointServicePermissions(null, actionModifyVpcEndpointServicePermissionsServiceId, null, null, actionModifyVpcEndpointServicePermissionsAction, actionModifyVpcEndpointServicePermissionsVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, data.response.ReturnValue);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionModifyVpcEndpointServicePermissions', 'getModifyVpcEndpointServicePermissions', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionModifyVpcPeeringConnectionOptionsAction = 'fakedata';
    const actionModifyVpcPeeringConnectionOptionsVersion = 'fakedata';
    const actionModifyVpcPeeringConnectionOptionsBodyFormData = 'fakedata';
    describe('#postModifyVpcPeeringConnectionOptions - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyVpcPeeringConnectionOptions(actionModifyVpcPeeringConnectionOptionsAction, actionModifyVpcPeeringConnectionOptionsVersion, actionModifyVpcPeeringConnectionOptionsBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.AccepterPeeringConnectionOptions);
              assert.equal('object', typeof data.response.RequesterPeeringConnectionOptions);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionModifyVpcPeeringConnectionOptions', 'postModifyVpcPeeringConnectionOptions', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionModifyVpcPeeringConnectionOptionsVpcPeeringConnectionId = 'fakedata';
    describe('#getModifyVpcPeeringConnectionOptions - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyVpcPeeringConnectionOptions(null, null, null, null, null, null, null, actionModifyVpcPeeringConnectionOptionsVpcPeeringConnectionId, actionModifyVpcPeeringConnectionOptionsAction, actionModifyVpcPeeringConnectionOptionsVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.AccepterPeeringConnectionOptions);
              assert.equal('object', typeof data.response.RequesterPeeringConnectionOptions);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionModifyVpcPeeringConnectionOptions', 'getModifyVpcPeeringConnectionOptions', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionModifyVpcTenancyAction = 'fakedata';
    const actionModifyVpcTenancyVersion = 'fakedata';
    const actionModifyVpcTenancyBodyFormData = 'fakedata';
    describe('#postModifyVpcTenancy - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyVpcTenancy(actionModifyVpcTenancyAction, actionModifyVpcTenancyVersion, actionModifyVpcTenancyBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, data.response.ReturnValue);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionModifyVpcTenancy', 'postModifyVpcTenancy', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionModifyVpcTenancyVpcId = 'fakedata';
    const actionModifyVpcTenancyInstanceTenancy = 'fakedata';
    describe('#getModifyVpcTenancy - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyVpcTenancy(actionModifyVpcTenancyVpcId, actionModifyVpcTenancyInstanceTenancy, null, actionModifyVpcTenancyAction, actionModifyVpcTenancyVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(false, data.response.ReturnValue);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionModifyVpcTenancy', 'getModifyVpcTenancy', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionModifyVpnConnectionAction = 'fakedata';
    const actionModifyVpnConnectionVersion = 'fakedata';
    const actionModifyVpnConnectionBodyFormData = 'fakedata';
    describe('#postModifyVpnConnection - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyVpnConnection(actionModifyVpnConnectionAction, actionModifyVpnConnectionVersion, actionModifyVpnConnectionBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.VpnConnection);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionModifyVpnConnection', 'postModifyVpnConnection', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionModifyVpnConnectionVpnConnectionId = 'fakedata';
    describe('#getModifyVpnConnection - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyVpnConnection(actionModifyVpnConnectionVpnConnectionId, null, null, null, actionModifyVpnConnectionAction, actionModifyVpnConnectionVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.VpnConnection);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionModifyVpnConnection', 'getModifyVpnConnection', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionMonitorInstancesAction = 'fakedata';
    const actionMonitorInstancesVersion = 'fakedata';
    const actionMonitorInstancesBodyFormData = 'fakedata';
    describe('#postMonitorInstances - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postMonitorInstances(actionMonitorInstancesAction, actionMonitorInstancesVersion, actionMonitorInstancesBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.InstanceMonitorings));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionMonitorInstances', 'postMonitorInstances', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionMonitorInstancesInstanceId = [];
    describe('#getMonitorInstances - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getMonitorInstances(actionMonitorInstancesInstanceId, null, actionMonitorInstancesAction, actionMonitorInstancesVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.InstanceMonitorings));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionMonitorInstances', 'getMonitorInstances', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionMoveAddressToVpcAction = 'fakedata';
    const actionMoveAddressToVpcVersion = 'fakedata';
    const actionMoveAddressToVpcBodyFormData = 'fakedata';
    describe('#postMoveAddressToVpc - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postMoveAddressToVpc(actionMoveAddressToVpcAction, actionMoveAddressToVpcVersion, actionMoveAddressToVpcBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.AllocationId);
              assert.equal('InClassic', data.response.Status);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionMoveAddressToVpc', 'postMoveAddressToVpc', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionMoveAddressToVpcPublicIp = 'fakedata';
    describe('#getMoveAddressToVpc - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getMoveAddressToVpc(null, actionMoveAddressToVpcPublicIp, actionMoveAddressToVpcAction, actionMoveAddressToVpcVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.AllocationId);
              assert.equal('InVpc', data.response.Status);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionMoveAddressToVpc', 'getMoveAddressToVpc', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionProvisionByoipCidrAction = 'fakedata';
    const actionProvisionByoipCidrVersion = 'fakedata';
    const actionProvisionByoipCidrBodyFormData = 'fakedata';
    describe('#postProvisionByoipCidr - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postProvisionByoipCidr(actionProvisionByoipCidrAction, actionProvisionByoipCidrVersion, actionProvisionByoipCidrBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.ByoipCidr);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionProvisionByoipCidr', 'postProvisionByoipCidr', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionProvisionByoipCidrCidr = 'fakedata';
    describe('#getProvisionByoipCidr - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getProvisionByoipCidr(actionProvisionByoipCidrCidr, null, null, null, null, actionProvisionByoipCidrAction, actionProvisionByoipCidrVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.ByoipCidr);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionProvisionByoipCidr', 'getProvisionByoipCidr', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionPurchaseHostReservationAction = 'fakedata';
    const actionPurchaseHostReservationVersion = 'fakedata';
    const actionPurchaseHostReservationBodyFormData = 'fakedata';
    describe('#postPurchaseHostReservation - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postPurchaseHostReservation(actionPurchaseHostReservationAction, actionPurchaseHostReservationVersion, actionPurchaseHostReservationBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.clientToken);
              assert.equal('USD', data.response.currencyCode);
              assert.equal(true, Array.isArray(data.response.Purchase));
              assert.equal('string', data.response.TotalHourlyPrice);
              assert.equal('string', data.response.TotalUpfrontPrice);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionPurchaseHostReservation', 'postPurchaseHostReservation', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionPurchaseHostReservationHostIdSet = [];
    const actionPurchaseHostReservationOfferingId = 'fakedata';
    describe('#getPurchaseHostReservation - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getPurchaseHostReservation(null, null, actionPurchaseHostReservationHostIdSet, null, actionPurchaseHostReservationOfferingId, actionPurchaseHostReservationAction, actionPurchaseHostReservationVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.clientToken);
              assert.equal('USD', data.response.currencyCode);
              assert.equal(true, Array.isArray(data.response.Purchase));
              assert.equal('string', data.response.TotalHourlyPrice);
              assert.equal('string', data.response.TotalUpfrontPrice);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionPurchaseHostReservation', 'getPurchaseHostReservation', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionPurchaseReservedInstancesOfferingAction = 'fakedata';
    const actionPurchaseReservedInstancesOfferingVersion = 'fakedata';
    const actionPurchaseReservedInstancesOfferingBodyFormData = 'fakedata';
    describe('#postPurchaseReservedInstancesOffering - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postPurchaseReservedInstancesOffering(actionPurchaseReservedInstancesOfferingAction, actionPurchaseReservedInstancesOfferingVersion, actionPurchaseReservedInstancesOfferingBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.ReservedInstancesId);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionPurchaseReservedInstancesOffering', 'postPurchaseReservedInstancesOffering', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionPurchaseReservedInstancesOfferingInstanceCount = 555;
    const actionPurchaseReservedInstancesOfferingReservedInstancesOfferingId = 'fakedata';
    describe('#getPurchaseReservedInstancesOffering - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getPurchaseReservedInstancesOffering(actionPurchaseReservedInstancesOfferingInstanceCount, actionPurchaseReservedInstancesOfferingReservedInstancesOfferingId, null, null, null, actionPurchaseReservedInstancesOfferingAction, actionPurchaseReservedInstancesOfferingVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.ReservedInstancesId);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionPurchaseReservedInstancesOffering', 'getPurchaseReservedInstancesOffering', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionPurchaseScheduledInstancesAction = 'fakedata';
    const actionPurchaseScheduledInstancesVersion = 'fakedata';
    const actionPurchaseScheduledInstancesBodyFormData = 'fakedata';
    describe('#postPurchaseScheduledInstances - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postPurchaseScheduledInstances(actionPurchaseScheduledInstancesAction, actionPurchaseScheduledInstancesVersion, actionPurchaseScheduledInstancesBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.ScheduledInstanceSet));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionPurchaseScheduledInstances', 'postPurchaseScheduledInstances', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionPurchaseScheduledInstancesPurchaseRequest = [];
    describe('#getPurchaseScheduledInstances - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getPurchaseScheduledInstances(null, null, actionPurchaseScheduledInstancesPurchaseRequest, actionPurchaseScheduledInstancesAction, actionPurchaseScheduledInstancesVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.ScheduledInstanceSet));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionPurchaseScheduledInstances', 'getPurchaseScheduledInstances', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionRebootInstancesAction = 'fakedata';
    const actionRebootInstancesVersion = 'fakedata';
    const actionRebootInstancesBodyFormData = 'fakedata';
    describe('#postRebootInstances - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postRebootInstances(actionRebootInstancesAction, actionRebootInstancesVersion, actionRebootInstancesBodyFormData, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionRebootInstances', 'postRebootInstances', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionRebootInstancesInstanceId = [];
    describe('#getRebootInstances - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getRebootInstances(actionRebootInstancesInstanceId, null, actionRebootInstancesAction, actionRebootInstancesVersion, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionRebootInstances', 'getRebootInstances', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionRegisterImageAction = 'fakedata';
    const actionRegisterImageVersion = 'fakedata';
    const actionRegisterImageBodyFormData = 'fakedata';
    describe('#postRegisterImage - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postRegisterImage(actionRegisterImageAction, actionRegisterImageVersion, actionRegisterImageBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.ImageId);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionRegisterImage', 'postRegisterImage', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionRegisterImageName = 'fakedata';
    describe('#getRegisterImage - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getRegisterImage(null, null, null, null, null, null, null, actionRegisterImageName, null, null, null, null, null, actionRegisterImageAction, actionRegisterImageVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.ImageId);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionRegisterImage', 'getRegisterImage', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionRejectTransitGatewayVpcAttachmentAction = 'fakedata';
    const actionRejectTransitGatewayVpcAttachmentVersion = 'fakedata';
    const actionRejectTransitGatewayVpcAttachmentBodyFormData = 'fakedata';
    describe('#postRejectTransitGatewayVpcAttachment - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postRejectTransitGatewayVpcAttachment(actionRejectTransitGatewayVpcAttachmentAction, actionRejectTransitGatewayVpcAttachmentVersion, actionRejectTransitGatewayVpcAttachmentBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.TransitGatewayVpcAttachment);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionRejectTransitGatewayVpcAttachment', 'postRejectTransitGatewayVpcAttachment', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionRejectTransitGatewayVpcAttachmentTransitGatewayAttachmentId = 'fakedata';
    describe('#getRejectTransitGatewayVpcAttachment - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getRejectTransitGatewayVpcAttachment(actionRejectTransitGatewayVpcAttachmentTransitGatewayAttachmentId, null, actionRejectTransitGatewayVpcAttachmentAction, actionRejectTransitGatewayVpcAttachmentVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.TransitGatewayVpcAttachment);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionRejectTransitGatewayVpcAttachment', 'getRejectTransitGatewayVpcAttachment', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionRejectVpcEndpointConnectionsAction = 'fakedata';
    const actionRejectVpcEndpointConnectionsVersion = 'fakedata';
    const actionRejectVpcEndpointConnectionsBodyFormData = 'fakedata';
    describe('#postRejectVpcEndpointConnections - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postRejectVpcEndpointConnections(actionRejectVpcEndpointConnectionsAction, actionRejectVpcEndpointConnectionsVersion, actionRejectVpcEndpointConnectionsBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.Unsuccessful));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionRejectVpcEndpointConnections', 'postRejectVpcEndpointConnections', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionRejectVpcEndpointConnectionsServiceId = 'fakedata';
    const actionRejectVpcEndpointConnectionsVpcEndpointId = [];
    describe('#getRejectVpcEndpointConnections - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getRejectVpcEndpointConnections(null, actionRejectVpcEndpointConnectionsServiceId, actionRejectVpcEndpointConnectionsVpcEndpointId, actionRejectVpcEndpointConnectionsAction, actionRejectVpcEndpointConnectionsVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.Unsuccessful));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionRejectVpcEndpointConnections', 'getRejectVpcEndpointConnections', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionRejectVpcPeeringConnectionAction = 'fakedata';
    const actionRejectVpcPeeringConnectionVersion = 'fakedata';
    const actionRejectVpcPeeringConnectionBodyFormData = 'fakedata';
    describe('#postRejectVpcPeeringConnection - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postRejectVpcPeeringConnection(actionRejectVpcPeeringConnectionAction, actionRejectVpcPeeringConnectionVersion, actionRejectVpcPeeringConnectionBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, data.response.Return);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionRejectVpcPeeringConnection', 'postRejectVpcPeeringConnection', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionRejectVpcPeeringConnectionVpcPeeringConnectionId = 'fakedata';
    describe('#getRejectVpcPeeringConnection - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getRejectVpcPeeringConnection(null, actionRejectVpcPeeringConnectionVpcPeeringConnectionId, actionRejectVpcPeeringConnectionAction, actionRejectVpcPeeringConnectionVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(false, data.response.Return);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionRejectVpcPeeringConnection', 'getRejectVpcPeeringConnection', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionReleaseAddressAction = 'fakedata';
    const actionReleaseAddressVersion = 'fakedata';
    describe('#postReleaseAddress - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postReleaseAddress(actionReleaseAddressAction, actionReleaseAddressVersion, null, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionReleaseAddress', 'postReleaseAddress', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getReleaseAddress - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getReleaseAddress(null, null, null, actionReleaseAddressAction, actionReleaseAddressVersion, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionReleaseAddress', 'getReleaseAddress', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionReleaseHostsAction = 'fakedata';
    const actionReleaseHostsVersion = 'fakedata';
    const actionReleaseHostsBodyFormData = 'fakedata';
    describe('#postReleaseHosts - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postReleaseHosts(actionReleaseHostsAction, actionReleaseHostsVersion, actionReleaseHostsBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.Successful));
              assert.equal(true, Array.isArray(data.response.Unsuccessful));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionReleaseHosts', 'postReleaseHosts', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionReleaseHostsHostId = [];
    describe('#getReleaseHosts - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getReleaseHosts(actionReleaseHostsHostId, actionReleaseHostsAction, actionReleaseHostsVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.Successful));
              assert.equal(true, Array.isArray(data.response.Unsuccessful));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionReleaseHosts', 'getReleaseHosts', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionReplaceIamInstanceProfileAssociationAction = 'fakedata';
    const actionReplaceIamInstanceProfileAssociationVersion = 'fakedata';
    const actionReplaceIamInstanceProfileAssociationBodyFormData = 'fakedata';
    describe('#postReplaceIamInstanceProfileAssociation - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postReplaceIamInstanceProfileAssociation(actionReplaceIamInstanceProfileAssociationAction, actionReplaceIamInstanceProfileAssociationVersion, actionReplaceIamInstanceProfileAssociationBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.IamInstanceProfileAssociation);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionReplaceIamInstanceProfileAssociation', 'postReplaceIamInstanceProfileAssociation', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionReplaceIamInstanceProfileAssociationAssociationId = 'fakedata';
    describe('#getReplaceIamInstanceProfileAssociation - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getReplaceIamInstanceProfileAssociation(null, null, actionReplaceIamInstanceProfileAssociationAssociationId, actionReplaceIamInstanceProfileAssociationAction, actionReplaceIamInstanceProfileAssociationVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.IamInstanceProfileAssociation);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionReplaceIamInstanceProfileAssociation', 'getReplaceIamInstanceProfileAssociation', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionReplaceNetworkAclAssociationAction = 'fakedata';
    const actionReplaceNetworkAclAssociationVersion = 'fakedata';
    const actionReplaceNetworkAclAssociationBodyFormData = 'fakedata';
    describe('#postReplaceNetworkAclAssociation - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postReplaceNetworkAclAssociation(actionReplaceNetworkAclAssociationAction, actionReplaceNetworkAclAssociationVersion, actionReplaceNetworkAclAssociationBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.NewAssociationId);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionReplaceNetworkAclAssociation', 'postReplaceNetworkAclAssociation', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionReplaceNetworkAclAssociationAssociationId = 'fakedata';
    const actionReplaceNetworkAclAssociationNetworkAclId = 'fakedata';
    describe('#getReplaceNetworkAclAssociation - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getReplaceNetworkAclAssociation(actionReplaceNetworkAclAssociationAssociationId, null, actionReplaceNetworkAclAssociationNetworkAclId, actionReplaceNetworkAclAssociationAction, actionReplaceNetworkAclAssociationVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.NewAssociationId);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionReplaceNetworkAclAssociation', 'getReplaceNetworkAclAssociation', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionReplaceNetworkAclEntryAction = 'fakedata';
    const actionReplaceNetworkAclEntryVersion = 'fakedata';
    const actionReplaceNetworkAclEntryBodyFormData = 'fakedata';
    describe('#postReplaceNetworkAclEntry - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postReplaceNetworkAclEntry(actionReplaceNetworkAclEntryAction, actionReplaceNetworkAclEntryVersion, actionReplaceNetworkAclEntryBodyFormData, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionReplaceNetworkAclEntry', 'postReplaceNetworkAclEntry', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionReplaceNetworkAclEntryEgress = true;
    const actionReplaceNetworkAclEntryNetworkAclId = 'fakedata';
    const actionReplaceNetworkAclEntryProtocol = 'fakedata';
    const actionReplaceNetworkAclEntryRuleAction = 'fakedata';
    const actionReplaceNetworkAclEntryRuleNumber = 555;
    describe('#getReplaceNetworkAclEntry - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getReplaceNetworkAclEntry(null, null, actionReplaceNetworkAclEntryEgress, null, null, null, actionReplaceNetworkAclEntryNetworkAclId, null, null, actionReplaceNetworkAclEntryProtocol, actionReplaceNetworkAclEntryRuleAction, actionReplaceNetworkAclEntryRuleNumber, actionReplaceNetworkAclEntryAction, actionReplaceNetworkAclEntryVersion, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionReplaceNetworkAclEntry', 'getReplaceNetworkAclEntry', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionReplaceRouteAction = 'fakedata';
    const actionReplaceRouteVersion = 'fakedata';
    const actionReplaceRouteBodyFormData = 'fakedata';
    describe('#postReplaceRoute - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postReplaceRoute(actionReplaceRouteAction, actionReplaceRouteVersion, actionReplaceRouteBodyFormData, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionReplaceRoute', 'postReplaceRoute', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionReplaceRouteRouteTableId = 'fakedata';
    describe('#getReplaceRoute - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getReplaceRoute(null, null, null, null, null, null, null, null, null, actionReplaceRouteRouteTableId, null, actionReplaceRouteAction, actionReplaceRouteVersion, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionReplaceRoute', 'getReplaceRoute', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionReplaceRouteTableAssociationAction = 'fakedata';
    const actionReplaceRouteTableAssociationVersion = 'fakedata';
    const actionReplaceRouteTableAssociationBodyFormData = 'fakedata';
    describe('#postReplaceRouteTableAssociation - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postReplaceRouteTableAssociation(actionReplaceRouteTableAssociationAction, actionReplaceRouteTableAssociationVersion, actionReplaceRouteTableAssociationBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.NewAssociationId);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionReplaceRouteTableAssociation', 'postReplaceRouteTableAssociation', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionReplaceRouteTableAssociationAssociationId = 'fakedata';
    const actionReplaceRouteTableAssociationRouteTableId = 'fakedata';
    describe('#getReplaceRouteTableAssociation - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getReplaceRouteTableAssociation(actionReplaceRouteTableAssociationAssociationId, null, actionReplaceRouteTableAssociationRouteTableId, actionReplaceRouteTableAssociationAction, actionReplaceRouteTableAssociationVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.NewAssociationId);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionReplaceRouteTableAssociation', 'getReplaceRouteTableAssociation', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionReplaceTransitGatewayRouteAction = 'fakedata';
    const actionReplaceTransitGatewayRouteVersion = 'fakedata';
    const actionReplaceTransitGatewayRouteBodyFormData = 'fakedata';
    describe('#postReplaceTransitGatewayRoute - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postReplaceTransitGatewayRoute(actionReplaceTransitGatewayRouteAction, actionReplaceTransitGatewayRouteVersion, actionReplaceTransitGatewayRouteBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.Route);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionReplaceTransitGatewayRoute', 'postReplaceTransitGatewayRoute', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionReplaceTransitGatewayRouteDestinationCidrBlock = 'fakedata';
    const actionReplaceTransitGatewayRouteTransitGatewayRouteTableId = 'fakedata';
    describe('#getReplaceTransitGatewayRoute - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getReplaceTransitGatewayRoute(actionReplaceTransitGatewayRouteDestinationCidrBlock, actionReplaceTransitGatewayRouteTransitGatewayRouteTableId, null, null, null, actionReplaceTransitGatewayRouteAction, actionReplaceTransitGatewayRouteVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.Route);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionReplaceTransitGatewayRoute', 'getReplaceTransitGatewayRoute', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionReportInstanceStatusAction = 'fakedata';
    const actionReportInstanceStatusVersion = 'fakedata';
    const actionReportInstanceStatusBodyFormData = 'fakedata';
    describe('#postReportInstanceStatus - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postReportInstanceStatus(actionReportInstanceStatusAction, actionReportInstanceStatusVersion, actionReportInstanceStatusBodyFormData, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionReportInstanceStatus', 'postReportInstanceStatus', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionReportInstanceStatusInstanceId = [];
    const actionReportInstanceStatusReasonCode = [];
    const actionReportInstanceStatusStatus = 'fakedata';
    describe('#getReportInstanceStatus - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getReportInstanceStatus(null, null, null, actionReportInstanceStatusInstanceId, actionReportInstanceStatusReasonCode, null, actionReportInstanceStatusStatus, actionReportInstanceStatusAction, actionReportInstanceStatusVersion, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionReportInstanceStatus', 'getReportInstanceStatus', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionRequestSpotFleetAction = 'fakedata';
    const actionRequestSpotFleetVersion = 'fakedata';
    describe('#postRequestSpotFleet - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postRequestSpotFleet(actionRequestSpotFleetAction, actionRequestSpotFleetVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.SpotFleetRequestId);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionRequestSpotFleet', 'postRequestSpotFleet', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getRequestSpotFleet - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getRequestSpotFleet(null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, actionRequestSpotFleetAction, actionRequestSpotFleetVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.SpotFleetRequestId);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionRequestSpotFleet', 'getRequestSpotFleet', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionRequestSpotInstancesAction = 'fakedata';
    const actionRequestSpotInstancesVersion = 'fakedata';
    describe('#postRequestSpotInstances - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postRequestSpotInstances(actionRequestSpotInstancesAction, actionRequestSpotInstancesVersion, null, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.SpotInstanceRequests));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionRequestSpotInstances', 'postRequestSpotInstances', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getRequestSpotInstances - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getRequestSpotInstances(null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, actionRequestSpotInstancesAction, actionRequestSpotInstancesVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.SpotInstanceRequests));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionRequestSpotInstances', 'getRequestSpotInstances', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionResetFpgaImageAttributeAction = 'fakedata';
    const actionResetFpgaImageAttributeVersion = 'fakedata';
    const actionResetFpgaImageAttributeBodyFormData = 'fakedata';
    describe('#postResetFpgaImageAttribute - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postResetFpgaImageAttribute(actionResetFpgaImageAttributeAction, actionResetFpgaImageAttributeVersion, actionResetFpgaImageAttributeBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(false, data.response.Return);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionResetFpgaImageAttribute', 'postResetFpgaImageAttribute', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionResetFpgaImageAttributeFpgaImageId = 'fakedata';
    describe('#getResetFpgaImageAttribute - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getResetFpgaImageAttribute(null, actionResetFpgaImageAttributeFpgaImageId, null, actionResetFpgaImageAttributeAction, actionResetFpgaImageAttributeVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, data.response.Return);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionResetFpgaImageAttribute', 'getResetFpgaImageAttribute', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionResetImageAttributeAction = 'fakedata';
    const actionResetImageAttributeVersion = 'fakedata';
    const actionResetImageAttributeBodyFormData = 'fakedata';
    describe('#postResetImageAttribute - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postResetImageAttribute(actionResetImageAttributeAction, actionResetImageAttributeVersion, actionResetImageAttributeBodyFormData, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionResetImageAttribute', 'postResetImageAttribute', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionResetImageAttributeAttribute = 'fakedata';
    const actionResetImageAttributeImageId = 'fakedata';
    describe('#getResetImageAttribute - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getResetImageAttribute(actionResetImageAttributeAttribute, actionResetImageAttributeImageId, null, actionResetImageAttributeAction, actionResetImageAttributeVersion, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionResetImageAttribute', 'getResetImageAttribute', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionResetInstanceAttributeAction = 'fakedata';
    const actionResetInstanceAttributeVersion = 'fakedata';
    const actionResetInstanceAttributeBodyFormData = 'fakedata';
    describe('#postResetInstanceAttribute - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postResetInstanceAttribute(actionResetInstanceAttributeAction, actionResetInstanceAttributeVersion, actionResetInstanceAttributeBodyFormData, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionResetInstanceAttribute', 'postResetInstanceAttribute', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionResetInstanceAttributeAttribute = 'fakedata';
    const actionResetInstanceAttributeInstanceId = 'fakedata';
    describe('#getResetInstanceAttribute - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getResetInstanceAttribute(actionResetInstanceAttributeAttribute, null, actionResetInstanceAttributeInstanceId, actionResetInstanceAttributeAction, actionResetInstanceAttributeVersion, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionResetInstanceAttribute', 'getResetInstanceAttribute', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionResetNetworkInterfaceAttributeAction = 'fakedata';
    const actionResetNetworkInterfaceAttributeVersion = 'fakedata';
    const actionResetNetworkInterfaceAttributeBodyFormData = 'fakedata';
    describe('#postResetNetworkInterfaceAttribute - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postResetNetworkInterfaceAttribute(actionResetNetworkInterfaceAttributeAction, actionResetNetworkInterfaceAttributeVersion, actionResetNetworkInterfaceAttributeBodyFormData, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionResetNetworkInterfaceAttribute', 'postResetNetworkInterfaceAttribute', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionResetNetworkInterfaceAttributeNetworkInterfaceId = 'fakedata';
    describe('#getResetNetworkInterfaceAttribute - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getResetNetworkInterfaceAttribute(null, actionResetNetworkInterfaceAttributeNetworkInterfaceId, null, actionResetNetworkInterfaceAttributeAction, actionResetNetworkInterfaceAttributeVersion, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionResetNetworkInterfaceAttribute', 'getResetNetworkInterfaceAttribute', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionResetSnapshotAttributeAction = 'fakedata';
    const actionResetSnapshotAttributeVersion = 'fakedata';
    const actionResetSnapshotAttributeBodyFormData = 'fakedata';
    describe('#postResetSnapshotAttribute - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postResetSnapshotAttribute(actionResetSnapshotAttributeAction, actionResetSnapshotAttributeVersion, actionResetSnapshotAttributeBodyFormData, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionResetSnapshotAttribute', 'postResetSnapshotAttribute', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionResetSnapshotAttributeAttribute = 'fakedata';
    const actionResetSnapshotAttributeSnapshotId = 'fakedata';
    describe('#getResetSnapshotAttribute - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getResetSnapshotAttribute(actionResetSnapshotAttributeAttribute, actionResetSnapshotAttributeSnapshotId, null, actionResetSnapshotAttributeAction, actionResetSnapshotAttributeVersion, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionResetSnapshotAttribute', 'getResetSnapshotAttribute', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    let actionRestoreAddressToClassicPublicIp = 'fakedata';
    const actionRestoreAddressToClassicAction = 'fakedata';
    const actionRestoreAddressToClassicVersion = 'fakedata';
    const actionRestoreAddressToClassicBodyFormData = 'fakedata';
    describe('#postRestoreAddressToClassic - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postRestoreAddressToClassic(actionRestoreAddressToClassicAction, actionRestoreAddressToClassicVersion, actionRestoreAddressToClassicBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.publicIp);
              assert.equal('InClassic', data.response.Status);
            } else {
              runCommonAsserts(data, error);
            }
            actionRestoreAddressToClassicPublicIp = data.response.publicIp;
            saveMockData('ActionRestoreAddressToClassic', 'postRestoreAddressToClassic', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getRestoreAddressToClassic - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getRestoreAddressToClassic(null, actionRestoreAddressToClassicPublicIp, actionRestoreAddressToClassicAction, actionRestoreAddressToClassicVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.publicIp);
              assert.equal('MoveInProgress', data.response.Status);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionRestoreAddressToClassic', 'getRestoreAddressToClassic', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionRevokeClientVpnIngressAction = 'fakedata';
    const actionRevokeClientVpnIngressVersion = 'fakedata';
    const actionRevokeClientVpnIngressBodyFormData = 'fakedata';
    describe('#postRevokeClientVpnIngress - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postRevokeClientVpnIngress(actionRevokeClientVpnIngressAction, actionRevokeClientVpnIngressVersion, actionRevokeClientVpnIngressBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.Status);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionRevokeClientVpnIngress', 'postRevokeClientVpnIngress', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionRevokeClientVpnIngressClientVpnEndpointId = 'fakedata';
    const actionRevokeClientVpnIngressTargetNetworkCidr = 'fakedata';
    describe('#getRevokeClientVpnIngress - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getRevokeClientVpnIngress(actionRevokeClientVpnIngressClientVpnEndpointId, actionRevokeClientVpnIngressTargetNetworkCidr, null, null, null, actionRevokeClientVpnIngressAction, actionRevokeClientVpnIngressVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.Status);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionRevokeClientVpnIngress', 'getRevokeClientVpnIngress', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionRevokeSecurityGroupEgressAction = 'fakedata';
    const actionRevokeSecurityGroupEgressVersion = 'fakedata';
    const actionRevokeSecurityGroupEgressBodyFormData = 'fakedata';
    describe('#postRevokeSecurityGroupEgress - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postRevokeSecurityGroupEgress(actionRevokeSecurityGroupEgressAction, actionRevokeSecurityGroupEgressVersion, actionRevokeSecurityGroupEgressBodyFormData, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionRevokeSecurityGroupEgress', 'postRevokeSecurityGroupEgress', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionRevokeSecurityGroupEgressGroupId = 'fakedata';
    describe('#getRevokeSecurityGroupEgress - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getRevokeSecurityGroupEgress(null, actionRevokeSecurityGroupEgressGroupId, null, null, null, null, null, null, null, actionRevokeSecurityGroupEgressAction, actionRevokeSecurityGroupEgressVersion, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionRevokeSecurityGroupEgress', 'getRevokeSecurityGroupEgress', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionRevokeSecurityGroupIngressAction = 'fakedata';
    const actionRevokeSecurityGroupIngressVersion = 'fakedata';
    describe('#postRevokeSecurityGroupIngress - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postRevokeSecurityGroupIngress(actionRevokeSecurityGroupIngressAction, actionRevokeSecurityGroupIngressVersion, null, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionRevokeSecurityGroupIngress', 'postRevokeSecurityGroupIngress', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getRevokeSecurityGroupIngress - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getRevokeSecurityGroupIngress(null, null, null, null, null, null, null, null, null, null, actionRevokeSecurityGroupIngressAction, actionRevokeSecurityGroupIngressVersion, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionRevokeSecurityGroupIngress', 'getRevokeSecurityGroupIngress', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionRunInstancesAction = 'fakedata';
    const actionRunInstancesVersion = 'fakedata';
    const actionRunInstancesBodyFormData = 'fakedata';
    describe('#postRunInstances - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postRunInstances(actionRunInstancesAction, actionRunInstancesVersion, actionRunInstancesBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.Groups));
              assert.equal(true, Array.isArray(data.response.Instances));
              assert.equal('string', data.response.OwnerId);
              assert.equal('string', data.response.RequesterId);
              assert.equal('string', data.response.ReservationId);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionRunInstances', 'postRunInstances', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionRunInstancesMaxCount = 555;
    const actionRunInstancesMinCount = 555;
    describe('#getRunInstances - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getRunInstances(null, null, null, null, null, null, null, actionRunInstancesMaxCount, actionRunInstancesMinCount, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, actionRunInstancesAction, actionRunInstancesVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.Groups));
              assert.equal(true, Array.isArray(data.response.Instances));
              assert.equal('string', data.response.OwnerId);
              assert.equal('string', data.response.RequesterId);
              assert.equal('string', data.response.ReservationId);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionRunInstances', 'getRunInstances', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionRunScheduledInstancesAction = 'fakedata';
    const actionRunScheduledInstancesVersion = 'fakedata';
    const actionRunScheduledInstancesBodyFormData = 'fakedata';
    describe('#postRunScheduledInstances - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postRunScheduledInstances(actionRunScheduledInstancesAction, actionRunScheduledInstancesVersion, actionRunScheduledInstancesBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.InstanceIdSet));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionRunScheduledInstances', 'postRunScheduledInstances', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionRunScheduledInstancesScheduledInstanceId = 'fakedata';
    describe('#getRunScheduledInstances - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getRunScheduledInstances(null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, actionRunScheduledInstancesScheduledInstanceId, actionRunScheduledInstancesAction, actionRunScheduledInstancesVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.InstanceIdSet));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionRunScheduledInstances', 'getRunScheduledInstances', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionSearchTransitGatewayRoutesAction = 'fakedata';
    const actionSearchTransitGatewayRoutesVersion = 'fakedata';
    const actionSearchTransitGatewayRoutesBodyFormData = 'fakedata';
    describe('#postSearchTransitGatewayRoutes - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postSearchTransitGatewayRoutes(actionSearchTransitGatewayRoutesAction, actionSearchTransitGatewayRoutesVersion, actionSearchTransitGatewayRoutesBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.Routes));
              assert.equal(true, data.response.AdditionalRoutesAvailable);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionSearchTransitGatewayRoutes', 'postSearchTransitGatewayRoutes', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionSearchTransitGatewayRoutesTransitGatewayRouteTableId = 'fakedata';
    const actionSearchTransitGatewayRoutesFilter = [];
    describe('#getSearchTransitGatewayRoutes - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getSearchTransitGatewayRoutes(actionSearchTransitGatewayRoutesTransitGatewayRouteTableId, actionSearchTransitGatewayRoutesFilter, null, null, actionSearchTransitGatewayRoutesAction, actionSearchTransitGatewayRoutesVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.Routes));
              assert.equal(true, data.response.AdditionalRoutesAvailable);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionSearchTransitGatewayRoutes', 'getSearchTransitGatewayRoutes', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionStartInstancesAction = 'fakedata';
    const actionStartInstancesVersion = 'fakedata';
    const actionStartInstancesBodyFormData = 'fakedata';
    describe('#postStartInstances - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postStartInstances(actionStartInstancesAction, actionStartInstancesVersion, actionStartInstancesBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.StartingInstances));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionStartInstances', 'postStartInstances', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionStartInstancesInstanceId = [];
    describe('#getStartInstances - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getStartInstances(actionStartInstancesInstanceId, null, null, actionStartInstancesAction, actionStartInstancesVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.StartingInstances));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionStartInstances', 'getStartInstances', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionStopInstancesAction = 'fakedata';
    const actionStopInstancesVersion = 'fakedata';
    const actionStopInstancesBodyFormData = 'fakedata';
    describe('#postStopInstances - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postStopInstances(actionStopInstancesAction, actionStopInstancesVersion, actionStopInstancesBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.StoppingInstances));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionStopInstances', 'postStopInstances', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionStopInstancesInstanceId = [];
    describe('#getStopInstances - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getStopInstances(actionStopInstancesInstanceId, null, null, null, actionStopInstancesAction, actionStopInstancesVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.StoppingInstances));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionStopInstances', 'getStopInstances', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    let actionTerminateClientVpnConnectionsClientVpnEndpointId = 'fakedata';
    const actionTerminateClientVpnConnectionsAction = 'fakedata';
    const actionTerminateClientVpnConnectionsVersion = 'fakedata';
    const actionTerminateClientVpnConnectionsBodyFormData = 'fakedata';
    describe('#postTerminateClientVpnConnections - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postTerminateClientVpnConnections(actionTerminateClientVpnConnectionsAction, actionTerminateClientVpnConnectionsVersion, actionTerminateClientVpnConnectionsBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.clientVpnEndpointId);
              assert.equal('string', data.response.username);
              assert.equal(true, Array.isArray(data.response.ConnectionStatuses));
            } else {
              runCommonAsserts(data, error);
            }
            actionTerminateClientVpnConnectionsClientVpnEndpointId = data.response.clientVpnEndpointId;
            saveMockData('ActionTerminateClientVpnConnections', 'postTerminateClientVpnConnections', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getTerminateClientVpnConnections - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getTerminateClientVpnConnections(actionTerminateClientVpnConnectionsClientVpnEndpointId, null, null, null, actionTerminateClientVpnConnectionsAction, actionTerminateClientVpnConnectionsVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.clientVpnEndpointId);
              assert.equal('string', data.response.username);
              assert.equal(true, Array.isArray(data.response.ConnectionStatuses));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionTerminateClientVpnConnections', 'getTerminateClientVpnConnections', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionTerminateInstancesAction = 'fakedata';
    const actionTerminateInstancesVersion = 'fakedata';
    const actionTerminateInstancesBodyFormData = 'fakedata';
    describe('#postTerminateInstances - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postTerminateInstances(actionTerminateInstancesAction, actionTerminateInstancesVersion, actionTerminateInstancesBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.TerminatingInstances));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionTerminateInstances', 'postTerminateInstances', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionTerminateInstancesInstanceId = [];
    describe('#getTerminateInstances - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getTerminateInstances(actionTerminateInstancesInstanceId, null, actionTerminateInstancesAction, actionTerminateInstancesVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.TerminatingInstances));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionTerminateInstances', 'getTerminateInstances', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    let actionUnassignIpv6AddressesNetworkInterfaceId = 'fakedata';
    const actionUnassignIpv6AddressesAction = 'fakedata';
    const actionUnassignIpv6AddressesVersion = 'fakedata';
    const actionUnassignIpv6AddressesBodyFormData = 'fakedata';
    describe('#postUnassignIpv6Addresses - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postUnassignIpv6Addresses(actionUnassignIpv6AddressesAction, actionUnassignIpv6AddressesVersion, actionUnassignIpv6AddressesBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.networkInterfaceId);
              assert.equal(true, Array.isArray(data.response.UnassignedIpv6Addresses));
            } else {
              runCommonAsserts(data, error);
            }
            actionUnassignIpv6AddressesNetworkInterfaceId = data.response.networkInterfaceId;
            saveMockData('ActionUnassignIpv6Addresses', 'postUnassignIpv6Addresses', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionUnassignIpv6AddressesIpv6Addresses = [];
    describe('#getUnassignIpv6Addresses - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getUnassignIpv6Addresses(actionUnassignIpv6AddressesIpv6Addresses, actionUnassignIpv6AddressesNetworkInterfaceId, actionUnassignIpv6AddressesAction, actionUnassignIpv6AddressesVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('string', data.response.networkInterfaceId);
              assert.equal(true, Array.isArray(data.response.UnassignedIpv6Addresses));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionUnassignIpv6Addresses', 'getUnassignIpv6Addresses', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionUnassignPrivateIpAddressesAction = 'fakedata';
    const actionUnassignPrivateIpAddressesVersion = 'fakedata';
    const actionUnassignPrivateIpAddressesBodyFormData = 'fakedata';
    describe('#postUnassignPrivateIpAddresses - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postUnassignPrivateIpAddresses(actionUnassignPrivateIpAddressesAction, actionUnassignPrivateIpAddressesVersion, actionUnassignPrivateIpAddressesBodyFormData, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionUnassignPrivateIpAddresses', 'postUnassignPrivateIpAddresses', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionUnassignPrivateIpAddressesNetworkInterfaceId = 'fakedata';
    const actionUnassignPrivateIpAddressesPrivateIpAddress = [];
    describe('#getUnassignPrivateIpAddresses - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getUnassignPrivateIpAddresses(actionUnassignPrivateIpAddressesNetworkInterfaceId, actionUnassignPrivateIpAddressesPrivateIpAddress, actionUnassignPrivateIpAddressesAction, actionUnassignPrivateIpAddressesVersion, null, (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-awsec2-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionUnassignPrivateIpAddresses', 'getUnassignPrivateIpAddresses', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionUnmonitorInstancesAction = 'fakedata';
    const actionUnmonitorInstancesVersion = 'fakedata';
    const actionUnmonitorInstancesBodyFormData = 'fakedata';
    describe('#postUnmonitorInstances - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postUnmonitorInstances(actionUnmonitorInstancesAction, actionUnmonitorInstancesVersion, actionUnmonitorInstancesBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.InstanceMonitorings));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionUnmonitorInstances', 'postUnmonitorInstances', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionUnmonitorInstancesInstanceId = [];
    describe('#getUnmonitorInstances - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getUnmonitorInstances(actionUnmonitorInstancesInstanceId, null, actionUnmonitorInstancesAction, actionUnmonitorInstancesVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, Array.isArray(data.response.InstanceMonitorings));
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionUnmonitorInstances', 'getUnmonitorInstances', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionUpdateSecurityGroupRuleDescriptionsEgressAction = 'fakedata';
    const actionUpdateSecurityGroupRuleDescriptionsEgressVersion = 'fakedata';
    const actionUpdateSecurityGroupRuleDescriptionsEgressBodyFormData = 'fakedata';
    describe('#postUpdateSecurityGroupRuleDescriptionsEgress - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postUpdateSecurityGroupRuleDescriptionsEgress(actionUpdateSecurityGroupRuleDescriptionsEgressAction, actionUpdateSecurityGroupRuleDescriptionsEgressVersion, actionUpdateSecurityGroupRuleDescriptionsEgressBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, data.response.Return);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionUpdateSecurityGroupRuleDescriptionsEgress', 'postUpdateSecurityGroupRuleDescriptionsEgress', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionUpdateSecurityGroupRuleDescriptionsEgressIpPermissions = [];
    describe('#getUpdateSecurityGroupRuleDescriptionsEgress - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getUpdateSecurityGroupRuleDescriptionsEgress(null, null, null, actionUpdateSecurityGroupRuleDescriptionsEgressIpPermissions, actionUpdateSecurityGroupRuleDescriptionsEgressAction, actionUpdateSecurityGroupRuleDescriptionsEgressVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(false, data.response.Return);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionUpdateSecurityGroupRuleDescriptionsEgress', 'getUpdateSecurityGroupRuleDescriptionsEgress', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionUpdateSecurityGroupRuleDescriptionsIngressAction = 'fakedata';
    const actionUpdateSecurityGroupRuleDescriptionsIngressVersion = 'fakedata';
    const actionUpdateSecurityGroupRuleDescriptionsIngressBodyFormData = 'fakedata';
    describe('#postUpdateSecurityGroupRuleDescriptionsIngress - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postUpdateSecurityGroupRuleDescriptionsIngress(actionUpdateSecurityGroupRuleDescriptionsIngressAction, actionUpdateSecurityGroupRuleDescriptionsIngressVersion, actionUpdateSecurityGroupRuleDescriptionsIngressBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(false, data.response.Return);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionUpdateSecurityGroupRuleDescriptionsIngress', 'postUpdateSecurityGroupRuleDescriptionsIngress', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionUpdateSecurityGroupRuleDescriptionsIngressIpPermissions = [];
    describe('#getUpdateSecurityGroupRuleDescriptionsIngress - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getUpdateSecurityGroupRuleDescriptionsIngress(null, null, null, actionUpdateSecurityGroupRuleDescriptionsIngressIpPermissions, actionUpdateSecurityGroupRuleDescriptionsIngressAction, actionUpdateSecurityGroupRuleDescriptionsIngressVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal(true, data.response.Return);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionUpdateSecurityGroupRuleDescriptionsIngress', 'getUpdateSecurityGroupRuleDescriptionsIngress', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionWithdrawByoipCidrAction = 'fakedata';
    const actionWithdrawByoipCidrVersion = 'fakedata';
    const actionWithdrawByoipCidrBodyFormData = 'fakedata';
    describe('#postWithdrawByoipCidr - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postWithdrawByoipCidr(actionWithdrawByoipCidrAction, actionWithdrawByoipCidrVersion, actionWithdrawByoipCidrBodyFormData, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.ByoipCidr);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionWithdrawByoipCidr', 'postWithdrawByoipCidr', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    const actionWithdrawByoipCidrCidr = 'fakedata';
    describe('#getWithdrawByoipCidr - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getWithdrawByoipCidr(actionWithdrawByoipCidrCidr, null, actionWithdrawByoipCidrAction, actionWithdrawByoipCidrVersion, null, (data, error) => {
            runCommonAsserts(data, error);
            if (stub) {
              assert.equal('object', typeof data.response.ByoipCidr);
            } else {
              runCommonAsserts(data, error);
            }
            saveMockData('ActionWithdrawByoipCidr', 'getWithdrawByoipCidr', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });
  });
});
