/* @copyright Itential, LLC 2019 (pre-modifications) */

// Set globals
/* global describe it log pronghornProps */
/* eslint global-require:warn */
/* eslint no-unused-vars: warn */

// include required items for testing & logging
const assert = require('assert');
const fs = require('fs-extra');
const mocha = require('mocha');
const path = require('path');
const util = require('util');
const winston = require('winston');
const execute = require('child_process').execSync;
const { expect } = require('chai');
const { use } = require('chai');
const td = require('testdouble');

const anything = td.matchers.anything();

// stub and attemptTimeout are used throughout the code so set them here
let logLevel = 'none';
const stub = true;
const isRapidFail = false;
const attemptTimeout = 120000;

// these variables can be changed to run in integrated mode so easier to set them here
// always check these in with bogus data!!!
const host = 'replace.hostorip.here';
const username = 'username';
const password = 'password';
const protocol = 'http';
const port = 80;
const sslenable = false;
const sslinvalid = false;

// these are the adapter properties. You generally should not need to alter
// any of these after they are initially set up
global.pronghornProps = {
  pathProps: {
    encrypted: false
  },
  adapterProps: {
    adapters: [{
      id: 'Test-awsec2',
      type: 'Awsec2',
      properties: {
        host,
        port,
        base_path: '/',
        version: '',
        cache_location: 'none',
        protocol,
        stub,
        authentication: {
          auth_method: 'no_authentication',
          username,
          password,
          token: '',
          token_timeout: -1,
          token_cache: 'local',
          invalid_token_error: 401,
          auth_field: 'header.headers.Authorization',
          auth_field_format: 'Basic {b64}{username}:{password}{/b64}'
        },
        healthcheck: {
          type: 'none',
          frequency: 60000
        },
        throttle: {
          throttle_enabled: false,
          number_pronghorns: 1,
          sync_async: 'sync',
          max_in_queue: 1000,
          concurrent_max: 1,
          expire_timeout: 0,
          avg_runtime: 200
        },
        request: {
          number_retries: 3,
          limit_retry_error: 0,
          failover_codes: [],
          attempt_timeout: attemptTimeout,
          healthcheck_on_timeout: true,
          archiving: false
        },
        proxy: {
          enabled: false,
          host: '',
          port: 1,
          protocol: 'http'
        },
        ssl: {
          ecdhCurve: '',
          enabled: sslenable,
          accept_invalid_cert: sslinvalid,
          ca_file: '',
          secure_protocol: '',
          ciphers: ''
        }
      }
    }]
  }
};

global.$HOME = `${__dirname}/../..`;

// set the log levels that Pronghorn uses, spam and trace are not defaulted in so without
// this you may error on log.trace calls.
const myCustomLevels = {
  levels: {
    spam: 6,
    trace: 5,
    debug: 4,
    info: 3,
    warn: 2,
    error: 1,
    none: 0
  }
};

// need to see if there is a log level passed in
process.argv.forEach((val) => {
  // is there a log level defined to be passed in?
  if (val.indexOf('--LOG') === 0) {
    // get the desired log level
    const inputVal = val.split('=')[1];

    // validate the log level is supported, if so set it
    if (Object.hasOwnProperty.call(myCustomLevels.levels, inputVal)) {
      logLevel = inputVal;
    }
  }
});

// need to set global logging
global.log = new (winston.Logger)({
  level: logLevel,
  levels: myCustomLevels.levels,
  transports: [
    new winston.transports.Console()
  ]
});

/**
 * Runs the error asserts for the test
 */
function runErrorAsserts(data, error, code, origin, displayStr) {
  assert.equal(null, data);
  assert.notEqual(undefined, error);
  assert.notEqual(null, error);
  assert.notEqual(undefined, error.IAPerror);
  assert.notEqual(null, error.IAPerror);
  assert.notEqual(undefined, error.IAPerror.displayString);
  assert.notEqual(null, error.IAPerror.displayString);
  assert.equal(code, error.icode);
  assert.equal(origin, error.IAPerror.origin);
  assert.equal(displayStr, error.IAPerror.displayString);
}


// require the adapter that we are going to be using
const Awsec2 = require('../../adapter.js');

// delete the .DS_Store directory in entities -- otherwise this will cause errors
const dirPath = path.join(__dirname, '../../entities/.DS_Store');
if (fs.existsSync(dirPath)) {
  try {
    fs.removeSync(dirPath);
    console.log('.DS_Store deleted');
  } catch (e) {
    console.log('Error when deleting .DS_Store:', e);
  }
}

// begin the testing - these should be pretty well defined between the describe and the it!
describe('[unit] Awsec2 Adapter Test', () => {
  describe('Awsec2 Class Tests', () => {
    const a = new Awsec2(
      pronghornProps.adapterProps.adapters[0].id,
      pronghornProps.adapterProps.adapters[0].properties
    );

    if (isRapidFail) {
      const state = {};
      state.passed = true;

      mocha.afterEach(function x() {
        state.passed = state.passed
        && (this.currentTest.state === 'passed');
      });
      mocha.beforeEach(function x() {
        if (!state.passed) {
          return this.currentTest.skip();
        }
        return true;
      });
    }

    describe('#class instance created', () => {
      it('should be a class with properties', (done) => {
        try {
          assert.notEqual(null, a);
          assert.notEqual(undefined, a);
          assert.notEqual(null, a.allProps);
          const check = global.pronghornProps.adapterProps.adapters[0].properties.healthcheck.type;
          assert.equal(check, a.healthcheckType);
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('adapterBase.js', () => {
      it('should have an adapterBase.js', (done) => {
        try {
          fs.exists('adapterBase.js', (val) => {
            assert.equal(true, val);
            done();
          });
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
    });

    let wffunctions = [];
    describe('#getWorkflowFunctions', () => {
      it('should retrieve workflow functions', (done) => {
        try {
          wffunctions = a.getWorkflowFunctions();

          try {
            assert.notEqual(0, wffunctions.length);
            done();
          } catch (err) {
            log.error(`Test Failure: ${err}`);
            done(err);
          }
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('package.json', () => {
      it('should have a package.json', (done) => {
        try {
          fs.exists('package.json', (val) => {
            assert.equal(true, val);
            done();
          });
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
      it('package.json should be validated', (done) => {
        try {
          const packageDotJson = require('../../package.json');
          const { PJV } = require('package-json-validator');
          const options = {
            warnings: true, // show warnings
            recommendations: true // show recommendations
          };
          const results = PJV.validate(JSON.stringify(packageDotJson), 'npm', options);

          if (results.valid === false) {
            log.error('The package.json contains the following errors: ');
            log.error(util.inspect(results));
            assert.equal(true, results.valid);
          } else {
            assert.equal(true, results.valid);
          }

          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
      it('package.json should be customized', (done) => {
        try {
          const packageDotJson = require('../../package.json');
          assert.notEqual(-1, packageDotJson.name.indexOf('aws_ec2'));
          assert.notEqual(undefined, packageDotJson.version);
          assert.notEqual(null, packageDotJson.version);
          assert.notEqual('', packageDotJson.version);
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
    });

    describe('pronghorn.json', () => {
      it('should have a pronghorn.json', (done) => {
        try {
          fs.exists('pronghorn.json', (val) => {
            assert.equal(true, val);
            done();
          });
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
      it('pronghorn.json should be customized', (done) => {
        try {
          const pronghornDotJson = require('../../pronghorn.json');
          assert.notEqual(-1, pronghornDotJson.id.indexOf('aws_ec2'));
          assert.equal('Awsec2', pronghornDotJson.export);
          assert.equal('Awsec2', pronghornDotJson.displayName);
          assert.equal('Awsec2', pronghornDotJson.title);
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
      it('pronghorn.json should only expose workflow functions', (done) => {
        try {
          const pronghornDotJson = require('../../pronghorn.json');

          for (let m = 0; m < pronghornDotJson.methods.length; m += 1) {
            let found = false;
            let paramissue = false;

            for (let w = 0; w < wffunctions.length; w += 1) {
              if (pronghornDotJson.methods[m].name === wffunctions[w]) {
                found = true;
                const methLine = execute(`grep "${wffunctions[w]}(" adapter.js | grep "callback) {"`).toString();
                let wfparams = [];

                if (methLine.indexOf('(') >= 0 && methLine.indexOf(')') >= 0) {
                  const temp = methLine.substring(methLine.indexOf('(') + 1, methLine.indexOf(')'));
                  wfparams = temp.split(',');

                  for (let t = 0; t < wfparams.length; t += 1) {
                    // remove default value from the parameter name
                    wfparams[t] = wfparams[t].substring(0, wfparams[t].search(/=/) > 0 ? wfparams[t].search(/#|\?|=/) : wfparams[t].length);
                    // remove spaces
                    wfparams[t] = wfparams[t].trim();

                    if (wfparams[t] === 'callback') {
                      wfparams.splice(t, 1);
                    }
                  }
                }

                // if there are inputs defined but not on the method line
                if (wfparams.length === 0 && (pronghornDotJson.methods[m].input
                    && pronghornDotJson.methods[m].input.length > 0)) {
                  paramissue = true;
                } else if (wfparams.length > 0 && (!pronghornDotJson.methods[m].input
                    || pronghornDotJson.methods[m].input.length === 0)) {
                  // if there are no inputs defined but there are on the method line
                  paramissue = true;
                } else {
                  for (let p = 0; p < pronghornDotJson.methods[m].input.length; p += 1) {
                    let pfound = false;
                    for (let wfp = 0; wfp < wfparams.length; wfp += 1) {
                      if (pronghornDotJson.methods[m].input[p].name.toUpperCase() === wfparams[wfp].toUpperCase()) {
                        pfound = true;
                      }
                    }

                    if (!pfound) {
                      paramissue = true;
                    }
                  }
                  for (let wfp = 0; wfp < wfparams.length; wfp += 1) {
                    let pfound = false;
                    for (let p = 0; p < pronghornDotJson.methods[m].input.length; p += 1) {
                      if (pronghornDotJson.methods[m].input[p].name.toUpperCase() === wfparams[wfp].toUpperCase()) {
                        pfound = true;
                      }
                    }

                    if (!pfound) {
                      paramissue = true;
                    }
                  }
                }

                break;
              }
            }

            if (!found) {
              // this is the reason to go through both loops - log which ones are not found so
              // they can be worked
              log.error(`${pronghornDotJson.methods[m].name} not found in workflow functions`);
            }
            if (paramissue) {
              // this is the reason to go through both loops - log which ones are not found so
              // they can be worked
              log.error(`${pronghornDotJson.methods[m].name} has a parameter mismatch`);
            }
            assert.equal(true, found);
            assert.equal(false, paramissue);
          }
          done();
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('pronghorn.json should expose all workflow functions', (done) => {
        try {
          const pronghornDotJson = require('../../pronghorn.json');
          for (let w = 0; w < wffunctions.length; w += 1) {
            let found = false;

            for (let m = 0; m < pronghornDotJson.methods.length; m += 1) {
              if (pronghornDotJson.methods[m].name === wffunctions[w]) {
                found = true;
                break;
              }
            }

            if (!found) {
              // this is the reason to go through both loops - log which ones are not found so
              // they can be worked
              log.error(`${wffunctions[w]} not found in pronghorn.json`);
            }
            assert.equal(true, found);
          }
          done();
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      });
    });

    describe('propertiesSchema.json', () => {
      it('should have a propertiesSchema.json', (done) => {
        try {
          fs.exists('propertiesSchema.json', (val) => {
            assert.equal(true, val);
            done();
          });
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
      it('propertiesSchema.json should be customized', (done) => {
        try {
          const propertiesDotJson = require('../../propertiesSchema.json');
          assert.equal('adapter-aws_ec2', propertiesDotJson.$id);
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
    });

    describe('error.json', () => {
      it('should have an error.json', (done) => {
        try {
          fs.exists('error.json', (val) => {
            assert.equal(true, val);
            done();
          });
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
    });

    describe('README.md', () => {
      it('should have a README', (done) => {
        try {
          fs.exists('README.md', (val) => {
            assert.equal(true, val);
            done();
          });
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
      it('README.md should be customized', (done) => {
        try {
          fs.readFile('README.md', 'utf8', (err, data) => {
            assert.equal(-1, data.indexOf('[System]'));
            assert.equal(-1, data.indexOf('[system]'));
            assert.equal(-1, data.indexOf('[version]'));
            assert.equal(-1, data.indexOf('[namespace]'));
            done();
          });
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
    });

    describe('#connect', () => {
      it('should have a connect function', (done) => {
        try {
          assert.equal(true, typeof a.connect === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
    });

    describe('#healthCheck', () => {
      it('should have a healthCheck function', (done) => {
        try {
          assert.equal(true, typeof a.healthCheck === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
    });

    describe('#checkActionFiles', () => {
      it('should have a checkActionFiles function', (done) => {
        try {
          assert.equal(true, typeof a.checkActionFiles === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
      it('should be good', (done) => {
        try {
          const clean = a.checkActionFiles();

          try {
            assert.equal(true, clean);
            done();
          } catch (err) {
            log.error(`Test Failure: ${err}`);
            done(err);
          }
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#encryptProperty', () => {
      it('should have a encryptProperty function', (done) => {
        try {
          assert.equal(true, typeof a.encryptProperty === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
      it('should get base64 encoded property', (done) => {
        try {
          a.encryptProperty('testing', 'base64', (data, error) => {
            try {
              assert.equal(undefined, error);
              assert.notEqual(undefined, data);
              assert.notEqual(null, data);
              assert.notEqual(undefined, data.response);
              assert.notEqual(null, data.response);
              assert.equal(0, data.response.indexOf('{code}'));
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should get encrypted property', (done) => {
        try {
          a.encryptProperty('testing', 'encrypt', (data, error) => {
            try {
              assert.equal(undefined, error);
              assert.notEqual(undefined, data);
              assert.notEqual(null, data);
              assert.notEqual(undefined, data.response);
              assert.notEqual(null, data.response);
              assert.equal(0, data.response.indexOf('{crypt}'));
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    // describe('#hasEntity', () => {
    //   it('should have a hasEntity function', (done) => {
    //     try {
    //       assert.equal(true, typeof a.hasEntity === 'function');
    //       done();
    //     } catch (error) {
    //       log.error(`Test Failure: ${error}`);
    //       done(error);
    //     }
    //   });
    //   it('should find entity', (done) => {
    //     try {
    //       a.hasEntity('template_entity', // 'a9e9c33dc61122760072455df62663d2', (data) => {
    //         try {
    //           assert.equal(true, data[0]);
    //           done();
    //         } catch (err) {
    //           log.error(`Test Failure: ${err}`);
    //           done(err);
    //         }
    //       });
    //     } catch (error) {
    //       log.error(`Adapter Exception: ${error}`);
    //       done(error);
    //     }
    //   }).timeout(attemptTimeout);
    //   it('should not find entity', (done) => {
    //     try {
    //       a.hasEntity('template_entity', 'blah', (data) => {
    //         try {
    //           assert.equal(false, data[0]);
    //           done();
    //         } catch (err) {
    //           log.error(`Test Failure: ${err}`);
    //           done(err);
    //         }
    //       });
    //     } catch (error) {
    //       log.error(`Adapter Exception: ${error}`);
    //       done(error);
    //     }
    //   }).timeout(attemptTimeout);
    // });

    /*
    -----------------------------------------------------------------------
    -----------------------------------------------------------------------
    *** All code above this comment will be replaced during a migration ***
    ******************* DO NOT REMOVE THIS COMMENT BLOCK ******************
    -----------------------------------------------------------------------
    -----------------------------------------------------------------------
    */

    describe('#getAcceptReservedInstancesExchangeQuote - errors', () => {
      it('should have a getAcceptReservedInstancesExchangeQuote function', (done) => {
        assert.equal(true, typeof a.getAcceptReservedInstancesExchangeQuote === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing reservedInstanceId', (done) => {
        const p = new Promise((resolve) => {
          a.getAcceptReservedInstancesExchangeQuote('fakeparam', null, null, null, null, null, (data, error) => {
            const displayE = 'reservedInstanceId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAcceptReservedInstancesExchangeQuote', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getAcceptReservedInstancesExchangeQuote('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAcceptReservedInstancesExchangeQuote', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getAcceptReservedInstancesExchangeQuote('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAcceptReservedInstancesExchangeQuote', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postAcceptReservedInstancesExchangeQuote - errors', () => {
      it('should have a postAcceptReservedInstancesExchangeQuote function', (done) => {
        assert.equal(true, typeof a.postAcceptReservedInstancesExchangeQuote === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postAcceptReservedInstancesExchangeQuote(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postAcceptReservedInstancesExchangeQuote', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postAcceptReservedInstancesExchangeQuote('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postAcceptReservedInstancesExchangeQuote', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postAcceptReservedInstancesExchangeQuote('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postAcceptReservedInstancesExchangeQuote', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getAcceptTransitGatewayVpcAttachment - errors', () => {
      it('should have a getAcceptTransitGatewayVpcAttachment function', (done) => {
        assert.equal(true, typeof a.getAcceptTransitGatewayVpcAttachment === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing transitGatewayAttachmentId', (done) => {
        const p = new Promise((resolve) => {
          a.getAcceptTransitGatewayVpcAttachment(null, null, null, null, null, (data, error) => {
            const displayE = 'transitGatewayAttachmentId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAcceptTransitGatewayVpcAttachment', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getAcceptTransitGatewayVpcAttachment('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAcceptTransitGatewayVpcAttachment', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getAcceptTransitGatewayVpcAttachment('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAcceptTransitGatewayVpcAttachment', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postAcceptTransitGatewayVpcAttachment - errors', () => {
      it('should have a postAcceptTransitGatewayVpcAttachment function', (done) => {
        assert.equal(true, typeof a.postAcceptTransitGatewayVpcAttachment === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postAcceptTransitGatewayVpcAttachment(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postAcceptTransitGatewayVpcAttachment', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postAcceptTransitGatewayVpcAttachment('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postAcceptTransitGatewayVpcAttachment', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postAcceptTransitGatewayVpcAttachment('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postAcceptTransitGatewayVpcAttachment', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getAcceptVpcEndpointConnections - errors', () => {
      it('should have a getAcceptVpcEndpointConnections function', (done) => {
        assert.equal(true, typeof a.getAcceptVpcEndpointConnections === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing serviceId', (done) => {
        const p = new Promise((resolve) => {
          a.getAcceptVpcEndpointConnections('fakeparam', null, null, null, null, null, (data, error) => {
            const displayE = 'serviceId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAcceptVpcEndpointConnections', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing vpcEndpointId', (done) => {
        const p = new Promise((resolve) => {
          a.getAcceptVpcEndpointConnections('fakeparam', 'fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'vpcEndpointId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAcceptVpcEndpointConnections', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getAcceptVpcEndpointConnections('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAcceptVpcEndpointConnections', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getAcceptVpcEndpointConnections('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAcceptVpcEndpointConnections', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postAcceptVpcEndpointConnections - errors', () => {
      it('should have a postAcceptVpcEndpointConnections function', (done) => {
        assert.equal(true, typeof a.postAcceptVpcEndpointConnections === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postAcceptVpcEndpointConnections(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postAcceptVpcEndpointConnections', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postAcceptVpcEndpointConnections('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postAcceptVpcEndpointConnections', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postAcceptVpcEndpointConnections('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postAcceptVpcEndpointConnections', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getAcceptVpcPeeringConnection - errors', () => {
      it('should have a getAcceptVpcPeeringConnection function', (done) => {
        assert.equal(true, typeof a.getAcceptVpcPeeringConnection === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getAcceptVpcPeeringConnection('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAcceptVpcPeeringConnection', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getAcceptVpcPeeringConnection('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAcceptVpcPeeringConnection', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postAcceptVpcPeeringConnection - errors', () => {
      it('should have a postAcceptVpcPeeringConnection function', (done) => {
        assert.equal(true, typeof a.postAcceptVpcPeeringConnection === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postAcceptVpcPeeringConnection(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postAcceptVpcPeeringConnection', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postAcceptVpcPeeringConnection('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postAcceptVpcPeeringConnection', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getAdvertiseByoipCidr - errors', () => {
      it('should have a getAdvertiseByoipCidr function', (done) => {
        assert.equal(true, typeof a.getAdvertiseByoipCidr === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing cidr', (done) => {
        const p = new Promise((resolve) => {
          a.getAdvertiseByoipCidr(null, null, null, null, null, (data, error) => {
            const displayE = 'cidr is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAdvertiseByoipCidr', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getAdvertiseByoipCidr('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAdvertiseByoipCidr', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getAdvertiseByoipCidr('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAdvertiseByoipCidr', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postAdvertiseByoipCidr - errors', () => {
      it('should have a postAdvertiseByoipCidr function', (done) => {
        assert.equal(true, typeof a.postAdvertiseByoipCidr === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postAdvertiseByoipCidr(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postAdvertiseByoipCidr', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postAdvertiseByoipCidr('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postAdvertiseByoipCidr', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postAdvertiseByoipCidr('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postAdvertiseByoipCidr', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getAllocateAddress - errors', () => {
      it('should have a getAllocateAddress function', (done) => {
        assert.equal(true, typeof a.getAllocateAddress === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getAllocateAddress('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAllocateAddress', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getAllocateAddress('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAllocateAddress', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postAllocateAddress - errors', () => {
      it('should have a postAllocateAddress function', (done) => {
        assert.equal(true, typeof a.postAllocateAddress === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postAllocateAddress(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postAllocateAddress', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postAllocateAddress('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postAllocateAddress', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getAllocateHosts - errors', () => {
      it('should have a getAllocateHosts function', (done) => {
        assert.equal(true, typeof a.getAllocateHosts === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing availabilityZone', (done) => {
        const p = new Promise((resolve) => {
          a.getAllocateHosts('fakeparam', null, null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'availabilityZone is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAllocateHosts', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing instanceType', (done) => {
        const p = new Promise((resolve) => {
          a.getAllocateHosts('fakeparam', 'fakeparam', 'fakeparam', null, null, null, null, null, null, (data, error) => {
            const displayE = 'instanceType is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAllocateHosts', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing quantity', (done) => {
        const p = new Promise((resolve) => {
          a.getAllocateHosts('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, null, null, (data, error) => {
            const displayE = 'quantity is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAllocateHosts', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getAllocateHosts('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAllocateHosts', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getAllocateHosts('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAllocateHosts', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postAllocateHosts - errors', () => {
      it('should have a postAllocateHosts function', (done) => {
        assert.equal(true, typeof a.postAllocateHosts === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postAllocateHosts(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postAllocateHosts', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postAllocateHosts('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postAllocateHosts', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postAllocateHosts('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postAllocateHosts', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getApplySecurityGroupsToClientVpnTargetNetwork - errors', () => {
      it('should have a getApplySecurityGroupsToClientVpnTargetNetwork function', (done) => {
        assert.equal(true, typeof a.getApplySecurityGroupsToClientVpnTargetNetwork === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing clientVpnEndpointId', (done) => {
        const p = new Promise((resolve) => {
          a.getApplySecurityGroupsToClientVpnTargetNetwork(null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'clientVpnEndpointId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getApplySecurityGroupsToClientVpnTargetNetwork', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing vpcId', (done) => {
        const p = new Promise((resolve) => {
          a.getApplySecurityGroupsToClientVpnTargetNetwork('fakeparam', null, null, null, null, null, null, (data, error) => {
            const displayE = 'vpcId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getApplySecurityGroupsToClientVpnTargetNetwork', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing securityGroupId', (done) => {
        const p = new Promise((resolve) => {
          a.getApplySecurityGroupsToClientVpnTargetNetwork('fakeparam', 'fakeparam', null, null, null, null, null, (data, error) => {
            const displayE = 'securityGroupId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getApplySecurityGroupsToClientVpnTargetNetwork', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getApplySecurityGroupsToClientVpnTargetNetwork('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getApplySecurityGroupsToClientVpnTargetNetwork', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getApplySecurityGroupsToClientVpnTargetNetwork('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getApplySecurityGroupsToClientVpnTargetNetwork', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postApplySecurityGroupsToClientVpnTargetNetwork - errors', () => {
      it('should have a postApplySecurityGroupsToClientVpnTargetNetwork function', (done) => {
        assert.equal(true, typeof a.postApplySecurityGroupsToClientVpnTargetNetwork === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postApplySecurityGroupsToClientVpnTargetNetwork(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postApplySecurityGroupsToClientVpnTargetNetwork', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postApplySecurityGroupsToClientVpnTargetNetwork('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postApplySecurityGroupsToClientVpnTargetNetwork', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postApplySecurityGroupsToClientVpnTargetNetwork('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postApplySecurityGroupsToClientVpnTargetNetwork', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getAssignIpv6Addresses - errors', () => {
      it('should have a getAssignIpv6Addresses function', (done) => {
        assert.equal(true, typeof a.getAssignIpv6Addresses === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing networkInterfaceId', (done) => {
        const p = new Promise((resolve) => {
          a.getAssignIpv6Addresses('fakeparam', 'fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'networkInterfaceId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAssignIpv6Addresses', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getAssignIpv6Addresses('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAssignIpv6Addresses', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getAssignIpv6Addresses('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAssignIpv6Addresses', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postAssignIpv6Addresses - errors', () => {
      it('should have a postAssignIpv6Addresses function', (done) => {
        assert.equal(true, typeof a.postAssignIpv6Addresses === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postAssignIpv6Addresses(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postAssignIpv6Addresses', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postAssignIpv6Addresses('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postAssignIpv6Addresses', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postAssignIpv6Addresses('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postAssignIpv6Addresses', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getAssignPrivateIpAddresses - errors', () => {
      it('should have a getAssignPrivateIpAddresses function', (done) => {
        assert.equal(true, typeof a.getAssignPrivateIpAddresses === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing networkInterfaceId', (done) => {
        const p = new Promise((resolve) => {
          a.getAssignPrivateIpAddresses('fakeparam', null, null, null, null, null, null, (data, error) => {
            const displayE = 'networkInterfaceId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAssignPrivateIpAddresses', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getAssignPrivateIpAddresses('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAssignPrivateIpAddresses', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getAssignPrivateIpAddresses('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAssignPrivateIpAddresses', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postAssignPrivateIpAddresses - errors', () => {
      it('should have a postAssignPrivateIpAddresses function', (done) => {
        assert.equal(true, typeof a.postAssignPrivateIpAddresses === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postAssignPrivateIpAddresses(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postAssignPrivateIpAddresses', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postAssignPrivateIpAddresses('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postAssignPrivateIpAddresses', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postAssignPrivateIpAddresses('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postAssignPrivateIpAddresses', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getAssociateAddress - errors', () => {
      it('should have a getAssociateAddress function', (done) => {
        assert.equal(true, typeof a.getAssociateAddress === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getAssociateAddress('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAssociateAddress', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getAssociateAddress('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAssociateAddress', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postAssociateAddress - errors', () => {
      it('should have a postAssociateAddress function', (done) => {
        assert.equal(true, typeof a.postAssociateAddress === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postAssociateAddress(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postAssociateAddress', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postAssociateAddress('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postAssociateAddress', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getAssociateClientVpnTargetNetwork - errors', () => {
      it('should have a getAssociateClientVpnTargetNetwork function', (done) => {
        assert.equal(true, typeof a.getAssociateClientVpnTargetNetwork === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing clientVpnEndpointId', (done) => {
        const p = new Promise((resolve) => {
          a.getAssociateClientVpnTargetNetwork(null, null, null, null, null, null, (data, error) => {
            const displayE = 'clientVpnEndpointId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAssociateClientVpnTargetNetwork', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing subnetId', (done) => {
        const p = new Promise((resolve) => {
          a.getAssociateClientVpnTargetNetwork('fakeparam', null, null, null, null, null, (data, error) => {
            const displayE = 'subnetId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAssociateClientVpnTargetNetwork', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getAssociateClientVpnTargetNetwork('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAssociateClientVpnTargetNetwork', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getAssociateClientVpnTargetNetwork('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAssociateClientVpnTargetNetwork', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postAssociateClientVpnTargetNetwork - errors', () => {
      it('should have a postAssociateClientVpnTargetNetwork function', (done) => {
        assert.equal(true, typeof a.postAssociateClientVpnTargetNetwork === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postAssociateClientVpnTargetNetwork(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postAssociateClientVpnTargetNetwork', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postAssociateClientVpnTargetNetwork('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postAssociateClientVpnTargetNetwork', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postAssociateClientVpnTargetNetwork('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postAssociateClientVpnTargetNetwork', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getAssociateDhcpOptions - errors', () => {
      it('should have a getAssociateDhcpOptions function', (done) => {
        assert.equal(true, typeof a.getAssociateDhcpOptions === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing dhcpOptionsId', (done) => {
        const p = new Promise((resolve) => {
          a.getAssociateDhcpOptions(null, null, null, null, null, null, (data, error) => {
            const displayE = 'dhcpOptionsId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAssociateDhcpOptions', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing vpcId', (done) => {
        const p = new Promise((resolve) => {
          a.getAssociateDhcpOptions('fakeparam', null, null, null, null, null, (data, error) => {
            const displayE = 'vpcId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAssociateDhcpOptions', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getAssociateDhcpOptions('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAssociateDhcpOptions', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getAssociateDhcpOptions('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAssociateDhcpOptions', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postAssociateDhcpOptions - errors', () => {
      it('should have a postAssociateDhcpOptions function', (done) => {
        assert.equal(true, typeof a.postAssociateDhcpOptions === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postAssociateDhcpOptions(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postAssociateDhcpOptions', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postAssociateDhcpOptions('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postAssociateDhcpOptions', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postAssociateDhcpOptions('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postAssociateDhcpOptions', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getAssociateIamInstanceProfile - errors', () => {
      it('should have a getAssociateIamInstanceProfile function', (done) => {
        assert.equal(true, typeof a.getAssociateIamInstanceProfile === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing instanceId', (done) => {
        const p = new Promise((resolve) => {
          a.getAssociateIamInstanceProfile('fakeparam', 'fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'instanceId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAssociateIamInstanceProfile', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getAssociateIamInstanceProfile('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAssociateIamInstanceProfile', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getAssociateIamInstanceProfile('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAssociateIamInstanceProfile', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postAssociateIamInstanceProfile - errors', () => {
      it('should have a postAssociateIamInstanceProfile function', (done) => {
        assert.equal(true, typeof a.postAssociateIamInstanceProfile === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postAssociateIamInstanceProfile(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postAssociateIamInstanceProfile', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postAssociateIamInstanceProfile('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postAssociateIamInstanceProfile', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postAssociateIamInstanceProfile('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postAssociateIamInstanceProfile', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getAssociateRouteTable - errors', () => {
      it('should have a getAssociateRouteTable function', (done) => {
        assert.equal(true, typeof a.getAssociateRouteTable === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing routeTableId', (done) => {
        const p = new Promise((resolve) => {
          a.getAssociateRouteTable('fakeparam', null, null, null, null, null, (data, error) => {
            const displayE = 'routeTableId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAssociateRouteTable', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing subnetId', (done) => {
        const p = new Promise((resolve) => {
          a.getAssociateRouteTable('fakeparam', 'fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'subnetId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAssociateRouteTable', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getAssociateRouteTable('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAssociateRouteTable', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getAssociateRouteTable('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAssociateRouteTable', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postAssociateRouteTable - errors', () => {
      it('should have a postAssociateRouteTable function', (done) => {
        assert.equal(true, typeof a.postAssociateRouteTable === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postAssociateRouteTable(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postAssociateRouteTable', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postAssociateRouteTable('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postAssociateRouteTable', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postAssociateRouteTable('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postAssociateRouteTable', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getAssociateSubnetCidrBlock - errors', () => {
      it('should have a getAssociateSubnetCidrBlock function', (done) => {
        assert.equal(true, typeof a.getAssociateSubnetCidrBlock === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing ipv6CidrBlock', (done) => {
        const p = new Promise((resolve) => {
          a.getAssociateSubnetCidrBlock(null, null, null, null, null, (data, error) => {
            const displayE = 'ipv6CidrBlock is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAssociateSubnetCidrBlock', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing subnetId', (done) => {
        const p = new Promise((resolve) => {
          a.getAssociateSubnetCidrBlock('fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'subnetId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAssociateSubnetCidrBlock', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getAssociateSubnetCidrBlock('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAssociateSubnetCidrBlock', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getAssociateSubnetCidrBlock('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAssociateSubnetCidrBlock', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postAssociateSubnetCidrBlock - errors', () => {
      it('should have a postAssociateSubnetCidrBlock function', (done) => {
        assert.equal(true, typeof a.postAssociateSubnetCidrBlock === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postAssociateSubnetCidrBlock(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postAssociateSubnetCidrBlock', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postAssociateSubnetCidrBlock('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postAssociateSubnetCidrBlock', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postAssociateSubnetCidrBlock('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postAssociateSubnetCidrBlock', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getAssociateTransitGatewayRouteTable - errors', () => {
      it('should have a getAssociateTransitGatewayRouteTable function', (done) => {
        assert.equal(true, typeof a.getAssociateTransitGatewayRouteTable === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing transitGatewayRouteTableId', (done) => {
        const p = new Promise((resolve) => {
          a.getAssociateTransitGatewayRouteTable(null, null, null, null, null, null, (data, error) => {
            const displayE = 'transitGatewayRouteTableId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAssociateTransitGatewayRouteTable', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing transitGatewayAttachmentId', (done) => {
        const p = new Promise((resolve) => {
          a.getAssociateTransitGatewayRouteTable('fakeparam', null, null, null, null, null, (data, error) => {
            const displayE = 'transitGatewayAttachmentId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAssociateTransitGatewayRouteTable', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getAssociateTransitGatewayRouteTable('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAssociateTransitGatewayRouteTable', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getAssociateTransitGatewayRouteTable('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAssociateTransitGatewayRouteTable', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postAssociateTransitGatewayRouteTable - errors', () => {
      it('should have a postAssociateTransitGatewayRouteTable function', (done) => {
        assert.equal(true, typeof a.postAssociateTransitGatewayRouteTable === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postAssociateTransitGatewayRouteTable(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postAssociateTransitGatewayRouteTable', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postAssociateTransitGatewayRouteTable('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postAssociateTransitGatewayRouteTable', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postAssociateTransitGatewayRouteTable('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postAssociateTransitGatewayRouteTable', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getAssociateVpcCidrBlock - errors', () => {
      it('should have a getAssociateVpcCidrBlock function', (done) => {
        assert.equal(true, typeof a.getAssociateVpcCidrBlock === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing vpcId', (done) => {
        const p = new Promise((resolve) => {
          a.getAssociateVpcCidrBlock('fakeparam', 'fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'vpcId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAssociateVpcCidrBlock', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getAssociateVpcCidrBlock('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAssociateVpcCidrBlock', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getAssociateVpcCidrBlock('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAssociateVpcCidrBlock', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postAssociateVpcCidrBlock - errors', () => {
      it('should have a postAssociateVpcCidrBlock function', (done) => {
        assert.equal(true, typeof a.postAssociateVpcCidrBlock === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postAssociateVpcCidrBlock(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postAssociateVpcCidrBlock', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postAssociateVpcCidrBlock('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postAssociateVpcCidrBlock', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postAssociateVpcCidrBlock('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postAssociateVpcCidrBlock', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getAttachClassicLinkVpc - errors', () => {
      it('should have a getAttachClassicLinkVpc function', (done) => {
        assert.equal(true, typeof a.getAttachClassicLinkVpc === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing securityGroupId', (done) => {
        const p = new Promise((resolve) => {
          a.getAttachClassicLinkVpc('fakeparam', null, null, null, null, null, null, (data, error) => {
            const displayE = 'securityGroupId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAttachClassicLinkVpc', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing instanceId', (done) => {
        const p = new Promise((resolve) => {
          a.getAttachClassicLinkVpc('fakeparam', 'fakeparam', null, null, null, null, null, (data, error) => {
            const displayE = 'instanceId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAttachClassicLinkVpc', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing vpcId', (done) => {
        const p = new Promise((resolve) => {
          a.getAttachClassicLinkVpc('fakeparam', 'fakeparam', 'fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'vpcId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAttachClassicLinkVpc', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getAttachClassicLinkVpc('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAttachClassicLinkVpc', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getAttachClassicLinkVpc('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAttachClassicLinkVpc', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postAttachClassicLinkVpc - errors', () => {
      it('should have a postAttachClassicLinkVpc function', (done) => {
        assert.equal(true, typeof a.postAttachClassicLinkVpc === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postAttachClassicLinkVpc(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postAttachClassicLinkVpc', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postAttachClassicLinkVpc('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postAttachClassicLinkVpc', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postAttachClassicLinkVpc('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postAttachClassicLinkVpc', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getAttachInternetGateway - errors', () => {
      it('should have a getAttachInternetGateway function', (done) => {
        assert.equal(true, typeof a.getAttachInternetGateway === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing internetGatewayId', (done) => {
        const p = new Promise((resolve) => {
          a.getAttachInternetGateway('fakeparam', null, null, null, null, null, (data, error) => {
            const displayE = 'internetGatewayId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAttachInternetGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing vpcId', (done) => {
        const p = new Promise((resolve) => {
          a.getAttachInternetGateway('fakeparam', 'fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'vpcId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAttachInternetGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getAttachInternetGateway('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAttachInternetGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getAttachInternetGateway('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAttachInternetGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postAttachInternetGateway - errors', () => {
      it('should have a postAttachInternetGateway function', (done) => {
        assert.equal(true, typeof a.postAttachInternetGateway === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postAttachInternetGateway(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postAttachInternetGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postAttachInternetGateway('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postAttachInternetGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postAttachInternetGateway('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postAttachInternetGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getAttachNetworkInterface - errors', () => {
      it('should have a getAttachNetworkInterface function', (done) => {
        assert.equal(true, typeof a.getAttachNetworkInterface === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing deviceIndex', (done) => {
        const p = new Promise((resolve) => {
          a.getAttachNetworkInterface(null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'deviceIndex is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAttachNetworkInterface', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing instanceId', (done) => {
        const p = new Promise((resolve) => {
          a.getAttachNetworkInterface('fakeparam', 'fakeparam', null, null, null, null, null, (data, error) => {
            const displayE = 'instanceId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAttachNetworkInterface', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing networkInterfaceId', (done) => {
        const p = new Promise((resolve) => {
          a.getAttachNetworkInterface('fakeparam', 'fakeparam', 'fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'networkInterfaceId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAttachNetworkInterface', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getAttachNetworkInterface('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAttachNetworkInterface', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getAttachNetworkInterface('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAttachNetworkInterface', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postAttachNetworkInterface - errors', () => {
      it('should have a postAttachNetworkInterface function', (done) => {
        assert.equal(true, typeof a.postAttachNetworkInterface === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postAttachNetworkInterface(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postAttachNetworkInterface', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postAttachNetworkInterface('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postAttachNetworkInterface', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postAttachNetworkInterface('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postAttachNetworkInterface', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getAttachVolume - errors', () => {
      it('should have a getAttachVolume function', (done) => {
        assert.equal(true, typeof a.getAttachVolume === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing device', (done) => {
        const p = new Promise((resolve) => {
          a.getAttachVolume(null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'device is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAttachVolume', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing instanceId', (done) => {
        const p = new Promise((resolve) => {
          a.getAttachVolume('fakeparam', null, null, null, null, null, null, (data, error) => {
            const displayE = 'instanceId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAttachVolume', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing volumeId', (done) => {
        const p = new Promise((resolve) => {
          a.getAttachVolume('fakeparam', 'fakeparam', null, null, null, null, null, (data, error) => {
            const displayE = 'volumeId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAttachVolume', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getAttachVolume('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAttachVolume', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getAttachVolume('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAttachVolume', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postAttachVolume - errors', () => {
      it('should have a postAttachVolume function', (done) => {
        assert.equal(true, typeof a.postAttachVolume === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postAttachVolume(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postAttachVolume', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postAttachVolume('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postAttachVolume', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postAttachVolume('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postAttachVolume', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getAttachVpnGateway - errors', () => {
      it('should have a getAttachVpnGateway function', (done) => {
        assert.equal(true, typeof a.getAttachVpnGateway === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing vpcId', (done) => {
        const p = new Promise((resolve) => {
          a.getAttachVpnGateway(null, null, null, null, null, null, (data, error) => {
            const displayE = 'vpcId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAttachVpnGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing vpnGatewayId', (done) => {
        const p = new Promise((resolve) => {
          a.getAttachVpnGateway('fakeparam', null, null, null, null, null, (data, error) => {
            const displayE = 'vpnGatewayId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAttachVpnGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getAttachVpnGateway('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAttachVpnGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getAttachVpnGateway('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAttachVpnGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postAttachVpnGateway - errors', () => {
      it('should have a postAttachVpnGateway function', (done) => {
        assert.equal(true, typeof a.postAttachVpnGateway === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postAttachVpnGateway(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postAttachVpnGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postAttachVpnGateway('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postAttachVpnGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postAttachVpnGateway('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postAttachVpnGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getAuthorizeClientVpnIngress - errors', () => {
      it('should have a getAuthorizeClientVpnIngress function', (done) => {
        assert.equal(true, typeof a.getAuthorizeClientVpnIngress === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing clientVpnEndpointId', (done) => {
        const p = new Promise((resolve) => {
          a.getAuthorizeClientVpnIngress(null, null, null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'clientVpnEndpointId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAuthorizeClientVpnIngress', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing targetNetworkCidr', (done) => {
        const p = new Promise((resolve) => {
          a.getAuthorizeClientVpnIngress('fakeparam', null, null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'targetNetworkCidr is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAuthorizeClientVpnIngress', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getAuthorizeClientVpnIngress('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAuthorizeClientVpnIngress', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getAuthorizeClientVpnIngress('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAuthorizeClientVpnIngress', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postAuthorizeClientVpnIngress - errors', () => {
      it('should have a postAuthorizeClientVpnIngress function', (done) => {
        assert.equal(true, typeof a.postAuthorizeClientVpnIngress === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postAuthorizeClientVpnIngress(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postAuthorizeClientVpnIngress', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postAuthorizeClientVpnIngress('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postAuthorizeClientVpnIngress', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postAuthorizeClientVpnIngress('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postAuthorizeClientVpnIngress', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getAuthorizeSecurityGroupEgress - errors', () => {
      it('should have a getAuthorizeSecurityGroupEgress function', (done) => {
        assert.equal(true, typeof a.getAuthorizeSecurityGroupEgress === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing groupId', (done) => {
        const p = new Promise((resolve) => {
          a.getAuthorizeSecurityGroupEgress('fakeparam', null, null, null, null, null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'groupId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAuthorizeSecurityGroupEgress', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getAuthorizeSecurityGroupEgress('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAuthorizeSecurityGroupEgress', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getAuthorizeSecurityGroupEgress('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAuthorizeSecurityGroupEgress', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postAuthorizeSecurityGroupEgress - errors', () => {
      it('should have a postAuthorizeSecurityGroupEgress function', (done) => {
        assert.equal(true, typeof a.postAuthorizeSecurityGroupEgress === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postAuthorizeSecurityGroupEgress(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postAuthorizeSecurityGroupEgress', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postAuthorizeSecurityGroupEgress('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postAuthorizeSecurityGroupEgress', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postAuthorizeSecurityGroupEgress('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postAuthorizeSecurityGroupEgress', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getAuthorizeSecurityGroupIngress - errors', () => {
      it('should have a getAuthorizeSecurityGroupIngress function', (done) => {
        assert.equal(true, typeof a.getAuthorizeSecurityGroupIngress === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getAuthorizeSecurityGroupIngress('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAuthorizeSecurityGroupIngress', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getAuthorizeSecurityGroupIngress('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getAuthorizeSecurityGroupIngress', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postAuthorizeSecurityGroupIngress - errors', () => {
      it('should have a postAuthorizeSecurityGroupIngress function', (done) => {
        assert.equal(true, typeof a.postAuthorizeSecurityGroupIngress === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postAuthorizeSecurityGroupIngress(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postAuthorizeSecurityGroupIngress', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postAuthorizeSecurityGroupIngress('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postAuthorizeSecurityGroupIngress', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getBundleInstance - errors', () => {
      it('should have a getBundleInstance function', (done) => {
        assert.equal(true, typeof a.getBundleInstance === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing instanceId', (done) => {
        const p = new Promise((resolve) => {
          a.getBundleInstance(null, null, null, null, null, null, (data, error) => {
            const displayE = 'instanceId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getBundleInstance', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getBundleInstance('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getBundleInstance', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getBundleInstance('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getBundleInstance', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postBundleInstance - errors', () => {
      it('should have a postBundleInstance function', (done) => {
        assert.equal(true, typeof a.postBundleInstance === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postBundleInstance(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postBundleInstance', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postBundleInstance('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postBundleInstance', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postBundleInstance('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postBundleInstance', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getCancelBundleTask - errors', () => {
      it('should have a getCancelBundleTask function', (done) => {
        assert.equal(true, typeof a.getCancelBundleTask === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing bundleId', (done) => {
        const p = new Promise((resolve) => {
          a.getCancelBundleTask(null, null, null, null, null, (data, error) => {
            const displayE = 'bundleId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCancelBundleTask', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getCancelBundleTask('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCancelBundleTask', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getCancelBundleTask('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCancelBundleTask', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postCancelBundleTask - errors', () => {
      it('should have a postCancelBundleTask function', (done) => {
        assert.equal(true, typeof a.postCancelBundleTask === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postCancelBundleTask(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCancelBundleTask', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postCancelBundleTask('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCancelBundleTask', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postCancelBundleTask('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCancelBundleTask', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getCancelCapacityReservation - errors', () => {
      it('should have a getCancelCapacityReservation function', (done) => {
        assert.equal(true, typeof a.getCancelCapacityReservation === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing capacityReservationId', (done) => {
        const p = new Promise((resolve) => {
          a.getCancelCapacityReservation(null, null, null, null, null, (data, error) => {
            const displayE = 'capacityReservationId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCancelCapacityReservation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getCancelCapacityReservation('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCancelCapacityReservation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getCancelCapacityReservation('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCancelCapacityReservation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postCancelCapacityReservation - errors', () => {
      it('should have a postCancelCapacityReservation function', (done) => {
        assert.equal(true, typeof a.postCancelCapacityReservation === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postCancelCapacityReservation(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCancelCapacityReservation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postCancelCapacityReservation('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCancelCapacityReservation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postCancelCapacityReservation('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCancelCapacityReservation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getCancelConversionTask - errors', () => {
      it('should have a getCancelConversionTask function', (done) => {
        assert.equal(true, typeof a.getCancelConversionTask === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing conversionTaskId', (done) => {
        const p = new Promise((resolve) => {
          a.getCancelConversionTask(null, null, null, null, null, null, (data, error) => {
            const displayE = 'conversionTaskId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCancelConversionTask', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getCancelConversionTask('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCancelConversionTask', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getCancelConversionTask('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCancelConversionTask', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postCancelConversionTask - errors', () => {
      it('should have a postCancelConversionTask function', (done) => {
        assert.equal(true, typeof a.postCancelConversionTask === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postCancelConversionTask(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCancelConversionTask', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postCancelConversionTask('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCancelConversionTask', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postCancelConversionTask('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCancelConversionTask', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getCancelExportTask - errors', () => {
      it('should have a getCancelExportTask function', (done) => {
        assert.equal(true, typeof a.getCancelExportTask === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing exportTaskId', (done) => {
        const p = new Promise((resolve) => {
          a.getCancelExportTask(null, null, null, null, (data, error) => {
            const displayE = 'exportTaskId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCancelExportTask', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getCancelExportTask('fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCancelExportTask', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getCancelExportTask('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCancelExportTask', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postCancelExportTask - errors', () => {
      it('should have a postCancelExportTask function', (done) => {
        assert.equal(true, typeof a.postCancelExportTask === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postCancelExportTask(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCancelExportTask', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postCancelExportTask('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCancelExportTask', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postCancelExportTask('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCancelExportTask', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getCancelImportTask - errors', () => {
      it('should have a getCancelImportTask function', (done) => {
        assert.equal(true, typeof a.getCancelImportTask === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getCancelImportTask('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCancelImportTask', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getCancelImportTask('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCancelImportTask', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postCancelImportTask - errors', () => {
      it('should have a postCancelImportTask function', (done) => {
        assert.equal(true, typeof a.postCancelImportTask === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postCancelImportTask(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCancelImportTask', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postCancelImportTask('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCancelImportTask', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getCancelReservedInstancesListing - errors', () => {
      it('should have a getCancelReservedInstancesListing function', (done) => {
        assert.equal(true, typeof a.getCancelReservedInstancesListing === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing reservedInstancesListingId', (done) => {
        const p = new Promise((resolve) => {
          a.getCancelReservedInstancesListing(null, null, null, null, (data, error) => {
            const displayE = 'reservedInstancesListingId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCancelReservedInstancesListing', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getCancelReservedInstancesListing('fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCancelReservedInstancesListing', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getCancelReservedInstancesListing('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCancelReservedInstancesListing', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postCancelReservedInstancesListing - errors', () => {
      it('should have a postCancelReservedInstancesListing function', (done) => {
        assert.equal(true, typeof a.postCancelReservedInstancesListing === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postCancelReservedInstancesListing(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCancelReservedInstancesListing', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postCancelReservedInstancesListing('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCancelReservedInstancesListing', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postCancelReservedInstancesListing('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCancelReservedInstancesListing', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getCancelSpotFleetRequests - errors', () => {
      it('should have a getCancelSpotFleetRequests function', (done) => {
        assert.equal(true, typeof a.getCancelSpotFleetRequests === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing spotFleetRequestId', (done) => {
        const p = new Promise((resolve) => {
          a.getCancelSpotFleetRequests('fakeparam', null, null, null, null, null, (data, error) => {
            const displayE = 'spotFleetRequestId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCancelSpotFleetRequests', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing terminateInstances', (done) => {
        const p = new Promise((resolve) => {
          a.getCancelSpotFleetRequests('fakeparam', 'fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'terminateInstances is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCancelSpotFleetRequests', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getCancelSpotFleetRequests('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCancelSpotFleetRequests', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getCancelSpotFleetRequests('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCancelSpotFleetRequests', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postCancelSpotFleetRequests - errors', () => {
      it('should have a postCancelSpotFleetRequests function', (done) => {
        assert.equal(true, typeof a.postCancelSpotFleetRequests === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postCancelSpotFleetRequests(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCancelSpotFleetRequests', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postCancelSpotFleetRequests('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCancelSpotFleetRequests', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postCancelSpotFleetRequests('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCancelSpotFleetRequests', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getCancelSpotInstanceRequests - errors', () => {
      it('should have a getCancelSpotInstanceRequests function', (done) => {
        assert.equal(true, typeof a.getCancelSpotInstanceRequests === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing spotInstanceRequestId', (done) => {
        const p = new Promise((resolve) => {
          a.getCancelSpotInstanceRequests('fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'spotInstanceRequestId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCancelSpotInstanceRequests', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getCancelSpotInstanceRequests('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCancelSpotInstanceRequests', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getCancelSpotInstanceRequests('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCancelSpotInstanceRequests', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postCancelSpotInstanceRequests - errors', () => {
      it('should have a postCancelSpotInstanceRequests function', (done) => {
        assert.equal(true, typeof a.postCancelSpotInstanceRequests === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postCancelSpotInstanceRequests(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCancelSpotInstanceRequests', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postCancelSpotInstanceRequests('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCancelSpotInstanceRequests', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postCancelSpotInstanceRequests('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCancelSpotInstanceRequests', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getConfirmProductInstance - errors', () => {
      it('should have a getConfirmProductInstance function', (done) => {
        assert.equal(true, typeof a.getConfirmProductInstance === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing instanceId', (done) => {
        const p = new Promise((resolve) => {
          a.getConfirmProductInstance(null, null, null, null, null, null, (data, error) => {
            const displayE = 'instanceId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getConfirmProductInstance', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing productCode', (done) => {
        const p = new Promise((resolve) => {
          a.getConfirmProductInstance('fakeparam', null, null, null, null, null, (data, error) => {
            const displayE = 'productCode is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getConfirmProductInstance', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getConfirmProductInstance('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getConfirmProductInstance', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getConfirmProductInstance('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getConfirmProductInstance', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postConfirmProductInstance - errors', () => {
      it('should have a postConfirmProductInstance function', (done) => {
        assert.equal(true, typeof a.postConfirmProductInstance === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postConfirmProductInstance(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postConfirmProductInstance', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postConfirmProductInstance('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postConfirmProductInstance', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postConfirmProductInstance('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postConfirmProductInstance', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getCopyFpgaImage - errors', () => {
      it('should have a getCopyFpgaImage function', (done) => {
        assert.equal(true, typeof a.getCopyFpgaImage === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing sourceFpgaImageId', (done) => {
        const p = new Promise((resolve) => {
          a.getCopyFpgaImage('fakeparam', null, null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'sourceFpgaImageId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCopyFpgaImage', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing sourceRegion', (done) => {
        const p = new Promise((resolve) => {
          a.getCopyFpgaImage('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, null, null, (data, error) => {
            const displayE = 'sourceRegion is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCopyFpgaImage', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getCopyFpgaImage('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCopyFpgaImage', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getCopyFpgaImage('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCopyFpgaImage', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postCopyFpgaImage - errors', () => {
      it('should have a postCopyFpgaImage function', (done) => {
        assert.equal(true, typeof a.postCopyFpgaImage === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postCopyFpgaImage(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCopyFpgaImage', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postCopyFpgaImage('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCopyFpgaImage', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postCopyFpgaImage('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCopyFpgaImage', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getCopyImage - errors', () => {
      it('should have a getCopyImage function', (done) => {
        assert.equal(true, typeof a.getCopyImage === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing name', (done) => {
        const p = new Promise((resolve) => {
          a.getCopyImage('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'name is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCopyImage', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing sourceImageId', (done) => {
        const p = new Promise((resolve) => {
          a.getCopyImage('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, null, null, null, (data, error) => {
            const displayE = 'sourceImageId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCopyImage', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing sourceRegion', (done) => {
        const p = new Promise((resolve) => {
          a.getCopyImage('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, null, null, (data, error) => {
            const displayE = 'sourceRegion is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCopyImage', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getCopyImage('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCopyImage', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getCopyImage('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCopyImage', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postCopyImage - errors', () => {
      it('should have a postCopyImage function', (done) => {
        assert.equal(true, typeof a.postCopyImage === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postCopyImage(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCopyImage', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postCopyImage('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCopyImage', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postCopyImage('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCopyImage', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getCopySnapshot - errors', () => {
      it('should have a getCopySnapshot function', (done) => {
        assert.equal(true, typeof a.getCopySnapshot === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing sourceRegion', (done) => {
        const p = new Promise((resolve) => {
          a.getCopySnapshot('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, null, null, null, (data, error) => {
            const displayE = 'sourceRegion is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCopySnapshot', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing sourceSnapshotId', (done) => {
        const p = new Promise((resolve) => {
          a.getCopySnapshot('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, null, null, (data, error) => {
            const displayE = 'sourceSnapshotId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCopySnapshot', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getCopySnapshot('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCopySnapshot', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getCopySnapshot('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCopySnapshot', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postCopySnapshot - errors', () => {
      it('should have a postCopySnapshot function', (done) => {
        assert.equal(true, typeof a.postCopySnapshot === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postCopySnapshot(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCopySnapshot', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postCopySnapshot('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCopySnapshot', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postCopySnapshot('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCopySnapshot', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getCreateCapacityReservation - errors', () => {
      it('should have a getCreateCapacityReservation function', (done) => {
        assert.equal(true, typeof a.getCreateCapacityReservation === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing instanceType', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateCapacityReservation('fakeparam', null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'instanceType is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateCapacityReservation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing instancePlatform', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateCapacityReservation('fakeparam', 'fakeparam', null, null, null, null, null, null, null, null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'instancePlatform is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateCapacityReservation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing availabilityZone', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateCapacityReservation('fakeparam', 'fakeparam', 'fakeparam', null, null, null, null, null, null, null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'availabilityZone is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateCapacityReservation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing instanceCount', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateCapacityReservation('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, null, null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'instanceCount is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateCapacityReservation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateCapacityReservation('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateCapacityReservation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateCapacityReservation('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateCapacityReservation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postCreateCapacityReservation - errors', () => {
      it('should have a postCreateCapacityReservation function', (done) => {
        assert.equal(true, typeof a.postCreateCapacityReservation === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateCapacityReservation(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateCapacityReservation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateCapacityReservation('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateCapacityReservation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateCapacityReservation('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateCapacityReservation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getCreateClientVpnEndpoint - errors', () => {
      it('should have a getCreateClientVpnEndpoint function', (done) => {
        assert.equal(true, typeof a.getCreateClientVpnEndpoint === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing clientCidrBlock', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateClientVpnEndpoint(null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'clientCidrBlock is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateClientVpnEndpoint', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing serverCertificateArn', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateClientVpnEndpoint('fakeparam', null, null, null, null, null, null, null, null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'serverCertificateArn is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateClientVpnEndpoint', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing authentication', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateClientVpnEndpoint('fakeparam', 'fakeparam', null, null, null, null, null, null, null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'authentication is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateClientVpnEndpoint', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateClientVpnEndpoint('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateClientVpnEndpoint', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateClientVpnEndpoint('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateClientVpnEndpoint', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postCreateClientVpnEndpoint - errors', () => {
      it('should have a postCreateClientVpnEndpoint function', (done) => {
        assert.equal(true, typeof a.postCreateClientVpnEndpoint === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateClientVpnEndpoint(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateClientVpnEndpoint', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateClientVpnEndpoint('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateClientVpnEndpoint', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateClientVpnEndpoint('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateClientVpnEndpoint', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getCreateClientVpnRoute - errors', () => {
      it('should have a getCreateClientVpnRoute function', (done) => {
        assert.equal(true, typeof a.getCreateClientVpnRoute === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing clientVpnEndpointId', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateClientVpnRoute(null, null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'clientVpnEndpointId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateClientVpnRoute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing destinationCidrBlock', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateClientVpnRoute('fakeparam', null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'destinationCidrBlock is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateClientVpnRoute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing targetVpcSubnetId', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateClientVpnRoute('fakeparam', 'fakeparam', null, null, null, null, null, null, (data, error) => {
            const displayE = 'targetVpcSubnetId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateClientVpnRoute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateClientVpnRoute('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateClientVpnRoute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateClientVpnRoute('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateClientVpnRoute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postCreateClientVpnRoute - errors', () => {
      it('should have a postCreateClientVpnRoute function', (done) => {
        assert.equal(true, typeof a.postCreateClientVpnRoute === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateClientVpnRoute(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateClientVpnRoute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateClientVpnRoute('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateClientVpnRoute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateClientVpnRoute('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateClientVpnRoute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getCreateCustomerGateway - errors', () => {
      it('should have a getCreateCustomerGateway function', (done) => {
        assert.equal(true, typeof a.getCreateCustomerGateway === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing bgpAsn', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateCustomerGateway(null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'bgpAsn is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateCustomerGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing ipAddress', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateCustomerGateway('fakeparam', null, null, null, null, null, null, (data, error) => {
            const displayE = 'ipAddress is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateCustomerGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing type', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateCustomerGateway('fakeparam', 'fakeparam', null, null, null, null, null, (data, error) => {
            const displayE = 'type is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateCustomerGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateCustomerGateway('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateCustomerGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateCustomerGateway('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateCustomerGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postCreateCustomerGateway - errors', () => {
      it('should have a postCreateCustomerGateway function', (done) => {
        assert.equal(true, typeof a.postCreateCustomerGateway === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateCustomerGateway(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateCustomerGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateCustomerGateway('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateCustomerGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateCustomerGateway('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateCustomerGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getCreateDefaultSubnet - errors', () => {
      it('should have a getCreateDefaultSubnet function', (done) => {
        assert.equal(true, typeof a.getCreateDefaultSubnet === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing availabilityZone', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateDefaultSubnet(null, null, null, null, null, (data, error) => {
            const displayE = 'availabilityZone is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateDefaultSubnet', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateDefaultSubnet('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateDefaultSubnet', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateDefaultSubnet('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateDefaultSubnet', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postCreateDefaultSubnet - errors', () => {
      it('should have a postCreateDefaultSubnet function', (done) => {
        assert.equal(true, typeof a.postCreateDefaultSubnet === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateDefaultSubnet(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateDefaultSubnet', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateDefaultSubnet('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateDefaultSubnet', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateDefaultSubnet('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateDefaultSubnet', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getCreateDefaultVpc - errors', () => {
      it('should have a getCreateDefaultVpc function', (done) => {
        assert.equal(true, typeof a.getCreateDefaultVpc === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateDefaultVpc('fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateDefaultVpc', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateDefaultVpc('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateDefaultVpc', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postCreateDefaultVpc - errors', () => {
      it('should have a postCreateDefaultVpc function', (done) => {
        assert.equal(true, typeof a.postCreateDefaultVpc === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateDefaultVpc(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateDefaultVpc', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateDefaultVpc('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateDefaultVpc', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getCreateDhcpOptions - errors', () => {
      it('should have a getCreateDhcpOptions function', (done) => {
        assert.equal(true, typeof a.getCreateDhcpOptions === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing dhcpConfiguration', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateDhcpOptions(null, null, null, null, null, (data, error) => {
            const displayE = 'dhcpConfiguration is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateDhcpOptions', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateDhcpOptions('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateDhcpOptions', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateDhcpOptions('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateDhcpOptions', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postCreateDhcpOptions - errors', () => {
      it('should have a postCreateDhcpOptions function', (done) => {
        assert.equal(true, typeof a.postCreateDhcpOptions === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateDhcpOptions(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateDhcpOptions', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateDhcpOptions('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateDhcpOptions', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateDhcpOptions('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateDhcpOptions', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getCreateEgressOnlyInternetGateway - errors', () => {
      it('should have a getCreateEgressOnlyInternetGateway function', (done) => {
        assert.equal(true, typeof a.getCreateEgressOnlyInternetGateway === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing vpcId', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateEgressOnlyInternetGateway('fakeparam', 'fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'vpcId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateEgressOnlyInternetGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateEgressOnlyInternetGateway('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateEgressOnlyInternetGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateEgressOnlyInternetGateway('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateEgressOnlyInternetGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postCreateEgressOnlyInternetGateway - errors', () => {
      it('should have a postCreateEgressOnlyInternetGateway function', (done) => {
        assert.equal(true, typeof a.postCreateEgressOnlyInternetGateway === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateEgressOnlyInternetGateway(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateEgressOnlyInternetGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateEgressOnlyInternetGateway('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateEgressOnlyInternetGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateEgressOnlyInternetGateway('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateEgressOnlyInternetGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getCreateFleet - errors', () => {
      it('should have a getCreateFleet function', (done) => {
        assert.equal(true, typeof a.getCreateFleet === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing launchTemplateConfigs', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateFleet('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, null, null, null, null, null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'launchTemplateConfigs is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateFleet', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateFleet('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateFleet', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateFleet('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateFleet', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postCreateFleet - errors', () => {
      it('should have a postCreateFleet function', (done) => {
        assert.equal(true, typeof a.postCreateFleet === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateFleet(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateFleet', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateFleet('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateFleet', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateFleet('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateFleet', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getCreateFlowLogs - errors', () => {
      it('should have a getCreateFlowLogs function', (done) => {
        assert.equal(true, typeof a.getCreateFlowLogs === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing resourceId', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateFlowLogs('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'resourceId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateFlowLogs', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing resourceType', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateFlowLogs('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'resourceType is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateFlowLogs', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing trafficType', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateFlowLogs('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, null, null, null, (data, error) => {
            const displayE = 'trafficType is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateFlowLogs', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateFlowLogs('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateFlowLogs', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateFlowLogs('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateFlowLogs', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postCreateFlowLogs - errors', () => {
      it('should have a postCreateFlowLogs function', (done) => {
        assert.equal(true, typeof a.postCreateFlowLogs === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateFlowLogs(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateFlowLogs', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateFlowLogs('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateFlowLogs', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateFlowLogs('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateFlowLogs', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getCreateFpgaImage - errors', () => {
      it('should have a getCreateFpgaImage function', (done) => {
        assert.equal(true, typeof a.getCreateFpgaImage === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateFpgaImage('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateFpgaImage', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateFpgaImage('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateFpgaImage', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postCreateFpgaImage - errors', () => {
      it('should have a postCreateFpgaImage function', (done) => {
        assert.equal(true, typeof a.postCreateFpgaImage === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateFpgaImage(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateFpgaImage', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateFpgaImage('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateFpgaImage', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getCreateImage - errors', () => {
      it('should have a getCreateImage function', (done) => {
        assert.equal(true, typeof a.getCreateImage === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing instanceId', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateImage('fakeparam', 'fakeparam', 'fakeparam', null, null, null, null, null, null, (data, error) => {
            const displayE = 'instanceId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateImage', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing name', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateImage('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, null, null, (data, error) => {
            const displayE = 'name is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateImage', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateImage('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateImage', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateImage('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateImage', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postCreateImage - errors', () => {
      it('should have a postCreateImage function', (done) => {
        assert.equal(true, typeof a.postCreateImage === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateImage(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateImage', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateImage('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateImage', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateImage('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateImage', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getCreateInstanceExportTask - errors', () => {
      it('should have a getCreateInstanceExportTask function', (done) => {
        assert.equal(true, typeof a.getCreateInstanceExportTask === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing instanceId', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateInstanceExportTask('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, null, null, (data, error) => {
            const displayE = 'instanceId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateInstanceExportTask', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateInstanceExportTask('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateInstanceExportTask', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateInstanceExportTask('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateInstanceExportTask', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postCreateInstanceExportTask - errors', () => {
      it('should have a postCreateInstanceExportTask function', (done) => {
        assert.equal(true, typeof a.postCreateInstanceExportTask === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateInstanceExportTask(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateInstanceExportTask', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateInstanceExportTask('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateInstanceExportTask', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateInstanceExportTask('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateInstanceExportTask', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getCreateInternetGateway - errors', () => {
      it('should have a getCreateInternetGateway function', (done) => {
        assert.equal(true, typeof a.getCreateInternetGateway === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateInternetGateway('fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateInternetGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateInternetGateway('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateInternetGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postCreateInternetGateway - errors', () => {
      it('should have a postCreateInternetGateway function', (done) => {
        assert.equal(true, typeof a.postCreateInternetGateway === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateInternetGateway(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateInternetGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateInternetGateway('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateInternetGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getCreateKeyPair - errors', () => {
      it('should have a getCreateKeyPair function', (done) => {
        assert.equal(true, typeof a.getCreateKeyPair === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing keyName', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateKeyPair(null, null, null, null, null, (data, error) => {
            const displayE = 'keyName is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateKeyPair', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateKeyPair('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateKeyPair', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateKeyPair('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateKeyPair', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postCreateKeyPair - errors', () => {
      it('should have a postCreateKeyPair function', (done) => {
        assert.equal(true, typeof a.postCreateKeyPair === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateKeyPair(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateKeyPair', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateKeyPair('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateKeyPair', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateKeyPair('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateKeyPair', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getCreateLaunchTemplate - errors', () => {
      it('should have a getCreateLaunchTemplate function', (done) => {
        assert.equal(true, typeof a.getCreateLaunchTemplate === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing launchTemplateName', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateLaunchTemplate('fakeparam', 'fakeparam', null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'launchTemplateName is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateLaunchTemplate', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateLaunchTemplate('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateLaunchTemplate', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateLaunchTemplate('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateLaunchTemplate', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postCreateLaunchTemplate - errors', () => {
      it('should have a postCreateLaunchTemplate function', (done) => {
        assert.equal(true, typeof a.postCreateLaunchTemplate === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateLaunchTemplate(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateLaunchTemplate', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateLaunchTemplate('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateLaunchTemplate', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateLaunchTemplate('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateLaunchTemplate', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getCreateLaunchTemplateVersion - errors', () => {
      it('should have a getCreateLaunchTemplateVersion function', (done) => {
        assert.equal(true, typeof a.getCreateLaunchTemplateVersion === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateLaunchTemplateVersion('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateLaunchTemplateVersion', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateLaunchTemplateVersion('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateLaunchTemplateVersion', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postCreateLaunchTemplateVersion - errors', () => {
      it('should have a postCreateLaunchTemplateVersion function', (done) => {
        assert.equal(true, typeof a.postCreateLaunchTemplateVersion === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateLaunchTemplateVersion(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateLaunchTemplateVersion', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateLaunchTemplateVersion('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateLaunchTemplateVersion', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getCreateNatGateway - errors', () => {
      it('should have a getCreateNatGateway function', (done) => {
        assert.equal(true, typeof a.getCreateNatGateway === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing allocationId', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateNatGateway(null, null, null, null, null, null, (data, error) => {
            const displayE = 'allocationId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateNatGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing subnetId', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateNatGateway('fakeparam', 'fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'subnetId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateNatGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateNatGateway('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateNatGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateNatGateway('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateNatGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postCreateNatGateway - errors', () => {
      it('should have a postCreateNatGateway function', (done) => {
        assert.equal(true, typeof a.postCreateNatGateway === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateNatGateway(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateNatGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateNatGateway('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateNatGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateNatGateway('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateNatGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getCreateNetworkAcl - errors', () => {
      it('should have a getCreateNetworkAcl function', (done) => {
        assert.equal(true, typeof a.getCreateNetworkAcl === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing vpcId', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateNetworkAcl('fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'vpcId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateNetworkAcl', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateNetworkAcl('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateNetworkAcl', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateNetworkAcl('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateNetworkAcl', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postCreateNetworkAcl - errors', () => {
      it('should have a postCreateNetworkAcl function', (done) => {
        assert.equal(true, typeof a.postCreateNetworkAcl === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateNetworkAcl(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateNetworkAcl', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateNetworkAcl('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateNetworkAcl', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateNetworkAcl('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateNetworkAcl', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getCreateNetworkAclEntry - errors', () => {
      it('should have a getCreateNetworkAclEntry function', (done) => {
        assert.equal(true, typeof a.getCreateNetworkAclEntry === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing egress', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateNetworkAclEntry('fakeparam', 'fakeparam', null, null, null, null, null, null, null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'egress is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateNetworkAclEntry', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing networkAclId', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateNetworkAclEntry('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'networkAclId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateNetworkAclEntry', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing protocol', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateNetworkAclEntry('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, null, null, null, (data, error) => {
            const displayE = 'protocol is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateNetworkAclEntry', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing ruleAction', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateNetworkAclEntry('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, null, null, (data, error) => {
            const displayE = 'ruleAction is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateNetworkAclEntry', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing ruleNumber', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateNetworkAclEntry('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'ruleNumber is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateNetworkAclEntry', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateNetworkAclEntry('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateNetworkAclEntry', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateNetworkAclEntry('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateNetworkAclEntry', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postCreateNetworkAclEntry - errors', () => {
      it('should have a postCreateNetworkAclEntry function', (done) => {
        assert.equal(true, typeof a.postCreateNetworkAclEntry === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateNetworkAclEntry(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateNetworkAclEntry', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateNetworkAclEntry('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateNetworkAclEntry', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateNetworkAclEntry('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateNetworkAclEntry', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getCreateNetworkInterface - errors', () => {
      it('should have a getCreateNetworkInterface function', (done) => {
        assert.equal(true, typeof a.getCreateNetworkInterface === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing subnetId', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateNetworkInterface('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'subnetId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateNetworkInterface', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateNetworkInterface('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateNetworkInterface', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateNetworkInterface('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateNetworkInterface', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postCreateNetworkInterface - errors', () => {
      it('should have a postCreateNetworkInterface function', (done) => {
        assert.equal(true, typeof a.postCreateNetworkInterface === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateNetworkInterface(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateNetworkInterface', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateNetworkInterface('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateNetworkInterface', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateNetworkInterface('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateNetworkInterface', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getCreateNetworkInterfacePermission - errors', () => {
      it('should have a getCreateNetworkInterfacePermission function', (done) => {
        assert.equal(true, typeof a.getCreateNetworkInterfacePermission === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing networkInterfaceId', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateNetworkInterfacePermission(null, null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'networkInterfaceId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateNetworkInterfacePermission', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing permission', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateNetworkInterfacePermission('fakeparam', 'fakeparam', 'fakeparam', null, null, null, null, null, (data, error) => {
            const displayE = 'permission is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateNetworkInterfacePermission', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateNetworkInterfacePermission('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateNetworkInterfacePermission', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateNetworkInterfacePermission('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateNetworkInterfacePermission', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postCreateNetworkInterfacePermission - errors', () => {
      it('should have a postCreateNetworkInterfacePermission function', (done) => {
        assert.equal(true, typeof a.postCreateNetworkInterfacePermission === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateNetworkInterfacePermission(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateNetworkInterfacePermission', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateNetworkInterfacePermission('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateNetworkInterfacePermission', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateNetworkInterfacePermission('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateNetworkInterfacePermission', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getCreatePlacementGroup - errors', () => {
      it('should have a getCreatePlacementGroup function', (done) => {
        assert.equal(true, typeof a.getCreatePlacementGroup === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getCreatePlacementGroup('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreatePlacementGroup', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getCreatePlacementGroup('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreatePlacementGroup', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postCreatePlacementGroup - errors', () => {
      it('should have a postCreatePlacementGroup function', (done) => {
        assert.equal(true, typeof a.postCreatePlacementGroup === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postCreatePlacementGroup(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreatePlacementGroup', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postCreatePlacementGroup('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreatePlacementGroup', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getCreateReservedInstancesListing - errors', () => {
      it('should have a getCreateReservedInstancesListing function', (done) => {
        assert.equal(true, typeof a.getCreateReservedInstancesListing === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing clientToken', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateReservedInstancesListing(null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'clientToken is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateReservedInstancesListing', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing instanceCount', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateReservedInstancesListing('fakeparam', null, null, null, null, null, null, (data, error) => {
            const displayE = 'instanceCount is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateReservedInstancesListing', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing priceSchedules', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateReservedInstancesListing('fakeparam', 'fakeparam', null, null, null, null, null, (data, error) => {
            const displayE = 'priceSchedules is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateReservedInstancesListing', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing reservedInstancesId', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateReservedInstancesListing('fakeparam', 'fakeparam', 'fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'reservedInstancesId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateReservedInstancesListing', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateReservedInstancesListing('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateReservedInstancesListing', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateReservedInstancesListing('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateReservedInstancesListing', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postCreateReservedInstancesListing - errors', () => {
      it('should have a postCreateReservedInstancesListing function', (done) => {
        assert.equal(true, typeof a.postCreateReservedInstancesListing === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateReservedInstancesListing(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateReservedInstancesListing', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateReservedInstancesListing('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateReservedInstancesListing', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateReservedInstancesListing('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateReservedInstancesListing', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getCreateRoute - errors', () => {
      it('should have a getCreateRoute function', (done) => {
        assert.equal(true, typeof a.getCreateRoute === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing routeTableId', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateRoute('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, null, null, (data, error) => {
            const displayE = 'routeTableId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateRoute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateRoute('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateRoute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateRoute('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateRoute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postCreateRoute - errors', () => {
      it('should have a postCreateRoute function', (done) => {
        assert.equal(true, typeof a.postCreateRoute === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateRoute(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateRoute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateRoute('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateRoute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateRoute('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateRoute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getCreateRouteTable - errors', () => {
      it('should have a getCreateRouteTable function', (done) => {
        assert.equal(true, typeof a.getCreateRouteTable === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing vpcId', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateRouteTable('fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'vpcId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateRouteTable', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateRouteTable('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateRouteTable', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateRouteTable('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateRouteTable', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postCreateRouteTable - errors', () => {
      it('should have a postCreateRouteTable function', (done) => {
        assert.equal(true, typeof a.postCreateRouteTable === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateRouteTable(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateRouteTable', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateRouteTable('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateRouteTable', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateRouteTable('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateRouteTable', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getCreateSecurityGroup - errors', () => {
      it('should have a getCreateSecurityGroup function', (done) => {
        assert.equal(true, typeof a.getCreateSecurityGroup === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing groupDescription', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateSecurityGroup(null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'groupDescription is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateSecurityGroup', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing groupName', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateSecurityGroup('fakeparam', null, null, null, null, null, null, (data, error) => {
            const displayE = 'groupName is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateSecurityGroup', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateSecurityGroup('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateSecurityGroup', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateSecurityGroup('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateSecurityGroup', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postCreateSecurityGroup - errors', () => {
      it('should have a postCreateSecurityGroup function', (done) => {
        assert.equal(true, typeof a.postCreateSecurityGroup === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateSecurityGroup(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateSecurityGroup', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateSecurityGroup('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateSecurityGroup', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateSecurityGroup('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateSecurityGroup', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getCreateSnapshot - errors', () => {
      it('should have a getCreateSnapshot function', (done) => {
        assert.equal(true, typeof a.getCreateSnapshot === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing volumeId', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateSnapshot('fakeparam', null, null, null, null, null, null, (data, error) => {
            const displayE = 'volumeId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateSnapshot', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateSnapshot('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateSnapshot', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateSnapshot('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateSnapshot', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postCreateSnapshot - errors', () => {
      it('should have a postCreateSnapshot function', (done) => {
        assert.equal(true, typeof a.postCreateSnapshot === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateSnapshot(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateSnapshot', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateSnapshot('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateSnapshot', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateSnapshot('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateSnapshot', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getCreateSpotDatafeedSubscription - errors', () => {
      it('should have a getCreateSpotDatafeedSubscription function', (done) => {
        assert.equal(true, typeof a.getCreateSpotDatafeedSubscription === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing bucket', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateSpotDatafeedSubscription(null, null, null, null, null, null, (data, error) => {
            const displayE = 'bucket is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateSpotDatafeedSubscription', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateSpotDatafeedSubscription('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateSpotDatafeedSubscription', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateSpotDatafeedSubscription('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateSpotDatafeedSubscription', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postCreateSpotDatafeedSubscription - errors', () => {
      it('should have a postCreateSpotDatafeedSubscription function', (done) => {
        assert.equal(true, typeof a.postCreateSpotDatafeedSubscription === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateSpotDatafeedSubscription(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateSpotDatafeedSubscription', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateSpotDatafeedSubscription('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateSpotDatafeedSubscription', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateSpotDatafeedSubscription('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateSpotDatafeedSubscription', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getCreateSubnet - errors', () => {
      it('should have a getCreateSubnet function', (done) => {
        assert.equal(true, typeof a.getCreateSubnet === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing cidrBlock', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateSubnet('fakeparam', 'fakeparam', null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'cidrBlock is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateSubnet', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing vpcId', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateSubnet('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, null, null, (data, error) => {
            const displayE = 'vpcId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateSubnet', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateSubnet('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateSubnet', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateSubnet('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateSubnet', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postCreateSubnet - errors', () => {
      it('should have a postCreateSubnet function', (done) => {
        assert.equal(true, typeof a.postCreateSubnet === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateSubnet(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateSubnet', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateSubnet('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateSubnet', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateSubnet('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateSubnet', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getCreateTags - errors', () => {
      it('should have a getCreateTags function', (done) => {
        assert.equal(true, typeof a.getCreateTags === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing resourceId', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateTags('fakeparam', null, null, null, null, null, (data, error) => {
            const displayE = 'resourceId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateTags', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing tag', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateTags('fakeparam', 'fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'tag is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateTags', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateTags('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateTags', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateTags('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateTags', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postCreateTags - errors', () => {
      it('should have a postCreateTags function', (done) => {
        assert.equal(true, typeof a.postCreateTags === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateTags(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateTags', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateTags('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateTags', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateTags('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateTags', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getCreateTransitGateway - errors', () => {
      it('should have a getCreateTransitGateway function', (done) => {
        assert.equal(true, typeof a.getCreateTransitGateway === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateTransitGateway('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateTransitGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateTransitGateway('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateTransitGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postCreateTransitGateway - errors', () => {
      it('should have a postCreateTransitGateway function', (done) => {
        assert.equal(true, typeof a.postCreateTransitGateway === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateTransitGateway(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateTransitGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateTransitGateway('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateTransitGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getCreateTransitGatewayRoute - errors', () => {
      it('should have a getCreateTransitGatewayRoute function', (done) => {
        assert.equal(true, typeof a.getCreateTransitGatewayRoute === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing destinationCidrBlock', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateTransitGatewayRoute(null, null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'destinationCidrBlock is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateTransitGatewayRoute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing transitGatewayRouteTableId', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateTransitGatewayRoute('fakeparam', null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'transitGatewayRouteTableId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateTransitGatewayRoute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateTransitGatewayRoute('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateTransitGatewayRoute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateTransitGatewayRoute('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateTransitGatewayRoute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postCreateTransitGatewayRoute - errors', () => {
      it('should have a postCreateTransitGatewayRoute function', (done) => {
        assert.equal(true, typeof a.postCreateTransitGatewayRoute === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateTransitGatewayRoute(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateTransitGatewayRoute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateTransitGatewayRoute('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateTransitGatewayRoute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateTransitGatewayRoute('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateTransitGatewayRoute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getCreateTransitGatewayRouteTable - errors', () => {
      it('should have a getCreateTransitGatewayRouteTable function', (done) => {
        assert.equal(true, typeof a.getCreateTransitGatewayRouteTable === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing transitGatewayId', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateTransitGatewayRouteTable(null, null, null, null, null, null, (data, error) => {
            const displayE = 'transitGatewayId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateTransitGatewayRouteTable', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateTransitGatewayRouteTable('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateTransitGatewayRouteTable', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateTransitGatewayRouteTable('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateTransitGatewayRouteTable', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postCreateTransitGatewayRouteTable - errors', () => {
      it('should have a postCreateTransitGatewayRouteTable function', (done) => {
        assert.equal(true, typeof a.postCreateTransitGatewayRouteTable === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateTransitGatewayRouteTable(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateTransitGatewayRouteTable', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateTransitGatewayRouteTable('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateTransitGatewayRouteTable', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateTransitGatewayRouteTable('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateTransitGatewayRouteTable', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getCreateTransitGatewayVpcAttachment - errors', () => {
      it('should have a getCreateTransitGatewayVpcAttachment function', (done) => {
        assert.equal(true, typeof a.getCreateTransitGatewayVpcAttachment === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing transitGatewayId', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateTransitGatewayVpcAttachment(null, null, null, null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'transitGatewayId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateTransitGatewayVpcAttachment', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing vpcId', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateTransitGatewayVpcAttachment('fakeparam', null, null, null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'vpcId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateTransitGatewayVpcAttachment', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing subnetIds', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateTransitGatewayVpcAttachment('fakeparam', 'fakeparam', null, null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'subnetIds is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateTransitGatewayVpcAttachment', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateTransitGatewayVpcAttachment('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateTransitGatewayVpcAttachment', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateTransitGatewayVpcAttachment('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateTransitGatewayVpcAttachment', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postCreateTransitGatewayVpcAttachment - errors', () => {
      it('should have a postCreateTransitGatewayVpcAttachment function', (done) => {
        assert.equal(true, typeof a.postCreateTransitGatewayVpcAttachment === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateTransitGatewayVpcAttachment(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateTransitGatewayVpcAttachment', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateTransitGatewayVpcAttachment('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateTransitGatewayVpcAttachment', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateTransitGatewayVpcAttachment('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateTransitGatewayVpcAttachment', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getCreateVolume - errors', () => {
      it('should have a getCreateVolume function', (done) => {
        assert.equal(true, typeof a.getCreateVolume === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing availabilityZone', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateVolume(null, null, null, null, null, null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'availabilityZone is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateVolume', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateVolume('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateVolume', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateVolume('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateVolume', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postCreateVolume - errors', () => {
      it('should have a postCreateVolume function', (done) => {
        assert.equal(true, typeof a.postCreateVolume === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateVolume(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateVolume', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateVolume('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateVolume', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateVolume('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateVolume', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getCreateVpc - errors', () => {
      it('should have a getCreateVpc function', (done) => {
        assert.equal(true, typeof a.getCreateVpc === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing cidrBlock', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateVpc(null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'cidrBlock is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateVpc', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateVpc('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateVpc', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateVpc('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateVpc', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postCreateVpc - errors', () => {
      it('should have a postCreateVpc function', (done) => {
        assert.equal(true, typeof a.postCreateVpc === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateVpc(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateVpc', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateVpc('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateVpc', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateVpc('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateVpc', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getCreateVpcEndpoint - errors', () => {
      it('should have a getCreateVpcEndpoint function', (done) => {
        assert.equal(true, typeof a.getCreateVpcEndpoint === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing vpcId', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateVpcEndpoint('fakeparam', 'fakeparam', null, null, null, null, null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'vpcId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateVpcEndpoint', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing serviceName', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateVpcEndpoint('fakeparam', 'fakeparam', 'fakeparam', null, null, null, null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'serviceName is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateVpcEndpoint', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateVpcEndpoint('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateVpcEndpoint', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateVpcEndpoint('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateVpcEndpoint', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postCreateVpcEndpoint - errors', () => {
      it('should have a postCreateVpcEndpoint function', (done) => {
        assert.equal(true, typeof a.postCreateVpcEndpoint === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateVpcEndpoint(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateVpcEndpoint', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateVpcEndpoint('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateVpcEndpoint', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateVpcEndpoint('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateVpcEndpoint', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getCreateVpcEndpointConnectionNotification - errors', () => {
      it('should have a getCreateVpcEndpointConnectionNotification function', (done) => {
        assert.equal(true, typeof a.getCreateVpcEndpointConnectionNotification === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing connectionNotificationArn', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateVpcEndpointConnectionNotification('fakeparam', 'fakeparam', 'fakeparam', null, null, null, null, null, null, (data, error) => {
            const displayE = 'connectionNotificationArn is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateVpcEndpointConnectionNotification', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing connectionEvents', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateVpcEndpointConnectionNotification('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, null, null, (data, error) => {
            const displayE = 'connectionEvents is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateVpcEndpointConnectionNotification', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateVpcEndpointConnectionNotification('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateVpcEndpointConnectionNotification', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateVpcEndpointConnectionNotification('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateVpcEndpointConnectionNotification', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postCreateVpcEndpointConnectionNotification - errors', () => {
      it('should have a postCreateVpcEndpointConnectionNotification function', (done) => {
        assert.equal(true, typeof a.postCreateVpcEndpointConnectionNotification === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateVpcEndpointConnectionNotification(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateVpcEndpointConnectionNotification', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateVpcEndpointConnectionNotification('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateVpcEndpointConnectionNotification', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateVpcEndpointConnectionNotification('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateVpcEndpointConnectionNotification', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getCreateVpcEndpointServiceConfiguration - errors', () => {
      it('should have a getCreateVpcEndpointServiceConfiguration function', (done) => {
        assert.equal(true, typeof a.getCreateVpcEndpointServiceConfiguration === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing networkLoadBalancerArn', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateVpcEndpointServiceConfiguration('fakeparam', 'fakeparam', null, null, null, null, null, (data, error) => {
            const displayE = 'networkLoadBalancerArn is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateVpcEndpointServiceConfiguration', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateVpcEndpointServiceConfiguration('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateVpcEndpointServiceConfiguration', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateVpcEndpointServiceConfiguration('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateVpcEndpointServiceConfiguration', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postCreateVpcEndpointServiceConfiguration - errors', () => {
      it('should have a postCreateVpcEndpointServiceConfiguration function', (done) => {
        assert.equal(true, typeof a.postCreateVpcEndpointServiceConfiguration === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateVpcEndpointServiceConfiguration(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateVpcEndpointServiceConfiguration', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateVpcEndpointServiceConfiguration('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateVpcEndpointServiceConfiguration', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateVpcEndpointServiceConfiguration('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateVpcEndpointServiceConfiguration', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getCreateVpcPeeringConnection - errors', () => {
      it('should have a getCreateVpcPeeringConnection function', (done) => {
        assert.equal(true, typeof a.getCreateVpcPeeringConnection === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateVpcPeeringConnection('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateVpcPeeringConnection', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateVpcPeeringConnection('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateVpcPeeringConnection', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postCreateVpcPeeringConnection - errors', () => {
      it('should have a postCreateVpcPeeringConnection function', (done) => {
        assert.equal(true, typeof a.postCreateVpcPeeringConnection === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateVpcPeeringConnection(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateVpcPeeringConnection', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateVpcPeeringConnection('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateVpcPeeringConnection', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getCreateVpnConnection - errors', () => {
      it('should have a getCreateVpnConnection function', (done) => {
        assert.equal(true, typeof a.getCreateVpnConnection === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing customerGatewayId', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateVpnConnection(null, null, null, null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'customerGatewayId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateVpnConnection', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing type', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateVpnConnection('fakeparam', null, null, null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'type is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateVpnConnection', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateVpnConnection('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateVpnConnection', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateVpnConnection('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateVpnConnection', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postCreateVpnConnection - errors', () => {
      it('should have a postCreateVpnConnection function', (done) => {
        assert.equal(true, typeof a.postCreateVpnConnection === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateVpnConnection(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateVpnConnection', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateVpnConnection('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateVpnConnection', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateVpnConnection('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateVpnConnection', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getCreateVpnConnectionRoute - errors', () => {
      it('should have a getCreateVpnConnectionRoute function', (done) => {
        assert.equal(true, typeof a.getCreateVpnConnectionRoute === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing destinationCidrBlock', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateVpnConnectionRoute(null, null, null, null, null, (data, error) => {
            const displayE = 'destinationCidrBlock is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateVpnConnectionRoute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing vpnConnectionId', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateVpnConnectionRoute('fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'vpnConnectionId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateVpnConnectionRoute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateVpnConnectionRoute('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateVpnConnectionRoute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateVpnConnectionRoute('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateVpnConnectionRoute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postCreateVpnConnectionRoute - errors', () => {
      it('should have a postCreateVpnConnectionRoute function', (done) => {
        assert.equal(true, typeof a.postCreateVpnConnectionRoute === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateVpnConnectionRoute(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateVpnConnectionRoute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateVpnConnectionRoute('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateVpnConnectionRoute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateVpnConnectionRoute('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateVpnConnectionRoute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getCreateVpnGateway - errors', () => {
      it('should have a getCreateVpnGateway function', (done) => {
        assert.equal(true, typeof a.getCreateVpnGateway === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing type', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateVpnGateway('fakeparam', null, null, null, null, null, null, (data, error) => {
            const displayE = 'type is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateVpnGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateVpnGateway('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateVpnGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getCreateVpnGateway('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getCreateVpnGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postCreateVpnGateway - errors', () => {
      it('should have a postCreateVpnGateway function', (done) => {
        assert.equal(true, typeof a.postCreateVpnGateway === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateVpnGateway(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateVpnGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateVpnGateway('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateVpnGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postCreateVpnGateway('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postCreateVpnGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDeleteClientVpnEndpoint - errors', () => {
      it('should have a getDeleteClientVpnEndpoint function', (done) => {
        assert.equal(true, typeof a.getDeleteClientVpnEndpoint === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing clientVpnEndpointId', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteClientVpnEndpoint(null, null, null, null, null, (data, error) => {
            const displayE = 'clientVpnEndpointId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteClientVpnEndpoint', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteClientVpnEndpoint('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteClientVpnEndpoint', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteClientVpnEndpoint('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteClientVpnEndpoint', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDeleteClientVpnEndpoint - errors', () => {
      it('should have a postDeleteClientVpnEndpoint function', (done) => {
        assert.equal(true, typeof a.postDeleteClientVpnEndpoint === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteClientVpnEndpoint(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteClientVpnEndpoint', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteClientVpnEndpoint('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteClientVpnEndpoint', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteClientVpnEndpoint('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteClientVpnEndpoint', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDeleteClientVpnRoute - errors', () => {
      it('should have a getDeleteClientVpnRoute function', (done) => {
        assert.equal(true, typeof a.getDeleteClientVpnRoute === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing clientVpnEndpointId', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteClientVpnRoute(null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'clientVpnEndpointId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteClientVpnRoute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing destinationCidrBlock', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteClientVpnRoute('fakeparam', 'fakeparam', null, null, null, null, null, (data, error) => {
            const displayE = 'destinationCidrBlock is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteClientVpnRoute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteClientVpnRoute('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteClientVpnRoute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteClientVpnRoute('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteClientVpnRoute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDeleteClientVpnRoute - errors', () => {
      it('should have a postDeleteClientVpnRoute function', (done) => {
        assert.equal(true, typeof a.postDeleteClientVpnRoute === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteClientVpnRoute(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteClientVpnRoute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteClientVpnRoute('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteClientVpnRoute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteClientVpnRoute('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteClientVpnRoute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDeleteCustomerGateway - errors', () => {
      it('should have a getDeleteCustomerGateway function', (done) => {
        assert.equal(true, typeof a.getDeleteCustomerGateway === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing customerGatewayId', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteCustomerGateway(null, null, null, null, null, (data, error) => {
            const displayE = 'customerGatewayId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteCustomerGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteCustomerGateway('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteCustomerGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteCustomerGateway('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteCustomerGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDeleteCustomerGateway - errors', () => {
      it('should have a postDeleteCustomerGateway function', (done) => {
        assert.equal(true, typeof a.postDeleteCustomerGateway === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteCustomerGateway(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteCustomerGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteCustomerGateway('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteCustomerGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteCustomerGateway('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteCustomerGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDeleteDhcpOptions - errors', () => {
      it('should have a getDeleteDhcpOptions function', (done) => {
        assert.equal(true, typeof a.getDeleteDhcpOptions === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing dhcpOptionsId', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteDhcpOptions(null, null, null, null, null, (data, error) => {
            const displayE = 'dhcpOptionsId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteDhcpOptions', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteDhcpOptions('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteDhcpOptions', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteDhcpOptions('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteDhcpOptions', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDeleteDhcpOptions - errors', () => {
      it('should have a postDeleteDhcpOptions function', (done) => {
        assert.equal(true, typeof a.postDeleteDhcpOptions === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteDhcpOptions(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteDhcpOptions', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteDhcpOptions('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteDhcpOptions', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteDhcpOptions('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteDhcpOptions', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDeleteEgressOnlyInternetGateway - errors', () => {
      it('should have a getDeleteEgressOnlyInternetGateway function', (done) => {
        assert.equal(true, typeof a.getDeleteEgressOnlyInternetGateway === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing egressOnlyInternetGatewayId', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteEgressOnlyInternetGateway('fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'egressOnlyInternetGatewayId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteEgressOnlyInternetGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteEgressOnlyInternetGateway('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteEgressOnlyInternetGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteEgressOnlyInternetGateway('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteEgressOnlyInternetGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDeleteEgressOnlyInternetGateway - errors', () => {
      it('should have a postDeleteEgressOnlyInternetGateway function', (done) => {
        assert.equal(true, typeof a.postDeleteEgressOnlyInternetGateway === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteEgressOnlyInternetGateway(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteEgressOnlyInternetGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteEgressOnlyInternetGateway('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteEgressOnlyInternetGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteEgressOnlyInternetGateway('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteEgressOnlyInternetGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDeleteFleets - errors', () => {
      it('should have a getDeleteFleets function', (done) => {
        assert.equal(true, typeof a.getDeleteFleets === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing fleetId', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteFleets('fakeparam', null, null, null, null, null, (data, error) => {
            const displayE = 'fleetId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteFleets', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing terminateInstances', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteFleets('fakeparam', 'fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'terminateInstances is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteFleets', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteFleets('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteFleets', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteFleets('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteFleets', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDeleteFleets - errors', () => {
      it('should have a postDeleteFleets function', (done) => {
        assert.equal(true, typeof a.postDeleteFleets === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteFleets(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteFleets', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteFleets('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteFleets', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteFleets('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteFleets', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDeleteFlowLogs - errors', () => {
      it('should have a getDeleteFlowLogs function', (done) => {
        assert.equal(true, typeof a.getDeleteFlowLogs === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing flowLogId', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteFlowLogs('fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'flowLogId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteFlowLogs', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteFlowLogs('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteFlowLogs', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteFlowLogs('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteFlowLogs', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDeleteFlowLogs - errors', () => {
      it('should have a postDeleteFlowLogs function', (done) => {
        assert.equal(true, typeof a.postDeleteFlowLogs === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteFlowLogs(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteFlowLogs', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteFlowLogs('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteFlowLogs', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteFlowLogs('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteFlowLogs', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDeleteFpgaImage - errors', () => {
      it('should have a getDeleteFpgaImage function', (done) => {
        assert.equal(true, typeof a.getDeleteFpgaImage === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing fpgaImageId', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteFpgaImage('fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'fpgaImageId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteFpgaImage', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteFpgaImage('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteFpgaImage', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteFpgaImage('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteFpgaImage', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDeleteFpgaImage - errors', () => {
      it('should have a postDeleteFpgaImage function', (done) => {
        assert.equal(true, typeof a.postDeleteFpgaImage === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteFpgaImage(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteFpgaImage', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteFpgaImage('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteFpgaImage', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteFpgaImage('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteFpgaImage', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDeleteInternetGateway - errors', () => {
      it('should have a getDeleteInternetGateway function', (done) => {
        assert.equal(true, typeof a.getDeleteInternetGateway === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing internetGatewayId', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteInternetGateway('fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'internetGatewayId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteInternetGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteInternetGateway('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteInternetGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteInternetGateway('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteInternetGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDeleteInternetGateway - errors', () => {
      it('should have a postDeleteInternetGateway function', (done) => {
        assert.equal(true, typeof a.postDeleteInternetGateway === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteInternetGateway(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteInternetGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteInternetGateway('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteInternetGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteInternetGateway('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteInternetGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDeleteKeyPair - errors', () => {
      it('should have a getDeleteKeyPair function', (done) => {
        assert.equal(true, typeof a.getDeleteKeyPair === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing keyName', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteKeyPair(null, null, null, null, null, (data, error) => {
            const displayE = 'keyName is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteKeyPair', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteKeyPair('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteKeyPair', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteKeyPair('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteKeyPair', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDeleteKeyPair - errors', () => {
      it('should have a postDeleteKeyPair function', (done) => {
        assert.equal(true, typeof a.postDeleteKeyPair === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteKeyPair(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteKeyPair', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteKeyPair('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteKeyPair', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteKeyPair('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteKeyPair', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDeleteLaunchTemplate - errors', () => {
      it('should have a getDeleteLaunchTemplate function', (done) => {
        assert.equal(true, typeof a.getDeleteLaunchTemplate === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteLaunchTemplate('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteLaunchTemplate', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteLaunchTemplate('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteLaunchTemplate', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDeleteLaunchTemplate - errors', () => {
      it('should have a postDeleteLaunchTemplate function', (done) => {
        assert.equal(true, typeof a.postDeleteLaunchTemplate === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteLaunchTemplate(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteLaunchTemplate', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteLaunchTemplate('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteLaunchTemplate', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDeleteLaunchTemplateVersions - errors', () => {
      it('should have a getDeleteLaunchTemplateVersions function', (done) => {
        assert.equal(true, typeof a.getDeleteLaunchTemplateVersions === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing launchTemplateVersion', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteLaunchTemplateVersions('fakeparam', 'fakeparam', 'fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'launchTemplateVersion is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteLaunchTemplateVersions', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteLaunchTemplateVersions('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteLaunchTemplateVersions', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteLaunchTemplateVersions('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteLaunchTemplateVersions', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDeleteLaunchTemplateVersions - errors', () => {
      it('should have a postDeleteLaunchTemplateVersions function', (done) => {
        assert.equal(true, typeof a.postDeleteLaunchTemplateVersions === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteLaunchTemplateVersions(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteLaunchTemplateVersions', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteLaunchTemplateVersions('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteLaunchTemplateVersions', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteLaunchTemplateVersions('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteLaunchTemplateVersions', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDeleteNatGateway - errors', () => {
      it('should have a getDeleteNatGateway function', (done) => {
        assert.equal(true, typeof a.getDeleteNatGateway === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing natGatewayId', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteNatGateway(null, null, null, null, (data, error) => {
            const displayE = 'natGatewayId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteNatGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteNatGateway('fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteNatGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteNatGateway('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteNatGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDeleteNatGateway - errors', () => {
      it('should have a postDeleteNatGateway function', (done) => {
        assert.equal(true, typeof a.postDeleteNatGateway === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteNatGateway(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteNatGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteNatGateway('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteNatGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteNatGateway('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteNatGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDeleteNetworkAcl - errors', () => {
      it('should have a getDeleteNetworkAcl function', (done) => {
        assert.equal(true, typeof a.getDeleteNetworkAcl === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing networkAclId', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteNetworkAcl('fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'networkAclId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteNetworkAcl', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteNetworkAcl('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteNetworkAcl', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteNetworkAcl('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteNetworkAcl', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDeleteNetworkAcl - errors', () => {
      it('should have a postDeleteNetworkAcl function', (done) => {
        assert.equal(true, typeof a.postDeleteNetworkAcl === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteNetworkAcl(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteNetworkAcl', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteNetworkAcl('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteNetworkAcl', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteNetworkAcl('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteNetworkAcl', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDeleteNetworkAclEntry - errors', () => {
      it('should have a getDeleteNetworkAclEntry function', (done) => {
        assert.equal(true, typeof a.getDeleteNetworkAclEntry === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing egress', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteNetworkAclEntry('fakeparam', null, null, null, null, null, null, (data, error) => {
            const displayE = 'egress is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteNetworkAclEntry', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing networkAclId', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteNetworkAclEntry('fakeparam', 'fakeparam', null, null, null, null, null, (data, error) => {
            const displayE = 'networkAclId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteNetworkAclEntry', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing ruleNumber', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteNetworkAclEntry('fakeparam', 'fakeparam', 'fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'ruleNumber is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteNetworkAclEntry', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteNetworkAclEntry('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteNetworkAclEntry', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteNetworkAclEntry('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteNetworkAclEntry', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDeleteNetworkAclEntry - errors', () => {
      it('should have a postDeleteNetworkAclEntry function', (done) => {
        assert.equal(true, typeof a.postDeleteNetworkAclEntry === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteNetworkAclEntry(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteNetworkAclEntry', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteNetworkAclEntry('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteNetworkAclEntry', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteNetworkAclEntry('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteNetworkAclEntry', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDeleteNetworkInterface - errors', () => {
      it('should have a getDeleteNetworkInterface function', (done) => {
        assert.equal(true, typeof a.getDeleteNetworkInterface === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing networkInterfaceId', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteNetworkInterface('fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'networkInterfaceId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteNetworkInterface', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteNetworkInterface('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteNetworkInterface', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteNetworkInterface('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteNetworkInterface', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDeleteNetworkInterface - errors', () => {
      it('should have a postDeleteNetworkInterface function', (done) => {
        assert.equal(true, typeof a.postDeleteNetworkInterface === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteNetworkInterface(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteNetworkInterface', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteNetworkInterface('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteNetworkInterface', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteNetworkInterface('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteNetworkInterface', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDeleteNetworkInterfacePermission - errors', () => {
      it('should have a getDeleteNetworkInterfacePermission function', (done) => {
        assert.equal(true, typeof a.getDeleteNetworkInterfacePermission === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing networkInterfacePermissionId', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteNetworkInterfacePermission(null, null, null, null, null, null, (data, error) => {
            const displayE = 'networkInterfacePermissionId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteNetworkInterfacePermission', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteNetworkInterfacePermission('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteNetworkInterfacePermission', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteNetworkInterfacePermission('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteNetworkInterfacePermission', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDeleteNetworkInterfacePermission - errors', () => {
      it('should have a postDeleteNetworkInterfacePermission function', (done) => {
        assert.equal(true, typeof a.postDeleteNetworkInterfacePermission === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteNetworkInterfacePermission(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteNetworkInterfacePermission', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteNetworkInterfacePermission('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteNetworkInterfacePermission', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteNetworkInterfacePermission('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteNetworkInterfacePermission', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDeletePlacementGroup - errors', () => {
      it('should have a getDeletePlacementGroup function', (done) => {
        assert.equal(true, typeof a.getDeletePlacementGroup === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing groupName', (done) => {
        const p = new Promise((resolve) => {
          a.getDeletePlacementGroup('fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'groupName is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeletePlacementGroup', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDeletePlacementGroup('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeletePlacementGroup', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDeletePlacementGroup('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeletePlacementGroup', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDeletePlacementGroup - errors', () => {
      it('should have a postDeletePlacementGroup function', (done) => {
        assert.equal(true, typeof a.postDeletePlacementGroup === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDeletePlacementGroup(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeletePlacementGroup', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDeletePlacementGroup('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeletePlacementGroup', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postDeletePlacementGroup('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeletePlacementGroup', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDeleteRoute - errors', () => {
      it('should have a getDeleteRoute function', (done) => {
        assert.equal(true, typeof a.getDeleteRoute === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing routeTableId', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteRoute('fakeparam', 'fakeparam', 'fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'routeTableId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteRoute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteRoute('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteRoute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteRoute('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteRoute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDeleteRoute - errors', () => {
      it('should have a postDeleteRoute function', (done) => {
        assert.equal(true, typeof a.postDeleteRoute === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteRoute(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteRoute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteRoute('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteRoute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteRoute('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteRoute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDeleteRouteTable - errors', () => {
      it('should have a getDeleteRouteTable function', (done) => {
        assert.equal(true, typeof a.getDeleteRouteTable === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing routeTableId', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteRouteTable('fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'routeTableId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteRouteTable', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteRouteTable('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteRouteTable', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteRouteTable('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteRouteTable', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDeleteRouteTable - errors', () => {
      it('should have a postDeleteRouteTable function', (done) => {
        assert.equal(true, typeof a.postDeleteRouteTable === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteRouteTable(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteRouteTable', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteRouteTable('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteRouteTable', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteRouteTable('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteRouteTable', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDeleteSecurityGroup - errors', () => {
      it('should have a getDeleteSecurityGroup function', (done) => {
        assert.equal(true, typeof a.getDeleteSecurityGroup === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteSecurityGroup('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteSecurityGroup', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteSecurityGroup('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteSecurityGroup', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDeleteSecurityGroup - errors', () => {
      it('should have a postDeleteSecurityGroup function', (done) => {
        assert.equal(true, typeof a.postDeleteSecurityGroup === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteSecurityGroup(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteSecurityGroup', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteSecurityGroup('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteSecurityGroup', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDeleteSnapshot - errors', () => {
      it('should have a getDeleteSnapshot function', (done) => {
        assert.equal(true, typeof a.getDeleteSnapshot === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing snapshotId', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteSnapshot(null, null, null, null, null, (data, error) => {
            const displayE = 'snapshotId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteSnapshot', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteSnapshot('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteSnapshot', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteSnapshot('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteSnapshot', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDeleteSnapshot - errors', () => {
      it('should have a postDeleteSnapshot function', (done) => {
        assert.equal(true, typeof a.postDeleteSnapshot === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteSnapshot(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteSnapshot', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteSnapshot('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteSnapshot', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteSnapshot('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteSnapshot', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDeleteSpotDatafeedSubscription - errors', () => {
      it('should have a getDeleteSpotDatafeedSubscription function', (done) => {
        assert.equal(true, typeof a.getDeleteSpotDatafeedSubscription === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteSpotDatafeedSubscription('fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteSpotDatafeedSubscription', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteSpotDatafeedSubscription('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteSpotDatafeedSubscription', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDeleteSpotDatafeedSubscription - errors', () => {
      it('should have a postDeleteSpotDatafeedSubscription function', (done) => {
        assert.equal(true, typeof a.postDeleteSpotDatafeedSubscription === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteSpotDatafeedSubscription(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteSpotDatafeedSubscription', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteSpotDatafeedSubscription('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteSpotDatafeedSubscription', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDeleteSubnet - errors', () => {
      it('should have a getDeleteSubnet function', (done) => {
        assert.equal(true, typeof a.getDeleteSubnet === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing subnetId', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteSubnet(null, null, null, null, null, (data, error) => {
            const displayE = 'subnetId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteSubnet', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteSubnet('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteSubnet', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteSubnet('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteSubnet', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDeleteSubnet - errors', () => {
      it('should have a postDeleteSubnet function', (done) => {
        assert.equal(true, typeof a.postDeleteSubnet === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteSubnet(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteSubnet', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteSubnet('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteSubnet', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteSubnet('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteSubnet', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDeleteTags - errors', () => {
      it('should have a getDeleteTags function', (done) => {
        assert.equal(true, typeof a.getDeleteTags === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing resourceId', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteTags('fakeparam', null, null, null, null, null, (data, error) => {
            const displayE = 'resourceId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteTags', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteTags('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteTags', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteTags('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteTags', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDeleteTags - errors', () => {
      it('should have a postDeleteTags function', (done) => {
        assert.equal(true, typeof a.postDeleteTags === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteTags(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteTags', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteTags('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteTags', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteTags('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteTags', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDeleteTransitGateway - errors', () => {
      it('should have a getDeleteTransitGateway function', (done) => {
        assert.equal(true, typeof a.getDeleteTransitGateway === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing transitGatewayId', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteTransitGateway(null, null, null, null, null, (data, error) => {
            const displayE = 'transitGatewayId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteTransitGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteTransitGateway('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteTransitGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteTransitGateway('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteTransitGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDeleteTransitGateway - errors', () => {
      it('should have a postDeleteTransitGateway function', (done) => {
        assert.equal(true, typeof a.postDeleteTransitGateway === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteTransitGateway(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteTransitGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteTransitGateway('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteTransitGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteTransitGateway('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteTransitGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDeleteTransitGatewayRoute - errors', () => {
      it('should have a getDeleteTransitGatewayRoute function', (done) => {
        assert.equal(true, typeof a.getDeleteTransitGatewayRoute === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing transitGatewayRouteTableId', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteTransitGatewayRoute(null, null, null, null, null, null, (data, error) => {
            const displayE = 'transitGatewayRouteTableId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteTransitGatewayRoute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing destinationCidrBlock', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteTransitGatewayRoute('fakeparam', null, null, null, null, null, (data, error) => {
            const displayE = 'destinationCidrBlock is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteTransitGatewayRoute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteTransitGatewayRoute('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteTransitGatewayRoute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteTransitGatewayRoute('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteTransitGatewayRoute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDeleteTransitGatewayRoute - errors', () => {
      it('should have a postDeleteTransitGatewayRoute function', (done) => {
        assert.equal(true, typeof a.postDeleteTransitGatewayRoute === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteTransitGatewayRoute(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteTransitGatewayRoute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteTransitGatewayRoute('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteTransitGatewayRoute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteTransitGatewayRoute('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteTransitGatewayRoute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDeleteTransitGatewayRouteTable - errors', () => {
      it('should have a getDeleteTransitGatewayRouteTable function', (done) => {
        assert.equal(true, typeof a.getDeleteTransitGatewayRouteTable === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing transitGatewayRouteTableId', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteTransitGatewayRouteTable(null, null, null, null, null, (data, error) => {
            const displayE = 'transitGatewayRouteTableId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteTransitGatewayRouteTable', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteTransitGatewayRouteTable('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteTransitGatewayRouteTable', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteTransitGatewayRouteTable('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteTransitGatewayRouteTable', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDeleteTransitGatewayRouteTable - errors', () => {
      it('should have a postDeleteTransitGatewayRouteTable function', (done) => {
        assert.equal(true, typeof a.postDeleteTransitGatewayRouteTable === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteTransitGatewayRouteTable(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteTransitGatewayRouteTable', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteTransitGatewayRouteTable('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteTransitGatewayRouteTable', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteTransitGatewayRouteTable('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteTransitGatewayRouteTable', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDeleteTransitGatewayVpcAttachment - errors', () => {
      it('should have a getDeleteTransitGatewayVpcAttachment function', (done) => {
        assert.equal(true, typeof a.getDeleteTransitGatewayVpcAttachment === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing transitGatewayAttachmentId', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteTransitGatewayVpcAttachment(null, null, null, null, null, (data, error) => {
            const displayE = 'transitGatewayAttachmentId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteTransitGatewayVpcAttachment', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteTransitGatewayVpcAttachment('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteTransitGatewayVpcAttachment', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteTransitGatewayVpcAttachment('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteTransitGatewayVpcAttachment', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDeleteTransitGatewayVpcAttachment - errors', () => {
      it('should have a postDeleteTransitGatewayVpcAttachment function', (done) => {
        assert.equal(true, typeof a.postDeleteTransitGatewayVpcAttachment === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteTransitGatewayVpcAttachment(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteTransitGatewayVpcAttachment', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteTransitGatewayVpcAttachment('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteTransitGatewayVpcAttachment', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteTransitGatewayVpcAttachment('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteTransitGatewayVpcAttachment', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDeleteVolume - errors', () => {
      it('should have a getDeleteVolume function', (done) => {
        assert.equal(true, typeof a.getDeleteVolume === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing volumeId', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteVolume(null, null, null, null, null, (data, error) => {
            const displayE = 'volumeId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteVolume', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteVolume('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteVolume', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteVolume('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteVolume', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDeleteVolume - errors', () => {
      it('should have a postDeleteVolume function', (done) => {
        assert.equal(true, typeof a.postDeleteVolume === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteVolume(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteVolume', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteVolume('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteVolume', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteVolume('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteVolume', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDeleteVpc - errors', () => {
      it('should have a getDeleteVpc function', (done) => {
        assert.equal(true, typeof a.getDeleteVpc === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing vpcId', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteVpc(null, null, null, null, null, (data, error) => {
            const displayE = 'vpcId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteVpc', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteVpc('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteVpc', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteVpc('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteVpc', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDeleteVpc - errors', () => {
      it('should have a postDeleteVpc function', (done) => {
        assert.equal(true, typeof a.postDeleteVpc === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteVpc(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteVpc', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteVpc('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteVpc', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteVpc('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteVpc', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDeleteVpcEndpointConnectionNotifications - errors', () => {
      it('should have a getDeleteVpcEndpointConnectionNotifications function', (done) => {
        assert.equal(true, typeof a.getDeleteVpcEndpointConnectionNotifications === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing connectionNotificationId', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteVpcEndpointConnectionNotifications('fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'connectionNotificationId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteVpcEndpointConnectionNotifications', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteVpcEndpointConnectionNotifications('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteVpcEndpointConnectionNotifications', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteVpcEndpointConnectionNotifications('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteVpcEndpointConnectionNotifications', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDeleteVpcEndpointConnectionNotifications - errors', () => {
      it('should have a postDeleteVpcEndpointConnectionNotifications function', (done) => {
        assert.equal(true, typeof a.postDeleteVpcEndpointConnectionNotifications === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteVpcEndpointConnectionNotifications(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteVpcEndpointConnectionNotifications', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteVpcEndpointConnectionNotifications('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteVpcEndpointConnectionNotifications', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteVpcEndpointConnectionNotifications('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteVpcEndpointConnectionNotifications', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDeleteVpcEndpointServiceConfigurations - errors', () => {
      it('should have a getDeleteVpcEndpointServiceConfigurations function', (done) => {
        assert.equal(true, typeof a.getDeleteVpcEndpointServiceConfigurations === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing serviceId', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteVpcEndpointServiceConfigurations('fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'serviceId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteVpcEndpointServiceConfigurations', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteVpcEndpointServiceConfigurations('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteVpcEndpointServiceConfigurations', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteVpcEndpointServiceConfigurations('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteVpcEndpointServiceConfigurations', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDeleteVpcEndpointServiceConfigurations - errors', () => {
      it('should have a postDeleteVpcEndpointServiceConfigurations function', (done) => {
        assert.equal(true, typeof a.postDeleteVpcEndpointServiceConfigurations === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteVpcEndpointServiceConfigurations(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteVpcEndpointServiceConfigurations', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteVpcEndpointServiceConfigurations('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteVpcEndpointServiceConfigurations', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteVpcEndpointServiceConfigurations('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteVpcEndpointServiceConfigurations', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDeleteVpcEndpoints - errors', () => {
      it('should have a getDeleteVpcEndpoints function', (done) => {
        assert.equal(true, typeof a.getDeleteVpcEndpoints === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing vpcEndpointId', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteVpcEndpoints('fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'vpcEndpointId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteVpcEndpoints', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteVpcEndpoints('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteVpcEndpoints', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteVpcEndpoints('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteVpcEndpoints', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDeleteVpcEndpoints - errors', () => {
      it('should have a postDeleteVpcEndpoints function', (done) => {
        assert.equal(true, typeof a.postDeleteVpcEndpoints === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteVpcEndpoints(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteVpcEndpoints', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteVpcEndpoints('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteVpcEndpoints', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteVpcEndpoints('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteVpcEndpoints', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDeleteVpcPeeringConnection - errors', () => {
      it('should have a getDeleteVpcPeeringConnection function', (done) => {
        assert.equal(true, typeof a.getDeleteVpcPeeringConnection === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing vpcPeeringConnectionId', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteVpcPeeringConnection('fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'vpcPeeringConnectionId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteVpcPeeringConnection', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteVpcPeeringConnection('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteVpcPeeringConnection', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteVpcPeeringConnection('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteVpcPeeringConnection', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDeleteVpcPeeringConnection - errors', () => {
      it('should have a postDeleteVpcPeeringConnection function', (done) => {
        assert.equal(true, typeof a.postDeleteVpcPeeringConnection === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteVpcPeeringConnection(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteVpcPeeringConnection', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteVpcPeeringConnection('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteVpcPeeringConnection', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteVpcPeeringConnection('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteVpcPeeringConnection', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDeleteVpnConnection - errors', () => {
      it('should have a getDeleteVpnConnection function', (done) => {
        assert.equal(true, typeof a.getDeleteVpnConnection === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing vpnConnectionId', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteVpnConnection(null, null, null, null, null, (data, error) => {
            const displayE = 'vpnConnectionId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteVpnConnection', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteVpnConnection('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteVpnConnection', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteVpnConnection('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteVpnConnection', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDeleteVpnConnection - errors', () => {
      it('should have a postDeleteVpnConnection function', (done) => {
        assert.equal(true, typeof a.postDeleteVpnConnection === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteVpnConnection(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteVpnConnection', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteVpnConnection('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteVpnConnection', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteVpnConnection('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteVpnConnection', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDeleteVpnConnectionRoute - errors', () => {
      it('should have a getDeleteVpnConnectionRoute function', (done) => {
        assert.equal(true, typeof a.getDeleteVpnConnectionRoute === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing destinationCidrBlock', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteVpnConnectionRoute(null, null, null, null, null, (data, error) => {
            const displayE = 'destinationCidrBlock is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteVpnConnectionRoute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing vpnConnectionId', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteVpnConnectionRoute('fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'vpnConnectionId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteVpnConnectionRoute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteVpnConnectionRoute('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteVpnConnectionRoute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteVpnConnectionRoute('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteVpnConnectionRoute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDeleteVpnConnectionRoute - errors', () => {
      it('should have a postDeleteVpnConnectionRoute function', (done) => {
        assert.equal(true, typeof a.postDeleteVpnConnectionRoute === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteVpnConnectionRoute(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteVpnConnectionRoute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteVpnConnectionRoute('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteVpnConnectionRoute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteVpnConnectionRoute('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteVpnConnectionRoute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDeleteVpnGateway - errors', () => {
      it('should have a getDeleteVpnGateway function', (done) => {
        assert.equal(true, typeof a.getDeleteVpnGateway === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing vpnGatewayId', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteVpnGateway(null, null, null, null, null, (data, error) => {
            const displayE = 'vpnGatewayId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteVpnGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteVpnGateway('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteVpnGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDeleteVpnGateway('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeleteVpnGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDeleteVpnGateway - errors', () => {
      it('should have a postDeleteVpnGateway function', (done) => {
        assert.equal(true, typeof a.postDeleteVpnGateway === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteVpnGateway(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteVpnGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteVpnGateway('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteVpnGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postDeleteVpnGateway('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeleteVpnGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDeprovisionByoipCidr - errors', () => {
      it('should have a getDeprovisionByoipCidr function', (done) => {
        assert.equal(true, typeof a.getDeprovisionByoipCidr === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing cidr', (done) => {
        const p = new Promise((resolve) => {
          a.getDeprovisionByoipCidr(null, null, null, null, null, (data, error) => {
            const displayE = 'cidr is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeprovisionByoipCidr', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDeprovisionByoipCidr('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeprovisionByoipCidr', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDeprovisionByoipCidr('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeprovisionByoipCidr', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDeprovisionByoipCidr - errors', () => {
      it('should have a postDeprovisionByoipCidr function', (done) => {
        assert.equal(true, typeof a.postDeprovisionByoipCidr === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDeprovisionByoipCidr(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeprovisionByoipCidr', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDeprovisionByoipCidr('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeprovisionByoipCidr', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postDeprovisionByoipCidr('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeprovisionByoipCidr', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDeregisterImage - errors', () => {
      it('should have a getDeregisterImage function', (done) => {
        assert.equal(true, typeof a.getDeregisterImage === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing imageId', (done) => {
        const p = new Promise((resolve) => {
          a.getDeregisterImage(null, null, null, null, null, (data, error) => {
            const displayE = 'imageId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeregisterImage', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDeregisterImage('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeregisterImage', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDeregisterImage('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDeregisterImage', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDeregisterImage - errors', () => {
      it('should have a postDeregisterImage function', (done) => {
        assert.equal(true, typeof a.postDeregisterImage === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDeregisterImage(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeregisterImage', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDeregisterImage('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeregisterImage', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postDeregisterImage('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDeregisterImage', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeAccountAttributes - errors', () => {
      it('should have a getDescribeAccountAttributes function', (done) => {
        assert.equal(true, typeof a.getDescribeAccountAttributes === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeAccountAttributes('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeAccountAttributes', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeAccountAttributes('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeAccountAttributes', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeAccountAttributes - errors', () => {
      it('should have a postDescribeAccountAttributes function', (done) => {
        assert.equal(true, typeof a.postDescribeAccountAttributes === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeAccountAttributes(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeAccountAttributes', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeAccountAttributes('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeAccountAttributes', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeAddresses - errors', () => {
      it('should have a getDescribeAddresses function', (done) => {
        assert.equal(true, typeof a.getDescribeAddresses === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeAddresses('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeAddresses', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeAddresses('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeAddresses', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeAddresses - errors', () => {
      it('should have a postDescribeAddresses function', (done) => {
        assert.equal(true, typeof a.postDescribeAddresses === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeAddresses(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeAddresses', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeAddresses('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeAddresses', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeAggregateIdFormat - errors', () => {
      it('should have a getDescribeAggregateIdFormat function', (done) => {
        assert.equal(true, typeof a.getDescribeAggregateIdFormat === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeAggregateIdFormat('fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeAggregateIdFormat', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeAggregateIdFormat('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeAggregateIdFormat', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeAggregateIdFormat - errors', () => {
      it('should have a postDescribeAggregateIdFormat function', (done) => {
        assert.equal(true, typeof a.postDescribeAggregateIdFormat === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeAggregateIdFormat(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeAggregateIdFormat', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeAggregateIdFormat('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeAggregateIdFormat', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeAvailabilityZones - errors', () => {
      it('should have a getDescribeAvailabilityZones function', (done) => {
        assert.equal(true, typeof a.getDescribeAvailabilityZones === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeAvailabilityZones('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeAvailabilityZones', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeAvailabilityZones('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeAvailabilityZones', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeAvailabilityZones - errors', () => {
      it('should have a postDescribeAvailabilityZones function', (done) => {
        assert.equal(true, typeof a.postDescribeAvailabilityZones === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeAvailabilityZones(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeAvailabilityZones', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeAvailabilityZones('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeAvailabilityZones', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeBundleTasks - errors', () => {
      it('should have a getDescribeBundleTasks function', (done) => {
        assert.equal(true, typeof a.getDescribeBundleTasks === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeBundleTasks('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeBundleTasks', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeBundleTasks('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeBundleTasks', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeBundleTasks - errors', () => {
      it('should have a postDescribeBundleTasks function', (done) => {
        assert.equal(true, typeof a.postDescribeBundleTasks === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeBundleTasks(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeBundleTasks', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeBundleTasks('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeBundleTasks', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeByoipCidrs - errors', () => {
      it('should have a getDescribeByoipCidrs function', (done) => {
        assert.equal(true, typeof a.getDescribeByoipCidrs === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing maxResults', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeByoipCidrs('fakeparam', null, null, null, null, null, (data, error) => {
            const displayE = 'maxResults is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeByoipCidrs', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeByoipCidrs('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeByoipCidrs', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeByoipCidrs('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeByoipCidrs', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeByoipCidrs - errors', () => {
      it('should have a postDescribeByoipCidrs function', (done) => {
        assert.equal(true, typeof a.postDescribeByoipCidrs === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeByoipCidrs(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeByoipCidrs', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeByoipCidrs('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeByoipCidrs', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeByoipCidrs('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeByoipCidrs', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeCapacityReservations - errors', () => {
      it('should have a getDescribeCapacityReservations function', (done) => {
        assert.equal(true, typeof a.getDescribeCapacityReservations === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeCapacityReservations('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeCapacityReservations', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeCapacityReservations('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeCapacityReservations', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeCapacityReservations - errors', () => {
      it('should have a postDescribeCapacityReservations function', (done) => {
        assert.equal(true, typeof a.postDescribeCapacityReservations === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeCapacityReservations(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeCapacityReservations', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeCapacityReservations('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeCapacityReservations', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeClassicLinkInstances - errors', () => {
      it('should have a getDescribeClassicLinkInstances function', (done) => {
        assert.equal(true, typeof a.getDescribeClassicLinkInstances === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeClassicLinkInstances('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeClassicLinkInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeClassicLinkInstances('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeClassicLinkInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeClassicLinkInstances - errors', () => {
      it('should have a postDescribeClassicLinkInstances function', (done) => {
        assert.equal(true, typeof a.postDescribeClassicLinkInstances === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeClassicLinkInstances(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeClassicLinkInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeClassicLinkInstances('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeClassicLinkInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeClientVpnAuthorizationRules - errors', () => {
      it('should have a getDescribeClientVpnAuthorizationRules function', (done) => {
        assert.equal(true, typeof a.getDescribeClientVpnAuthorizationRules === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing clientVpnEndpointId', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeClientVpnAuthorizationRules(null, null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'clientVpnEndpointId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeClientVpnAuthorizationRules', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeClientVpnAuthorizationRules('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeClientVpnAuthorizationRules', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeClientVpnAuthorizationRules('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeClientVpnAuthorizationRules', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeClientVpnAuthorizationRules - errors', () => {
      it('should have a postDescribeClientVpnAuthorizationRules function', (done) => {
        assert.equal(true, typeof a.postDescribeClientVpnAuthorizationRules === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeClientVpnAuthorizationRules(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeClientVpnAuthorizationRules', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeClientVpnAuthorizationRules('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeClientVpnAuthorizationRules', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeClientVpnAuthorizationRules('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeClientVpnAuthorizationRules', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeClientVpnConnections - errors', () => {
      it('should have a getDescribeClientVpnConnections function', (done) => {
        assert.equal(true, typeof a.getDescribeClientVpnConnections === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing clientVpnEndpointId', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeClientVpnConnections(null, null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'clientVpnEndpointId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeClientVpnConnections', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeClientVpnConnections('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeClientVpnConnections', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeClientVpnConnections('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeClientVpnConnections', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeClientVpnConnections - errors', () => {
      it('should have a postDescribeClientVpnConnections function', (done) => {
        assert.equal(true, typeof a.postDescribeClientVpnConnections === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeClientVpnConnections(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeClientVpnConnections', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeClientVpnConnections('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeClientVpnConnections', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeClientVpnConnections('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeClientVpnConnections', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeClientVpnEndpoints - errors', () => {
      it('should have a getDescribeClientVpnEndpoints function', (done) => {
        assert.equal(true, typeof a.getDescribeClientVpnEndpoints === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeClientVpnEndpoints('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeClientVpnEndpoints', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeClientVpnEndpoints('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeClientVpnEndpoints', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeClientVpnEndpoints - errors', () => {
      it('should have a postDescribeClientVpnEndpoints function', (done) => {
        assert.equal(true, typeof a.postDescribeClientVpnEndpoints === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeClientVpnEndpoints(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeClientVpnEndpoints', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeClientVpnEndpoints('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeClientVpnEndpoints', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeClientVpnRoutes - errors', () => {
      it('should have a getDescribeClientVpnRoutes function', (done) => {
        assert.equal(true, typeof a.getDescribeClientVpnRoutes === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing clientVpnEndpointId', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeClientVpnRoutes(null, null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'clientVpnEndpointId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeClientVpnRoutes', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeClientVpnRoutes('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeClientVpnRoutes', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeClientVpnRoutes('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeClientVpnRoutes', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeClientVpnRoutes - errors', () => {
      it('should have a postDescribeClientVpnRoutes function', (done) => {
        assert.equal(true, typeof a.postDescribeClientVpnRoutes === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeClientVpnRoutes(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeClientVpnRoutes', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeClientVpnRoutes('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeClientVpnRoutes', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeClientVpnRoutes('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeClientVpnRoutes', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeClientVpnTargetNetworks - errors', () => {
      it('should have a getDescribeClientVpnTargetNetworks function', (done) => {
        assert.equal(true, typeof a.getDescribeClientVpnTargetNetworks === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing clientVpnEndpointId', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeClientVpnTargetNetworks(null, null, null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'clientVpnEndpointId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeClientVpnTargetNetworks', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeClientVpnTargetNetworks('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeClientVpnTargetNetworks', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeClientVpnTargetNetworks('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeClientVpnTargetNetworks', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeClientVpnTargetNetworks - errors', () => {
      it('should have a postDescribeClientVpnTargetNetworks function', (done) => {
        assert.equal(true, typeof a.postDescribeClientVpnTargetNetworks === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeClientVpnTargetNetworks(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeClientVpnTargetNetworks', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeClientVpnTargetNetworks('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeClientVpnTargetNetworks', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeClientVpnTargetNetworks('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeClientVpnTargetNetworks', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeConversionTasks - errors', () => {
      it('should have a getDescribeConversionTasks function', (done) => {
        assert.equal(true, typeof a.getDescribeConversionTasks === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeConversionTasks('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeConversionTasks', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeConversionTasks('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeConversionTasks', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeConversionTasks - errors', () => {
      it('should have a postDescribeConversionTasks function', (done) => {
        assert.equal(true, typeof a.postDescribeConversionTasks === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeConversionTasks(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeConversionTasks', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeConversionTasks('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeConversionTasks', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeCustomerGateways - errors', () => {
      it('should have a getDescribeCustomerGateways function', (done) => {
        assert.equal(true, typeof a.getDescribeCustomerGateways === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeCustomerGateways('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeCustomerGateways', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeCustomerGateways('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeCustomerGateways', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeCustomerGateways - errors', () => {
      it('should have a postDescribeCustomerGateways function', (done) => {
        assert.equal(true, typeof a.postDescribeCustomerGateways === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeCustomerGateways(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeCustomerGateways', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeCustomerGateways('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeCustomerGateways', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeDhcpOptions - errors', () => {
      it('should have a getDescribeDhcpOptions function', (done) => {
        assert.equal(true, typeof a.getDescribeDhcpOptions === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeDhcpOptions('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeDhcpOptions', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeDhcpOptions('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeDhcpOptions', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeDhcpOptions - errors', () => {
      it('should have a postDescribeDhcpOptions function', (done) => {
        assert.equal(true, typeof a.postDescribeDhcpOptions === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeDhcpOptions(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeDhcpOptions', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeDhcpOptions('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeDhcpOptions', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeEgressOnlyInternetGateways - errors', () => {
      it('should have a getDescribeEgressOnlyInternetGateways function', (done) => {
        assert.equal(true, typeof a.getDescribeEgressOnlyInternetGateways === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeEgressOnlyInternetGateways('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeEgressOnlyInternetGateways', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeEgressOnlyInternetGateways('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeEgressOnlyInternetGateways', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeEgressOnlyInternetGateways - errors', () => {
      it('should have a postDescribeEgressOnlyInternetGateways function', (done) => {
        assert.equal(true, typeof a.postDescribeEgressOnlyInternetGateways === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeEgressOnlyInternetGateways(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeEgressOnlyInternetGateways', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeEgressOnlyInternetGateways('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeEgressOnlyInternetGateways', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeElasticGpus - errors', () => {
      it('should have a getDescribeElasticGpus function', (done) => {
        assert.equal(true, typeof a.getDescribeElasticGpus === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeElasticGpus('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeElasticGpus', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeElasticGpus('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeElasticGpus', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeElasticGpus - errors', () => {
      it('should have a postDescribeElasticGpus function', (done) => {
        assert.equal(true, typeof a.postDescribeElasticGpus === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeElasticGpus(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeElasticGpus', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeElasticGpus('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeElasticGpus', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeExportTasks - errors', () => {
      it('should have a getDescribeExportTasks function', (done) => {
        assert.equal(true, typeof a.getDescribeExportTasks === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeExportTasks('fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeExportTasks', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeExportTasks('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeExportTasks', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeExportTasks - errors', () => {
      it('should have a postDescribeExportTasks function', (done) => {
        assert.equal(true, typeof a.postDescribeExportTasks === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeExportTasks(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeExportTasks', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeExportTasks('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeExportTasks', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeFleetHistory - errors', () => {
      it('should have a getDescribeFleetHistory function', (done) => {
        assert.equal(true, typeof a.getDescribeFleetHistory === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing fleetId', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeFleetHistory('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, null, null, (data, error) => {
            const displayE = 'fleetId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeFleetHistory', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing startTime', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeFleetHistory('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'startTime is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeFleetHistory', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeFleetHistory('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeFleetHistory', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeFleetHistory('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeFleetHistory', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeFleetHistory - errors', () => {
      it('should have a postDescribeFleetHistory function', (done) => {
        assert.equal(true, typeof a.postDescribeFleetHistory === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeFleetHistory(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeFleetHistory', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeFleetHistory('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeFleetHistory', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeFleetHistory('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeFleetHistory', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeFleetInstances - errors', () => {
      it('should have a getDescribeFleetInstances function', (done) => {
        assert.equal(true, typeof a.getDescribeFleetInstances === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing fleetId', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeFleetInstances('fakeparam', 'fakeparam', 'fakeparam', null, null, null, null, null, (data, error) => {
            const displayE = 'fleetId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeFleetInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeFleetInstances('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeFleetInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeFleetInstances('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeFleetInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeFleetInstances - errors', () => {
      it('should have a postDescribeFleetInstances function', (done) => {
        assert.equal(true, typeof a.postDescribeFleetInstances === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeFleetInstances(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeFleetInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeFleetInstances('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeFleetInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeFleetInstances('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeFleetInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeFleets - errors', () => {
      it('should have a getDescribeFleets function', (done) => {
        assert.equal(true, typeof a.getDescribeFleets === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeFleets('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeFleets', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeFleets('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeFleets', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeFleets - errors', () => {
      it('should have a postDescribeFleets function', (done) => {
        assert.equal(true, typeof a.postDescribeFleets === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeFleets(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeFleets', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeFleets('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeFleets', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeFlowLogs - errors', () => {
      it('should have a getDescribeFlowLogs function', (done) => {
        assert.equal(true, typeof a.getDescribeFlowLogs === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeFlowLogs('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeFlowLogs', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeFlowLogs('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeFlowLogs', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeFlowLogs - errors', () => {
      it('should have a postDescribeFlowLogs function', (done) => {
        assert.equal(true, typeof a.postDescribeFlowLogs === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeFlowLogs(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeFlowLogs', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeFlowLogs('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeFlowLogs', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeFpgaImageAttribute - errors', () => {
      it('should have a getDescribeFpgaImageAttribute function', (done) => {
        assert.equal(true, typeof a.getDescribeFpgaImageAttribute === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing fpgaImageId', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeFpgaImageAttribute('fakeparam', null, null, null, null, null, (data, error) => {
            const displayE = 'fpgaImageId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeFpgaImageAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing attribute', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeFpgaImageAttribute('fakeparam', 'fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'attribute is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeFpgaImageAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeFpgaImageAttribute('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeFpgaImageAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeFpgaImageAttribute('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeFpgaImageAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeFpgaImageAttribute - errors', () => {
      it('should have a postDescribeFpgaImageAttribute function', (done) => {
        assert.equal(true, typeof a.postDescribeFpgaImageAttribute === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeFpgaImageAttribute(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeFpgaImageAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeFpgaImageAttribute('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeFpgaImageAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeFpgaImageAttribute('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeFpgaImageAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeFpgaImages - errors', () => {
      it('should have a getDescribeFpgaImages function', (done) => {
        assert.equal(true, typeof a.getDescribeFpgaImages === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeFpgaImages('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeFpgaImages', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeFpgaImages('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeFpgaImages', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeFpgaImages - errors', () => {
      it('should have a postDescribeFpgaImages function', (done) => {
        assert.equal(true, typeof a.postDescribeFpgaImages === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeFpgaImages(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeFpgaImages', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeFpgaImages('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeFpgaImages', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeHostReservationOfferings - errors', () => {
      it('should have a getDescribeHostReservationOfferings function', (done) => {
        assert.equal(true, typeof a.getDescribeHostReservationOfferings === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeHostReservationOfferings('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeHostReservationOfferings', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeHostReservationOfferings('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeHostReservationOfferings', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeHostReservationOfferings - errors', () => {
      it('should have a postDescribeHostReservationOfferings function', (done) => {
        assert.equal(true, typeof a.postDescribeHostReservationOfferings === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeHostReservationOfferings(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeHostReservationOfferings', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeHostReservationOfferings('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeHostReservationOfferings', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeHostReservations - errors', () => {
      it('should have a getDescribeHostReservations function', (done) => {
        assert.equal(true, typeof a.getDescribeHostReservations === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeHostReservations('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeHostReservations', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeHostReservations('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeHostReservations', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeHostReservations - errors', () => {
      it('should have a postDescribeHostReservations function', (done) => {
        assert.equal(true, typeof a.postDescribeHostReservations === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeHostReservations(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeHostReservations', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeHostReservations('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeHostReservations', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeHosts - errors', () => {
      it('should have a getDescribeHosts function', (done) => {
        assert.equal(true, typeof a.getDescribeHosts === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeHosts('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeHosts', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeHosts('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeHosts', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeHosts - errors', () => {
      it('should have a postDescribeHosts function', (done) => {
        assert.equal(true, typeof a.postDescribeHosts === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeHosts(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeHosts', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeHosts('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeHosts', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeIamInstanceProfileAssociations - errors', () => {
      it('should have a getDescribeIamInstanceProfileAssociations function', (done) => {
        assert.equal(true, typeof a.getDescribeIamInstanceProfileAssociations === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeIamInstanceProfileAssociations('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeIamInstanceProfileAssociations', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeIamInstanceProfileAssociations('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeIamInstanceProfileAssociations', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeIamInstanceProfileAssociations - errors', () => {
      it('should have a postDescribeIamInstanceProfileAssociations function', (done) => {
        assert.equal(true, typeof a.postDescribeIamInstanceProfileAssociations === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeIamInstanceProfileAssociations(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeIamInstanceProfileAssociations', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeIamInstanceProfileAssociations('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeIamInstanceProfileAssociations', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeIdFormat - errors', () => {
      it('should have a getDescribeIdFormat function', (done) => {
        assert.equal(true, typeof a.getDescribeIdFormat === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeIdFormat('fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeIdFormat', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeIdFormat('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeIdFormat', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeIdFormat - errors', () => {
      it('should have a postDescribeIdFormat function', (done) => {
        assert.equal(true, typeof a.postDescribeIdFormat === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeIdFormat(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeIdFormat', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeIdFormat('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeIdFormat', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeIdentityIdFormat - errors', () => {
      it('should have a getDescribeIdentityIdFormat function', (done) => {
        assert.equal(true, typeof a.getDescribeIdentityIdFormat === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing principalArn', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeIdentityIdFormat(null, null, null, null, null, (data, error) => {
            const displayE = 'principalArn is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeIdentityIdFormat', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeIdentityIdFormat('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeIdentityIdFormat', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeIdentityIdFormat('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeIdentityIdFormat', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeIdentityIdFormat - errors', () => {
      it('should have a postDescribeIdentityIdFormat function', (done) => {
        assert.equal(true, typeof a.postDescribeIdentityIdFormat === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeIdentityIdFormat(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeIdentityIdFormat', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeIdentityIdFormat('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeIdentityIdFormat', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeIdentityIdFormat('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeIdentityIdFormat', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeImageAttribute - errors', () => {
      it('should have a getDescribeImageAttribute function', (done) => {
        assert.equal(true, typeof a.getDescribeImageAttribute === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing attribute', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeImageAttribute(null, null, null, null, null, null, (data, error) => {
            const displayE = 'attribute is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeImageAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing imageId', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeImageAttribute('fakeparam', null, null, null, null, null, (data, error) => {
            const displayE = 'imageId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeImageAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeImageAttribute('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeImageAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeImageAttribute('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeImageAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeImageAttribute - errors', () => {
      it('should have a postDescribeImageAttribute function', (done) => {
        assert.equal(true, typeof a.postDescribeImageAttribute === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeImageAttribute(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeImageAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeImageAttribute('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeImageAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeImageAttribute('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeImageAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeImages - errors', () => {
      it('should have a getDescribeImages function', (done) => {
        assert.equal(true, typeof a.getDescribeImages === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeImages('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeImages', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeImages('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeImages', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeImages - errors', () => {
      it('should have a postDescribeImages function', (done) => {
        assert.equal(true, typeof a.postDescribeImages === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeImages(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeImages', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeImages('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeImages', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeImportImageTasks - errors', () => {
      it('should have a getDescribeImportImageTasks function', (done) => {
        assert.equal(true, typeof a.getDescribeImportImageTasks === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeImportImageTasks('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeImportImageTasks', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeImportImageTasks('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeImportImageTasks', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeImportImageTasks - errors', () => {
      it('should have a postDescribeImportImageTasks function', (done) => {
        assert.equal(true, typeof a.postDescribeImportImageTasks === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeImportImageTasks(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeImportImageTasks', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeImportImageTasks('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeImportImageTasks', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeImportSnapshotTasks - errors', () => {
      it('should have a getDescribeImportSnapshotTasks function', (done) => {
        assert.equal(true, typeof a.getDescribeImportSnapshotTasks === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeImportSnapshotTasks('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeImportSnapshotTasks', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeImportSnapshotTasks('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeImportSnapshotTasks', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeImportSnapshotTasks - errors', () => {
      it('should have a postDescribeImportSnapshotTasks function', (done) => {
        assert.equal(true, typeof a.postDescribeImportSnapshotTasks === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeImportSnapshotTasks(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeImportSnapshotTasks', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeImportSnapshotTasks('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeImportSnapshotTasks', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeInstanceAttribute - errors', () => {
      it('should have a getDescribeInstanceAttribute function', (done) => {
        assert.equal(true, typeof a.getDescribeInstanceAttribute === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing attribute', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeInstanceAttribute(null, null, null, null, null, null, (data, error) => {
            const displayE = 'attribute is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeInstanceAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing instanceId', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeInstanceAttribute('fakeparam', 'fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'instanceId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeInstanceAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeInstanceAttribute('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeInstanceAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeInstanceAttribute('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeInstanceAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeInstanceAttribute - errors', () => {
      it('should have a postDescribeInstanceAttribute function', (done) => {
        assert.equal(true, typeof a.postDescribeInstanceAttribute === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeInstanceAttribute(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeInstanceAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeInstanceAttribute('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeInstanceAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeInstanceAttribute('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeInstanceAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeInstanceCreditSpecifications - errors', () => {
      it('should have a getDescribeInstanceCreditSpecifications function', (done) => {
        assert.equal(true, typeof a.getDescribeInstanceCreditSpecifications === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeInstanceCreditSpecifications('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeInstanceCreditSpecifications', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeInstanceCreditSpecifications('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeInstanceCreditSpecifications', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeInstanceCreditSpecifications - errors', () => {
      it('should have a postDescribeInstanceCreditSpecifications function', (done) => {
        assert.equal(true, typeof a.postDescribeInstanceCreditSpecifications === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeInstanceCreditSpecifications(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeInstanceCreditSpecifications', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeInstanceCreditSpecifications('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeInstanceCreditSpecifications', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeInstanceStatus - errors', () => {
      it('should have a getDescribeInstanceStatus function', (done) => {
        assert.equal(true, typeof a.getDescribeInstanceStatus === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeInstanceStatus('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeInstanceStatus', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeInstanceStatus('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeInstanceStatus', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeInstanceStatus - errors', () => {
      it('should have a postDescribeInstanceStatus function', (done) => {
        assert.equal(true, typeof a.postDescribeInstanceStatus === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeInstanceStatus(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeInstanceStatus', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeInstanceStatus('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeInstanceStatus', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeInstances - errors', () => {
      it('should have a getDescribeInstances function', (done) => {
        assert.equal(true, typeof a.getDescribeInstances === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeInstances('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeInstances('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeInstances - errors', () => {
      it('should have a postDescribeInstances function', (done) => {
        assert.equal(true, typeof a.postDescribeInstances === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeInstances(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeInstances('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeInternetGateways - errors', () => {
      it('should have a getDescribeInternetGateways function', (done) => {
        assert.equal(true, typeof a.getDescribeInternetGateways === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeInternetGateways('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeInternetGateways', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeInternetGateways('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeInternetGateways', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeInternetGateways - errors', () => {
      it('should have a postDescribeInternetGateways function', (done) => {
        assert.equal(true, typeof a.postDescribeInternetGateways === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeInternetGateways(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeInternetGateways', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeInternetGateways('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeInternetGateways', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeKeyPairs - errors', () => {
      it('should have a getDescribeKeyPairs function', (done) => {
        assert.equal(true, typeof a.getDescribeKeyPairs === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeKeyPairs('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeKeyPairs', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeKeyPairs('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeKeyPairs', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeKeyPairs - errors', () => {
      it('should have a postDescribeKeyPairs function', (done) => {
        assert.equal(true, typeof a.postDescribeKeyPairs === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeKeyPairs(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeKeyPairs', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeKeyPairs('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeKeyPairs', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeLaunchTemplateVersions - errors', () => {
      it('should have a getDescribeLaunchTemplateVersions function', (done) => {
        assert.equal(true, typeof a.getDescribeLaunchTemplateVersions === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeLaunchTemplateVersions('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeLaunchTemplateVersions', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeLaunchTemplateVersions('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeLaunchTemplateVersions', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeLaunchTemplateVersions - errors', () => {
      it('should have a postDescribeLaunchTemplateVersions function', (done) => {
        assert.equal(true, typeof a.postDescribeLaunchTemplateVersions === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeLaunchTemplateVersions(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeLaunchTemplateVersions', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeLaunchTemplateVersions('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeLaunchTemplateVersions', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeLaunchTemplates - errors', () => {
      it('should have a getDescribeLaunchTemplates function', (done) => {
        assert.equal(true, typeof a.getDescribeLaunchTemplates === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeLaunchTemplates('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeLaunchTemplates', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeLaunchTemplates('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeLaunchTemplates', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeLaunchTemplates - errors', () => {
      it('should have a postDescribeLaunchTemplates function', (done) => {
        assert.equal(true, typeof a.postDescribeLaunchTemplates === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeLaunchTemplates(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeLaunchTemplates', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeLaunchTemplates('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeLaunchTemplates', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeMovingAddresses - errors', () => {
      it('should have a getDescribeMovingAddresses function', (done) => {
        assert.equal(true, typeof a.getDescribeMovingAddresses === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeMovingAddresses('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeMovingAddresses', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeMovingAddresses('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeMovingAddresses', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeMovingAddresses - errors', () => {
      it('should have a postDescribeMovingAddresses function', (done) => {
        assert.equal(true, typeof a.postDescribeMovingAddresses === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeMovingAddresses(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeMovingAddresses', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeMovingAddresses('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeMovingAddresses', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeNatGateways - errors', () => {
      it('should have a getDescribeNatGateways function', (done) => {
        assert.equal(true, typeof a.getDescribeNatGateways === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeNatGateways('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeNatGateways', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeNatGateways('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeNatGateways', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeNatGateways - errors', () => {
      it('should have a postDescribeNatGateways function', (done) => {
        assert.equal(true, typeof a.postDescribeNatGateways === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeNatGateways(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeNatGateways', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeNatGateways('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeNatGateways', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeNetworkAcls - errors', () => {
      it('should have a getDescribeNetworkAcls function', (done) => {
        assert.equal(true, typeof a.getDescribeNetworkAcls === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeNetworkAcls('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeNetworkAcls', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeNetworkAcls('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeNetworkAcls', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeNetworkAcls - errors', () => {
      it('should have a postDescribeNetworkAcls function', (done) => {
        assert.equal(true, typeof a.postDescribeNetworkAcls === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeNetworkAcls(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeNetworkAcls', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeNetworkAcls('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeNetworkAcls', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeNetworkInterfaceAttribute - errors', () => {
      it('should have a getDescribeNetworkInterfaceAttribute function', (done) => {
        assert.equal(true, typeof a.getDescribeNetworkInterfaceAttribute === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing networkInterfaceId', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeNetworkInterfaceAttribute('fakeparam', 'fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'networkInterfaceId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeNetworkInterfaceAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeNetworkInterfaceAttribute('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeNetworkInterfaceAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeNetworkInterfaceAttribute('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeNetworkInterfaceAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeNetworkInterfaceAttribute - errors', () => {
      it('should have a postDescribeNetworkInterfaceAttribute function', (done) => {
        assert.equal(true, typeof a.postDescribeNetworkInterfaceAttribute === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeNetworkInterfaceAttribute(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeNetworkInterfaceAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeNetworkInterfaceAttribute('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeNetworkInterfaceAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeNetworkInterfaceAttribute('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeNetworkInterfaceAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeNetworkInterfacePermissions - errors', () => {
      it('should have a getDescribeNetworkInterfacePermissions function', (done) => {
        assert.equal(true, typeof a.getDescribeNetworkInterfacePermissions === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeNetworkInterfacePermissions('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeNetworkInterfacePermissions', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeNetworkInterfacePermissions('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeNetworkInterfacePermissions', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeNetworkInterfacePermissions - errors', () => {
      it('should have a postDescribeNetworkInterfacePermissions function', (done) => {
        assert.equal(true, typeof a.postDescribeNetworkInterfacePermissions === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeNetworkInterfacePermissions(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeNetworkInterfacePermissions', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeNetworkInterfacePermissions('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeNetworkInterfacePermissions', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeNetworkInterfaces - errors', () => {
      it('should have a getDescribeNetworkInterfaces function', (done) => {
        assert.equal(true, typeof a.getDescribeNetworkInterfaces === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeNetworkInterfaces('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeNetworkInterfaces', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeNetworkInterfaces('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeNetworkInterfaces', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeNetworkInterfaces - errors', () => {
      it('should have a postDescribeNetworkInterfaces function', (done) => {
        assert.equal(true, typeof a.postDescribeNetworkInterfaces === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeNetworkInterfaces(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeNetworkInterfaces', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeNetworkInterfaces('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeNetworkInterfaces', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribePlacementGroups - errors', () => {
      it('should have a getDescribePlacementGroups function', (done) => {
        assert.equal(true, typeof a.getDescribePlacementGroups === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribePlacementGroups('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribePlacementGroups', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribePlacementGroups('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribePlacementGroups', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribePlacementGroups - errors', () => {
      it('should have a postDescribePlacementGroups function', (done) => {
        assert.equal(true, typeof a.postDescribePlacementGroups === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribePlacementGroups(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribePlacementGroups', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribePlacementGroups('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribePlacementGroups', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribePrefixLists - errors', () => {
      it('should have a getDescribePrefixLists function', (done) => {
        assert.equal(true, typeof a.getDescribePrefixLists === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribePrefixLists('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribePrefixLists', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribePrefixLists('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribePrefixLists', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribePrefixLists - errors', () => {
      it('should have a postDescribePrefixLists function', (done) => {
        assert.equal(true, typeof a.postDescribePrefixLists === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribePrefixLists(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribePrefixLists', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribePrefixLists('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribePrefixLists', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribePrincipalIdFormat - errors', () => {
      it('should have a getDescribePrincipalIdFormat function', (done) => {
        assert.equal(true, typeof a.getDescribePrincipalIdFormat === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribePrincipalIdFormat('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribePrincipalIdFormat', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribePrincipalIdFormat('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribePrincipalIdFormat', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribePrincipalIdFormat - errors', () => {
      it('should have a postDescribePrincipalIdFormat function', (done) => {
        assert.equal(true, typeof a.postDescribePrincipalIdFormat === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribePrincipalIdFormat(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribePrincipalIdFormat', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribePrincipalIdFormat('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribePrincipalIdFormat', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribePublicIpv4Pools - errors', () => {
      it('should have a getDescribePublicIpv4Pools function', (done) => {
        assert.equal(true, typeof a.getDescribePublicIpv4Pools === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribePublicIpv4Pools('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribePublicIpv4Pools', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribePublicIpv4Pools('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribePublicIpv4Pools', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribePublicIpv4Pools - errors', () => {
      it('should have a postDescribePublicIpv4Pools function', (done) => {
        assert.equal(true, typeof a.postDescribePublicIpv4Pools === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribePublicIpv4Pools(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribePublicIpv4Pools', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribePublicIpv4Pools('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribePublicIpv4Pools', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeRegions - errors', () => {
      it('should have a getDescribeRegions function', (done) => {
        assert.equal(true, typeof a.getDescribeRegions === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeRegions('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeRegions', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeRegions('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeRegions', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeRegions - errors', () => {
      it('should have a postDescribeRegions function', (done) => {
        assert.equal(true, typeof a.postDescribeRegions === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeRegions(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeRegions', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeRegions('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeRegions', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeReservedInstances - errors', () => {
      it('should have a getDescribeReservedInstances function', (done) => {
        assert.equal(true, typeof a.getDescribeReservedInstances === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeReservedInstances('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeReservedInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeReservedInstances('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeReservedInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeReservedInstances - errors', () => {
      it('should have a postDescribeReservedInstances function', (done) => {
        assert.equal(true, typeof a.postDescribeReservedInstances === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeReservedInstances(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeReservedInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeReservedInstances('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeReservedInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeReservedInstancesListings - errors', () => {
      it('should have a getDescribeReservedInstancesListings function', (done) => {
        assert.equal(true, typeof a.getDescribeReservedInstancesListings === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeReservedInstancesListings('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeReservedInstancesListings', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeReservedInstancesListings('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeReservedInstancesListings', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeReservedInstancesListings - errors', () => {
      it('should have a postDescribeReservedInstancesListings function', (done) => {
        assert.equal(true, typeof a.postDescribeReservedInstancesListings === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeReservedInstancesListings(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeReservedInstancesListings', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeReservedInstancesListings('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeReservedInstancesListings', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeReservedInstancesModifications - errors', () => {
      it('should have a getDescribeReservedInstancesModifications function', (done) => {
        assert.equal(true, typeof a.getDescribeReservedInstancesModifications === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeReservedInstancesModifications('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeReservedInstancesModifications', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeReservedInstancesModifications('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeReservedInstancesModifications', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeReservedInstancesModifications - errors', () => {
      it('should have a postDescribeReservedInstancesModifications function', (done) => {
        assert.equal(true, typeof a.postDescribeReservedInstancesModifications === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeReservedInstancesModifications(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeReservedInstancesModifications', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeReservedInstancesModifications('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeReservedInstancesModifications', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeReservedInstancesOfferings - errors', () => {
      it('should have a getDescribeReservedInstancesOfferings function', (done) => {
        assert.equal(true, typeof a.getDescribeReservedInstancesOfferings === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeReservedInstancesOfferings('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeReservedInstancesOfferings', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeReservedInstancesOfferings('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeReservedInstancesOfferings', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeReservedInstancesOfferings - errors', () => {
      it('should have a postDescribeReservedInstancesOfferings function', (done) => {
        assert.equal(true, typeof a.postDescribeReservedInstancesOfferings === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeReservedInstancesOfferings(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeReservedInstancesOfferings', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeReservedInstancesOfferings('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeReservedInstancesOfferings', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeRouteTables - errors', () => {
      it('should have a getDescribeRouteTables function', (done) => {
        assert.equal(true, typeof a.getDescribeRouteTables === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeRouteTables('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeRouteTables', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeRouteTables('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeRouteTables', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeRouteTables - errors', () => {
      it('should have a postDescribeRouteTables function', (done) => {
        assert.equal(true, typeof a.postDescribeRouteTables === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeRouteTables(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeRouteTables', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeRouteTables('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeRouteTables', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeScheduledInstanceAvailability - errors', () => {
      it('should have a getDescribeScheduledInstanceAvailability function', (done) => {
        assert.equal(true, typeof a.getDescribeScheduledInstanceAvailability === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeScheduledInstanceAvailability('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeScheduledInstanceAvailability', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeScheduledInstanceAvailability('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeScheduledInstanceAvailability', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeScheduledInstanceAvailability - errors', () => {
      it('should have a postDescribeScheduledInstanceAvailability function', (done) => {
        assert.equal(true, typeof a.postDescribeScheduledInstanceAvailability === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeScheduledInstanceAvailability(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeScheduledInstanceAvailability', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeScheduledInstanceAvailability('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeScheduledInstanceAvailability', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeScheduledInstances - errors', () => {
      it('should have a getDescribeScheduledInstances function', (done) => {
        assert.equal(true, typeof a.getDescribeScheduledInstances === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeScheduledInstances('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeScheduledInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeScheduledInstances('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeScheduledInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeScheduledInstances - errors', () => {
      it('should have a postDescribeScheduledInstances function', (done) => {
        assert.equal(true, typeof a.postDescribeScheduledInstances === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeScheduledInstances(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeScheduledInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeScheduledInstances('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeScheduledInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeSecurityGroupReferences - errors', () => {
      it('should have a getDescribeSecurityGroupReferences function', (done) => {
        assert.equal(true, typeof a.getDescribeSecurityGroupReferences === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing groupId', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeSecurityGroupReferences('fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'groupId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeSecurityGroupReferences', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeSecurityGroupReferences('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeSecurityGroupReferences', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeSecurityGroupReferences('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeSecurityGroupReferences', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeSecurityGroupReferences - errors', () => {
      it('should have a postDescribeSecurityGroupReferences function', (done) => {
        assert.equal(true, typeof a.postDescribeSecurityGroupReferences === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeSecurityGroupReferences(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeSecurityGroupReferences', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeSecurityGroupReferences('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeSecurityGroupReferences', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeSecurityGroupReferences('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeSecurityGroupReferences', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeSecurityGroups - errors', () => {
      it('should have a getDescribeSecurityGroups function', (done) => {
        assert.equal(true, typeof a.getDescribeSecurityGroups === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeSecurityGroups('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeSecurityGroups', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeSecurityGroups('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeSecurityGroups', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeSecurityGroups - errors', () => {
      it('should have a postDescribeSecurityGroups function', (done) => {
        assert.equal(true, typeof a.postDescribeSecurityGroups === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeSecurityGroups(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeSecurityGroups', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeSecurityGroups('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeSecurityGroups', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeSnapshotAttribute - errors', () => {
      it('should have a getDescribeSnapshotAttribute function', (done) => {
        assert.equal(true, typeof a.getDescribeSnapshotAttribute === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing attribute', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeSnapshotAttribute(null, null, null, null, null, null, (data, error) => {
            const displayE = 'attribute is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeSnapshotAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing snapshotId', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeSnapshotAttribute('fakeparam', null, null, null, null, null, (data, error) => {
            const displayE = 'snapshotId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeSnapshotAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeSnapshotAttribute('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeSnapshotAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeSnapshotAttribute('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeSnapshotAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeSnapshotAttribute - errors', () => {
      it('should have a postDescribeSnapshotAttribute function', (done) => {
        assert.equal(true, typeof a.postDescribeSnapshotAttribute === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeSnapshotAttribute(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeSnapshotAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeSnapshotAttribute('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeSnapshotAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeSnapshotAttribute('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeSnapshotAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeSnapshots - errors', () => {
      it('should have a getDescribeSnapshots function', (done) => {
        assert.equal(true, typeof a.getDescribeSnapshots === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeSnapshots('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeSnapshots', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeSnapshots('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeSnapshots', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeSnapshots - errors', () => {
      it('should have a postDescribeSnapshots function', (done) => {
        assert.equal(true, typeof a.postDescribeSnapshots === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeSnapshots(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeSnapshots', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeSnapshots('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeSnapshots', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeSpotDatafeedSubscription - errors', () => {
      it('should have a getDescribeSpotDatafeedSubscription function', (done) => {
        assert.equal(true, typeof a.getDescribeSpotDatafeedSubscription === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeSpotDatafeedSubscription('fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeSpotDatafeedSubscription', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeSpotDatafeedSubscription('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeSpotDatafeedSubscription', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeSpotDatafeedSubscription - errors', () => {
      it('should have a postDescribeSpotDatafeedSubscription function', (done) => {
        assert.equal(true, typeof a.postDescribeSpotDatafeedSubscription === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeSpotDatafeedSubscription(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeSpotDatafeedSubscription', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeSpotDatafeedSubscription('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeSpotDatafeedSubscription', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeSpotFleetInstances - errors', () => {
      it('should have a getDescribeSpotFleetInstances function', (done) => {
        assert.equal(true, typeof a.getDescribeSpotFleetInstances === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing spotFleetRequestId', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeSpotFleetInstances('fakeparam', 'fakeparam', 'fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'spotFleetRequestId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeSpotFleetInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeSpotFleetInstances('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeSpotFleetInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeSpotFleetInstances('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeSpotFleetInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeSpotFleetInstances - errors', () => {
      it('should have a postDescribeSpotFleetInstances function', (done) => {
        assert.equal(true, typeof a.postDescribeSpotFleetInstances === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeSpotFleetInstances(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeSpotFleetInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeSpotFleetInstances('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeSpotFleetInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeSpotFleetInstances('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeSpotFleetInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeSpotFleetRequestHistory - errors', () => {
      it('should have a getDescribeSpotFleetRequestHistory function', (done) => {
        assert.equal(true, typeof a.getDescribeSpotFleetRequestHistory === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing spotFleetRequestId', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeSpotFleetRequestHistory('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, null, null, (data, error) => {
            const displayE = 'spotFleetRequestId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeSpotFleetRequestHistory', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing startTime', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeSpotFleetRequestHistory('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'startTime is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeSpotFleetRequestHistory', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeSpotFleetRequestHistory('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeSpotFleetRequestHistory', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeSpotFleetRequestHistory('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeSpotFleetRequestHistory', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeSpotFleetRequestHistory - errors', () => {
      it('should have a postDescribeSpotFleetRequestHistory function', (done) => {
        assert.equal(true, typeof a.postDescribeSpotFleetRequestHistory === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeSpotFleetRequestHistory(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeSpotFleetRequestHistory', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeSpotFleetRequestHistory('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeSpotFleetRequestHistory', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeSpotFleetRequestHistory('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeSpotFleetRequestHistory', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeSpotFleetRequests - errors', () => {
      it('should have a getDescribeSpotFleetRequests function', (done) => {
        assert.equal(true, typeof a.getDescribeSpotFleetRequests === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeSpotFleetRequests('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeSpotFleetRequests', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeSpotFleetRequests('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeSpotFleetRequests', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeSpotFleetRequests - errors', () => {
      it('should have a postDescribeSpotFleetRequests function', (done) => {
        assert.equal(true, typeof a.postDescribeSpotFleetRequests === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeSpotFleetRequests(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeSpotFleetRequests', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeSpotFleetRequests('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeSpotFleetRequests', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeSpotInstanceRequests - errors', () => {
      it('should have a getDescribeSpotInstanceRequests function', (done) => {
        assert.equal(true, typeof a.getDescribeSpotInstanceRequests === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeSpotInstanceRequests('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeSpotInstanceRequests', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeSpotInstanceRequests('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeSpotInstanceRequests', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeSpotInstanceRequests - errors', () => {
      it('should have a postDescribeSpotInstanceRequests function', (done) => {
        assert.equal(true, typeof a.postDescribeSpotInstanceRequests === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeSpotInstanceRequests(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeSpotInstanceRequests', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeSpotInstanceRequests('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeSpotInstanceRequests', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeSpotPriceHistory - errors', () => {
      it('should have a getDescribeSpotPriceHistory function', (done) => {
        assert.equal(true, typeof a.getDescribeSpotPriceHistory === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeSpotPriceHistory('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeSpotPriceHistory', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeSpotPriceHistory('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeSpotPriceHistory', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeSpotPriceHistory - errors', () => {
      it('should have a postDescribeSpotPriceHistory function', (done) => {
        assert.equal(true, typeof a.postDescribeSpotPriceHistory === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeSpotPriceHistory(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeSpotPriceHistory', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeSpotPriceHistory('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeSpotPriceHistory', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeStaleSecurityGroups - errors', () => {
      it('should have a getDescribeStaleSecurityGroups function', (done) => {
        assert.equal(true, typeof a.getDescribeStaleSecurityGroups === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing vpcId', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeStaleSecurityGroups('fakeparam', 'fakeparam', 'fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'vpcId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeStaleSecurityGroups', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeStaleSecurityGroups('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeStaleSecurityGroups', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeStaleSecurityGroups('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeStaleSecurityGroups', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeStaleSecurityGroups - errors', () => {
      it('should have a postDescribeStaleSecurityGroups function', (done) => {
        assert.equal(true, typeof a.postDescribeStaleSecurityGroups === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeStaleSecurityGroups(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeStaleSecurityGroups', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeStaleSecurityGroups('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeStaleSecurityGroups', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeStaleSecurityGroups('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeStaleSecurityGroups', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeSubnets - errors', () => {
      it('should have a getDescribeSubnets function', (done) => {
        assert.equal(true, typeof a.getDescribeSubnets === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeSubnets('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeSubnets', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeSubnets('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeSubnets', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeSubnets - errors', () => {
      it('should have a postDescribeSubnets function', (done) => {
        assert.equal(true, typeof a.postDescribeSubnets === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeSubnets(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeSubnets', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeSubnets('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeSubnets', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeTags - errors', () => {
      it('should have a getDescribeTags function', (done) => {
        assert.equal(true, typeof a.getDescribeTags === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeTags('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeTags', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeTags('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeTags', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeTags - errors', () => {
      it('should have a postDescribeTags function', (done) => {
        assert.equal(true, typeof a.postDescribeTags === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeTags(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeTags', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeTags('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeTags', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeTransitGatewayAttachments - errors', () => {
      it('should have a getDescribeTransitGatewayAttachments function', (done) => {
        assert.equal(true, typeof a.getDescribeTransitGatewayAttachments === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeTransitGatewayAttachments('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeTransitGatewayAttachments', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeTransitGatewayAttachments('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeTransitGatewayAttachments', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeTransitGatewayAttachments - errors', () => {
      it('should have a postDescribeTransitGatewayAttachments function', (done) => {
        assert.equal(true, typeof a.postDescribeTransitGatewayAttachments === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeTransitGatewayAttachments(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeTransitGatewayAttachments', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeTransitGatewayAttachments('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeTransitGatewayAttachments', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeTransitGatewayRouteTables - errors', () => {
      it('should have a getDescribeTransitGatewayRouteTables function', (done) => {
        assert.equal(true, typeof a.getDescribeTransitGatewayRouteTables === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeTransitGatewayRouteTables('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeTransitGatewayRouteTables', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeTransitGatewayRouteTables('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeTransitGatewayRouteTables', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeTransitGatewayRouteTables - errors', () => {
      it('should have a postDescribeTransitGatewayRouteTables function', (done) => {
        assert.equal(true, typeof a.postDescribeTransitGatewayRouteTables === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeTransitGatewayRouteTables(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeTransitGatewayRouteTables', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeTransitGatewayRouteTables('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeTransitGatewayRouteTables', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeTransitGatewayVpcAttachments - errors', () => {
      it('should have a getDescribeTransitGatewayVpcAttachments function', (done) => {
        assert.equal(true, typeof a.getDescribeTransitGatewayVpcAttachments === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeTransitGatewayVpcAttachments('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeTransitGatewayVpcAttachments', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeTransitGatewayVpcAttachments('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeTransitGatewayVpcAttachments', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeTransitGatewayVpcAttachments - errors', () => {
      it('should have a postDescribeTransitGatewayVpcAttachments function', (done) => {
        assert.equal(true, typeof a.postDescribeTransitGatewayVpcAttachments === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeTransitGatewayVpcAttachments(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeTransitGatewayVpcAttachments', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeTransitGatewayVpcAttachments('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeTransitGatewayVpcAttachments', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeTransitGateways - errors', () => {
      it('should have a getDescribeTransitGateways function', (done) => {
        assert.equal(true, typeof a.getDescribeTransitGateways === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeTransitGateways('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeTransitGateways', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeTransitGateways('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeTransitGateways', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeTransitGateways - errors', () => {
      it('should have a postDescribeTransitGateways function', (done) => {
        assert.equal(true, typeof a.postDescribeTransitGateways === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeTransitGateways(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeTransitGateways', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeTransitGateways('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeTransitGateways', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeVolumeAttribute - errors', () => {
      it('should have a getDescribeVolumeAttribute function', (done) => {
        assert.equal(true, typeof a.getDescribeVolumeAttribute === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing attribute', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeVolumeAttribute(null, null, null, null, null, null, (data, error) => {
            const displayE = 'attribute is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeVolumeAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing volumeId', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeVolumeAttribute('fakeparam', null, null, null, null, null, (data, error) => {
            const displayE = 'volumeId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeVolumeAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeVolumeAttribute('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeVolumeAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeVolumeAttribute('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeVolumeAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeVolumeAttribute - errors', () => {
      it('should have a postDescribeVolumeAttribute function', (done) => {
        assert.equal(true, typeof a.postDescribeVolumeAttribute === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeVolumeAttribute(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeVolumeAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeVolumeAttribute('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeVolumeAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeVolumeAttribute('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeVolumeAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeVolumeStatus - errors', () => {
      it('should have a getDescribeVolumeStatus function', (done) => {
        assert.equal(true, typeof a.getDescribeVolumeStatus === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeVolumeStatus('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeVolumeStatus', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeVolumeStatus('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeVolumeStatus', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeVolumeStatus - errors', () => {
      it('should have a postDescribeVolumeStatus function', (done) => {
        assert.equal(true, typeof a.postDescribeVolumeStatus === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeVolumeStatus(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeVolumeStatus', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeVolumeStatus('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeVolumeStatus', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeVolumes - errors', () => {
      it('should have a getDescribeVolumes function', (done) => {
        assert.equal(true, typeof a.getDescribeVolumes === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeVolumes('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeVolumes', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeVolumes('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeVolumes', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeVolumes - errors', () => {
      it('should have a postDescribeVolumes function', (done) => {
        assert.equal(true, typeof a.postDescribeVolumes === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeVolumes(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeVolumes', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeVolumes('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeVolumes', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeVolumesModifications - errors', () => {
      it('should have a getDescribeVolumesModifications function', (done) => {
        assert.equal(true, typeof a.getDescribeVolumesModifications === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeVolumesModifications('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeVolumesModifications', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeVolumesModifications('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeVolumesModifications', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeVolumesModifications - errors', () => {
      it('should have a postDescribeVolumesModifications function', (done) => {
        assert.equal(true, typeof a.postDescribeVolumesModifications === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeVolumesModifications(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeVolumesModifications', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeVolumesModifications('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeVolumesModifications', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeVpcAttribute - errors', () => {
      it('should have a getDescribeVpcAttribute function', (done) => {
        assert.equal(true, typeof a.getDescribeVpcAttribute === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing attribute', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeVpcAttribute(null, null, null, null, null, null, (data, error) => {
            const displayE = 'attribute is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeVpcAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing vpcId', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeVpcAttribute('fakeparam', null, null, null, null, null, (data, error) => {
            const displayE = 'vpcId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeVpcAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeVpcAttribute('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeVpcAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeVpcAttribute('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeVpcAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeVpcAttribute - errors', () => {
      it('should have a postDescribeVpcAttribute function', (done) => {
        assert.equal(true, typeof a.postDescribeVpcAttribute === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeVpcAttribute(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeVpcAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeVpcAttribute('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeVpcAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeVpcAttribute('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeVpcAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeVpcClassicLink - errors', () => {
      it('should have a getDescribeVpcClassicLink function', (done) => {
        assert.equal(true, typeof a.getDescribeVpcClassicLink === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeVpcClassicLink('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeVpcClassicLink', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeVpcClassicLink('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeVpcClassicLink', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeVpcClassicLink - errors', () => {
      it('should have a postDescribeVpcClassicLink function', (done) => {
        assert.equal(true, typeof a.postDescribeVpcClassicLink === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeVpcClassicLink(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeVpcClassicLink', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeVpcClassicLink('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeVpcClassicLink', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeVpcClassicLinkDnsSupport - errors', () => {
      it('should have a getDescribeVpcClassicLinkDnsSupport function', (done) => {
        assert.equal(true, typeof a.getDescribeVpcClassicLinkDnsSupport === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeVpcClassicLinkDnsSupport('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeVpcClassicLinkDnsSupport', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeVpcClassicLinkDnsSupport('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeVpcClassicLinkDnsSupport', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeVpcClassicLinkDnsSupport - errors', () => {
      it('should have a postDescribeVpcClassicLinkDnsSupport function', (done) => {
        assert.equal(true, typeof a.postDescribeVpcClassicLinkDnsSupport === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeVpcClassicLinkDnsSupport(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeVpcClassicLinkDnsSupport', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeVpcClassicLinkDnsSupport('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeVpcClassicLinkDnsSupport', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeVpcEndpointConnectionNotifications - errors', () => {
      it('should have a getDescribeVpcEndpointConnectionNotifications function', (done) => {
        assert.equal(true, typeof a.getDescribeVpcEndpointConnectionNotifications === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeVpcEndpointConnectionNotifications('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeVpcEndpointConnectionNotifications', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeVpcEndpointConnectionNotifications('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeVpcEndpointConnectionNotifications', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeVpcEndpointConnectionNotifications - errors', () => {
      it('should have a postDescribeVpcEndpointConnectionNotifications function', (done) => {
        assert.equal(true, typeof a.postDescribeVpcEndpointConnectionNotifications === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeVpcEndpointConnectionNotifications(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeVpcEndpointConnectionNotifications', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeVpcEndpointConnectionNotifications('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeVpcEndpointConnectionNotifications', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeVpcEndpointConnections - errors', () => {
      it('should have a getDescribeVpcEndpointConnections function', (done) => {
        assert.equal(true, typeof a.getDescribeVpcEndpointConnections === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeVpcEndpointConnections('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeVpcEndpointConnections', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeVpcEndpointConnections('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeVpcEndpointConnections', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeVpcEndpointConnections - errors', () => {
      it('should have a postDescribeVpcEndpointConnections function', (done) => {
        assert.equal(true, typeof a.postDescribeVpcEndpointConnections === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeVpcEndpointConnections(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeVpcEndpointConnections', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeVpcEndpointConnections('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeVpcEndpointConnections', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeVpcEndpointServiceConfigurations - errors', () => {
      it('should have a getDescribeVpcEndpointServiceConfigurations function', (done) => {
        assert.equal(true, typeof a.getDescribeVpcEndpointServiceConfigurations === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeVpcEndpointServiceConfigurations('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeVpcEndpointServiceConfigurations', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeVpcEndpointServiceConfigurations('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeVpcEndpointServiceConfigurations', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeVpcEndpointServiceConfigurations - errors', () => {
      it('should have a postDescribeVpcEndpointServiceConfigurations function', (done) => {
        assert.equal(true, typeof a.postDescribeVpcEndpointServiceConfigurations === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeVpcEndpointServiceConfigurations(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeVpcEndpointServiceConfigurations', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeVpcEndpointServiceConfigurations('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeVpcEndpointServiceConfigurations', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeVpcEndpointServicePermissions - errors', () => {
      it('should have a getDescribeVpcEndpointServicePermissions function', (done) => {
        assert.equal(true, typeof a.getDescribeVpcEndpointServicePermissions === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing serviceId', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeVpcEndpointServicePermissions('fakeparam', null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'serviceId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeVpcEndpointServicePermissions', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeVpcEndpointServicePermissions('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeVpcEndpointServicePermissions', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeVpcEndpointServicePermissions('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeVpcEndpointServicePermissions', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeVpcEndpointServicePermissions - errors', () => {
      it('should have a postDescribeVpcEndpointServicePermissions function', (done) => {
        assert.equal(true, typeof a.postDescribeVpcEndpointServicePermissions === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeVpcEndpointServicePermissions(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeVpcEndpointServicePermissions', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeVpcEndpointServicePermissions('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeVpcEndpointServicePermissions', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeVpcEndpointServicePermissions('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeVpcEndpointServicePermissions', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeVpcEndpointServices - errors', () => {
      it('should have a getDescribeVpcEndpointServices function', (done) => {
        assert.equal(true, typeof a.getDescribeVpcEndpointServices === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeVpcEndpointServices('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeVpcEndpointServices', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeVpcEndpointServices('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeVpcEndpointServices', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeVpcEndpointServices - errors', () => {
      it('should have a postDescribeVpcEndpointServices function', (done) => {
        assert.equal(true, typeof a.postDescribeVpcEndpointServices === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeVpcEndpointServices(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeVpcEndpointServices', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeVpcEndpointServices('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeVpcEndpointServices', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeVpcEndpoints - errors', () => {
      it('should have a getDescribeVpcEndpoints function', (done) => {
        assert.equal(true, typeof a.getDescribeVpcEndpoints === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeVpcEndpoints('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeVpcEndpoints', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeVpcEndpoints('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeVpcEndpoints', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeVpcEndpoints - errors', () => {
      it('should have a postDescribeVpcEndpoints function', (done) => {
        assert.equal(true, typeof a.postDescribeVpcEndpoints === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeVpcEndpoints(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeVpcEndpoints', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeVpcEndpoints('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeVpcEndpoints', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeVpcPeeringConnections - errors', () => {
      it('should have a getDescribeVpcPeeringConnections function', (done) => {
        assert.equal(true, typeof a.getDescribeVpcPeeringConnections === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeVpcPeeringConnections('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeVpcPeeringConnections', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeVpcPeeringConnections('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeVpcPeeringConnections', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeVpcPeeringConnections - errors', () => {
      it('should have a postDescribeVpcPeeringConnections function', (done) => {
        assert.equal(true, typeof a.postDescribeVpcPeeringConnections === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeVpcPeeringConnections(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeVpcPeeringConnections', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeVpcPeeringConnections('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeVpcPeeringConnections', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeVpcs - errors', () => {
      it('should have a getDescribeVpcs function', (done) => {
        assert.equal(true, typeof a.getDescribeVpcs === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeVpcs('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeVpcs', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeVpcs('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeVpcs', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeVpcs - errors', () => {
      it('should have a postDescribeVpcs function', (done) => {
        assert.equal(true, typeof a.postDescribeVpcs === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeVpcs(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeVpcs', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeVpcs('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeVpcs', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeVpnConnections - errors', () => {
      it('should have a getDescribeVpnConnections function', (done) => {
        assert.equal(true, typeof a.getDescribeVpnConnections === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeVpnConnections('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeVpnConnections', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeVpnConnections('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeVpnConnections', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeVpnConnections - errors', () => {
      it('should have a postDescribeVpnConnections function', (done) => {
        assert.equal(true, typeof a.postDescribeVpnConnections === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeVpnConnections(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeVpnConnections', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeVpnConnections('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeVpnConnections', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDescribeVpnGateways - errors', () => {
      it('should have a getDescribeVpnGateways function', (done) => {
        assert.equal(true, typeof a.getDescribeVpnGateways === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeVpnGateways('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeVpnGateways', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDescribeVpnGateways('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDescribeVpnGateways', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDescribeVpnGateways - errors', () => {
      it('should have a postDescribeVpnGateways function', (done) => {
        assert.equal(true, typeof a.postDescribeVpnGateways === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeVpnGateways(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeVpnGateways', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDescribeVpnGateways('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDescribeVpnGateways', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDetachClassicLinkVpc - errors', () => {
      it('should have a getDetachClassicLinkVpc function', (done) => {
        assert.equal(true, typeof a.getDetachClassicLinkVpc === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing instanceId', (done) => {
        const p = new Promise((resolve) => {
          a.getDetachClassicLinkVpc('fakeparam', null, null, null, null, null, (data, error) => {
            const displayE = 'instanceId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDetachClassicLinkVpc', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing vpcId', (done) => {
        const p = new Promise((resolve) => {
          a.getDetachClassicLinkVpc('fakeparam', 'fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'vpcId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDetachClassicLinkVpc', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDetachClassicLinkVpc('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDetachClassicLinkVpc', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDetachClassicLinkVpc('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDetachClassicLinkVpc', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDetachClassicLinkVpc - errors', () => {
      it('should have a postDetachClassicLinkVpc function', (done) => {
        assert.equal(true, typeof a.postDetachClassicLinkVpc === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDetachClassicLinkVpc(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDetachClassicLinkVpc', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDetachClassicLinkVpc('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDetachClassicLinkVpc', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postDetachClassicLinkVpc('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDetachClassicLinkVpc', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDetachInternetGateway - errors', () => {
      it('should have a getDetachInternetGateway function', (done) => {
        assert.equal(true, typeof a.getDetachInternetGateway === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing internetGatewayId', (done) => {
        const p = new Promise((resolve) => {
          a.getDetachInternetGateway('fakeparam', null, null, null, null, null, (data, error) => {
            const displayE = 'internetGatewayId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDetachInternetGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing vpcId', (done) => {
        const p = new Promise((resolve) => {
          a.getDetachInternetGateway('fakeparam', 'fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'vpcId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDetachInternetGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDetachInternetGateway('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDetachInternetGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDetachInternetGateway('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDetachInternetGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDetachInternetGateway - errors', () => {
      it('should have a postDetachInternetGateway function', (done) => {
        assert.equal(true, typeof a.postDetachInternetGateway === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDetachInternetGateway(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDetachInternetGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDetachInternetGateway('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDetachInternetGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postDetachInternetGateway('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDetachInternetGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDetachNetworkInterface - errors', () => {
      it('should have a getDetachNetworkInterface function', (done) => {
        assert.equal(true, typeof a.getDetachNetworkInterface === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing attachmentId', (done) => {
        const p = new Promise((resolve) => {
          a.getDetachNetworkInterface(null, null, null, null, null, null, (data, error) => {
            const displayE = 'attachmentId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDetachNetworkInterface', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDetachNetworkInterface('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDetachNetworkInterface', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDetachNetworkInterface('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDetachNetworkInterface', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDetachNetworkInterface - errors', () => {
      it('should have a postDetachNetworkInterface function', (done) => {
        assert.equal(true, typeof a.postDetachNetworkInterface === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDetachNetworkInterface(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDetachNetworkInterface', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDetachNetworkInterface('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDetachNetworkInterface', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postDetachNetworkInterface('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDetachNetworkInterface', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDetachVolume - errors', () => {
      it('should have a getDetachVolume function', (done) => {
        assert.equal(true, typeof a.getDetachVolume === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing volumeId', (done) => {
        const p = new Promise((resolve) => {
          a.getDetachVolume('fakeparam', 'fakeparam', 'fakeparam', null, null, null, null, null, (data, error) => {
            const displayE = 'volumeId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDetachVolume', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDetachVolume('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDetachVolume', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDetachVolume('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDetachVolume', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDetachVolume - errors', () => {
      it('should have a postDetachVolume function', (done) => {
        assert.equal(true, typeof a.postDetachVolume === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDetachVolume(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDetachVolume', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDetachVolume('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDetachVolume', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postDetachVolume('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDetachVolume', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDetachVpnGateway - errors', () => {
      it('should have a getDetachVpnGateway function', (done) => {
        assert.equal(true, typeof a.getDetachVpnGateway === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing vpcId', (done) => {
        const p = new Promise((resolve) => {
          a.getDetachVpnGateway(null, null, null, null, null, null, (data, error) => {
            const displayE = 'vpcId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDetachVpnGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing vpnGatewayId', (done) => {
        const p = new Promise((resolve) => {
          a.getDetachVpnGateway('fakeparam', null, null, null, null, null, (data, error) => {
            const displayE = 'vpnGatewayId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDetachVpnGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDetachVpnGateway('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDetachVpnGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDetachVpnGateway('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDetachVpnGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDetachVpnGateway - errors', () => {
      it('should have a postDetachVpnGateway function', (done) => {
        assert.equal(true, typeof a.postDetachVpnGateway === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDetachVpnGateway(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDetachVpnGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDetachVpnGateway('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDetachVpnGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postDetachVpnGateway('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDetachVpnGateway', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDisableTransitGatewayRouteTablePropagation - errors', () => {
      it('should have a getDisableTransitGatewayRouteTablePropagation function', (done) => {
        assert.equal(true, typeof a.getDisableTransitGatewayRouteTablePropagation === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing transitGatewayRouteTableId', (done) => {
        const p = new Promise((resolve) => {
          a.getDisableTransitGatewayRouteTablePropagation(null, null, null, null, null, null, (data, error) => {
            const displayE = 'transitGatewayRouteTableId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDisableTransitGatewayRouteTablePropagation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing transitGatewayAttachmentId', (done) => {
        const p = new Promise((resolve) => {
          a.getDisableTransitGatewayRouteTablePropagation('fakeparam', null, null, null, null, null, (data, error) => {
            const displayE = 'transitGatewayAttachmentId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDisableTransitGatewayRouteTablePropagation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDisableTransitGatewayRouteTablePropagation('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDisableTransitGatewayRouteTablePropagation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDisableTransitGatewayRouteTablePropagation('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDisableTransitGatewayRouteTablePropagation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDisableTransitGatewayRouteTablePropagation - errors', () => {
      it('should have a postDisableTransitGatewayRouteTablePropagation function', (done) => {
        assert.equal(true, typeof a.postDisableTransitGatewayRouteTablePropagation === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDisableTransitGatewayRouteTablePropagation(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDisableTransitGatewayRouteTablePropagation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDisableTransitGatewayRouteTablePropagation('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDisableTransitGatewayRouteTablePropagation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postDisableTransitGatewayRouteTablePropagation('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDisableTransitGatewayRouteTablePropagation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDisableVgwRoutePropagation - errors', () => {
      it('should have a getDisableVgwRoutePropagation function', (done) => {
        assert.equal(true, typeof a.getDisableVgwRoutePropagation === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing gatewayId', (done) => {
        const p = new Promise((resolve) => {
          a.getDisableVgwRoutePropagation(null, null, null, null, null, (data, error) => {
            const displayE = 'gatewayId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDisableVgwRoutePropagation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing routeTableId', (done) => {
        const p = new Promise((resolve) => {
          a.getDisableVgwRoutePropagation('fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'routeTableId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDisableVgwRoutePropagation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDisableVgwRoutePropagation('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDisableVgwRoutePropagation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDisableVgwRoutePropagation('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDisableVgwRoutePropagation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDisableVgwRoutePropagation - errors', () => {
      it('should have a postDisableVgwRoutePropagation function', (done) => {
        assert.equal(true, typeof a.postDisableVgwRoutePropagation === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDisableVgwRoutePropagation(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDisableVgwRoutePropagation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDisableVgwRoutePropagation('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDisableVgwRoutePropagation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postDisableVgwRoutePropagation('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDisableVgwRoutePropagation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDisableVpcClassicLink - errors', () => {
      it('should have a getDisableVpcClassicLink function', (done) => {
        assert.equal(true, typeof a.getDisableVpcClassicLink === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing vpcId', (done) => {
        const p = new Promise((resolve) => {
          a.getDisableVpcClassicLink('fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'vpcId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDisableVpcClassicLink', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDisableVpcClassicLink('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDisableVpcClassicLink', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDisableVpcClassicLink('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDisableVpcClassicLink', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDisableVpcClassicLink - errors', () => {
      it('should have a postDisableVpcClassicLink function', (done) => {
        assert.equal(true, typeof a.postDisableVpcClassicLink === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDisableVpcClassicLink(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDisableVpcClassicLink', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDisableVpcClassicLink('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDisableVpcClassicLink', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postDisableVpcClassicLink('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDisableVpcClassicLink', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDisableVpcClassicLinkDnsSupport - errors', () => {
      it('should have a getDisableVpcClassicLinkDnsSupport function', (done) => {
        assert.equal(true, typeof a.getDisableVpcClassicLinkDnsSupport === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDisableVpcClassicLinkDnsSupport('fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDisableVpcClassicLinkDnsSupport', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDisableVpcClassicLinkDnsSupport('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDisableVpcClassicLinkDnsSupport', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDisableVpcClassicLinkDnsSupport - errors', () => {
      it('should have a postDisableVpcClassicLinkDnsSupport function', (done) => {
        assert.equal(true, typeof a.postDisableVpcClassicLinkDnsSupport === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDisableVpcClassicLinkDnsSupport(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDisableVpcClassicLinkDnsSupport', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDisableVpcClassicLinkDnsSupport('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDisableVpcClassicLinkDnsSupport', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDisassociateAddress - errors', () => {
      it('should have a getDisassociateAddress function', (done) => {
        assert.equal(true, typeof a.getDisassociateAddress === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDisassociateAddress('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDisassociateAddress', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDisassociateAddress('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDisassociateAddress', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDisassociateAddress - errors', () => {
      it('should have a postDisassociateAddress function', (done) => {
        assert.equal(true, typeof a.postDisassociateAddress === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDisassociateAddress(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDisassociateAddress', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDisassociateAddress('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDisassociateAddress', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDisassociateClientVpnTargetNetwork - errors', () => {
      it('should have a getDisassociateClientVpnTargetNetwork function', (done) => {
        assert.equal(true, typeof a.getDisassociateClientVpnTargetNetwork === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing clientVpnEndpointId', (done) => {
        const p = new Promise((resolve) => {
          a.getDisassociateClientVpnTargetNetwork(null, null, null, null, null, null, (data, error) => {
            const displayE = 'clientVpnEndpointId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDisassociateClientVpnTargetNetwork', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing associationId', (done) => {
        const p = new Promise((resolve) => {
          a.getDisassociateClientVpnTargetNetwork('fakeparam', null, null, null, null, null, (data, error) => {
            const displayE = 'associationId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDisassociateClientVpnTargetNetwork', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDisassociateClientVpnTargetNetwork('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDisassociateClientVpnTargetNetwork', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDisassociateClientVpnTargetNetwork('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDisassociateClientVpnTargetNetwork', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDisassociateClientVpnTargetNetwork - errors', () => {
      it('should have a postDisassociateClientVpnTargetNetwork function', (done) => {
        assert.equal(true, typeof a.postDisassociateClientVpnTargetNetwork === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDisassociateClientVpnTargetNetwork(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDisassociateClientVpnTargetNetwork', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDisassociateClientVpnTargetNetwork('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDisassociateClientVpnTargetNetwork', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postDisassociateClientVpnTargetNetwork('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDisassociateClientVpnTargetNetwork', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDisassociateIamInstanceProfile - errors', () => {
      it('should have a getDisassociateIamInstanceProfile function', (done) => {
        assert.equal(true, typeof a.getDisassociateIamInstanceProfile === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing associationId', (done) => {
        const p = new Promise((resolve) => {
          a.getDisassociateIamInstanceProfile(null, null, null, null, (data, error) => {
            const displayE = 'associationId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDisassociateIamInstanceProfile', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDisassociateIamInstanceProfile('fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDisassociateIamInstanceProfile', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDisassociateIamInstanceProfile('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDisassociateIamInstanceProfile', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDisassociateIamInstanceProfile - errors', () => {
      it('should have a postDisassociateIamInstanceProfile function', (done) => {
        assert.equal(true, typeof a.postDisassociateIamInstanceProfile === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDisassociateIamInstanceProfile(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDisassociateIamInstanceProfile', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDisassociateIamInstanceProfile('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDisassociateIamInstanceProfile', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postDisassociateIamInstanceProfile('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDisassociateIamInstanceProfile', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDisassociateRouteTable - errors', () => {
      it('should have a getDisassociateRouteTable function', (done) => {
        assert.equal(true, typeof a.getDisassociateRouteTable === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing associationId', (done) => {
        const p = new Promise((resolve) => {
          a.getDisassociateRouteTable(null, null, null, null, null, (data, error) => {
            const displayE = 'associationId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDisassociateRouteTable', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDisassociateRouteTable('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDisassociateRouteTable', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDisassociateRouteTable('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDisassociateRouteTable', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDisassociateRouteTable - errors', () => {
      it('should have a postDisassociateRouteTable function', (done) => {
        assert.equal(true, typeof a.postDisassociateRouteTable === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDisassociateRouteTable(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDisassociateRouteTable', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDisassociateRouteTable('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDisassociateRouteTable', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postDisassociateRouteTable('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDisassociateRouteTable', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDisassociateSubnetCidrBlock - errors', () => {
      it('should have a getDisassociateSubnetCidrBlock function', (done) => {
        assert.equal(true, typeof a.getDisassociateSubnetCidrBlock === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing associationId', (done) => {
        const p = new Promise((resolve) => {
          a.getDisassociateSubnetCidrBlock(null, null, null, null, (data, error) => {
            const displayE = 'associationId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDisassociateSubnetCidrBlock', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDisassociateSubnetCidrBlock('fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDisassociateSubnetCidrBlock', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDisassociateSubnetCidrBlock('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDisassociateSubnetCidrBlock', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDisassociateSubnetCidrBlock - errors', () => {
      it('should have a postDisassociateSubnetCidrBlock function', (done) => {
        assert.equal(true, typeof a.postDisassociateSubnetCidrBlock === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDisassociateSubnetCidrBlock(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDisassociateSubnetCidrBlock', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDisassociateSubnetCidrBlock('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDisassociateSubnetCidrBlock', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postDisassociateSubnetCidrBlock('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDisassociateSubnetCidrBlock', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDisassociateTransitGatewayRouteTable - errors', () => {
      it('should have a getDisassociateTransitGatewayRouteTable function', (done) => {
        assert.equal(true, typeof a.getDisassociateTransitGatewayRouteTable === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing transitGatewayRouteTableId', (done) => {
        const p = new Promise((resolve) => {
          a.getDisassociateTransitGatewayRouteTable(null, null, null, null, null, null, (data, error) => {
            const displayE = 'transitGatewayRouteTableId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDisassociateTransitGatewayRouteTable', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing transitGatewayAttachmentId', (done) => {
        const p = new Promise((resolve) => {
          a.getDisassociateTransitGatewayRouteTable('fakeparam', null, null, null, null, null, (data, error) => {
            const displayE = 'transitGatewayAttachmentId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDisassociateTransitGatewayRouteTable', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDisassociateTransitGatewayRouteTable('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDisassociateTransitGatewayRouteTable', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDisassociateTransitGatewayRouteTable('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDisassociateTransitGatewayRouteTable', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDisassociateTransitGatewayRouteTable - errors', () => {
      it('should have a postDisassociateTransitGatewayRouteTable function', (done) => {
        assert.equal(true, typeof a.postDisassociateTransitGatewayRouteTable === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDisassociateTransitGatewayRouteTable(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDisassociateTransitGatewayRouteTable', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDisassociateTransitGatewayRouteTable('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDisassociateTransitGatewayRouteTable', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postDisassociateTransitGatewayRouteTable('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDisassociateTransitGatewayRouteTable', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getDisassociateVpcCidrBlock - errors', () => {
      it('should have a getDisassociateVpcCidrBlock function', (done) => {
        assert.equal(true, typeof a.getDisassociateVpcCidrBlock === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing associationId', (done) => {
        const p = new Promise((resolve) => {
          a.getDisassociateVpcCidrBlock(null, null, null, null, (data, error) => {
            const displayE = 'associationId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDisassociateVpcCidrBlock', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getDisassociateVpcCidrBlock('fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDisassociateVpcCidrBlock', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getDisassociateVpcCidrBlock('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getDisassociateVpcCidrBlock', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postDisassociateVpcCidrBlock - errors', () => {
      it('should have a postDisassociateVpcCidrBlock function', (done) => {
        assert.equal(true, typeof a.postDisassociateVpcCidrBlock === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postDisassociateVpcCidrBlock(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDisassociateVpcCidrBlock', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postDisassociateVpcCidrBlock('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDisassociateVpcCidrBlock', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postDisassociateVpcCidrBlock('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postDisassociateVpcCidrBlock', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getEnableTransitGatewayRouteTablePropagation - errors', () => {
      it('should have a getEnableTransitGatewayRouteTablePropagation function', (done) => {
        assert.equal(true, typeof a.getEnableTransitGatewayRouteTablePropagation === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing transitGatewayRouteTableId', (done) => {
        const p = new Promise((resolve) => {
          a.getEnableTransitGatewayRouteTablePropagation(null, null, null, null, null, null, (data, error) => {
            const displayE = 'transitGatewayRouteTableId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getEnableTransitGatewayRouteTablePropagation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing transitGatewayAttachmentId', (done) => {
        const p = new Promise((resolve) => {
          a.getEnableTransitGatewayRouteTablePropagation('fakeparam', null, null, null, null, null, (data, error) => {
            const displayE = 'transitGatewayAttachmentId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getEnableTransitGatewayRouteTablePropagation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getEnableTransitGatewayRouteTablePropagation('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getEnableTransitGatewayRouteTablePropagation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getEnableTransitGatewayRouteTablePropagation('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getEnableTransitGatewayRouteTablePropagation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postEnableTransitGatewayRouteTablePropagation - errors', () => {
      it('should have a postEnableTransitGatewayRouteTablePropagation function', (done) => {
        assert.equal(true, typeof a.postEnableTransitGatewayRouteTablePropagation === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postEnableTransitGatewayRouteTablePropagation(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postEnableTransitGatewayRouteTablePropagation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postEnableTransitGatewayRouteTablePropagation('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postEnableTransitGatewayRouteTablePropagation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postEnableTransitGatewayRouteTablePropagation('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postEnableTransitGatewayRouteTablePropagation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getEnableVgwRoutePropagation - errors', () => {
      it('should have a getEnableVgwRoutePropagation function', (done) => {
        assert.equal(true, typeof a.getEnableVgwRoutePropagation === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing gatewayId', (done) => {
        const p = new Promise((resolve) => {
          a.getEnableVgwRoutePropagation(null, null, null, null, null, (data, error) => {
            const displayE = 'gatewayId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getEnableVgwRoutePropagation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing routeTableId', (done) => {
        const p = new Promise((resolve) => {
          a.getEnableVgwRoutePropagation('fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'routeTableId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getEnableVgwRoutePropagation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getEnableVgwRoutePropagation('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getEnableVgwRoutePropagation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getEnableVgwRoutePropagation('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getEnableVgwRoutePropagation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postEnableVgwRoutePropagation - errors', () => {
      it('should have a postEnableVgwRoutePropagation function', (done) => {
        assert.equal(true, typeof a.postEnableVgwRoutePropagation === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postEnableVgwRoutePropagation(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postEnableVgwRoutePropagation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postEnableVgwRoutePropagation('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postEnableVgwRoutePropagation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postEnableVgwRoutePropagation('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postEnableVgwRoutePropagation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getEnableVolumeIO - errors', () => {
      it('should have a getEnableVolumeIO function', (done) => {
        assert.equal(true, typeof a.getEnableVolumeIO === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing volumeId', (done) => {
        const p = new Promise((resolve) => {
          a.getEnableVolumeIO('fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'volumeId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getEnableVolumeIO', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getEnableVolumeIO('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getEnableVolumeIO', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getEnableVolumeIO('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getEnableVolumeIO', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postEnableVolumeIO - errors', () => {
      it('should have a postEnableVolumeIO function', (done) => {
        assert.equal(true, typeof a.postEnableVolumeIO === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postEnableVolumeIO(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postEnableVolumeIO', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postEnableVolumeIO('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postEnableVolumeIO', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postEnableVolumeIO('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postEnableVolumeIO', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getEnableVpcClassicLink - errors', () => {
      it('should have a getEnableVpcClassicLink function', (done) => {
        assert.equal(true, typeof a.getEnableVpcClassicLink === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing vpcId', (done) => {
        const p = new Promise((resolve) => {
          a.getEnableVpcClassicLink('fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'vpcId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getEnableVpcClassicLink', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getEnableVpcClassicLink('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getEnableVpcClassicLink', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getEnableVpcClassicLink('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getEnableVpcClassicLink', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postEnableVpcClassicLink - errors', () => {
      it('should have a postEnableVpcClassicLink function', (done) => {
        assert.equal(true, typeof a.postEnableVpcClassicLink === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postEnableVpcClassicLink(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postEnableVpcClassicLink', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postEnableVpcClassicLink('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postEnableVpcClassicLink', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postEnableVpcClassicLink('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postEnableVpcClassicLink', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getEnableVpcClassicLinkDnsSupport - errors', () => {
      it('should have a getEnableVpcClassicLinkDnsSupport function', (done) => {
        assert.equal(true, typeof a.getEnableVpcClassicLinkDnsSupport === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getEnableVpcClassicLinkDnsSupport('fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getEnableVpcClassicLinkDnsSupport', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getEnableVpcClassicLinkDnsSupport('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getEnableVpcClassicLinkDnsSupport', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postEnableVpcClassicLinkDnsSupport - errors', () => {
      it('should have a postEnableVpcClassicLinkDnsSupport function', (done) => {
        assert.equal(true, typeof a.postEnableVpcClassicLinkDnsSupport === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postEnableVpcClassicLinkDnsSupport(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postEnableVpcClassicLinkDnsSupport', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postEnableVpcClassicLinkDnsSupport('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postEnableVpcClassicLinkDnsSupport', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getExportClientVpnClientCertificateRevocationList - errors', () => {
      it('should have a getExportClientVpnClientCertificateRevocationList function', (done) => {
        assert.equal(true, typeof a.getExportClientVpnClientCertificateRevocationList === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing clientVpnEndpointId', (done) => {
        const p = new Promise((resolve) => {
          a.getExportClientVpnClientCertificateRevocationList(null, null, null, null, null, (data, error) => {
            const displayE = 'clientVpnEndpointId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getExportClientVpnClientCertificateRevocationList', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getExportClientVpnClientCertificateRevocationList('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getExportClientVpnClientCertificateRevocationList', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getExportClientVpnClientCertificateRevocationList('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getExportClientVpnClientCertificateRevocationList', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postExportClientVpnClientCertificateRevocationList - errors', () => {
      it('should have a postExportClientVpnClientCertificateRevocationList function', (done) => {
        assert.equal(true, typeof a.postExportClientVpnClientCertificateRevocationList === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postExportClientVpnClientCertificateRevocationList(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postExportClientVpnClientCertificateRevocationList', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postExportClientVpnClientCertificateRevocationList('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postExportClientVpnClientCertificateRevocationList', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postExportClientVpnClientCertificateRevocationList('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postExportClientVpnClientCertificateRevocationList', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getExportClientVpnClientConfiguration - errors', () => {
      it('should have a getExportClientVpnClientConfiguration function', (done) => {
        assert.equal(true, typeof a.getExportClientVpnClientConfiguration === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing clientVpnEndpointId', (done) => {
        const p = new Promise((resolve) => {
          a.getExportClientVpnClientConfiguration(null, null, null, null, null, (data, error) => {
            const displayE = 'clientVpnEndpointId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getExportClientVpnClientConfiguration', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getExportClientVpnClientConfiguration('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getExportClientVpnClientConfiguration', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getExportClientVpnClientConfiguration('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getExportClientVpnClientConfiguration', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postExportClientVpnClientConfiguration - errors', () => {
      it('should have a postExportClientVpnClientConfiguration function', (done) => {
        assert.equal(true, typeof a.postExportClientVpnClientConfiguration === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postExportClientVpnClientConfiguration(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postExportClientVpnClientConfiguration', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postExportClientVpnClientConfiguration('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postExportClientVpnClientConfiguration', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postExportClientVpnClientConfiguration('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postExportClientVpnClientConfiguration', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getExportTransitGatewayRoutes - errors', () => {
      it('should have a getExportTransitGatewayRoutes function', (done) => {
        assert.equal(true, typeof a.getExportTransitGatewayRoutes === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing transitGatewayRouteTableId', (done) => {
        const p = new Promise((resolve) => {
          a.getExportTransitGatewayRoutes(null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'transitGatewayRouteTableId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getExportTransitGatewayRoutes', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing s3Bucket', (done) => {
        const p = new Promise((resolve) => {
          a.getExportTransitGatewayRoutes('fakeparam', 'fakeparam', null, null, null, null, null, (data, error) => {
            const displayE = 's3Bucket is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getExportTransitGatewayRoutes', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getExportTransitGatewayRoutes('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getExportTransitGatewayRoutes', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getExportTransitGatewayRoutes('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getExportTransitGatewayRoutes', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postExportTransitGatewayRoutes - errors', () => {
      it('should have a postExportTransitGatewayRoutes function', (done) => {
        assert.equal(true, typeof a.postExportTransitGatewayRoutes === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postExportTransitGatewayRoutes(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postExportTransitGatewayRoutes', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postExportTransitGatewayRoutes('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postExportTransitGatewayRoutes', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postExportTransitGatewayRoutes('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postExportTransitGatewayRoutes', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getGetConsoleOutput - errors', () => {
      it('should have a getGetConsoleOutput function', (done) => {
        assert.equal(true, typeof a.getGetConsoleOutput === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing instanceId', (done) => {
        const p = new Promise((resolve) => {
          a.getGetConsoleOutput(null, null, null, null, null, null, (data, error) => {
            const displayE = 'instanceId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getGetConsoleOutput', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getGetConsoleOutput('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getGetConsoleOutput', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getGetConsoleOutput('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getGetConsoleOutput', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postGetConsoleOutput - errors', () => {
      it('should have a postGetConsoleOutput function', (done) => {
        assert.equal(true, typeof a.postGetConsoleOutput === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postGetConsoleOutput(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postGetConsoleOutput', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postGetConsoleOutput('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postGetConsoleOutput', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postGetConsoleOutput('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postGetConsoleOutput', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getGetConsoleScreenshot - errors', () => {
      it('should have a getGetConsoleScreenshot function', (done) => {
        assert.equal(true, typeof a.getGetConsoleScreenshot === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing instanceId', (done) => {
        const p = new Promise((resolve) => {
          a.getGetConsoleScreenshot('fakeparam', null, null, null, null, null, (data, error) => {
            const displayE = 'instanceId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getGetConsoleScreenshot', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getGetConsoleScreenshot('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getGetConsoleScreenshot', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getGetConsoleScreenshot('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getGetConsoleScreenshot', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postGetConsoleScreenshot - errors', () => {
      it('should have a postGetConsoleScreenshot function', (done) => {
        assert.equal(true, typeof a.postGetConsoleScreenshot === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postGetConsoleScreenshot(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postGetConsoleScreenshot', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postGetConsoleScreenshot('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postGetConsoleScreenshot', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postGetConsoleScreenshot('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postGetConsoleScreenshot', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getGetHostReservationPurchasePreview - errors', () => {
      it('should have a getGetHostReservationPurchasePreview function', (done) => {
        assert.equal(true, typeof a.getGetHostReservationPurchasePreview === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing hostIdSet', (done) => {
        const p = new Promise((resolve) => {
          a.getGetHostReservationPurchasePreview(null, null, null, null, null, (data, error) => {
            const displayE = 'hostIdSet is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getGetHostReservationPurchasePreview', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing offeringId', (done) => {
        const p = new Promise((resolve) => {
          a.getGetHostReservationPurchasePreview('fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'offeringId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getGetHostReservationPurchasePreview', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getGetHostReservationPurchasePreview('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getGetHostReservationPurchasePreview', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getGetHostReservationPurchasePreview('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getGetHostReservationPurchasePreview', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postGetHostReservationPurchasePreview - errors', () => {
      it('should have a postGetHostReservationPurchasePreview function', (done) => {
        assert.equal(true, typeof a.postGetHostReservationPurchasePreview === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postGetHostReservationPurchasePreview(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postGetHostReservationPurchasePreview', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postGetHostReservationPurchasePreview('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postGetHostReservationPurchasePreview', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postGetHostReservationPurchasePreview('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postGetHostReservationPurchasePreview', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getGetLaunchTemplateData - errors', () => {
      it('should have a getGetLaunchTemplateData function', (done) => {
        assert.equal(true, typeof a.getGetLaunchTemplateData === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing instanceId', (done) => {
        const p = new Promise((resolve) => {
          a.getGetLaunchTemplateData('fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'instanceId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getGetLaunchTemplateData', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getGetLaunchTemplateData('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getGetLaunchTemplateData', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getGetLaunchTemplateData('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getGetLaunchTemplateData', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postGetLaunchTemplateData - errors', () => {
      it('should have a postGetLaunchTemplateData function', (done) => {
        assert.equal(true, typeof a.postGetLaunchTemplateData === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postGetLaunchTemplateData(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postGetLaunchTemplateData', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postGetLaunchTemplateData('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postGetLaunchTemplateData', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postGetLaunchTemplateData('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postGetLaunchTemplateData', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getGetPasswordData - errors', () => {
      it('should have a getGetPasswordData function', (done) => {
        assert.equal(true, typeof a.getGetPasswordData === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing instanceId', (done) => {
        const p = new Promise((resolve) => {
          a.getGetPasswordData(null, null, null, null, null, (data, error) => {
            const displayE = 'instanceId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getGetPasswordData', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getGetPasswordData('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getGetPasswordData', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getGetPasswordData('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getGetPasswordData', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postGetPasswordData - errors', () => {
      it('should have a postGetPasswordData function', (done) => {
        assert.equal(true, typeof a.postGetPasswordData === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postGetPasswordData(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postGetPasswordData', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postGetPasswordData('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postGetPasswordData', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postGetPasswordData('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postGetPasswordData', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getGetReservedInstancesExchangeQuote - errors', () => {
      it('should have a getGetReservedInstancesExchangeQuote function', (done) => {
        assert.equal(true, typeof a.getGetReservedInstancesExchangeQuote === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing reservedInstanceId', (done) => {
        const p = new Promise((resolve) => {
          a.getGetReservedInstancesExchangeQuote('fakeparam', null, null, null, null, null, (data, error) => {
            const displayE = 'reservedInstanceId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getGetReservedInstancesExchangeQuote', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getGetReservedInstancesExchangeQuote('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getGetReservedInstancesExchangeQuote', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getGetReservedInstancesExchangeQuote('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getGetReservedInstancesExchangeQuote', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postGetReservedInstancesExchangeQuote - errors', () => {
      it('should have a postGetReservedInstancesExchangeQuote function', (done) => {
        assert.equal(true, typeof a.postGetReservedInstancesExchangeQuote === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postGetReservedInstancesExchangeQuote(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postGetReservedInstancesExchangeQuote', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postGetReservedInstancesExchangeQuote('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postGetReservedInstancesExchangeQuote', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postGetReservedInstancesExchangeQuote('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postGetReservedInstancesExchangeQuote', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getGetTransitGatewayAttachmentPropagations - errors', () => {
      it('should have a getGetTransitGatewayAttachmentPropagations function', (done) => {
        assert.equal(true, typeof a.getGetTransitGatewayAttachmentPropagations === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing transitGatewayAttachmentId', (done) => {
        const p = new Promise((resolve) => {
          a.getGetTransitGatewayAttachmentPropagations(null, null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'transitGatewayAttachmentId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getGetTransitGatewayAttachmentPropagations', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getGetTransitGatewayAttachmentPropagations('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getGetTransitGatewayAttachmentPropagations', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getGetTransitGatewayAttachmentPropagations('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getGetTransitGatewayAttachmentPropagations', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postGetTransitGatewayAttachmentPropagations - errors', () => {
      it('should have a postGetTransitGatewayAttachmentPropagations function', (done) => {
        assert.equal(true, typeof a.postGetTransitGatewayAttachmentPropagations === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postGetTransitGatewayAttachmentPropagations(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postGetTransitGatewayAttachmentPropagations', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postGetTransitGatewayAttachmentPropagations('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postGetTransitGatewayAttachmentPropagations', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postGetTransitGatewayAttachmentPropagations('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postGetTransitGatewayAttachmentPropagations', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getGetTransitGatewayRouteTableAssociations - errors', () => {
      it('should have a getGetTransitGatewayRouteTableAssociations function', (done) => {
        assert.equal(true, typeof a.getGetTransitGatewayRouteTableAssociations === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing transitGatewayRouteTableId', (done) => {
        const p = new Promise((resolve) => {
          a.getGetTransitGatewayRouteTableAssociations(null, null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'transitGatewayRouteTableId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getGetTransitGatewayRouteTableAssociations', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getGetTransitGatewayRouteTableAssociations('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getGetTransitGatewayRouteTableAssociations', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getGetTransitGatewayRouteTableAssociations('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getGetTransitGatewayRouteTableAssociations', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postGetTransitGatewayRouteTableAssociations - errors', () => {
      it('should have a postGetTransitGatewayRouteTableAssociations function', (done) => {
        assert.equal(true, typeof a.postGetTransitGatewayRouteTableAssociations === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postGetTransitGatewayRouteTableAssociations(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postGetTransitGatewayRouteTableAssociations', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postGetTransitGatewayRouteTableAssociations('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postGetTransitGatewayRouteTableAssociations', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postGetTransitGatewayRouteTableAssociations('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postGetTransitGatewayRouteTableAssociations', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getGetTransitGatewayRouteTablePropagations - errors', () => {
      it('should have a getGetTransitGatewayRouteTablePropagations function', (done) => {
        assert.equal(true, typeof a.getGetTransitGatewayRouteTablePropagations === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing transitGatewayRouteTableId', (done) => {
        const p = new Promise((resolve) => {
          a.getGetTransitGatewayRouteTablePropagations(null, null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'transitGatewayRouteTableId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getGetTransitGatewayRouteTablePropagations', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getGetTransitGatewayRouteTablePropagations('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getGetTransitGatewayRouteTablePropagations', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getGetTransitGatewayRouteTablePropagations('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getGetTransitGatewayRouteTablePropagations', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postGetTransitGatewayRouteTablePropagations - errors', () => {
      it('should have a postGetTransitGatewayRouteTablePropagations function', (done) => {
        assert.equal(true, typeof a.postGetTransitGatewayRouteTablePropagations === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postGetTransitGatewayRouteTablePropagations(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postGetTransitGatewayRouteTablePropagations', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postGetTransitGatewayRouteTablePropagations('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postGetTransitGatewayRouteTablePropagations', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postGetTransitGatewayRouteTablePropagations('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postGetTransitGatewayRouteTablePropagations', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getImportClientVpnClientCertificateRevocationList - errors', () => {
      it('should have a getImportClientVpnClientCertificateRevocationList function', (done) => {
        assert.equal(true, typeof a.getImportClientVpnClientCertificateRevocationList === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing clientVpnEndpointId', (done) => {
        const p = new Promise((resolve) => {
          a.getImportClientVpnClientCertificateRevocationList(null, null, null, null, null, null, (data, error) => {
            const displayE = 'clientVpnEndpointId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getImportClientVpnClientCertificateRevocationList', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing certificateRevocationList', (done) => {
        const p = new Promise((resolve) => {
          a.getImportClientVpnClientCertificateRevocationList('fakeparam', null, null, null, null, null, (data, error) => {
            const displayE = 'certificateRevocationList is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getImportClientVpnClientCertificateRevocationList', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getImportClientVpnClientCertificateRevocationList('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getImportClientVpnClientCertificateRevocationList', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getImportClientVpnClientCertificateRevocationList('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getImportClientVpnClientCertificateRevocationList', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postImportClientVpnClientCertificateRevocationList - errors', () => {
      it('should have a postImportClientVpnClientCertificateRevocationList function', (done) => {
        assert.equal(true, typeof a.postImportClientVpnClientCertificateRevocationList === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postImportClientVpnClientCertificateRevocationList(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postImportClientVpnClientCertificateRevocationList', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postImportClientVpnClientCertificateRevocationList('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postImportClientVpnClientCertificateRevocationList', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postImportClientVpnClientCertificateRevocationList('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postImportClientVpnClientCertificateRevocationList', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getImportImage - errors', () => {
      it('should have a getImportImage function', (done) => {
        assert.equal(true, typeof a.getImportImage === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getImportImage('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getImportImage', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getImportImage('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getImportImage', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postImportImage - errors', () => {
      it('should have a postImportImage function', (done) => {
        assert.equal(true, typeof a.postImportImage === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postImportImage(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postImportImage', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postImportImage('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postImportImage', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getImportInstance - errors', () => {
      it('should have a getImportInstance function', (done) => {
        assert.equal(true, typeof a.getImportInstance === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing platform', (done) => {
        const p = new Promise((resolve) => {
          a.getImportInstance('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'platform is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getImportInstance', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getImportInstance('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getImportInstance', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getImportInstance('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getImportInstance', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postImportInstance - errors', () => {
      it('should have a postImportInstance function', (done) => {
        assert.equal(true, typeof a.postImportInstance === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postImportInstance(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postImportInstance', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postImportInstance('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postImportInstance', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postImportInstance('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postImportInstance', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getImportKeyPair - errors', () => {
      it('should have a getImportKeyPair function', (done) => {
        assert.equal(true, typeof a.getImportKeyPair === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing keyName', (done) => {
        const p = new Promise((resolve) => {
          a.getImportKeyPair('fakeparam', null, null, null, null, null, (data, error) => {
            const displayE = 'keyName is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getImportKeyPair', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing publicKeyMaterial', (done) => {
        const p = new Promise((resolve) => {
          a.getImportKeyPair('fakeparam', 'fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'publicKeyMaterial is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getImportKeyPair', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getImportKeyPair('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getImportKeyPair', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getImportKeyPair('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getImportKeyPair', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postImportKeyPair - errors', () => {
      it('should have a postImportKeyPair function', (done) => {
        assert.equal(true, typeof a.postImportKeyPair === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postImportKeyPair(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postImportKeyPair', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postImportKeyPair('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postImportKeyPair', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postImportKeyPair('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postImportKeyPair', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getImportSnapshot - errors', () => {
      it('should have a getImportSnapshot function', (done) => {
        assert.equal(true, typeof a.getImportSnapshot === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getImportSnapshot('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getImportSnapshot', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getImportSnapshot('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getImportSnapshot', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postImportSnapshot - errors', () => {
      it('should have a postImportSnapshot function', (done) => {
        assert.equal(true, typeof a.postImportSnapshot === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postImportSnapshot(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postImportSnapshot', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postImportSnapshot('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postImportSnapshot', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getImportVolume - errors', () => {
      it('should have a getImportVolume function', (done) => {
        assert.equal(true, typeof a.getImportVolume === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing availabilityZone', (done) => {
        const p = new Promise((resolve) => {
          a.getImportVolume(null, null, null, null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'availabilityZone is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getImportVolume', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getImportVolume('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getImportVolume', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getImportVolume('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getImportVolume', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postImportVolume - errors', () => {
      it('should have a postImportVolume function', (done) => {
        assert.equal(true, typeof a.postImportVolume === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postImportVolume(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postImportVolume', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postImportVolume('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postImportVolume', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postImportVolume('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postImportVolume', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getModifyCapacityReservation - errors', () => {
      it('should have a getModifyCapacityReservation function', (done) => {
        assert.equal(true, typeof a.getModifyCapacityReservation === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing capacityReservationId', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyCapacityReservation(null, null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'capacityReservationId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyCapacityReservation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyCapacityReservation('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyCapacityReservation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyCapacityReservation('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyCapacityReservation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postModifyCapacityReservation - errors', () => {
      it('should have a postModifyCapacityReservation function', (done) => {
        assert.equal(true, typeof a.postModifyCapacityReservation === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyCapacityReservation(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyCapacityReservation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyCapacityReservation('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyCapacityReservation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyCapacityReservation('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyCapacityReservation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getModifyClientVpnEndpoint - errors', () => {
      it('should have a getModifyClientVpnEndpoint function', (done) => {
        assert.equal(true, typeof a.getModifyClientVpnEndpoint === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing clientVpnEndpointId', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyClientVpnEndpoint(null, null, null, null, null, null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'clientVpnEndpointId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyClientVpnEndpoint', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyClientVpnEndpoint('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyClientVpnEndpoint', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyClientVpnEndpoint('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyClientVpnEndpoint', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postModifyClientVpnEndpoint - errors', () => {
      it('should have a postModifyClientVpnEndpoint function', (done) => {
        assert.equal(true, typeof a.postModifyClientVpnEndpoint === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyClientVpnEndpoint(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyClientVpnEndpoint', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyClientVpnEndpoint('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyClientVpnEndpoint', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyClientVpnEndpoint('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyClientVpnEndpoint', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getModifyFleet - errors', () => {
      it('should have a getModifyFleet function', (done) => {
        assert.equal(true, typeof a.getModifyFleet === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing fleetId', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyFleet('fakeparam', 'fakeparam', null, null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'fleetId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyFleet', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyFleet('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyFleet', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyFleet('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyFleet', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postModifyFleet - errors', () => {
      it('should have a postModifyFleet function', (done) => {
        assert.equal(true, typeof a.postModifyFleet === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyFleet(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyFleet', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyFleet('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyFleet', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyFleet('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyFleet', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getModifyFpgaImageAttribute - errors', () => {
      it('should have a getModifyFpgaImageAttribute function', (done) => {
        assert.equal(true, typeof a.getModifyFpgaImageAttribute === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing fpgaImageId', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyFpgaImageAttribute('fakeparam', null, null, null, null, null, null, null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'fpgaImageId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyFpgaImageAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyFpgaImageAttribute('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyFpgaImageAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyFpgaImageAttribute('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyFpgaImageAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postModifyFpgaImageAttribute - errors', () => {
      it('should have a postModifyFpgaImageAttribute function', (done) => {
        assert.equal(true, typeof a.postModifyFpgaImageAttribute === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyFpgaImageAttribute(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyFpgaImageAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyFpgaImageAttribute('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyFpgaImageAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyFpgaImageAttribute('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyFpgaImageAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getModifyHosts - errors', () => {
      it('should have a getModifyHosts function', (done) => {
        assert.equal(true, typeof a.getModifyHosts === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing autoPlacement', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyHosts(null, null, null, null, null, (data, error) => {
            const displayE = 'autoPlacement is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyHosts', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing hostId', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyHosts('fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'hostId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyHosts', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyHosts('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyHosts', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyHosts('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyHosts', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postModifyHosts - errors', () => {
      it('should have a postModifyHosts function', (done) => {
        assert.equal(true, typeof a.postModifyHosts === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyHosts(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyHosts', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyHosts('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyHosts', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyHosts('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyHosts', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getModifyIdFormat - errors', () => {
      it('should have a getModifyIdFormat function', (done) => {
        assert.equal(true, typeof a.getModifyIdFormat === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing resource', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyIdFormat(null, null, null, null, null, (data, error) => {
            const displayE = 'resource is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyIdFormat', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing useLongIds', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyIdFormat('fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'useLongIds is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyIdFormat', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyIdFormat('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyIdFormat', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyIdFormat('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyIdFormat', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postModifyIdFormat - errors', () => {
      it('should have a postModifyIdFormat function', (done) => {
        assert.equal(true, typeof a.postModifyIdFormat === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyIdFormat(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyIdFormat', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyIdFormat('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyIdFormat', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyIdFormat('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyIdFormat', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getModifyIdentityIdFormat - errors', () => {
      it('should have a getModifyIdentityIdFormat function', (done) => {
        assert.equal(true, typeof a.getModifyIdentityIdFormat === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing principalArn', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyIdentityIdFormat(null, null, null, null, null, null, (data, error) => {
            const displayE = 'principalArn is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyIdentityIdFormat', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing resource', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyIdentityIdFormat('fakeparam', null, null, null, null, null, (data, error) => {
            const displayE = 'resource is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyIdentityIdFormat', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing useLongIds', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyIdentityIdFormat('fakeparam', 'fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'useLongIds is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyIdentityIdFormat', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyIdentityIdFormat('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyIdentityIdFormat', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyIdentityIdFormat('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyIdentityIdFormat', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postModifyIdentityIdFormat - errors', () => {
      it('should have a postModifyIdentityIdFormat function', (done) => {
        assert.equal(true, typeof a.postModifyIdentityIdFormat === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyIdentityIdFormat(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyIdentityIdFormat', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyIdentityIdFormat('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyIdentityIdFormat', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyIdentityIdFormat('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyIdentityIdFormat', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getModifyImageAttribute - errors', () => {
      it('should have a getModifyImageAttribute function', (done) => {
        assert.equal(true, typeof a.getModifyImageAttribute === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing imageId', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyImageAttribute('fakeparam', 'fakeparam', null, null, null, null, null, null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'imageId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyImageAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyImageAttribute('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyImageAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyImageAttribute('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyImageAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postModifyImageAttribute - errors', () => {
      it('should have a postModifyImageAttribute function', (done) => {
        assert.equal(true, typeof a.postModifyImageAttribute === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyImageAttribute(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyImageAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyImageAttribute('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyImageAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyImageAttribute('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyImageAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getModifyInstanceAttribute - errors', () => {
      it('should have a getModifyInstanceAttribute function', (done) => {
        assert.equal(true, typeof a.getModifyInstanceAttribute === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing instanceId', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyInstanceAttribute('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, null, null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'instanceId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyInstanceAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyInstanceAttribute('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyInstanceAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyInstanceAttribute('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyInstanceAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postModifyInstanceAttribute - errors', () => {
      it('should have a postModifyInstanceAttribute function', (done) => {
        assert.equal(true, typeof a.postModifyInstanceAttribute === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyInstanceAttribute(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyInstanceAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyInstanceAttribute('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyInstanceAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyInstanceAttribute('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyInstanceAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getModifyInstanceCapacityReservationAttributes - errors', () => {
      it('should have a getModifyInstanceCapacityReservationAttributes function', (done) => {
        assert.equal(true, typeof a.getModifyInstanceCapacityReservationAttributes === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing instanceId', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyInstanceCapacityReservationAttributes(null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'instanceId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyInstanceCapacityReservationAttributes', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyInstanceCapacityReservationAttributes('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyInstanceCapacityReservationAttributes', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyInstanceCapacityReservationAttributes('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyInstanceCapacityReservationAttributes', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postModifyInstanceCapacityReservationAttributes - errors', () => {
      it('should have a postModifyInstanceCapacityReservationAttributes function', (done) => {
        assert.equal(true, typeof a.postModifyInstanceCapacityReservationAttributes === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyInstanceCapacityReservationAttributes(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyInstanceCapacityReservationAttributes', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyInstanceCapacityReservationAttributes('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyInstanceCapacityReservationAttributes', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyInstanceCapacityReservationAttributes('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyInstanceCapacityReservationAttributes', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getModifyInstanceCreditSpecification - errors', () => {
      it('should have a getModifyInstanceCreditSpecification function', (done) => {
        assert.equal(true, typeof a.getModifyInstanceCreditSpecification === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing instanceCreditSpecification', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyInstanceCreditSpecification('fakeparam', 'fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'instanceCreditSpecification is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyInstanceCreditSpecification', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyInstanceCreditSpecification('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyInstanceCreditSpecification', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyInstanceCreditSpecification('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyInstanceCreditSpecification', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postModifyInstanceCreditSpecification - errors', () => {
      it('should have a postModifyInstanceCreditSpecification function', (done) => {
        assert.equal(true, typeof a.postModifyInstanceCreditSpecification === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyInstanceCreditSpecification(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyInstanceCreditSpecification', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyInstanceCreditSpecification('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyInstanceCreditSpecification', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyInstanceCreditSpecification('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyInstanceCreditSpecification', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getModifyInstanceEventStartTime - errors', () => {
      it('should have a getModifyInstanceEventStartTime function', (done) => {
        assert.equal(true, typeof a.getModifyInstanceEventStartTime === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing instanceId', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyInstanceEventStartTime('fakeparam', null, null, null, null, null, null, (data, error) => {
            const displayE = 'instanceId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyInstanceEventStartTime', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing instanceEventId', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyInstanceEventStartTime('fakeparam', 'fakeparam', null, null, null, null, null, (data, error) => {
            const displayE = 'instanceEventId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyInstanceEventStartTime', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing notBefore', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyInstanceEventStartTime('fakeparam', 'fakeparam', 'fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'notBefore is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyInstanceEventStartTime', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyInstanceEventStartTime('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyInstanceEventStartTime', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyInstanceEventStartTime('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyInstanceEventStartTime', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postModifyInstanceEventStartTime - errors', () => {
      it('should have a postModifyInstanceEventStartTime function', (done) => {
        assert.equal(true, typeof a.postModifyInstanceEventStartTime === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyInstanceEventStartTime(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyInstanceEventStartTime', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyInstanceEventStartTime('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyInstanceEventStartTime', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyInstanceEventStartTime('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyInstanceEventStartTime', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getModifyInstancePlacement - errors', () => {
      it('should have a getModifyInstancePlacement function', (done) => {
        assert.equal(true, typeof a.getModifyInstancePlacement === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing instanceId', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyInstancePlacement('fakeparam', 'fakeparam', 'fakeparam', null, null, null, null, null, null, (data, error) => {
            const displayE = 'instanceId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyInstancePlacement', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyInstancePlacement('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyInstancePlacement', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyInstancePlacement('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyInstancePlacement', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postModifyInstancePlacement - errors', () => {
      it('should have a postModifyInstancePlacement function', (done) => {
        assert.equal(true, typeof a.postModifyInstancePlacement === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyInstancePlacement(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyInstancePlacement', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyInstancePlacement('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyInstancePlacement', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyInstancePlacement('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyInstancePlacement', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getModifyLaunchTemplate - errors', () => {
      it('should have a getModifyLaunchTemplate function', (done) => {
        assert.equal(true, typeof a.getModifyLaunchTemplate === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyLaunchTemplate('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyLaunchTemplate', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyLaunchTemplate('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyLaunchTemplate', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postModifyLaunchTemplate - errors', () => {
      it('should have a postModifyLaunchTemplate function', (done) => {
        assert.equal(true, typeof a.postModifyLaunchTemplate === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyLaunchTemplate(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyLaunchTemplate', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyLaunchTemplate('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyLaunchTemplate', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getModifyNetworkInterfaceAttribute - errors', () => {
      it('should have a getModifyNetworkInterfaceAttribute function', (done) => {
        assert.equal(true, typeof a.getModifyNetworkInterfaceAttribute === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing networkInterfaceId', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyNetworkInterfaceAttribute('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, null, null, (data, error) => {
            const displayE = 'networkInterfaceId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyNetworkInterfaceAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyNetworkInterfaceAttribute('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyNetworkInterfaceAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyNetworkInterfaceAttribute('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyNetworkInterfaceAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postModifyNetworkInterfaceAttribute - errors', () => {
      it('should have a postModifyNetworkInterfaceAttribute function', (done) => {
        assert.equal(true, typeof a.postModifyNetworkInterfaceAttribute === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyNetworkInterfaceAttribute(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyNetworkInterfaceAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyNetworkInterfaceAttribute('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyNetworkInterfaceAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyNetworkInterfaceAttribute('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyNetworkInterfaceAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getModifyReservedInstances - errors', () => {
      it('should have a getModifyReservedInstances function', (done) => {
        assert.equal(true, typeof a.getModifyReservedInstances === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing reservedInstancesId', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyReservedInstances(null, null, null, null, null, null, (data, error) => {
            const displayE = 'reservedInstancesId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyReservedInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing reservedInstancesConfigurationSetItemType', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyReservedInstances('fakeparam', 'fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'reservedInstancesConfigurationSetItemType is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyReservedInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyReservedInstances('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyReservedInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyReservedInstances('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyReservedInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postModifyReservedInstances - errors', () => {
      it('should have a postModifyReservedInstances function', (done) => {
        assert.equal(true, typeof a.postModifyReservedInstances === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyReservedInstances(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyReservedInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyReservedInstances('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyReservedInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyReservedInstances('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyReservedInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getModifySnapshotAttribute - errors', () => {
      it('should have a getModifySnapshotAttribute function', (done) => {
        assert.equal(true, typeof a.getModifySnapshotAttribute === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing snapshotId', (done) => {
        const p = new Promise((resolve) => {
          a.getModifySnapshotAttribute('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, null, null, null, (data, error) => {
            const displayE = 'snapshotId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifySnapshotAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getModifySnapshotAttribute('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifySnapshotAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getModifySnapshotAttribute('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifySnapshotAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postModifySnapshotAttribute - errors', () => {
      it('should have a postModifySnapshotAttribute function', (done) => {
        assert.equal(true, typeof a.postModifySnapshotAttribute === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postModifySnapshotAttribute(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifySnapshotAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postModifySnapshotAttribute('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifySnapshotAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postModifySnapshotAttribute('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifySnapshotAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getModifySpotFleetRequest - errors', () => {
      it('should have a getModifySpotFleetRequest function', (done) => {
        assert.equal(true, typeof a.getModifySpotFleetRequest === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing spotFleetRequestId', (done) => {
        const p = new Promise((resolve) => {
          a.getModifySpotFleetRequest('fakeparam', null, null, null, null, null, (data, error) => {
            const displayE = 'spotFleetRequestId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifySpotFleetRequest', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getModifySpotFleetRequest('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifySpotFleetRequest', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getModifySpotFleetRequest('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifySpotFleetRequest', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postModifySpotFleetRequest - errors', () => {
      it('should have a postModifySpotFleetRequest function', (done) => {
        assert.equal(true, typeof a.postModifySpotFleetRequest === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postModifySpotFleetRequest(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifySpotFleetRequest', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postModifySpotFleetRequest('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifySpotFleetRequest', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postModifySpotFleetRequest('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifySpotFleetRequest', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getModifySubnetAttribute - errors', () => {
      it('should have a getModifySubnetAttribute function', (done) => {
        assert.equal(true, typeof a.getModifySubnetAttribute === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing subnetId', (done) => {
        const p = new Promise((resolve) => {
          a.getModifySubnetAttribute('fakeparam', 'fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'subnetId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifySubnetAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getModifySubnetAttribute('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifySubnetAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getModifySubnetAttribute('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifySubnetAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postModifySubnetAttribute - errors', () => {
      it('should have a postModifySubnetAttribute function', (done) => {
        assert.equal(true, typeof a.postModifySubnetAttribute === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postModifySubnetAttribute(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifySubnetAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postModifySubnetAttribute('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifySubnetAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postModifySubnetAttribute('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifySubnetAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getModifyTransitGatewayVpcAttachment - errors', () => {
      it('should have a getModifyTransitGatewayVpcAttachment function', (done) => {
        assert.equal(true, typeof a.getModifyTransitGatewayVpcAttachment === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing transitGatewayAttachmentId', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyTransitGatewayVpcAttachment(null, null, null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'transitGatewayAttachmentId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyTransitGatewayVpcAttachment', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyTransitGatewayVpcAttachment('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyTransitGatewayVpcAttachment', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyTransitGatewayVpcAttachment('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyTransitGatewayVpcAttachment', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postModifyTransitGatewayVpcAttachment - errors', () => {
      it('should have a postModifyTransitGatewayVpcAttachment function', (done) => {
        assert.equal(true, typeof a.postModifyTransitGatewayVpcAttachment === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyTransitGatewayVpcAttachment(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyTransitGatewayVpcAttachment', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyTransitGatewayVpcAttachment('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyTransitGatewayVpcAttachment', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyTransitGatewayVpcAttachment('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyTransitGatewayVpcAttachment', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getModifyVolume - errors', () => {
      it('should have a getModifyVolume function', (done) => {
        assert.equal(true, typeof a.getModifyVolume === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing volumeId', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyVolume('fakeparam', null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'volumeId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyVolume', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyVolume('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyVolume', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyVolume('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyVolume', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postModifyVolume - errors', () => {
      it('should have a postModifyVolume function', (done) => {
        assert.equal(true, typeof a.postModifyVolume === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyVolume(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyVolume', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyVolume('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyVolume', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyVolume('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyVolume', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getModifyVolumeAttribute - errors', () => {
      it('should have a getModifyVolumeAttribute function', (done) => {
        assert.equal(true, typeof a.getModifyVolumeAttribute === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing volumeId', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyVolumeAttribute('fakeparam', null, null, null, null, null, (data, error) => {
            const displayE = 'volumeId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyVolumeAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyVolumeAttribute('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyVolumeAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyVolumeAttribute('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyVolumeAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postModifyVolumeAttribute - errors', () => {
      it('should have a postModifyVolumeAttribute function', (done) => {
        assert.equal(true, typeof a.postModifyVolumeAttribute === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyVolumeAttribute(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyVolumeAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyVolumeAttribute('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyVolumeAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyVolumeAttribute('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyVolumeAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getModifyVpcAttribute - errors', () => {
      it('should have a getModifyVpcAttribute function', (done) => {
        assert.equal(true, typeof a.getModifyVpcAttribute === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing vpcId', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyVpcAttribute('fakeparam', 'fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'vpcId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyVpcAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyVpcAttribute('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyVpcAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyVpcAttribute('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyVpcAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postModifyVpcAttribute - errors', () => {
      it('should have a postModifyVpcAttribute function', (done) => {
        assert.equal(true, typeof a.postModifyVpcAttribute === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyVpcAttribute(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyVpcAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyVpcAttribute('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyVpcAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyVpcAttribute('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyVpcAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getModifyVpcEndpoint - errors', () => {
      it('should have a getModifyVpcEndpoint function', (done) => {
        assert.equal(true, typeof a.getModifyVpcEndpoint === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing vpcEndpointId', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyVpcEndpoint('fakeparam', null, null, null, null, null, null, null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'vpcEndpointId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyVpcEndpoint', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyVpcEndpoint('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyVpcEndpoint', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyVpcEndpoint('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyVpcEndpoint', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postModifyVpcEndpoint - errors', () => {
      it('should have a postModifyVpcEndpoint function', (done) => {
        assert.equal(true, typeof a.postModifyVpcEndpoint === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyVpcEndpoint(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyVpcEndpoint', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyVpcEndpoint('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyVpcEndpoint', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyVpcEndpoint('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyVpcEndpoint', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getModifyVpcEndpointConnectionNotification - errors', () => {
      it('should have a getModifyVpcEndpointConnectionNotification function', (done) => {
        assert.equal(true, typeof a.getModifyVpcEndpointConnectionNotification === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing connectionNotificationId', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyVpcEndpointConnectionNotification('fakeparam', null, null, null, null, null, null, (data, error) => {
            const displayE = 'connectionNotificationId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyVpcEndpointConnectionNotification', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyVpcEndpointConnectionNotification('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyVpcEndpointConnectionNotification', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyVpcEndpointConnectionNotification('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyVpcEndpointConnectionNotification', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postModifyVpcEndpointConnectionNotification - errors', () => {
      it('should have a postModifyVpcEndpointConnectionNotification function', (done) => {
        assert.equal(true, typeof a.postModifyVpcEndpointConnectionNotification === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyVpcEndpointConnectionNotification(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyVpcEndpointConnectionNotification', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyVpcEndpointConnectionNotification('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyVpcEndpointConnectionNotification', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyVpcEndpointConnectionNotification('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyVpcEndpointConnectionNotification', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getModifyVpcEndpointServiceConfiguration - errors', () => {
      it('should have a getModifyVpcEndpointServiceConfiguration function', (done) => {
        assert.equal(true, typeof a.getModifyVpcEndpointServiceConfiguration === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing serviceId', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyVpcEndpointServiceConfiguration('fakeparam', null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'serviceId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyVpcEndpointServiceConfiguration', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyVpcEndpointServiceConfiguration('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyVpcEndpointServiceConfiguration', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyVpcEndpointServiceConfiguration('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyVpcEndpointServiceConfiguration', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postModifyVpcEndpointServiceConfiguration - errors', () => {
      it('should have a postModifyVpcEndpointServiceConfiguration function', (done) => {
        assert.equal(true, typeof a.postModifyVpcEndpointServiceConfiguration === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyVpcEndpointServiceConfiguration(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyVpcEndpointServiceConfiguration', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyVpcEndpointServiceConfiguration('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyVpcEndpointServiceConfiguration', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyVpcEndpointServiceConfiguration('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyVpcEndpointServiceConfiguration', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getModifyVpcEndpointServicePermissions - errors', () => {
      it('should have a getModifyVpcEndpointServicePermissions function', (done) => {
        assert.equal(true, typeof a.getModifyVpcEndpointServicePermissions === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing serviceId', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyVpcEndpointServicePermissions('fakeparam', null, null, null, null, null, null, (data, error) => {
            const displayE = 'serviceId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyVpcEndpointServicePermissions', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyVpcEndpointServicePermissions('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyVpcEndpointServicePermissions', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyVpcEndpointServicePermissions('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyVpcEndpointServicePermissions', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postModifyVpcEndpointServicePermissions - errors', () => {
      it('should have a postModifyVpcEndpointServicePermissions function', (done) => {
        assert.equal(true, typeof a.postModifyVpcEndpointServicePermissions === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyVpcEndpointServicePermissions(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyVpcEndpointServicePermissions', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyVpcEndpointServicePermissions('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyVpcEndpointServicePermissions', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyVpcEndpointServicePermissions('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyVpcEndpointServicePermissions', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getModifyVpcPeeringConnectionOptions - errors', () => {
      it('should have a getModifyVpcPeeringConnectionOptions function', (done) => {
        assert.equal(true, typeof a.getModifyVpcPeeringConnectionOptions === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing vpcPeeringConnectionId', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyVpcPeeringConnectionOptions('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'vpcPeeringConnectionId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyVpcPeeringConnectionOptions', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyVpcPeeringConnectionOptions('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyVpcPeeringConnectionOptions', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyVpcPeeringConnectionOptions('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyVpcPeeringConnectionOptions', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postModifyVpcPeeringConnectionOptions - errors', () => {
      it('should have a postModifyVpcPeeringConnectionOptions function', (done) => {
        assert.equal(true, typeof a.postModifyVpcPeeringConnectionOptions === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyVpcPeeringConnectionOptions(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyVpcPeeringConnectionOptions', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyVpcPeeringConnectionOptions('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyVpcPeeringConnectionOptions', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyVpcPeeringConnectionOptions('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyVpcPeeringConnectionOptions', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getModifyVpcTenancy - errors', () => {
      it('should have a getModifyVpcTenancy function', (done) => {
        assert.equal(true, typeof a.getModifyVpcTenancy === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing vpcId', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyVpcTenancy(null, null, null, null, null, null, (data, error) => {
            const displayE = 'vpcId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyVpcTenancy', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing instanceTenancy', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyVpcTenancy('fakeparam', null, null, null, null, null, (data, error) => {
            const displayE = 'instanceTenancy is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyVpcTenancy', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyVpcTenancy('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyVpcTenancy', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyVpcTenancy('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyVpcTenancy', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postModifyVpcTenancy - errors', () => {
      it('should have a postModifyVpcTenancy function', (done) => {
        assert.equal(true, typeof a.postModifyVpcTenancy === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyVpcTenancy(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyVpcTenancy', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyVpcTenancy('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyVpcTenancy', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyVpcTenancy('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyVpcTenancy', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getModifyVpnConnection - errors', () => {
      it('should have a getModifyVpnConnection function', (done) => {
        assert.equal(true, typeof a.getModifyVpnConnection === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing vpnConnectionId', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyVpnConnection(null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'vpnConnectionId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyVpnConnection', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyVpnConnection('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyVpnConnection', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getModifyVpnConnection('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getModifyVpnConnection', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postModifyVpnConnection - errors', () => {
      it('should have a postModifyVpnConnection function', (done) => {
        assert.equal(true, typeof a.postModifyVpnConnection === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyVpnConnection(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyVpnConnection', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyVpnConnection('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyVpnConnection', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postModifyVpnConnection('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postModifyVpnConnection', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getMonitorInstances - errors', () => {
      it('should have a getMonitorInstances function', (done) => {
        assert.equal(true, typeof a.getMonitorInstances === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing instanceId', (done) => {
        const p = new Promise((resolve) => {
          a.getMonitorInstances(null, null, null, null, null, (data, error) => {
            const displayE = 'instanceId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getMonitorInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getMonitorInstances('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getMonitorInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getMonitorInstances('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getMonitorInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postMonitorInstances - errors', () => {
      it('should have a postMonitorInstances function', (done) => {
        assert.equal(true, typeof a.postMonitorInstances === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postMonitorInstances(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postMonitorInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postMonitorInstances('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postMonitorInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postMonitorInstances('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postMonitorInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getMoveAddressToVpc - errors', () => {
      it('should have a getMoveAddressToVpc function', (done) => {
        assert.equal(true, typeof a.getMoveAddressToVpc === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing publicIp', (done) => {
        const p = new Promise((resolve) => {
          a.getMoveAddressToVpc('fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'publicIp is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getMoveAddressToVpc', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getMoveAddressToVpc('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getMoveAddressToVpc', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getMoveAddressToVpc('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getMoveAddressToVpc', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postMoveAddressToVpc - errors', () => {
      it('should have a postMoveAddressToVpc function', (done) => {
        assert.equal(true, typeof a.postMoveAddressToVpc === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postMoveAddressToVpc(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postMoveAddressToVpc', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postMoveAddressToVpc('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postMoveAddressToVpc', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postMoveAddressToVpc('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postMoveAddressToVpc', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getProvisionByoipCidr - errors', () => {
      it('should have a getProvisionByoipCidr function', (done) => {
        assert.equal(true, typeof a.getProvisionByoipCidr === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing cidr', (done) => {
        const p = new Promise((resolve) => {
          a.getProvisionByoipCidr(null, null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'cidr is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getProvisionByoipCidr', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getProvisionByoipCidr('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getProvisionByoipCidr', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getProvisionByoipCidr('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getProvisionByoipCidr', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postProvisionByoipCidr - errors', () => {
      it('should have a postProvisionByoipCidr function', (done) => {
        assert.equal(true, typeof a.postProvisionByoipCidr === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postProvisionByoipCidr(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postProvisionByoipCidr', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postProvisionByoipCidr('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postProvisionByoipCidr', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postProvisionByoipCidr('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postProvisionByoipCidr', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getPurchaseHostReservation - errors', () => {
      it('should have a getPurchaseHostReservation function', (done) => {
        assert.equal(true, typeof a.getPurchaseHostReservation === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing hostIdSet', (done) => {
        const p = new Promise((resolve) => {
          a.getPurchaseHostReservation('fakeparam', 'fakeparam', null, null, null, null, null, null, (data, error) => {
            const displayE = 'hostIdSet is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getPurchaseHostReservation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing offeringId', (done) => {
        const p = new Promise((resolve) => {
          a.getPurchaseHostReservation('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'offeringId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getPurchaseHostReservation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getPurchaseHostReservation('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getPurchaseHostReservation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getPurchaseHostReservation('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getPurchaseHostReservation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postPurchaseHostReservation - errors', () => {
      it('should have a postPurchaseHostReservation function', (done) => {
        assert.equal(true, typeof a.postPurchaseHostReservation === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postPurchaseHostReservation(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postPurchaseHostReservation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postPurchaseHostReservation('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postPurchaseHostReservation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postPurchaseHostReservation('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postPurchaseHostReservation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getPurchaseReservedInstancesOffering - errors', () => {
      it('should have a getPurchaseReservedInstancesOffering function', (done) => {
        assert.equal(true, typeof a.getPurchaseReservedInstancesOffering === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing instanceCount', (done) => {
        const p = new Promise((resolve) => {
          a.getPurchaseReservedInstancesOffering(null, null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'instanceCount is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getPurchaseReservedInstancesOffering', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing reservedInstancesOfferingId', (done) => {
        const p = new Promise((resolve) => {
          a.getPurchaseReservedInstancesOffering('fakeparam', null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'reservedInstancesOfferingId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getPurchaseReservedInstancesOffering', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getPurchaseReservedInstancesOffering('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getPurchaseReservedInstancesOffering', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getPurchaseReservedInstancesOffering('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getPurchaseReservedInstancesOffering', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postPurchaseReservedInstancesOffering - errors', () => {
      it('should have a postPurchaseReservedInstancesOffering function', (done) => {
        assert.equal(true, typeof a.postPurchaseReservedInstancesOffering === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postPurchaseReservedInstancesOffering(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postPurchaseReservedInstancesOffering', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postPurchaseReservedInstancesOffering('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postPurchaseReservedInstancesOffering', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postPurchaseReservedInstancesOffering('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postPurchaseReservedInstancesOffering', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getPurchaseScheduledInstances - errors', () => {
      it('should have a getPurchaseScheduledInstances function', (done) => {
        assert.equal(true, typeof a.getPurchaseScheduledInstances === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing purchaseRequest', (done) => {
        const p = new Promise((resolve) => {
          a.getPurchaseScheduledInstances('fakeparam', 'fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'purchaseRequest is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getPurchaseScheduledInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getPurchaseScheduledInstances('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getPurchaseScheduledInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getPurchaseScheduledInstances('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getPurchaseScheduledInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postPurchaseScheduledInstances - errors', () => {
      it('should have a postPurchaseScheduledInstances function', (done) => {
        assert.equal(true, typeof a.postPurchaseScheduledInstances === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postPurchaseScheduledInstances(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postPurchaseScheduledInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postPurchaseScheduledInstances('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postPurchaseScheduledInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postPurchaseScheduledInstances('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postPurchaseScheduledInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getRebootInstances - errors', () => {
      it('should have a getRebootInstances function', (done) => {
        assert.equal(true, typeof a.getRebootInstances === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing instanceId', (done) => {
        const p = new Promise((resolve) => {
          a.getRebootInstances(null, null, null, null, null, (data, error) => {
            const displayE = 'instanceId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getRebootInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getRebootInstances('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getRebootInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getRebootInstances('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getRebootInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postRebootInstances - errors', () => {
      it('should have a postRebootInstances function', (done) => {
        assert.equal(true, typeof a.postRebootInstances === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postRebootInstances(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postRebootInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postRebootInstances('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postRebootInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postRebootInstances('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postRebootInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getRegisterImage - errors', () => {
      it('should have a getRegisterImage function', (done) => {
        assert.equal(true, typeof a.getRegisterImage === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing name', (done) => {
        const p = new Promise((resolve) => {
          a.getRegisterImage('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'name is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getRegisterImage', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getRegisterImage('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getRegisterImage', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getRegisterImage('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getRegisterImage', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postRegisterImage - errors', () => {
      it('should have a postRegisterImage function', (done) => {
        assert.equal(true, typeof a.postRegisterImage === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postRegisterImage(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postRegisterImage', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postRegisterImage('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postRegisterImage', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postRegisterImage('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postRegisterImage', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getRejectTransitGatewayVpcAttachment - errors', () => {
      it('should have a getRejectTransitGatewayVpcAttachment function', (done) => {
        assert.equal(true, typeof a.getRejectTransitGatewayVpcAttachment === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing transitGatewayAttachmentId', (done) => {
        const p = new Promise((resolve) => {
          a.getRejectTransitGatewayVpcAttachment(null, null, null, null, null, (data, error) => {
            const displayE = 'transitGatewayAttachmentId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getRejectTransitGatewayVpcAttachment', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getRejectTransitGatewayVpcAttachment('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getRejectTransitGatewayVpcAttachment', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getRejectTransitGatewayVpcAttachment('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getRejectTransitGatewayVpcAttachment', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postRejectTransitGatewayVpcAttachment - errors', () => {
      it('should have a postRejectTransitGatewayVpcAttachment function', (done) => {
        assert.equal(true, typeof a.postRejectTransitGatewayVpcAttachment === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postRejectTransitGatewayVpcAttachment(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postRejectTransitGatewayVpcAttachment', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postRejectTransitGatewayVpcAttachment('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postRejectTransitGatewayVpcAttachment', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postRejectTransitGatewayVpcAttachment('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postRejectTransitGatewayVpcAttachment', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getRejectVpcEndpointConnections - errors', () => {
      it('should have a getRejectVpcEndpointConnections function', (done) => {
        assert.equal(true, typeof a.getRejectVpcEndpointConnections === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing serviceId', (done) => {
        const p = new Promise((resolve) => {
          a.getRejectVpcEndpointConnections('fakeparam', null, null, null, null, null, (data, error) => {
            const displayE = 'serviceId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getRejectVpcEndpointConnections', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing vpcEndpointId', (done) => {
        const p = new Promise((resolve) => {
          a.getRejectVpcEndpointConnections('fakeparam', 'fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'vpcEndpointId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getRejectVpcEndpointConnections', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getRejectVpcEndpointConnections('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getRejectVpcEndpointConnections', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getRejectVpcEndpointConnections('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getRejectVpcEndpointConnections', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postRejectVpcEndpointConnections - errors', () => {
      it('should have a postRejectVpcEndpointConnections function', (done) => {
        assert.equal(true, typeof a.postRejectVpcEndpointConnections === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postRejectVpcEndpointConnections(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postRejectVpcEndpointConnections', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postRejectVpcEndpointConnections('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postRejectVpcEndpointConnections', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postRejectVpcEndpointConnections('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postRejectVpcEndpointConnections', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getRejectVpcPeeringConnection - errors', () => {
      it('should have a getRejectVpcPeeringConnection function', (done) => {
        assert.equal(true, typeof a.getRejectVpcPeeringConnection === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing vpcPeeringConnectionId', (done) => {
        const p = new Promise((resolve) => {
          a.getRejectVpcPeeringConnection('fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'vpcPeeringConnectionId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getRejectVpcPeeringConnection', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getRejectVpcPeeringConnection('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getRejectVpcPeeringConnection', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getRejectVpcPeeringConnection('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getRejectVpcPeeringConnection', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postRejectVpcPeeringConnection - errors', () => {
      it('should have a postRejectVpcPeeringConnection function', (done) => {
        assert.equal(true, typeof a.postRejectVpcPeeringConnection === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postRejectVpcPeeringConnection(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postRejectVpcPeeringConnection', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postRejectVpcPeeringConnection('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postRejectVpcPeeringConnection', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postRejectVpcPeeringConnection('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postRejectVpcPeeringConnection', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getReleaseAddress - errors', () => {
      it('should have a getReleaseAddress function', (done) => {
        assert.equal(true, typeof a.getReleaseAddress === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getReleaseAddress('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getReleaseAddress', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getReleaseAddress('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getReleaseAddress', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postReleaseAddress - errors', () => {
      it('should have a postReleaseAddress function', (done) => {
        assert.equal(true, typeof a.postReleaseAddress === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postReleaseAddress(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postReleaseAddress', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postReleaseAddress('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postReleaseAddress', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getReleaseHosts - errors', () => {
      it('should have a getReleaseHosts function', (done) => {
        assert.equal(true, typeof a.getReleaseHosts === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing hostId', (done) => {
        const p = new Promise((resolve) => {
          a.getReleaseHosts(null, null, null, null, (data, error) => {
            const displayE = 'hostId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getReleaseHosts', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getReleaseHosts('fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getReleaseHosts', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getReleaseHosts('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getReleaseHosts', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postReleaseHosts - errors', () => {
      it('should have a postReleaseHosts function', (done) => {
        assert.equal(true, typeof a.postReleaseHosts === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postReleaseHosts(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postReleaseHosts', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postReleaseHosts('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postReleaseHosts', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postReleaseHosts('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postReleaseHosts', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getReplaceIamInstanceProfileAssociation - errors', () => {
      it('should have a getReplaceIamInstanceProfileAssociation function', (done) => {
        assert.equal(true, typeof a.getReplaceIamInstanceProfileAssociation === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing associationId', (done) => {
        const p = new Promise((resolve) => {
          a.getReplaceIamInstanceProfileAssociation('fakeparam', 'fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'associationId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getReplaceIamInstanceProfileAssociation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getReplaceIamInstanceProfileAssociation('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getReplaceIamInstanceProfileAssociation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getReplaceIamInstanceProfileAssociation('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getReplaceIamInstanceProfileAssociation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postReplaceIamInstanceProfileAssociation - errors', () => {
      it('should have a postReplaceIamInstanceProfileAssociation function', (done) => {
        assert.equal(true, typeof a.postReplaceIamInstanceProfileAssociation === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postReplaceIamInstanceProfileAssociation(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postReplaceIamInstanceProfileAssociation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postReplaceIamInstanceProfileAssociation('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postReplaceIamInstanceProfileAssociation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postReplaceIamInstanceProfileAssociation('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postReplaceIamInstanceProfileAssociation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getReplaceNetworkAclAssociation - errors', () => {
      it('should have a getReplaceNetworkAclAssociation function', (done) => {
        assert.equal(true, typeof a.getReplaceNetworkAclAssociation === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing associationId', (done) => {
        const p = new Promise((resolve) => {
          a.getReplaceNetworkAclAssociation(null, null, null, null, null, null, (data, error) => {
            const displayE = 'associationId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getReplaceNetworkAclAssociation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing networkAclId', (done) => {
        const p = new Promise((resolve) => {
          a.getReplaceNetworkAclAssociation('fakeparam', 'fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'networkAclId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getReplaceNetworkAclAssociation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getReplaceNetworkAclAssociation('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getReplaceNetworkAclAssociation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getReplaceNetworkAclAssociation('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getReplaceNetworkAclAssociation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postReplaceNetworkAclAssociation - errors', () => {
      it('should have a postReplaceNetworkAclAssociation function', (done) => {
        assert.equal(true, typeof a.postReplaceNetworkAclAssociation === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postReplaceNetworkAclAssociation(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postReplaceNetworkAclAssociation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postReplaceNetworkAclAssociation('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postReplaceNetworkAclAssociation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postReplaceNetworkAclAssociation('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postReplaceNetworkAclAssociation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getReplaceNetworkAclEntry - errors', () => {
      it('should have a getReplaceNetworkAclEntry function', (done) => {
        assert.equal(true, typeof a.getReplaceNetworkAclEntry === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing egress', (done) => {
        const p = new Promise((resolve) => {
          a.getReplaceNetworkAclEntry('fakeparam', 'fakeparam', null, null, null, null, null, null, null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'egress is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getReplaceNetworkAclEntry', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing networkAclId', (done) => {
        const p = new Promise((resolve) => {
          a.getReplaceNetworkAclEntry('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'networkAclId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getReplaceNetworkAclEntry', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing protocol', (done) => {
        const p = new Promise((resolve) => {
          a.getReplaceNetworkAclEntry('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, null, null, null, (data, error) => {
            const displayE = 'protocol is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getReplaceNetworkAclEntry', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing ruleAction', (done) => {
        const p = new Promise((resolve) => {
          a.getReplaceNetworkAclEntry('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, null, null, (data, error) => {
            const displayE = 'ruleAction is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getReplaceNetworkAclEntry', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing ruleNumber', (done) => {
        const p = new Promise((resolve) => {
          a.getReplaceNetworkAclEntry('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'ruleNumber is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getReplaceNetworkAclEntry', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getReplaceNetworkAclEntry('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getReplaceNetworkAclEntry', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getReplaceNetworkAclEntry('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getReplaceNetworkAclEntry', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postReplaceNetworkAclEntry - errors', () => {
      it('should have a postReplaceNetworkAclEntry function', (done) => {
        assert.equal(true, typeof a.postReplaceNetworkAclEntry === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postReplaceNetworkAclEntry(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postReplaceNetworkAclEntry', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postReplaceNetworkAclEntry('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postReplaceNetworkAclEntry', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postReplaceNetworkAclEntry('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postReplaceNetworkAclEntry', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getReplaceRoute - errors', () => {
      it('should have a getReplaceRoute function', (done) => {
        assert.equal(true, typeof a.getReplaceRoute === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing routeTableId', (done) => {
        const p = new Promise((resolve) => {
          a.getReplaceRoute('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, null, null, (data, error) => {
            const displayE = 'routeTableId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getReplaceRoute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getReplaceRoute('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getReplaceRoute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getReplaceRoute('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getReplaceRoute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postReplaceRoute - errors', () => {
      it('should have a postReplaceRoute function', (done) => {
        assert.equal(true, typeof a.postReplaceRoute === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postReplaceRoute(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postReplaceRoute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postReplaceRoute('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postReplaceRoute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postReplaceRoute('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postReplaceRoute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getReplaceRouteTableAssociation - errors', () => {
      it('should have a getReplaceRouteTableAssociation function', (done) => {
        assert.equal(true, typeof a.getReplaceRouteTableAssociation === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing associationId', (done) => {
        const p = new Promise((resolve) => {
          a.getReplaceRouteTableAssociation(null, null, null, null, null, null, (data, error) => {
            const displayE = 'associationId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getReplaceRouteTableAssociation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing routeTableId', (done) => {
        const p = new Promise((resolve) => {
          a.getReplaceRouteTableAssociation('fakeparam', 'fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'routeTableId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getReplaceRouteTableAssociation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getReplaceRouteTableAssociation('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getReplaceRouteTableAssociation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getReplaceRouteTableAssociation('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getReplaceRouteTableAssociation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postReplaceRouteTableAssociation - errors', () => {
      it('should have a postReplaceRouteTableAssociation function', (done) => {
        assert.equal(true, typeof a.postReplaceRouteTableAssociation === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postReplaceRouteTableAssociation(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postReplaceRouteTableAssociation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postReplaceRouteTableAssociation('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postReplaceRouteTableAssociation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postReplaceRouteTableAssociation('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postReplaceRouteTableAssociation', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getReplaceTransitGatewayRoute - errors', () => {
      it('should have a getReplaceTransitGatewayRoute function', (done) => {
        assert.equal(true, typeof a.getReplaceTransitGatewayRoute === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing destinationCidrBlock', (done) => {
        const p = new Promise((resolve) => {
          a.getReplaceTransitGatewayRoute(null, null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'destinationCidrBlock is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getReplaceTransitGatewayRoute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing transitGatewayRouteTableId', (done) => {
        const p = new Promise((resolve) => {
          a.getReplaceTransitGatewayRoute('fakeparam', null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'transitGatewayRouteTableId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getReplaceTransitGatewayRoute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getReplaceTransitGatewayRoute('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getReplaceTransitGatewayRoute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getReplaceTransitGatewayRoute('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getReplaceTransitGatewayRoute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postReplaceTransitGatewayRoute - errors', () => {
      it('should have a postReplaceTransitGatewayRoute function', (done) => {
        assert.equal(true, typeof a.postReplaceTransitGatewayRoute === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postReplaceTransitGatewayRoute(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postReplaceTransitGatewayRoute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postReplaceTransitGatewayRoute('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postReplaceTransitGatewayRoute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postReplaceTransitGatewayRoute('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postReplaceTransitGatewayRoute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getReportInstanceStatus - errors', () => {
      it('should have a getReportInstanceStatus function', (done) => {
        assert.equal(true, typeof a.getReportInstanceStatus === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing instanceId', (done) => {
        const p = new Promise((resolve) => {
          a.getReportInstanceStatus('fakeparam', 'fakeparam', 'fakeparam', null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'instanceId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getReportInstanceStatus', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing reasonCode', (done) => {
        const p = new Promise((resolve) => {
          a.getReportInstanceStatus('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, null, null, null, (data, error) => {
            const displayE = 'reasonCode is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getReportInstanceStatus', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing status', (done) => {
        const p = new Promise((resolve) => {
          a.getReportInstanceStatus('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'status is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getReportInstanceStatus', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getReportInstanceStatus('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getReportInstanceStatus', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getReportInstanceStatus('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getReportInstanceStatus', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postReportInstanceStatus - errors', () => {
      it('should have a postReportInstanceStatus function', (done) => {
        assert.equal(true, typeof a.postReportInstanceStatus === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postReportInstanceStatus(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postReportInstanceStatus', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postReportInstanceStatus('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postReportInstanceStatus', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postReportInstanceStatus('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postReportInstanceStatus', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getRequestSpotFleet - errors', () => {
      it('should have a getRequestSpotFleet function', (done) => {
        assert.equal(true, typeof a.getRequestSpotFleet === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getRequestSpotFleet('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getRequestSpotFleet', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getRequestSpotFleet('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getRequestSpotFleet', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postRequestSpotFleet - errors', () => {
      it('should have a postRequestSpotFleet function', (done) => {
        assert.equal(true, typeof a.postRequestSpotFleet === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postRequestSpotFleet(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postRequestSpotFleet', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postRequestSpotFleet('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postRequestSpotFleet', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getRequestSpotInstances - errors', () => {
      it('should have a getRequestSpotInstances function', (done) => {
        assert.equal(true, typeof a.getRequestSpotInstances === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getRequestSpotInstances('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getRequestSpotInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getRequestSpotInstances('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getRequestSpotInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postRequestSpotInstances - errors', () => {
      it('should have a postRequestSpotInstances function', (done) => {
        assert.equal(true, typeof a.postRequestSpotInstances === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postRequestSpotInstances(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postRequestSpotInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postRequestSpotInstances('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postRequestSpotInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getResetFpgaImageAttribute - errors', () => {
      it('should have a getResetFpgaImageAttribute function', (done) => {
        assert.equal(true, typeof a.getResetFpgaImageAttribute === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing fpgaImageId', (done) => {
        const p = new Promise((resolve) => {
          a.getResetFpgaImageAttribute('fakeparam', null, null, null, null, null, (data, error) => {
            const displayE = 'fpgaImageId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getResetFpgaImageAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getResetFpgaImageAttribute('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getResetFpgaImageAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getResetFpgaImageAttribute('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getResetFpgaImageAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postResetFpgaImageAttribute - errors', () => {
      it('should have a postResetFpgaImageAttribute function', (done) => {
        assert.equal(true, typeof a.postResetFpgaImageAttribute === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postResetFpgaImageAttribute(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postResetFpgaImageAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postResetFpgaImageAttribute('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postResetFpgaImageAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postResetFpgaImageAttribute('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postResetFpgaImageAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getResetImageAttribute - errors', () => {
      it('should have a getResetImageAttribute function', (done) => {
        assert.equal(true, typeof a.getResetImageAttribute === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing attribute', (done) => {
        const p = new Promise((resolve) => {
          a.getResetImageAttribute(null, null, null, null, null, null, (data, error) => {
            const displayE = 'attribute is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getResetImageAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing imageId', (done) => {
        const p = new Promise((resolve) => {
          a.getResetImageAttribute('fakeparam', null, null, null, null, null, (data, error) => {
            const displayE = 'imageId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getResetImageAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getResetImageAttribute('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getResetImageAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getResetImageAttribute('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getResetImageAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postResetImageAttribute - errors', () => {
      it('should have a postResetImageAttribute function', (done) => {
        assert.equal(true, typeof a.postResetImageAttribute === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postResetImageAttribute(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postResetImageAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postResetImageAttribute('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postResetImageAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postResetImageAttribute('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postResetImageAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getResetInstanceAttribute - errors', () => {
      it('should have a getResetInstanceAttribute function', (done) => {
        assert.equal(true, typeof a.getResetInstanceAttribute === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing attribute', (done) => {
        const p = new Promise((resolve) => {
          a.getResetInstanceAttribute(null, null, null, null, null, null, (data, error) => {
            const displayE = 'attribute is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getResetInstanceAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing instanceId', (done) => {
        const p = new Promise((resolve) => {
          a.getResetInstanceAttribute('fakeparam', 'fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'instanceId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getResetInstanceAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getResetInstanceAttribute('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getResetInstanceAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getResetInstanceAttribute('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getResetInstanceAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postResetInstanceAttribute - errors', () => {
      it('should have a postResetInstanceAttribute function', (done) => {
        assert.equal(true, typeof a.postResetInstanceAttribute === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postResetInstanceAttribute(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postResetInstanceAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postResetInstanceAttribute('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postResetInstanceAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postResetInstanceAttribute('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postResetInstanceAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getResetNetworkInterfaceAttribute - errors', () => {
      it('should have a getResetNetworkInterfaceAttribute function', (done) => {
        assert.equal(true, typeof a.getResetNetworkInterfaceAttribute === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing networkInterfaceId', (done) => {
        const p = new Promise((resolve) => {
          a.getResetNetworkInterfaceAttribute('fakeparam', null, null, null, null, null, (data, error) => {
            const displayE = 'networkInterfaceId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getResetNetworkInterfaceAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getResetNetworkInterfaceAttribute('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getResetNetworkInterfaceAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getResetNetworkInterfaceAttribute('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getResetNetworkInterfaceAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postResetNetworkInterfaceAttribute - errors', () => {
      it('should have a postResetNetworkInterfaceAttribute function', (done) => {
        assert.equal(true, typeof a.postResetNetworkInterfaceAttribute === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postResetNetworkInterfaceAttribute(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postResetNetworkInterfaceAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postResetNetworkInterfaceAttribute('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postResetNetworkInterfaceAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postResetNetworkInterfaceAttribute('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postResetNetworkInterfaceAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getResetSnapshotAttribute - errors', () => {
      it('should have a getResetSnapshotAttribute function', (done) => {
        assert.equal(true, typeof a.getResetSnapshotAttribute === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing attribute', (done) => {
        const p = new Promise((resolve) => {
          a.getResetSnapshotAttribute(null, null, null, null, null, null, (data, error) => {
            const displayE = 'attribute is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getResetSnapshotAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing snapshotId', (done) => {
        const p = new Promise((resolve) => {
          a.getResetSnapshotAttribute('fakeparam', null, null, null, null, null, (data, error) => {
            const displayE = 'snapshotId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getResetSnapshotAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getResetSnapshotAttribute('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getResetSnapshotAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getResetSnapshotAttribute('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getResetSnapshotAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postResetSnapshotAttribute - errors', () => {
      it('should have a postResetSnapshotAttribute function', (done) => {
        assert.equal(true, typeof a.postResetSnapshotAttribute === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postResetSnapshotAttribute(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postResetSnapshotAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postResetSnapshotAttribute('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postResetSnapshotAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postResetSnapshotAttribute('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postResetSnapshotAttribute', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getRestoreAddressToClassic - errors', () => {
      it('should have a getRestoreAddressToClassic function', (done) => {
        assert.equal(true, typeof a.getRestoreAddressToClassic === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing publicIp', (done) => {
        const p = new Promise((resolve) => {
          a.getRestoreAddressToClassic('fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'publicIp is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getRestoreAddressToClassic', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getRestoreAddressToClassic('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getRestoreAddressToClassic', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getRestoreAddressToClassic('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getRestoreAddressToClassic', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postRestoreAddressToClassic - errors', () => {
      it('should have a postRestoreAddressToClassic function', (done) => {
        assert.equal(true, typeof a.postRestoreAddressToClassic === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postRestoreAddressToClassic(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postRestoreAddressToClassic', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postRestoreAddressToClassic('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postRestoreAddressToClassic', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postRestoreAddressToClassic('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postRestoreAddressToClassic', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getRevokeClientVpnIngress - errors', () => {
      it('should have a getRevokeClientVpnIngress function', (done) => {
        assert.equal(true, typeof a.getRevokeClientVpnIngress === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing clientVpnEndpointId', (done) => {
        const p = new Promise((resolve) => {
          a.getRevokeClientVpnIngress(null, null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'clientVpnEndpointId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getRevokeClientVpnIngress', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing targetNetworkCidr', (done) => {
        const p = new Promise((resolve) => {
          a.getRevokeClientVpnIngress('fakeparam', null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'targetNetworkCidr is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getRevokeClientVpnIngress', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getRevokeClientVpnIngress('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getRevokeClientVpnIngress', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getRevokeClientVpnIngress('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getRevokeClientVpnIngress', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postRevokeClientVpnIngress - errors', () => {
      it('should have a postRevokeClientVpnIngress function', (done) => {
        assert.equal(true, typeof a.postRevokeClientVpnIngress === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postRevokeClientVpnIngress(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postRevokeClientVpnIngress', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postRevokeClientVpnIngress('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postRevokeClientVpnIngress', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postRevokeClientVpnIngress('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postRevokeClientVpnIngress', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getRevokeSecurityGroupEgress - errors', () => {
      it('should have a getRevokeSecurityGroupEgress function', (done) => {
        assert.equal(true, typeof a.getRevokeSecurityGroupEgress === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing groupId', (done) => {
        const p = new Promise((resolve) => {
          a.getRevokeSecurityGroupEgress('fakeparam', null, null, null, null, null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'groupId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getRevokeSecurityGroupEgress', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getRevokeSecurityGroupEgress('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getRevokeSecurityGroupEgress', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getRevokeSecurityGroupEgress('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getRevokeSecurityGroupEgress', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postRevokeSecurityGroupEgress - errors', () => {
      it('should have a postRevokeSecurityGroupEgress function', (done) => {
        assert.equal(true, typeof a.postRevokeSecurityGroupEgress === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postRevokeSecurityGroupEgress(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postRevokeSecurityGroupEgress', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postRevokeSecurityGroupEgress('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postRevokeSecurityGroupEgress', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postRevokeSecurityGroupEgress('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postRevokeSecurityGroupEgress', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getRevokeSecurityGroupIngress - errors', () => {
      it('should have a getRevokeSecurityGroupIngress function', (done) => {
        assert.equal(true, typeof a.getRevokeSecurityGroupIngress === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getRevokeSecurityGroupIngress('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getRevokeSecurityGroupIngress', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getRevokeSecurityGroupIngress('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getRevokeSecurityGroupIngress', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postRevokeSecurityGroupIngress - errors', () => {
      it('should have a postRevokeSecurityGroupIngress function', (done) => {
        assert.equal(true, typeof a.postRevokeSecurityGroupIngress === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postRevokeSecurityGroupIngress(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postRevokeSecurityGroupIngress', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postRevokeSecurityGroupIngress('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postRevokeSecurityGroupIngress', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getRunInstances - errors', () => {
      it('should have a getRunInstances function', (done) => {
        assert.equal(true, typeof a.getRunInstances === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing maxCount', (done) => {
        const p = new Promise((resolve) => {
          a.getRunInstances('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'maxCount is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getRunInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing minCount', (done) => {
        const p = new Promise((resolve) => {
          a.getRunInstances('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'minCount is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getRunInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getRunInstances('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getRunInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getRunInstances('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getRunInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postRunInstances - errors', () => {
      it('should have a postRunInstances function', (done) => {
        assert.equal(true, typeof a.postRunInstances === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postRunInstances(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postRunInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postRunInstances('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postRunInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postRunInstances('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postRunInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getRunScheduledInstances - errors', () => {
      it('should have a getRunScheduledInstances function', (done) => {
        assert.equal(true, typeof a.getRunScheduledInstances === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing scheduledInstanceId', (done) => {
        const p = new Promise((resolve) => {
          a.getRunScheduledInstances('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'scheduledInstanceId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getRunScheduledInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getRunScheduledInstances('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getRunScheduledInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getRunScheduledInstances('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getRunScheduledInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postRunScheduledInstances - errors', () => {
      it('should have a postRunScheduledInstances function', (done) => {
        assert.equal(true, typeof a.postRunScheduledInstances === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postRunScheduledInstances(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postRunScheduledInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postRunScheduledInstances('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postRunScheduledInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postRunScheduledInstances('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postRunScheduledInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getSearchTransitGatewayRoutes - errors', () => {
      it('should have a getSearchTransitGatewayRoutes function', (done) => {
        assert.equal(true, typeof a.getSearchTransitGatewayRoutes === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing transitGatewayRouteTableId', (done) => {
        const p = new Promise((resolve) => {
          a.getSearchTransitGatewayRoutes(null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'transitGatewayRouteTableId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getSearchTransitGatewayRoutes', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing filter', (done) => {
        const p = new Promise((resolve) => {
          a.getSearchTransitGatewayRoutes('fakeparam', null, null, null, null, null, null, (data, error) => {
            const displayE = 'filter is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getSearchTransitGatewayRoutes', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getSearchTransitGatewayRoutes('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getSearchTransitGatewayRoutes', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getSearchTransitGatewayRoutes('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getSearchTransitGatewayRoutes', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postSearchTransitGatewayRoutes - errors', () => {
      it('should have a postSearchTransitGatewayRoutes function', (done) => {
        assert.equal(true, typeof a.postSearchTransitGatewayRoutes === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postSearchTransitGatewayRoutes(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postSearchTransitGatewayRoutes', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postSearchTransitGatewayRoutes('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postSearchTransitGatewayRoutes', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postSearchTransitGatewayRoutes('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postSearchTransitGatewayRoutes', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getStartInstances - errors', () => {
      it('should have a getStartInstances function', (done) => {
        assert.equal(true, typeof a.getStartInstances === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing instanceId', (done) => {
        const p = new Promise((resolve) => {
          a.getStartInstances(null, null, null, null, null, null, (data, error) => {
            const displayE = 'instanceId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getStartInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getStartInstances('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getStartInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getStartInstances('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getStartInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postStartInstances - errors', () => {
      it('should have a postStartInstances function', (done) => {
        assert.equal(true, typeof a.postStartInstances === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postStartInstances(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postStartInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postStartInstances('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postStartInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postStartInstances('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postStartInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getStopInstances - errors', () => {
      it('should have a getStopInstances function', (done) => {
        assert.equal(true, typeof a.getStopInstances === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing instanceId', (done) => {
        const p = new Promise((resolve) => {
          a.getStopInstances(null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'instanceId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getStopInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getStopInstances('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getStopInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getStopInstances('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getStopInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postStopInstances - errors', () => {
      it('should have a postStopInstances function', (done) => {
        assert.equal(true, typeof a.postStopInstances === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postStopInstances(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postStopInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postStopInstances('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postStopInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postStopInstances('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postStopInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getTerminateClientVpnConnections - errors', () => {
      it('should have a getTerminateClientVpnConnections function', (done) => {
        assert.equal(true, typeof a.getTerminateClientVpnConnections === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing clientVpnEndpointId', (done) => {
        const p = new Promise((resolve) => {
          a.getTerminateClientVpnConnections(null, null, null, null, null, null, null, (data, error) => {
            const displayE = 'clientVpnEndpointId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getTerminateClientVpnConnections', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getTerminateClientVpnConnections('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getTerminateClientVpnConnections', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getTerminateClientVpnConnections('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getTerminateClientVpnConnections', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postTerminateClientVpnConnections - errors', () => {
      it('should have a postTerminateClientVpnConnections function', (done) => {
        assert.equal(true, typeof a.postTerminateClientVpnConnections === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postTerminateClientVpnConnections(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postTerminateClientVpnConnections', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postTerminateClientVpnConnections('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postTerminateClientVpnConnections', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postTerminateClientVpnConnections('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postTerminateClientVpnConnections', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getTerminateInstances - errors', () => {
      it('should have a getTerminateInstances function', (done) => {
        assert.equal(true, typeof a.getTerminateInstances === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing instanceId', (done) => {
        const p = new Promise((resolve) => {
          a.getTerminateInstances(null, null, null, null, null, (data, error) => {
            const displayE = 'instanceId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getTerminateInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getTerminateInstances('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getTerminateInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getTerminateInstances('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getTerminateInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postTerminateInstances - errors', () => {
      it('should have a postTerminateInstances function', (done) => {
        assert.equal(true, typeof a.postTerminateInstances === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postTerminateInstances(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postTerminateInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postTerminateInstances('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postTerminateInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postTerminateInstances('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postTerminateInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getUnassignIpv6Addresses - errors', () => {
      it('should have a getUnassignIpv6Addresses function', (done) => {
        assert.equal(true, typeof a.getUnassignIpv6Addresses === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing ipv6Addresses', (done) => {
        const p = new Promise((resolve) => {
          a.getUnassignIpv6Addresses(null, null, null, null, null, (data, error) => {
            const displayE = 'ipv6Addresses is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getUnassignIpv6Addresses', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing networkInterfaceId', (done) => {
        const p = new Promise((resolve) => {
          a.getUnassignIpv6Addresses('fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'networkInterfaceId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getUnassignIpv6Addresses', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getUnassignIpv6Addresses('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getUnassignIpv6Addresses', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getUnassignIpv6Addresses('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getUnassignIpv6Addresses', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postUnassignIpv6Addresses - errors', () => {
      it('should have a postUnassignIpv6Addresses function', (done) => {
        assert.equal(true, typeof a.postUnassignIpv6Addresses === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postUnassignIpv6Addresses(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postUnassignIpv6Addresses', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postUnassignIpv6Addresses('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postUnassignIpv6Addresses', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postUnassignIpv6Addresses('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postUnassignIpv6Addresses', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getUnassignPrivateIpAddresses - errors', () => {
      it('should have a getUnassignPrivateIpAddresses function', (done) => {
        assert.equal(true, typeof a.getUnassignPrivateIpAddresses === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing networkInterfaceId', (done) => {
        const p = new Promise((resolve) => {
          a.getUnassignPrivateIpAddresses(null, null, null, null, null, (data, error) => {
            const displayE = 'networkInterfaceId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getUnassignPrivateIpAddresses', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing privateIpAddress', (done) => {
        const p = new Promise((resolve) => {
          a.getUnassignPrivateIpAddresses('fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'privateIpAddress is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getUnassignPrivateIpAddresses', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getUnassignPrivateIpAddresses('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getUnassignPrivateIpAddresses', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getUnassignPrivateIpAddresses('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getUnassignPrivateIpAddresses', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postUnassignPrivateIpAddresses - errors', () => {
      it('should have a postUnassignPrivateIpAddresses function', (done) => {
        assert.equal(true, typeof a.postUnassignPrivateIpAddresses === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postUnassignPrivateIpAddresses(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postUnassignPrivateIpAddresses', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postUnassignPrivateIpAddresses('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postUnassignPrivateIpAddresses', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postUnassignPrivateIpAddresses('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postUnassignPrivateIpAddresses', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getUnmonitorInstances - errors', () => {
      it('should have a getUnmonitorInstances function', (done) => {
        assert.equal(true, typeof a.getUnmonitorInstances === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing instanceId', (done) => {
        const p = new Promise((resolve) => {
          a.getUnmonitorInstances(null, null, null, null, null, (data, error) => {
            const displayE = 'instanceId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getUnmonitorInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getUnmonitorInstances('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getUnmonitorInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getUnmonitorInstances('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getUnmonitorInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postUnmonitorInstances - errors', () => {
      it('should have a postUnmonitorInstances function', (done) => {
        assert.equal(true, typeof a.postUnmonitorInstances === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postUnmonitorInstances(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postUnmonitorInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postUnmonitorInstances('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postUnmonitorInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postUnmonitorInstances('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postUnmonitorInstances', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getUpdateSecurityGroupRuleDescriptionsEgress - errors', () => {
      it('should have a getUpdateSecurityGroupRuleDescriptionsEgress function', (done) => {
        assert.equal(true, typeof a.getUpdateSecurityGroupRuleDescriptionsEgress === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing ipPermissions', (done) => {
        const p = new Promise((resolve) => {
          a.getUpdateSecurityGroupRuleDescriptionsEgress('fakeparam', 'fakeparam', 'fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'ipPermissions is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getUpdateSecurityGroupRuleDescriptionsEgress', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getUpdateSecurityGroupRuleDescriptionsEgress('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getUpdateSecurityGroupRuleDescriptionsEgress', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getUpdateSecurityGroupRuleDescriptionsEgress('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getUpdateSecurityGroupRuleDescriptionsEgress', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postUpdateSecurityGroupRuleDescriptionsEgress - errors', () => {
      it('should have a postUpdateSecurityGroupRuleDescriptionsEgress function', (done) => {
        assert.equal(true, typeof a.postUpdateSecurityGroupRuleDescriptionsEgress === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postUpdateSecurityGroupRuleDescriptionsEgress(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postUpdateSecurityGroupRuleDescriptionsEgress', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postUpdateSecurityGroupRuleDescriptionsEgress('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postUpdateSecurityGroupRuleDescriptionsEgress', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postUpdateSecurityGroupRuleDescriptionsEgress('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postUpdateSecurityGroupRuleDescriptionsEgress', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getUpdateSecurityGroupRuleDescriptionsIngress - errors', () => {
      it('should have a getUpdateSecurityGroupRuleDescriptionsIngress function', (done) => {
        assert.equal(true, typeof a.getUpdateSecurityGroupRuleDescriptionsIngress === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing ipPermissions', (done) => {
        const p = new Promise((resolve) => {
          a.getUpdateSecurityGroupRuleDescriptionsIngress('fakeparam', 'fakeparam', 'fakeparam', null, null, null, null, (data, error) => {
            const displayE = 'ipPermissions is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getUpdateSecurityGroupRuleDescriptionsIngress', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getUpdateSecurityGroupRuleDescriptionsIngress('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getUpdateSecurityGroupRuleDescriptionsIngress', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getUpdateSecurityGroupRuleDescriptionsIngress('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getUpdateSecurityGroupRuleDescriptionsIngress', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postUpdateSecurityGroupRuleDescriptionsIngress - errors', () => {
      it('should have a postUpdateSecurityGroupRuleDescriptionsIngress function', (done) => {
        assert.equal(true, typeof a.postUpdateSecurityGroupRuleDescriptionsIngress === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postUpdateSecurityGroupRuleDescriptionsIngress(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postUpdateSecurityGroupRuleDescriptionsIngress', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postUpdateSecurityGroupRuleDescriptionsIngress('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postUpdateSecurityGroupRuleDescriptionsIngress', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postUpdateSecurityGroupRuleDescriptionsIngress('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postUpdateSecurityGroupRuleDescriptionsIngress', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getWithdrawByoipCidr - errors', () => {
      it('should have a getWithdrawByoipCidr function', (done) => {
        assert.equal(true, typeof a.getWithdrawByoipCidr === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing cidr', (done) => {
        const p = new Promise((resolve) => {
          a.getWithdrawByoipCidr(null, null, null, null, null, (data, error) => {
            const displayE = 'cidr is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getWithdrawByoipCidr', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.getWithdrawByoipCidr('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getWithdrawByoipCidr', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.getWithdrawByoipCidr('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-getWithdrawByoipCidr', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postWithdrawByoipCidr - errors', () => {
      it('should have a postWithdrawByoipCidr function', (done) => {
        assert.equal(true, typeof a.postWithdrawByoipCidr === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing action', (done) => {
        const p = new Promise((resolve) => {
          a.postWithdrawByoipCidr(null, null, null, null, (data, error) => {
            const displayE = 'action is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postWithdrawByoipCidr', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing version', (done) => {
        const p = new Promise((resolve) => {
          a.postWithdrawByoipCidr('fakeparam', null, null, null, (data, error) => {
            const displayE = 'version is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postWithdrawByoipCidr', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing bodyFormData', (done) => {
        const p = new Promise((resolve) => {
          a.postWithdrawByoipCidr('fakeparam', 'fakeparam', null, null, (data, error) => {
            const displayE = 'bodyFormData is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-awsec2-adapter-postWithdrawByoipCidr', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });
  });
});
